(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    760520,      16860]*)
(*NotebookOutlinePosition[    761196,      16884]*)
(*  CellTagsIndexPosition[    761152,      16880]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Animation of a solution of the 2-body problem", "Title"],

Cell["Bernd Fiedler, Leipzig, October 2001", "Subtitle"],

Cell["\<\
Bernd Fiedler, Eichelbaumstr. 13, D-04249 Leipzig, Germany
Bernd.Fiedler.RoschStr.Leipzig@t-online.de\
\>", "Subsubtitle"],

Cell["Evaluate the complete notebook to generate the anmiation.", "Text"],

Cell[CellGroupData[{

Cell["Solution of the differential equation of the 2-body problem", "Section"],

Cell[CellGroupData[{

Cell["The differential equations", "Subsection"],

Cell["\<\
We define:

The vector between the 2 bodies:\
\>", "Text"],

Cell[CellGroupData[{

Cell["relvect = {x[t], y[t], z[t]}", "Input"],

Cell[OutputFormData["\<\
{x[t], y[t], z[t]}\
\>", "\<\
{x[t], y[t], z[t]}\
\>"], "Output"]
}, Open  ]],

Cell["The acceleration vector:", "Text"],

Cell[CellGroupData[{

Cell["acc = {x''[t], y''[t], z''[t]}", "Input"],

Cell[OutputFormData["\<\
{Derivative[2][x][t], Derivative[2][y][t], Derivative[2][z][t]}\
\>", "\<\
{x''[t], y''[t], z''[t]}\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "The length of ",
  StyleBox["relvect",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell["r = Sqrt[relvect.relvect]", "Input"],

Cell[OutputFormData["\<\
Sqrt[x[t]^2 + y[t]^2 + z[t]^2]\
\>", "\<\
         2       2       2
Sqrt[x[t]  + y[t]  + z[t] ]\
\>"], "Output"]
}, Open  ]],

Cell["\<\
Now we form the left hand side of the differential equation system.\
\>", "Text"],

Cell[CellGroupData[{

Cell["lhs = m acc + gamma m M/(r^3) relvect", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"gamma\" is \
similar to existing symbol 
    \"Gamma\".\
\>", "Message"],

Cell[OutputFormData["\<\
{(gamma*m*M*x[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + m*Derivative[2][x][t], 
  (gamma*m*M*y[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + m*Derivative[2][y][t], 
  (gamma*m*M*z[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + \
m*Derivative[2][z][t]}\
\>", "\<\
       gamma m M x[t]                         gamma m M y[t]
{-------------------------- + m x''[t], -------------------------- + m \
y''[t], 
      2       2       2 3/2                  2       2       2 3/2
 (x[t]  + y[t]  + z[t] )                (x[t]  + y[t]  + z[t] )
 
        gamma m M z[t]
  -------------------------- + m z''[t]}
       2       2       2 3/2
  (x[t]  + y[t]  + z[t] )\
\>"], "Output"]
}, Open  ]],

Cell["\<\
From the left hand side we form the differential equation system of the \
2-body problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell["dgl = # == 0 & /@ lhs", "Input"],

Cell[OutputFormData["\<\
{(gamma*m*M*x[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + m*Derivative[2][x][t] == \
0, 
  (gamma*m*M*y[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + m*Derivative[2][y][t] \
== 0, 
  (gamma*m*M*z[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + m*Derivative[2][z][t] \
== 0}\
\>", "\<\
       gamma m M x[t]                              gamma m M y[t]
{-------------------------- + m x''[t] == 0, -------------------------- + m \
y''[t] == 0, 
      2       2       2 3/2                       2       2       2 3/2
 (x[t]  + y[t]  + z[t] )                     (x[t]  + y[t]  + z[t] )
 
        gamma m M z[t]
  -------------------------- + m z''[t] == 0}
       2       2       2 3/2
  (x[t]  + y[t]  + z[t] )\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we choose values for ",
  StyleBox["gamma",
    FontWeight->"Bold"],
  ", ",
  StyleBox["m",
    FontWeight->"Bold"],
  " and ",
  StyleBox["M",
    FontWeight->"Bold"],
  ". We can set ",
  StyleBox["gamma = 1",
    FontWeight->"Bold"],
  ", if we use a suitable gauge of the time. Further we set ",
  StyleBox["m = 1",
    FontWeight->"Bold"],
  " and ",
  StyleBox["M = 3",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["const1 = {gamma->1, m->1, M->3}", "Input"],

Cell[OutputFormData["\<\
{gamma -> 1, m -> 1, M -> 3}\
\>", "\<\
{gamma -> 1, m -> 1, M -> 3}\
\>"], "Output"]
}, Open  ]],

Cell["\<\
Finally we define initial values. We assume that the movement of the bodies \
goes in the x-y-plane.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
aw = {x[0] == 10, y[0] == 0, z[0] == 0,
      x'[0] == 0, y'[0] == 0.3, z'[0]== 0}\
\>", "Input"],

Cell[OutputFormData["\<\
{x[0] == 10, y[0] == 0, z[0] == 0, Derivative[1][x][0] == 0, \
Derivative[1][y][0] == 0.3, 
  Derivative[1][z][0] == 0}\
\>", "\<\
{x[0] == 10, y[0] == 0, z[0] == 0, x'[0] == 0, y'[0] == 0.3, z'[0] == 0}\
\>"], "Output"]
}, Open  ]],

Cell["We combine all the above things in a initial value problem.", "Text"],

Cell[CellGroupData[{

Cell["awp = Join[dgl/. const1, aw]", "Input"],

Cell[OutputFormData["\<\
{(3*x[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + Derivative[2][x][t] == 0, 
  (3*y[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + Derivative[2][y][t] == 0, 
  (3*z[t])/(x[t]^2 + y[t]^2 + z[t]^2)^(3/2) + Derivative[2][z][t] == 0, x[0] \
== 10, y[0] == 0, 
  z[0] == 0, Derivative[1][x][0] == 0, Derivative[1][y][0] == 0.3, \
Derivative[1][z][0] == 0}\
\>", "\<\
           3 x[t]                                    3 y[t]
{-------------------------- + x''[t] == 0, -------------------------- + \
y''[t] == 0, 
      2       2       2 3/2                     2       2       2 3/2
 (x[t]  + y[t]  + z[t] )                   (x[t]  + y[t]  + z[t] )
 
            3 z[t]
  -------------------------- + z''[t] == 0, x[0] == 10, y[0] == 0, z[0] == 0, \
x'[0] == 0, 
       2       2       2 3/2
  (x[t]  + y[t]  + z[t] )
 
  y'[0] == 0.3, z'[0] == 0}\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Solution of the differential equation system of the 2-body problem\
\>", "Subsection"],

Cell[TextData[
"We determine a numerical solution of the above initial value problem over \
the interval 0 \[LessEqual]  t \[LessEqual]  100."], "Text"],

Cell[CellGroupData[{

Cell["sol1 = NDSolve[awp, {x[t], y[t], z[t]}, {t,0,100}][[1]]", "Input"],

Cell[OutputFormData["\<\
{x[t] -> InterpolatingFunction[{{0., 100.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003331483023263849, 0.006662966046527698, 0.1760831648387825, 
       0.3455033636310373, 0.5149235624232922, 1.113331746264325, \
1.711739930105358, 
       2.310148113946391, 2.908556297787424, 3.549226293889243, \
4.189896289991062, 
       4.830566286092881, 5.471236282194699, 6.430795500662957, \
7.390354719131214, 
       8.34991393759947, 9.309473156067728, 10.26903237453598, \
11.41748921768868, 
       12.56594606084139, 13.71440290399409, 14.86285974714679, \
15.76992300897745, 
       16.67698627080811, 17.40746358480685, 18.13794089880559, \
18.7397959150954, 
       19.3416509313852, 19.94350594767501, 20.42463542003453, \
20.90576489239406, 
       21.38689436475359, 21.77943140165771, 22.17196843856184, \
22.49018228099118, 
       22.80839612342052, 23.12660996584985, 23.35745430632501, \
23.58829864680017, 
       23.81914298727534, 24.0499873277505, 24.22894782904176, \
24.40790833033302, 
       24.58686883162428, 24.73263871122103, 24.87840859081777, \
25.02417847041451, 
       25.16994835001125, 25.31571822960799, 25.43261488145184, \
25.54951153329568, 
       25.66640818513952, 25.75972586508166, 25.8530435450238, \
25.94636122496595, 
       26.03967890490809, 26.13299658485023, 26.22631426479237, \
26.32916699997962, 
       26.43201973516686, 26.5348724703541, 26.63772520554135, \
26.7405779407286, 
       26.84343067591584, 26.95721769562641, 27.07100471533697, \
27.18479173504754, 
       27.29857875475811, 27.41236577446868, 27.52615279417925, \
27.66074382830965, 
       27.79533486244006, 27.92992589657046, 28.06451693070087, \
28.19910796483128, 
       28.33369899896168, 28.46829003309208, 28.63486560498111, \
28.80144117687013, 
       28.96801674875915, 29.13459232064816, 29.30116789253718, \
29.4677434644262, 
       29.71773345304378, 29.96772344166136, 30.21771343027894, \
30.46770341889652, 
       30.71769340751409, 30.96768339613167, 31.3010544995537, \
31.63442560297573, 
       31.96779670639775, 32.30116780981978, 32.63453891324182, \
32.96791001666385, 
       33.4114262068452, 33.85494239702655, 34.29845858720789, \
34.74197477738924, 
       35.18549096757059, 35.62900715775194, 36.23354495905478, \
36.83808276035762, 
       37.44262056166046, 38.0471583629633, 38.65169616426614, \
39.25623396556898, 
       40.10946796733268, 40.96270196909638, 41.81593597086009, \
42.66916997262379, 
       43.52240397438749, 44.37563797615119, 45.41195670648726, \
46.44827543682334, 
       47.48459416715941, 48.52091289749548, 49.55723162783154, \
50.59355035816762, 
       51.68339887256983, 52.77324738697206, 53.86309590137428, \
54.9529444157765, 
       56.04279293017872, 57.13264144458094, 57.58494946950075, \
58.03725749442055, 
       58.48956551934037, 58.94187354426017, 59.39418156917998, \
60.46962757399835, 
       61.54507357881672, 62.62051958363509, 63.69596558845345, \
64.77141159327182, 
       65.59501642075933, 66.41862124824685, 67.24222607573437, \
67.88129038764838, 
       68.52035469956239, 69.1594190114764, 69.6629816849138, \
70.1665443583512, 
       70.6701070317886, 71.07547552469601, 71.48084401760343, \
71.88621251051085, 
       72.29158100341826, 72.61679430492302, 72.94200760642778, \
73.26722090793253, 
       73.5924342094373, 73.86075147913136, 74.12906874882543, \
74.39738601851949, 
       74.61050073963264, 74.82361546074578, 75.03673018185892, \
75.20550076096502, 
       75.37427134007112, 75.54304191917721, 75.71181249828331, \
75.8805830773894, 
       76.01266973050996, 76.1447563836305, 76.27684303675106, \
76.40892968987161, 
       76.54101634299216, 76.64435076816506, 76.74768519333794, \
76.85101961851083, 
       76.95435404368372, 77.05768846885661, 77.1610228940295, \
77.26435731920239, 
       77.36769174437528, 77.45298990779566, 77.53828807121606, \
77.62358623463645, 
       77.69157185629193, 77.75955747794741, 77.82754309960289, \
77.89552872125837, 
       77.96351434291385, 78.04706179169975, 78.13060924048564, \
78.21415668927153, 
       78.29770413805743, 78.38125158684332, 78.46479903562921, \
78.57822588435457, 
       78.69165273307991, 78.80507958180527, 78.91850643053063, \
79.03193327925598, 
       79.14536012798134, 79.27402872242009, 79.40269731685884, \
79.53136591129759, 
       79.66003450573634, 79.78870310017509, 79.91737169461384, \
80.08386115675204, 
       80.25035061889024, 80.41684008102844, 80.58332954316664, \
80.74981900530485, 
       80.91630846744305, 81.1446878201505, 81.37306717285797, \
81.60144652556544, 
       81.82982587827289, 82.05820523098037, 82.28658458368782, \
82.59230296432988, 
       82.89802134497195, 83.20373972561402, 83.50945810625608, \
83.81517648689813, 
       84.1208948675402, 84.53825979449733, 84.95562472145447, \
85.37298964841161, 
       85.79035457536873, 86.20771950232587, 86.62508442928301, \
87.17941917293771, 
       87.73375391659241, 88.28808866024713, 88.84242340390184, \
89.39675814755654, 
       89.95109289121124, 90.73059797678343, 91.5101030623556, \
92.28960814792779, 
       93.06911323349998, 93.84861831907215, 94.62812340464434, \
95.67627335203383, 
       96.72442329942333, 97.77257324681281, 98.82072319420231, \
99.86887314159179, 100.}}, 
     {{10., 0.}, {9.999999667036631, -0.0000999444958559831, \
-0.01500000077413987}, 
      {9.999999001109841, -0.0001998890005305997, -0.01500000209766957, 
       -1.324264791109243*^-7}, {9.999534576762165, -0.005282625504428216, 
       -0.0150007684133492, -1.507721993584276*^-6}, 
      {9.998208991793807, -0.01036586246377459, -0.01500295602791122, 
       -4.304119929069237*^-6}, {9.996022120608474, -0.01545008165889415, 
       -0.01500656604421129, -7.102687727121121*^-6, -4.129625360497192*^-6}, \

      {9.981400241583472, -0.03342262383181047, -0.01503073319595624, 
       -0.0000191127230847176, -4.721537082102554*^-6}, 
      {9.956012469678931, -0.05143505229681426, -0.01507282617828626, 
       -0.0000284398392274892, -4.171603209899904*^-6}, 
      {9.919828658426069, -0.0695087116399322, -0.01513309835171913, 
       -0.00003863682062805801, -4.230563911563298*^-6}, 
      {9.872805623569009, -0.08766557247047764, -0.01521192709147297, 
       -0.00004907855278582778, -4.318384649569083*^-6}, 
      {9.81038261489742, -0.107222499287526, -0.0153174532391323, \
-0.00006058346991576568, 
       -4.432400504372727*^-6}, {9.735383677993993, -0.1269290396648642, 
       -0.01544558233706431, -0.00007254414592885217, \
-4.588968878448765*^-6}, 
      {9.647703538352775, -0.1468147427068354, -0.01559725969919556, 
       -0.00008504195879595016, -4.780891443294509*^-6}, 
      {9.547217590031241, -0.1669104909825564, -0.01577362469039725, 
       -0.00009818305153725399, -5.012211243232934*^-6, \
-7.221184114938992*^-8}, 
      {9.372442204223318, -0.197472874900302, -0.01608695657920668, \
-0.0001195931113178307, 
       -5.78702254976335*^-6, -1.168525062588226*^-7}, 
      {9.168032993449278, -0.2286970116059297, -0.01646432291176811, \
-0.0001429404572800871, 
       -6.364556460545446*^-6, -1.186136704004384*^-7}, 
      {8.933292791282246, -0.260712319041386, -0.01691268856189597, \
-0.0001688924540068049, 
       -7.056191662638264*^-6, -1.313852633765306*^-7}, 
      {8.667395388332906, -0.2936630083860327, -0.0174407104763387, \
-0.000198263148513609, 
       -7.992835333365194*^-6, -1.633044989602086*^-7}, 
      {8.369366750464829, -0.3277118576594026, -0.0180590827279232, \
-0.0002317425536843819, 
       -9.145079433893918*^-6, -2.017328112997333*^-7, \
-6.674646650237976*^-9}, 
      {7.968816142012063, -0.3701690068505776, -0.01893659139232798, \
-0.0002787135616863236, 
       -0.00001107465150007242, -3.431254019763608*^-7, \
-1.221247360582406*^-8}, 
      {7.518274503800109, -0.414838413713528, -0.01999080480698278, \
-0.0003349583307450799, 
       -0.00001343107216080355, -4.488450062968237*^-7, \
-1.346439184390526*^-8}, 
      {7.014951780512314, -0.4621657314031956, -0.02125747179881629, \
-0.000402485301793165, 
       -0.00001612216272916904, -5.188330342389742*^-7, \
-1.214136376462528*^-8}, 
      {6.455497396799624, -0.512687933559517, -0.02278082313985004, \
-0.0004842897384518391, 
       -0.00001950348807824395, -6.266522083292501*^-7, \
-1.35436036734884*^-8}, 
      {5.97133898606567, -0.5552707545359659, -0.02419939017419869, \
-0.0005601265030493545, 
       -0.00002240279167923185, -6.795893910714335*^-7, \
-1.201690022056054*^-8}, 
      {5.447329733198281, -0.6006216785503866, -0.02583684494983387, \
-0.0006452335497285234, 
       -0.00002488208423645443, -6.030247723696108*^-7, \
-1.582850252738259*^-9}, 
      {4.994544650370255, -0.6394385514619155, -0.02732867880703784, \
-0.000717201706104935, 
       -0.00002519740076763747, -1.641091850653157*^-7, \
3.910771338891892*^-8}, 
      {4.512580908924368, -0.6805491139298358, -0.0289757133609065, \
-0.0007858751769655075, 
       -0.00002283803684240479, 6.281968783074834*^-7, 9.57740662768286*^-8}, \

      {4.092319745637765, -0.7162969802110944, -0.03043332624609293, \
-0.0008273011461061351, 
       -0.00001411079028945251, 2.77318611640668*^-6, 2.950619984297771*^-7}, \

      {3.650008142795814, -0.75383482300199, -0.03194057616362307, \
-0.000837781169029431, 
       2.908436903233675*^-6, 5.852679633130613*^-6, 5.181485335569721*^-7}, 
      {3.1845598496585, -0.79317524826911, -0.03340799726604421, \
-0.0007783044052743819, 
       0.0000402096752775269, 0.00001252994661705028, 1.05052095872131*^-6}, 
      {2.795123830452612, -0.8258317671964205, -0.03443185625620501, \
-0.0006278774417888875, 
       0.0001043331974498909, 0.00002637041406078575, 2.548087067527602*^-6}, \

      {2.389759786684089, -0.8593368182272554, -0.03513376415841387, \
-0.0003199016637782932, 
       0.000206055352991998, 0.00004421454926120045, 4.001386312326734*^-6}, 
      {1.968155531916544, -0.8932404493893415, -0.03519114266930007, \
0.0002827634427434235, 
       0.0003953090430077192, 0.00008034892976792972, 7.407714214770003*^-6}, \

      {1.612133209471725, -0.9206115023756767, -0.03436728267542904, \
0.001167439858402861, 
       0.0006871266341954606, 0.0001488904533067763, 0.00001608540245080362}, \

      {1.245555540759198, -0.9468482956797268, -0.03218984578762213, \
0.002621886890082032, 
       0.001129481833143386, 0.0002361035965623702, 0.00002446311653895632}, 
      {0.9410949773821739, -0.966358753037646, -0.02882430239550862, \
0.004525018473827788, 
       0.001773955569951093, 0.0004076105297705326, 0.00005060903954164654}, 
      {0.6308354498336753, -0.9830621744834262, -0.02321541729391173, \
0.007385941096909567, 
       0.002672674309817698, 0.0005976044118931324, 0.00007016965949133741}, 
      {0.3159329033211111, -0.9951821873328565, -0.01418079842381167, \
0.0117798170386407, 
       0.00410579946418588, 0.0009339835134525934, 0.0001125741336235873}, 
      {0.08560335649456762, -0.9996129609887983, -0.004482330450570064, \
0.01642162314968502, 
       0.00576686120618707, 0.001456054946450888, 0.0002183160439397852}, 
      {-0.1451702265413573, -0.9987482287446461, 0.008944808399650272, \
0.02264345221763056, 
       0.007723879946969937, 0.001834109976141647, 0.000240169988308947}, 
      {-0.3749456063221925, -0.9905773914167145, 0.02741935162540686, \
0.03107598350330992, 
       0.01043310429724995, 0.002464013997760112, 0.0003260150576712633}, 
      {-0.6017387375295777, -0.9723924795846807, 0.05264323645792687, \
0.04225310284735142, 
       0.01376539691381106, 0.003084643881453037, 0.0003748437756163892}, 
      {-0.7738158055527949, -0.9491601274429262, 0.07814553734785738, \
0.05309767995134918, 
       0.01662708636520343, 0.003411908848460098, 0.0003468195608161223}, 
      {-0.9408535339078351, -0.9156988073385244, 0.1099738103419988, \
0.06584203831678264, 
       0.0192785575839224, 0.003240095165481745, 0.0001440874145904611}, 
      {-1.100808772763281, -0.8695725576350916, 0.1490507001639068, \
0.08005639655896086, 
       0.02099484013545759, 0.002195328912962099, -0.0003027456312620047}, 
      {-1.224142472303899, -0.8207703584797918, 0.1866031930914387, \
0.09179495343339265, 
       0.02021541922650071, -0.0007543045972586409, -0.001530638230356364}, 
      {-1.33952851736341, -0.7602835314026485, 0.2291401128507386, \
0.1026148577824002, 
       0.01746777968847483, -0.004104028198274166, -0.002450351732810804}, 
      {-1.445162192248201, -0.6867593887327357, 0.275833749234575, \
0.1105177652221271, 
       0.01067421937078416, -0.009800308264555146, -0.004075358313384443}, 
      {-1.539065201186615, -0.5992156043209392, 0.3249345401591812, \
0.1131708827674436, 
       -0.0007350921776814427, -0.01685443687395152, -0.005671363228856519}, 
      {-1.619160833224345, -0.4973376950367515, 0.3735911421003334, \
0.1079523752975144, 
       -0.01688521672199175, -0.02423512469871897, -0.006778315374409239}, 
      {-1.672024021985982, -0.4056987108781396, 0.4096808678420924, \
0.0966620508229592, 
       -0.03204075166667096, -0.02840437588302364, -0.006444731226400632}, 
      {-1.713702588354966, -0.3061740827215168, 0.4406456804412915, \
0.07857411442903958, 
       -0.04702584240831086, -0.0286163306114332, -0.003987717435139482}, 
      {-1.743355119247177, -0.2002387345344999, 0.4641462012253661, \
0.05414719726831878, 
       -0.0597799018856442, -0.02439006661974707, 0.00001762619156583489}, 
      {-1.75795932936631, -0.1123875727219862, 0.4761993229511499, \
0.0313174561773808, 
       -0.06512673778296038, -0.01330102214838375, 0.007932650415924164}, 
      {-1.764279647202571, -0.02290665551731321, 0.4815191432379402, \
0.006382162918550237, 
       -0.06878153842854827, -0.006076148810749007, 0.009921079720870334}, 
      {-1.762223826513715, 0.06691049589659529, 0.4797874009404809, \
-0.0188158170163781, 
       -0.06715502086673829, 0.005294174165014238, 0.01407566945272897}, 
      {-1.751821955733147, 0.155751060490902, 0.4711086541032221, \
-0.04290609466393452, 
       -0.06177003765455255, 0.0151522139981943, 0.01548803985073501}, 
      {-1.733224460883608, 0.2423603294564177, 0.4559952245730086, \
-0.06450387532258949, 
       -0.05309731173939685, 0.02305211216894931, 0.01493655485592607}, 
      {-1.706693348546919, 0.3256124926101664, 0.4353008771655004, \
-0.08256690960168473, 
       -0.04224149893062334, 0.02801464749481559, 0.01250719559685647}, 
      {-1.668692654678519, 0.412359129944089, 0.4073365968631816, \
-0.09760259069625952, 
       -0.02888812232876095, 0.03066918572144901, 0.009224925125974586}, 
      {-1.62208075503742, 0.4929304368465945, 0.3755323809365263, \
-0.107417863653821, 
       -0.01633305998383765, 0.02856037156042201, 0.004168072508201493}, 
      {-1.567527641358179, 0.5667026310117222, 0.3414869902407993, \
-0.1122528016207183, 
       -0.005160690210655312, 0.02417128788145345, -0.0003440548642397125}, 
      {-1.505751051625999, 0.6333666156659133, 0.3066411771593892, \
-0.1127997083545189, 
       0.003903201675029067, 0.01843884817645036, -0.003922062321150074}, 
      {-1.437486077725288, 0.6928852511256023, 0.2721891602681367, \
-0.1099263567718038, 
       0.01072932209884744, 0.01262840807382944, -0.006119424775095162}, 
      {-1.363459985257284, 0.7454382257429471, 0.2390432712013494, \
-0.1045481395850094, 
       0.01544034908084466, 0.007498165008552404, -0.006996954904274852}, 
      {-1.275695292831957, 0.7958745082789214, 0.2046554328863238, \
-0.09670414248609255, 
       0.01850643077951405, 0.00296074506120534, -0.006856601504327985}, 
      {-1.182624699237246, 0.8388072668707323, 0.1731584415484179, \
-0.08779458284969184, 
       0.01979767392710229, -0.0003066278568882941, -0.006028281725484223}, 
      {-1.085063345232264, 0.8749251563780388, 0.1447822147716374, \
-0.07854257361846822, 
       0.01986264524798186, -0.00229771488427016, -0.004783526833327872}, 
      {-0.9837459924491243, 0.9049438029998547, 0.1195459111447898, \
-0.06946499892145786, 
       0.01908920147668002, -0.003359677913334314, -0.003492309522858367}, 
      {-0.8793264172623459, 0.9295659206037399, 0.09732707521821147, \
-0.06089248762631475, 
       0.01779753107448159, -0.003788395074525548, -0.002346566772434333}, 
      {-0.7723804427241156, 0.949455681665119, 0.07791737540342962, \
-0.05301144981926074, 
       0.0162327829364989, -0.003814067118620961, -0.00142298105504922, \
0.001159541897704244}\\
, {-0.6433046772204916, 0.9677058079823323, 0.05823800213964823, \
-0.04468096080343019, 
       0.01441045682303597, -0.002783953393701194, 0.001188784355638088, \
0.00169708488897577}\\
, {-0.5121094235401235, 0.9810896023448465, 0.04169120868490231, \
-0.03741547048946922, 
       0.01280428488306296, -0.001516084967311337, 0.002492469865323495, 
       0.001592641024670129}, {-0.3793957097178879, 0.9903923267145891, \
0.02784422498433534, 
       -0.03126811991568303, 0.01073262730526809, -0.002037579450504574, 
       0.001248140006742295, 0.0006215099400203063}, 
      {-0.2456663049306292, 0.9962859521056437, 0.01629772943270821, \
-0.02604464512542574, 
       0.008980329954290976, -0.002095510542613372, 0.0006953457677540004, 
       0.0002187583199734274}, {-0.1113406020941798, 0.9993407070526551, 
       0.006696011209325232, -0.02163334956681168, 0.007533050836745637, 
       -0.001862874904160483, 0.000541221119365383, 0.00009130873227738209}, 
      {0.02323261969026428, 1.000037397907161, -0.001270333341516546, \
-0.01793006061141642, 
       0.006305476211154202, -0.00160798664708415, 0.0004376459356836445, 
       0.00002422701892495869}, {0.1577639456370035, 0.9987796211243416, 
       -0.007866233174697851, -0.01483069305048608, 0.005266230595892914, 
       -0.00137692714962097, 0.0003454595099410986}, 
      {0.3238532788946496, 0.9950163399210451, -0.01446408708299931, \
-0.01168715112605315, 
       0.004231197158314246, -0.001064594359794493, 0.0003322771437643408}, 
      {0.4891464610344511, 0.9892980059252545, -0.01965510751695885, \
-0.009173011038926198, 
       0.003397858162454783, -0.0008199334616744494, 0.0002972841643506164}, 
      {0.6533540830778655, 0.9820447047147046, -0.02372070898263512, \
-0.007162523770806481, 
       0.002726308508999299, -0.0006384640635437778, 0.0002509979537539023}, 
      {0.816249457848254, 0.9735925369217659, -0.02688566534445808, \
-0.005553832092528896, 
       0.002185764170192419, -0.0005041526575440372, 0.0002043527148729412}, 
      {0.977656122708394, 0.9642105711595263, -0.02932921099414475, \
-0.004264731413917804, 
       0.001753678999311149, -0.0003999861588278783, 0.000164301014522096}, 
      {1.137437817960645, 0.9541144435805353, -0.03119425776334561, \
-0.003230473607966385, 
       0.001408187107908597, -0.0003188633259734991, 0.0001310474872334872}, 
      {1.373962263518643, 0.9379913448263447, -0.03315104239759477, \
-0.002035991443025575, 
       0.001055016694584687, -0.0001754136803349024, 0.0001168832631096097}, 
      {1.606350777538078, 0.921089707063399, -0.03435027896805395, \
-0.001185642482056167, 
       0.0007611889982477815, -0.0001263673727715483, \
0.00008320949699306595}, 
      {1.834451389994988, 0.9037326207957461, -0.03500295780754145, \
-0.0005720107642449367, 
       0.0005488587587780501, -0.00009233662124596904, \
0.00005900092869173958}, 
      {2.058180957943374, 0.8861532084450008, -0.03526139784712657, \
-0.0001299062237899076, 
       0.0003943008954814655, -0.00006860752561953588, \
0.00004172856945736134}, 
      {2.277506071313209, 0.8685194550442609, -0.03523617484059259, \
0.0001875164949581709, 
       0.0002818250665690771, -0.00005116453353093513, \
0.00002968879250919858}, 
      {2.492429067265235, 0.850951947624747, -0.03500799052702379, \
0.0004136604200055531, 
       0.0001995414230634581, -0.00003828803111409595, \
0.00002124714699454556}, 
      {2.772238840912962, 0.827772476580113, -0.03448789377931135, \
0.0006187351375100056, 
       0.000135231936385602, -0.0000142542167258472, 0.00001755450648050448}, \

      {3.044385531217866, 0.8049971977489439, -0.03380946993633155, \
0.0007368051310598128, 
       0.00007834629900650612, -0.00001122390637328985, \
0.00001113869729354016}, 
      {3.309018897546296, 0.7827080059760389, -0.03303896019032098, \
0.0008026315901872795, 
       0.00004206215070822079, -7.530337946610575*^-6, \
7.421848367099138*^-6}, 
      {3.566309385444315, 0.7609505051884798, -0.03222073878811793, \
0.0008326582023136406, 
       0.00001753260850283639, -5.206452899102176*^-6, \
4.917833371721242*^-6}, 
      {3.816438358901661, 0.7397459238434345, -0.03138449257301725, \
0.0008389397975120747, 
       1.350761010714219*^-6, -3.443911266680812*^-6, 3.303168411230164*^-6}, \

      {4.059591345450913, 0.7190992335318648, -0.03054996879974727, \
0.000829471043668777, 
       -9.266705135230321*^-6, -2.176302469330319*^-6, \
2.235394082844824*^-6}, 
      {4.372586056844254, 0.6924845763855139, -0.02946402640734989, \
0.0008029885153141623, 
       -0.0000151220610565394, 8.250787784383916*^-7, 1.792385895012974*^-6}, \

      {4.673987604959827, 0.6668147584567116, -0.02842204356733706, \
0.0007647137732773082, 
       -0.00002078612215513698, 6.54136918086063*^-7, 1.049736592210326*^-6}, \

      {4.964205732592358, 0.6420460094573485, -0.02743350100585447, \
0.0007221979095896903, 
       -0.00002314976664604992, 7.761063057776203*^-7, \
6.481756547328529*^-7}, 
      {5.243629213829849, 0.6181288216389053, -0.02650242638086074, \
0.000678187471784092, 
       -0.0000239345237456289, 7.931801490029656*^-7, 3.91471829511522*^-7}, 
      {5.512624351616197, 0.5950116957825927, -0.02562955676108836, \
0.0006345834294087487, 
       -0.00002369251861338706, 8.021342613663854*^-7, \
2.362290256289218*^-7}, 
      {5.771534593579228, 0.5726434229524559, -0.02481368999251229, \
0.000592425473316875, 
       -0.00002288648563482767, 7.853559560198135*^-7, \
1.392154021689647*^-7}, 
      {6.108778478587181, 0.5432709651278483, -0.02378916392059457, \
0.0005385766856827133, 
       -0.00002090222035060868, 9.634230237838947*^-7, \
1.031659585179949*^-7}, 
      {6.428628285049846, 0.5150795504695917, -0.02285881665290834, \
0.0004886504225997844, 
       -0.00001936888879237151, 7.862703393446195*^-7, \
4.236369342206515*^-8}, 
      {6.731764582882849, 0.4879601047517246, -0.02201464770937683, \
0.0004432614167729918, 
       -0.00001769376751624496, 6.751451556916494*^-7, \
1.316365469926102*^-8}, 
      {7.018804879497923, 0.4618132221070451, -0.0212487838594931, \
0.0004021275423222285, 
       -0.00001608642974839905, 5.795258334566936*^-7, \
-2.646427332553702*^-9}, 
      {7.290309437364093, 0.4365487482657936, -0.02055383213948169, \
0.0003649288807771958, 
       -0.00001458398747316392, 5.03351179019625*^-7, \
-9.988175262736955*^-9}, 
      {7.546786632940721, 0.4120850951254194, -0.01992303664940939, \
0.0003312779198101439, 
       -0.00001322154742601821, 4.375514544916265*^-7, \
-1.324910699053483*^-8}, 
      {7.884086391876182, 0.3787788096942453, -0.01913029234850465, \
0.0002891022855594955, 
       -0.00001152915788609441, 3.637773120533617*^-7, \
-1.371374005813379*^-8}, 
      {8.193519912214346, 0.3467372696916771, -0.01843847871742815, \
0.0002522378627539954, 
       -0.00001012455948914267, 2.940570077974138*^-7, \
-1.367577692049199*^-8}, 
      {8.476096003274097, 0.3157992197941938, -0.01783508941229122, \
0.0002198514361491721, 
       -8.938517398316328*^-6, 2.402965084296406*^-7, \
-1.240599412442992*^-8}, 
      {8.732694467647508, 0.2858229496662481, -0.01730967543895278, \
0.000191192164962064, 
       -7.945450305774636*^-6, 1.975592143498741*^-7, \
-1.078283627612117*^-8}, 
      {8.964081379766222, 0.2566830509301514, -0.01685353000126704, \
0.0001656356422998087, 
       -7.11516127866211*^-6, 1.6349747232274*^-7, -9.131085157702385*^-9}, 
      {9.170921765681947, 0.2282676835290948, -0.01645941936274106, \
0.0001426479405711071, 
       -6.427510315663576*^-6, 1.348051943066835*^-7, \
-7.720496274782806*^-9}, 
      {9.389954596038501, 0.1945852380470904, -0.01605561981421979, \
0.0001175238187663003, 
       -5.77104442479653*^-6, 1.004192934818946*^-7, -6.844352146609804*^-9}, \

      {9.574488182258052, 0.1616616513034422, -0.01572586704651665, \
0.00009490547229228969, 
       -5.233270029100994*^-6, 7.898601291768716*^-8, \
-5.485420074413066*^-9}, 
      {9.725231972497066, 0.1293508008327695, -0.01546336137483217, \
0.0000741972065061533, 
       -4.824922819069928*^-6, 5.934259158604834*^-8, -4.55491869832742*^-9}, \

      {9.842750737858269, 0.0975189661749996, -0.01526288448190638, \
0.00005494017614087423, 
       -4.520670981671909*^-6, 4.262301669709238*^-8, \
-3.808526033290244*^-9}, 
      {9.927475772352664, 0.06604181088376856, -0.01512056745880051, \
0.00003672916741598575, 
       -4.308672181495744*^-6, 2.762594625535797*^-8, \
-3.249881253218464*^-9}, 
      {9.979713233600646, 0.03480176640703292, -0.01503372609428847, \
0.0000192032612215678, 
       -4.180602265771845*^-6, 1.358484941232721*^-8, \
-2.853196342747618*^-9}, 
      {9.999804227048507, 0.0020797439404147, -0.01500049197622097, \
1.146311289113123*^-6, 
       -4.131571582867462*^-6, -1.008308189615254*^-9, \
-2.604589732624086*^-9}, 
      {9.984249322305531, -0.03063405172794555, -0.01502616200661516, 
       -0.00001688412125571555, -4.164162112351305*^-6, \
-1.500276790649841*^-8, 
       -2.418803069166029*^-9}, {9.932987422411585, -0.06346836426561185, 
       -0.01511125892846576, -0.00003526015010445098, -4.283225002888669*^-6, \

       -2.990949905165338*^-8, -2.363135244253259*^-9}, 
      {9.845816028669478, -0.09655440206413105, -0.0152575289222806, 
       -0.00005436365604809559, -4.493066031753912*^-6, \
-4.611004038560043*^-8, 
       -2.408877670066236*^-9}, {9.722387063732151, -0.1300285800011931, 
       -0.01546802131918495, -0.00007461154053008613, -4.803560550337905*^-6, \

       -6.442769476350544*^-8, -2.565828160182265*^-9}, 
      {9.56219960141742, -0.1640355024807342, -0.01574723020212407, \
-0.00009647406264619327, 
       -5.229333004127447*^-6, -8.576370007615768*^-8}, 
      {9.484774275498253, -0.1783418769769565, -0.01588467504155742, \
-0.0001061626397757676, 
       -5.454670976607011*^-6, -9.270143316829521*^-8}, 
      {9.400849024123806, -0.1927786093030251, -0.0160355254606662, \
-0.0001162405308879906, 
       -5.676061387176919*^-6, -9.529754007001434*^-8}, 
      {9.310362118353209, -0.207358088847576, -0.0162003772600372, \
-0.000126794927511473, 
       -5.945921296529864*^-6, -1.073116312899651*^-7}, 
      {9.213246082319651, -0.2220932762961385, -0.01637989348837529, \
-0.0001378628786505842, 
       -6.243395684055681*^-6, -1.194239141832637*^-7}, 
      {9.109427438949866, -0.236997764550794, -0.01657481026343212, \
-0.0001495016742451358, 
       -6.573004604228352*^-6, -1.325846239498221*^-7}, 
      {8.835183338759176, -0.2732012362180455, -0.01710506165067106, \
-0.0001796778052437345, 
       -7.379019984884315*^-6, -1.412393922601821*^-7}, 
      {8.521351720527729, -0.3106555083202919, -0.01774025090807023, \
-0.0002144887625348807, 
       -8.502266609548199*^-6, -1.750644213539845*^-7}, 
      {8.166460143311342, -0.3496033694579082, -0.01849691643540753, \
-0.0002550620730206818, 
       -9.944129773234195*^-6, -2.21603392049739*^-7}, 
      {7.768754196223725, -0.390327656649928, -0.01939588291845573, \
-0.0003028382390345804, 
       -0.00001175340673272481, -2.790367307346022*^-7}, 
      {7.326149298055811, -0.4331614637342636, -0.02046323163430517, \
-0.000359613154629776, 
       -0.00001401133939238982, -3.494715056968666*^-7}, 
      {6.955306506454701, -0.467634855648247, -0.02141437409755651, \
-0.0004108343232401809, 
       -0.00001634169411375785, -4.576814864810286*^-7}, 
      {6.555396222689868, -0.5037834596103723, -0.02250020571823135, \
-0.0004690139847278278, 
       -0.00001863661922186976, -5.07484703489363*^-7}, 
      {6.124943551747679, -0.5418446123582906, -0.02373992386652616, \
-0.0005354754656387622, 
       -0.00002126364209712545, -5.727087768529074*^-7}, 
      {5.768831094256033, -0.5728663402102728, -0.02482077050310747, \
-0.0005927791648563482, 
       -0.00002335369811769432, -6.134037920004262*^-7}, 
      {5.392437025619387, -0.6053412001057028, -0.0260151340946831, \
-0.0006540875717753897, 
       -0.00002493184946402778, -5.536490837733603*^-7}, 
      {4.994785634267183, -0.6394185216234758, -0.02732907552219287, \
-0.0007175859108780784, 
       -0.00002563616839219215, -3.870355042317577*^-7}, 
      {4.665775360092284, -0.6674999883949212, -0.028448802400839, \
-0.0007655691810542998, 
       -0.00002409990884044, 1.115603707849714*^-7}, 
      {4.322334437046174, -0.6967443379779679, -0.02963703773528973, \
-0.0008079737310047569, 
       -0.00002064753574200819, 7.413697416765887*^-7}, 
      {3.963861070955235, -0.7272139625463237, -0.03087872378483398, \
-0.0008363024947574903, 
       -0.00001261721349884815, 1.965386517079039*^-6}, 
      {3.663941852231141, -0.7526607228351071, -0.03189658354128313, \
-0.0008379992259372304, 
       1.816173064356771*^-6, 4.543252802692748*^-6}, 
      {3.353540498853655, -0.7789291934482131, -0.0329000693062936, \
-0.000811318218962565, 
       0.00002197123143171712, 7.243660173088941*^-6}, 
      {3.032328670219146, -0.8059897944919455, -0.0338410673095244, \
-0.0007349002323655486, 
       0.00005608928662522266, 0.00001203838336842431}, 
      {2.699999456997757, -0.8337624796877745, -0.03464109144566363, \
-0.0005783833555527922, 
       0.0001112946001640972, 0.00001963774233745295}, 
      {2.42516752643929, -0.8564535181483041, -0.03509703367938602, \
-0.0003546369467890064, 
       0.000192033055843695, 0.00003464517910447828}, 
      {2.142916835136672, -0.8793585295333008, -0.03527974370718083, 
       -0.00001273428594556359, 0.0002948725775887559, \
0.00004894476529634975}, 
      {1.853211553119839, -0.9022537703517116, -0.035037469593479, \
0.0005179679107372344, 
       0.0004544219200834743, 0.00007353228940982403}, 
      {1.556107238542793, -0.9247934731101903, -0.03414212148875883, \
0.001330321816547742, 
       0.0006942866594433025, 0.0001105222728368095}, 
      {1.305542512951654, -0.9427556785462524, -0.0326715109476275, \
0.002333855642732774, 
       0.001024308521813347, 0.0001782580134909593}, 
      {1.050285725977653, -0.9596851690390483, -0.03023978260508592, \
0.003735070942888119, 
       0.001439830278542835, 0.0002439911060815616}, 
      {0.7906920763512326, -0.9749637212387691, -0.02644054618674398, \
0.005737553265834374, 
       0.002053289714500098, 0.0003506276633245231}, 
      {0.581773669823783, -0.9853510498985814, -0.0220690963181522, \
0.007961725193632396, 
       0.002829482744186109, 0.0005395275404252143}, 
      {0.3708635613122279, -0.9935436946690142, -0.0160684082506817, \
0.01086862850609924, 
       0.003724119040339392, 0.0006895547126122689}, 
      {0.1585108905365732, -0.9987383206197984, -0.007900291511464995, \
0.01475141002323004, 
       0.004964305697027844, 0.0009267111852836368}, 
      {-0.01019562829094918, -1.000031425027784, 0.0005707898685043567, \
0.01876251212404623, 
       0.006385956422995687, 0.001305712556454863}, 
      {-0.1788585165848888, -0.9980981517443604, 0.01129769222430227, \
0.023710118431065, 
       0.007915446410665703, 0.001559110197465615}, 
      {-0.3468641814492824, -0.9920867767621208, 0.02483572427634737, \
0.02988020757153405, 
       0.009849086392735541, 0.001925276107875177}, 
      {-0.5134381955759886, -0.9809389912948859, 0.04185262877703904, \
0.03748465667219955, 
       0.01213162586024128, 0.002315089102926869}, 
      {-0.6776074762544007, -0.9633523851300072, 0.06312573274183046, \
0.04673072132854367, 
       0.0147264351879456, 0.002695021842498295}, 
      {-0.8036394108236114, -0.9440855018651676, 0.08329723879731682, \
0.05521431273115359, 
       0.01698685289364705, 0.003058825162543732}, 
      {-0.9267543066246947, -0.9190302047520255, 0.107017048264052, \
0.06468541433466481, 
       0.01892954484080065, 0.00300018339819953}, 
      {-1.046123669807684, -0.8871984576345342, 0.1346592570442646, \
0.07502172846056924, 
       0.02052178883970547, 0.002705545816747502}, 
      {-1.160782303155622, -0.8475163211351228, 0.1664847175628157, \
0.08581244809792163, 
       0.02122682852885966, 0.001886543484353676}, 
      {-1.269619747707029, -0.7988669030239494, 0.2025380621600144, \
0.09635635188778453, 
       0.02040725646417328, 0.0003227911369650783}, 
      {-1.349899437124269, -0.7538480996973123, 0.2335077417215031, \
0.1035714519102542, 
       0.01726318745282707, -0.00288121971300368}, 
      {-1.425188864921972, -0.7022096438184043, 0.2665258440522284, \
0.1094317235345257, 
       0.01322079122002782, -0.005352564876366695}, 
      {-1.494784057870099, -0.6435853022559724, 0.3009917475707371, \
0.1128684748896354, 
       0.006611563764522239, -0.009072241427114484}, 
      {-1.557950537439052, -0.5777615350599233, 0.336027543458169, \
0.1129926957717953, 
       -0.002403823680436516, -0.01326059702421098}, 
      {-1.613942168473566, -0.504736048103298, 0.3704665660221333, \
0.1088754539178037, 
       -0.01376224051083587, -0.01762219865709182}, 
      {-1.662025973732703, -0.4247754241117603, 0.4028814426926791, \
0.09976350351602896, 
       -0.0269363594619987, -0.02156011199215868}, 
      {-1.701512466375834, -0.3384616036477171, 0.4316658229968077, \
0.08526904084812619, 
       -0.04086942903856019, -0.02426352924640257}, 
      {-1.73178970488652, -0.2467155268910818, 0.4551733936317265, \
0.06554896771779318, 
       -0.05402947454942631, -0.02486715797236664}, 
      {-1.749484650892886, -0.1677685632643207, 0.4695278762866671, \
0.04597746205166833, 
       -0.06248573122944543, -0.02234734071437314}, 
      {-1.760353707815711, -0.08681638421746196, 0.4785817569993307, \
0.02414222162517438, 
       -0.0684664210405525, -0.01818518100558304}, 
      {-1.764265435916514, -0.004805076280645706, 0.4818897748402959, \
0.00112025114341608, 
       -0.07091022799529279, -0.01195760758726978}, 
      {-1.76236577741184, 0.0606521921715394, 0.480290484777385, \
-0.01713117920872794, 
       -0.06861762399131655, -0.002606614280396006}, 
      {-1.756029122362558, 0.125638682995093, 0.4749807758685636, \
-0.03505393830411185, 
       -0.06606271558326897, 0.00245470572463218}, 
      {-1.745304369527454, 0.1896598132292471, 0.4661293124311477, \
-0.0518056563790933, 
       -0.06081525948563206, 0.0089458321081614}, 
      {-1.730273147198572, 0.2522515331649098, 0.4540100153497991, \
-0.06698429564510738, 
       -0.05397886505482611, 0.01452856350472839}, 
      {-1.711047218718022, 0.312993131635787, 0.4389831223451164, \
-0.08021603846893547, 
       -0.04592769253080176, 0.01910674539096174, 0.0112234071821679}, 
      {-1.681882002291772, 0.3845681430853439, 0.4171620342687122, \
-0.09336590315190585, 
       -0.03369560200961965, 0.0310431315268761, 0.01625868075591384}, 
      {-1.64689662182044, 0.4522426319878079, 0.3924498532520257, \
-0.1030385161184949, 
       -0.0222443506330142, 0.03258849453589323, 0.01098833049495457}, 
      {-1.606434812591194, 0.515607829323531, 0.36572213189472, \
-0.1094689249296306, 
       -0.0133431291287566, 0.02606724544213453, 0.00138936915088037}, 
      {-1.560868771036133, 0.574397280153226, 0.3378140229666989, \
-0.1126306820232994, 
       -0.004563733627122644, 0.02213606013132171, -0.002303266882837862}, 
      {-1.510587242725673, 0.6284778821047289, 0.309476637954035, \
-0.1130003101717239, 
       0.00292253317290613, 0.0178633795248808, -0.004791344592090221}, 
      {-1.455985072088432, 0.6778329958274733, 0.2813492480291091, \
-0.1110636828661127, 
       0.008915080261078875, 0.01347537083722533, -0.006376217232311955}, 
      {-1.375641498739476, 0.7374320787816258, 0.2444028272964234, \
-0.1056097126544974, 
       0.01489965461333539, 0.008490226891348038, -0.006755750290217954}, 
      {-1.289004237623477, 0.788891807135293, 0.2097107613312894, \
-0.09803053817775328, 
       0.01817630741349152, 0.003537827270278958, -0.006964224637568179}, 
      {-1.196964717716656, 0.8327936866303476, 0.1778365262305198, \
-0.0892489713987476, 
       0.01971179532451445, 0.0001177441671680824, -0.006188689721778199}, 
      {-1.100342520552938, 0.8698119606519135, 0.1490465900101704, \
-0.08003165750832796, 
       0.01994010852089246, -0.002044848686377623, -0.00498427847537343}, 
      {-0.999878358424711, 0.9006549812913164, 0.1233873832491196, \
-0.07092199305035602, 
       0.01927263068309745, -0.003239265476359214, -0.003692585936083426}, 
      {-0.8962327113103235, 0.926023448973112, 0.1007555294642846, \
-0.06227240472027338, 
       0.01804969920197315, -0.003747056772031509, -0.002514006058316793}, 
      {-0.7755422233257732, 0.9490136902344843, 0.07849704368346685, \
-0.05329868675549393, 
       0.01613396732739201, -0.004196726500590367, -0.001741389640896867}, 
      {-0.6522434151077084, 0.9667061965232136, 0.05952004929242279, \
-0.04527538684086182, 
       0.01433050625110385, -0.003770544358843295, -0.0008240173303981437}, 
      {-0.5269657952726466, 0.9798957942680742, 0.04343673386904138, \
-0.03827069759993994, 
       0.01248485568271127, -0.003361173066411727, -0.0002823040982168518}, 
      {-0.4002429608239173, 0.9892777531226624, 0.02986644777501683, \
-0.03222455331964014, 
       0.0107664709959633, -0.002894155249681107, 0.00007259205902576042}, 
      {-0.2725252408432976, 0.995452535103027, 0.01845507692158688, \
-0.02705482100712088, 
       0.009206978357109621, -0.002459180090412363, 0.0002689275889236384}, 
      {-0.1441913683513293, 0.9989339558079228, 0.008884327972586461, \
-0.02266178633958879, 
       0.007827983594130666, -0.002069945373768072, 0.0003630295507379626}, 
      {0.02226819434234248, 1.000145182466093, -0.001219024861145227, \
-0.0179683154676857, 
       0.006299151660199119, -0.001662668150305876, 0.0003809020154706281}, 
      {0.1886698608753065, 0.9983553159555206, -0.009218032475455466, \
-0.01419776378003345, 
       0.005076165547349214, -0.0012793646077268, 0.000382025815317443}, 
      {0.3545682506358343, 0.9941930965280139, -0.01553061596257232, \
-0.01118183215672045, 
       0.004074944369167255, -0.0009956216131683516, 0.0003428334887580776}, 
      {0.5196118520941745, 0.9881619471779671, -0.02049367368226837, \
-0.008770001716371446, 
       0.0032676395295519, -0.0007777896042162058, 0.0002929256374042323}, 
      {0.6835242821381898, 0.9806646357849489, -0.0243770856019539, \
-0.006840862212028387, 
       0.002619164649998601, -0.0006116173550132476, 0.0002422950288837543}, 
      {0.846089264886865, 0.9720234415504707, -0.02739631737230428, \
-0.005296351224643264, 
       0.002100246571211936, -0.0004833792190916945, 0.000196726868255594}, 
      {1.066592896664793, 0.9587717986591574, -0.03044018257059564, \
-0.003652439184346356, 
       0.001595753698635616, -0.0002937019783829837, 0.0001734051778784717}, 
      {1.283929331693501, 0.9443617780501638, -0.03251750654753809, \
-0.002447564922427267, 
       0.001179955247842791, -0.0002182896984028213, 0.0001260568539087319}, 
      {1.497879825405811, 0.9291746337439207, -0.03387891943982661, \
-0.00155349890912378, 
       0.0008760267165344156, -0.0001606179550143507, \
0.00009246918454850233}, 
      {1.708300765140247, 0.9134930196979686, -0.03470926294450196, \
-0.0008902958939989568, 
       0.0006495337103677596, -0.0001205532923284167, \
0.00006717686532543776}, 
      {1.915104381391104, 0.8975266689053345, -0.03514546113291541, \
-0.000398149654282465, 
       0.0004811514462536032, -0.00009101432091619566, \
0.00004892889852040235}, 
      {2.118244307579018, 0.8814311908546203, -0.03528941540611969, \
-0.00003363377852995554, 
       0.0003554110338595445, -0.00006907461181609892, \
0.00003576180280828011}, 
      {2.384417734767659, 0.8598787516858068, -0.03515449090637718, \
0.0003148766654492357, 
       0.0002518892275406904, -0.0000304319250740445, \
0.00002988372293148579}, 
      {2.644023536256568, 0.8384932333463952, -0.03476205604310844, \
0.0005369636829576831, 
       0.0001618883596816725, -0.00002349107808201303, \
0.00001944379382626559}, 
      {2.897133842541354, 0.8174026028438277, -0.03420256706022472, \
0.0006795449017593617, 
       0.0001022438113594314, -0.00001642041801534602, \
0.00001320814413107836}, 
      {3.143852271199849, 0.7966887465627933, -0.03353839956306629, \
0.0007662117491005494, 
       0.00006066836083214086, -0.00001181432155714301, \
8.929317735180017*^-6}, 
      {3.384302345658927, 0.7764016486833618, -0.03281270411307159, \
0.0008143465949939741, 
       0.00003209832393187845, -8.348618875393476*^-6, \
6.113341227529192*^-6}, 
      {3.618619272195064, 0.7565692233608628, -0.03205536139344508, \
0.0008357621968473683, 
       0.00001242071990042339, -5.818816994915398*^-6, \
4.219667539206514*^-6}, 
      {3.92886194715618, 0.7302490160559004, -0.03100663149767763, \
0.0008385287297372506, 
       -4.108347797107607*^-7, -6.349693779122061*^-8, 3.45111112924639*^-6}, \

      {4.228301708150481, 0.7048008058245118, -0.02997067434209798, \
0.0008176997788354373, 
       -0.00001253317670702427, -4.978381959764352*^-8, \
2.072857105685236*^-6}, 
      {4.517299043398252, 0.6802047621818131, -0.02896743471545147, \
0.0007857167574707482, 
       -0.00001895006177028341, 3.234020266992194*^-7, \
1.303324103176969*^-6}, 
      {4.796203149911096, 0.6564284491962737, -0.02800800845072081, \
0.0007475737667940269, 
       -0.00002238777417242241, 4.992052427002188*^-7, \
8.100759168705813*^-7}, 
      {5.065348156163043, 0.6334326611729082, -0.02709794617932593, \
0.0007067487047813926, 
       -0.00002383916372681342, 6.343615968652629*^-7, 5.07634387681592*^-7}, \

      {5.325051068702551, 0.6111751233028137, -0.02623934422235111, \
0.000665314332732988, 
       -0.00002410642451112824, 7.072556028664549*^-7, \
3.162241610566118*^-7}, 
      {5.655894707793652, 0.5826807061915037, -0.02517828387816169, \
0.0006118966526689353, 
       -0.0000227192258322392, 1.131037221975536*^-6, 2.407002862836298*^-7}, \

      {5.971259853341118, 0.5553139221569464, -0.02420446318052591, \
0.0005606225412516008, 
       -0.00002175396769429596, 9.175530371056984*^-7, \
1.187456508164852*^-7}, 
      {6.271745338570467, 0.5289808403688724, -0.02331258294775238, \
0.0005130296340243782, 
       -0.00002029311797627877, 8.085334005617951*^-7, \
5.813622281947584*^-8}, 
      {6.557899598696153, 0.5035939385343456, -0.02249657749762699, \
0.0004691999956915362, 
       -0.00001874102309095765, 7.059839853884869*^-7, \
2.254870251065767*^-8}, 
      {6.830224466643866, 0.4790725291549845, -0.02175025773394738, \
0.0004290853821866332, 
       -0.00001718899571067967, 6.236763965412493*^-7, \
3.630558915558019*^-9}, 
      {7.089178920785931, 0.4553426881432329, -0.02106765971655919, \
0.0003924637250643549, 
       -0.00001571934317312086, 5.504882927561948*^-7, \
-6.623578972028509*^-9}, 
      {7.43149972864376, 0.4231844277515278, -0.02020499039701404, \
0.0003463988622463432, 
       -0.00001378405187492558, 4.865478793280816*^-7, \
-9.442609754327765*^-9}, 
      {7.749256045456239, 0.3922905621343921, -0.01944346965038604, \
0.0003058084201040788, 
       -0.00001218860414036386, 3.951411092828779*^-7, \
-1.348307055201396*^-8}, 
      {8.043374553912123, 0.3625130276620445, -0.01877103566132193, \
0.0002700205816455207, 
       -0.00001079691936949478, 3.264730066438901*^-7, \
-1.396263725454813*^-8}, 
      {8.314673472069433, 0.3337211953793819, -0.01817736448502738, \
0.0002383121579390274, 
       -9.604546342830444*^-6, 2.715490020924377*^-7, -1.30749222049024*^-8}, \

      {8.563875162225574, 0.3057993052705894, -0.0176536704333936, \
0.0002100689685149639, 
       -8.585500612918368*^-6, 2.279571155613731*^-7, \
-1.157312113419368*^-8}, 
      {8.79161679704528, 0.2786442277531095, -0.01719250736201303, \
0.0001847517317766545, 
       -7.723027681494581*^-6, 1.913099477342379*^-7, \
-1.007809793065122*^-8}, 
      {9.064993293084725, 0.2431782754827715, -0.01666007054065354, \
0.0001544947360029797, 
       -6.802049634377*^-6, 1.417419303208223*^-7, -9.19958943634187*^-9}, 
      {9.301747451181386, 0.2087329926332507, -0.01621685541758018, \
0.0001278423466985189, 
       -6.03699548356089*^-6, 1.123159472922386*^-7, -7.391367744114103*^-9}, \

      {9.502854884057679, 0.175132195087845, -0.01585290772474365, \
0.0001039852109013272, 
       -5.439993273713115*^-6, 8.712488414348191*^-8, \
-6.037076329541117*^-9}, 
      {9.669116690051, 0.1422182385984541, -0.0155604185736437, \
0.00008231217261183656, 
       -4.977179853004686*^-6, 6.644597617068165*^-8, \
-4.937509771440324*^-9}, 
      {9.801176637316414, 0.1098479333272967, -0.01533335324301237, \
0.00006230706870166256, 
       -4.628193620216817*^-6, 4.882647877761499*^-8, \
-4.083178684976437*^-9}, 
      {9.815317147397847, 0.1058298776274191, -0.01530930964653196, \
0.00005993856329819537, 
       -4.461626311090628*^-6, 2.229011151363054*^-7, \
8.605199009764021*^-8}}][t], 
  y[t] -> InterpolatingFunction[{{0., 100.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003331483023263849, 0.006662966046527698, 0.1760831648387825, 
       0.3455033636310373, 0.5149235624232922, 1.113331746264325, \
1.711739930105358, 
       2.310148113946391, 2.908556297787424, 3.549226293889243, \
4.189896289991062, 
       4.830566286092881, 5.471236282194699, 6.430795500662957, \
7.390354719131214, 
       8.34991393759947, 9.309473156067728, 10.26903237453598, \
11.41748921768868, 
       12.56594606084139, 13.71440290399409, 14.86285974714679, \
15.76992300897745, 
       16.67698627080811, 17.40746358480685, 18.13794089880559, \
18.7397959150954, 
       19.3416509313852, 19.94350594767501, 20.42463542003453, \
20.90576489239406, 
       21.38689436475359, 21.77943140165771, 22.17196843856184, \
22.49018228099118, 
       22.80839612342052, 23.12660996584985, 23.35745430632501, \
23.58829864680017, 
       23.81914298727534, 24.0499873277505, 24.22894782904176, \
24.40790833033302, 
       24.58686883162428, 24.73263871122103, 24.87840859081777, \
25.02417847041451, 
       25.16994835001125, 25.31571822960799, 25.43261488145184, \
25.54951153329568, 
       25.66640818513952, 25.75972586508166, 25.8530435450238, \
25.94636122496595, 
       26.03967890490809, 26.13299658485023, 26.22631426479237, \
26.32916699997962, 
       26.43201973516686, 26.5348724703541, 26.63772520554135, \
26.7405779407286, 
       26.84343067591584, 26.95721769562641, 27.07100471533697, \
27.18479173504754, 
       27.29857875475811, 27.41236577446868, 27.52615279417925, \
27.66074382830965, 
       27.79533486244006, 27.92992589657046, 28.06451693070087, \
28.19910796483128, 
       28.33369899896168, 28.46829003309208, 28.63486560498111, \
28.80144117687013, 
       28.96801674875915, 29.13459232064816, 29.30116789253718, \
29.4677434644262, 
       29.71773345304378, 29.96772344166136, 30.21771343027894, \
30.46770341889652, 
       30.71769340751409, 30.96768339613167, 31.3010544995537, \
31.63442560297573, 
       31.96779670639775, 32.30116780981978, 32.63453891324182, \
32.96791001666385, 
       33.4114262068452, 33.85494239702655, 34.29845858720789, \
34.74197477738924, 
       35.18549096757059, 35.62900715775194, 36.23354495905478, \
36.83808276035762, 
       37.44262056166046, 38.0471583629633, 38.65169616426614, \
39.25623396556898, 
       40.10946796733268, 40.96270196909638, 41.81593597086009, \
42.66916997262379, 
       43.52240397438749, 44.37563797615119, 45.41195670648726, \
46.44827543682334, 
       47.48459416715941, 48.52091289749548, 49.55723162783154, \
50.59355035816762, 
       51.68339887256983, 52.77324738697206, 53.86309590137428, \
54.9529444157765, 
       56.04279293017872, 57.13264144458094, 57.58494946950075, \
58.03725749442055, 
       58.48956551934037, 58.94187354426017, 59.39418156917998, \
60.46962757399835, 
       61.54507357881672, 62.62051958363509, 63.69596558845345, \
64.77141159327182, 
       65.59501642075933, 66.41862124824685, 67.24222607573437, \
67.88129038764838, 
       68.52035469956239, 69.1594190114764, 69.6629816849138, \
70.1665443583512, 
       70.6701070317886, 71.07547552469601, 71.48084401760343, \
71.88621251051085, 
       72.29158100341826, 72.61679430492302, 72.94200760642778, \
73.26722090793253, 
       73.5924342094373, 73.86075147913136, 74.12906874882543, \
74.39738601851949, 
       74.61050073963264, 74.82361546074578, 75.03673018185892, \
75.20550076096502, 
       75.37427134007112, 75.54304191917721, 75.71181249828331, \
75.8805830773894, 
       76.01266973050996, 76.1447563836305, 76.27684303675106, \
76.40892968987161, 
       76.54101634299216, 76.64435076816506, 76.74768519333794, \
76.85101961851083, 
       76.95435404368372, 77.05768846885661, 77.1610228940295, \
77.26435731920239, 
       77.36769174437528, 77.45298990779566, 77.53828807121606, \
77.62358623463645, 
       77.69157185629193, 77.75955747794741, 77.82754309960289, \
77.89552872125837, 
       77.96351434291385, 78.04706179169975, 78.13060924048564, \
78.21415668927153, 
       78.29770413805743, 78.38125158684332, 78.46479903562921, \
78.57822588435457, 
       78.69165273307991, 78.80507958180527, 78.91850643053063, \
79.03193327925598, 
       79.14536012798134, 79.27402872242009, 79.40269731685884, \
79.53136591129759, 
       79.66003450573634, 79.78870310017509, 79.91737169461384, \
80.08386115675204, 
       80.25035061889024, 80.41684008102844, 80.58332954316664, \
80.74981900530485, 
       80.91630846744305, 81.1446878201505, 81.37306717285797, \
81.60144652556544, 
       81.82982587827289, 82.05820523098037, 82.28658458368782, \
82.59230296432988, 
       82.89802134497195, 83.20373972561402, 83.50945810625608, \
83.81517648689813, 
       84.1208948675402, 84.53825979449733, 84.95562472145447, \
85.37298964841161, 
       85.79035457536873, 86.20771950232587, 86.62508442928301, \
87.17941917293771, 
       87.73375391659241, 88.28808866024713, 88.84242340390184, \
89.39675814755654, 
       89.95109289121124, 90.73059797678343, 91.5101030623556, \
92.28960814792779, 
       93.06911323349998, 93.84861831907215, 94.62812340464434, \
95.67627335203383, 
       96.72442329942333, 97.77257324681281, 98.82072319420231, \
99.86887314159179, 100.}}, 
     {{0., 0.3}, {0.0009994448737013001, 0.2999999900110978, \
-1.499167487756533*^-6}, 
      {0.00199888968084688, 0.2999999700332916, -2.998335289988881*^-6, 
       -0.0001500000442008972}, {0.05282376391745863, 0.2999860366233051, 
       -0.00007924339318023418, -0.0001500117428613848}, 
      {0.1036440885092901, 0.299946262178933, -0.0001555246253661658, 
       -0.0001500829155943178}, {0.1544554839482764, 0.299880628538707, 
       -0.0002318768810297158, -0.0001502226539059727, \
-2.062007845744026*^-7}, 
      {0.3337934300807004, 0.299441233999099, -0.0005026510261369603, 
       -0.0001512574212291957, -3.569335647017451*^-7}, 
      {0.5127688475869407, 0.2986761846590499, -0.0007763026058184363, 
       -0.0001532344779572006, -6.696211508402681*^-7}, 
      {0.6911879297003016, 0.2975811030163217, -0.001054435340140069, 
       -0.0001561772934777651, -1.042830288517257*^-6}, 
      {0.8688513700083616, 0.2961496336216181, -0.001338718424604862, 
       -0.0001600681426134533, -1.431276518956978*^-6}, 
      {1.057993201287945, 0.2942346011796492, -0.001651899448899558, \
-0.0001652997074935318, 
       -1.838054111765936*^-6}, {1.245778024608853, 0.2919112256037301, 
       -0.001976478035186562, -0.0001718395686249002, \
-2.313992493985606*^-6}, 
      {1.431939197556614, 0.2891632988175841, -0.002314989549908035, \
-0.0001797482744838896, 
       -2.828735815462428*^-6}, {1.616198620337447, 0.285971201746954, 
       -0.002670235186165005, -0.0001891835626438646, -3.397448651976029*^-6, \

       -1.775369035459611*^-7}, {1.887974817730012, 0.2803075055591735, 
       -0.003240541654733827, -0.0002072785022960245, -5.221285660321966*^-6, \

       -2.788387437615591*^-7}, {2.153774944318532, 0.2734968363337465, 
       -0.003867835458278296, -0.0002294388022435563, -6.43186544068556*^-6, 
       -2.655793583687462*^-7}, {2.412440671783842, 0.265415593882329, 
       -0.004567281372179837, -0.0002572628765213672, -7.902662366444084*^-6, \

       -2.860680696631133*^-7}, {2.662681341173103, 0.2559078938491431, 
       -0.005357903666291043, -0.0002926871322040292, -9.973769937385709*^-6, \

       -3.588735089442362*^-7}, {2.903037169430532, 0.2447763566117847, 
       -0.006264059362911156, -0.0003376694168875125, \
-0.00001266085919358178, 
       -4.594704620827311*^-7, -1.747277138682448*^-8}, 
      {3.175351924960481, 0.2289627985088232, -0.007545712866846237, \
-0.0004088587135559304, 
       -0.00001760696568293132, -8.727373379029582*^-7, \
-3.447335405901919*^-8}, 
      {3.427700056323644, 0.2098934285097027, -0.009114128634632832, \
-0.0005061008503925311, 
       -0.00002445961508137534, -1.28330341928551*^-6, \
-4.451692549205896*^-8}, 
      {3.655917296564617, 0.1867913368607099, -0.01107856605235668, \
-0.00064070881417733, 
       -0.00003391929625372602, -1.770650987954265*^-6, \
-5.500014991276092*^-8}, 
      {3.854785566402926, 0.1585716724413545, -0.01360318641865599, \
-0.0008339183629275508, 
       -0.00004894481516545157, -2.712355395188257*^-6, \
-8.766500329630028*^-8}, 
      {3.986766641465378, 0.1316661691671603, -0.01615674938434624, \
-0.001051633774165488, 
       -0.00006869731687694258, -4.393195250020522*^-6, \
-1.761361300232891*^-7}, 
      {4.09206404988277, 0.09952892079127101, -0.01940879768533031, \
-0.001352405581222583, 
       -0.00009571377807437961, -6.281291555040811*^-6, \
-2.444515877855505*^-7}, 
      {4.153852447730103, 0.06883782038992785, -0.02272867814587069, \
-0.00169051344986589, 
       -0.0001316410970271743, -9.940985667775324*^-6, \
-4.806712054376383*^-7}, 
      {4.191307089481091, 0.0326973275645756, -0.02691280237314174, \
-0.002148317666669569, 
       -0.0001796396843152926, -0.00001388829746499856, \
-6.486522680079726*^-7}, 
      {4.200742206976096, -0.002209393363074649, -0.03123965422032688, 
       -0.002663858406128182, -0.0002423671183676872, -0.0000211894234164147, \

       -1.197927213992449*^-6}, {4.187479758384353, -0.04294153668025093, 
       -0.03664391948151121, -0.003351455142184531, -0.0003255158356822546, 
       -0.00002918254086158613, -1.604143144027118*^-6}, 
      {4.147581330897977, -0.09101328379716587, -0.04351075536272874, \
-0.004295486281482091, 
       -0.00044977522678771, -0.00004287234651527241, \
-2.478887155067151*^-6}, 
      {4.09321441436822, -0.1360896654413775, -0.0504224977543499, \
-0.005319612738662994, 
       -0.0006006270723973962, -0.00006396294406072243, \
-4.409705411169836*^-6}, 
      {4.015437020370768, -0.1885969999225027, -0.05903420088196576, \
-0.006668684748934035, 
       -0.0007954661888555848, -0.00008583379909492283, \
-5.676311059326454*^-6}, 
      {3.910240462220841, -0.2504298720649793, -0.0699163201970832, \
-0.008485422348512763, 
       -0.001075865851204047, -0.0001215331860058628, \
-8.352395114441184*^-6}, 
      {3.800622921340645, -0.309528333429926, -0.08102144486918339, \
-0.01044541308008853, 
       -0.001399106456554768, -0.0001697683514934161, \
-0.00001320347348013746}, 
      {3.665969273135835, -0.3783294081665258, -0.09474267585026909, \
-0.01295466572309489, 
       -0.001793932666684747, -0.0002144506991247332, -0.000015510726420828}, \

      {3.535549033541424, -0.4428080644602409, -0.1082887571036107, \
-0.01550366292064587, 
       -0.002200968380312102, -0.0002668371140452862, \
-0.00002028153245642826}, 
      {3.383152972930747, -0.5167309309805996, -0.1245039795902115, \
-0.01856326415444272, 
       -0.002628631870240631, -0.0002906385493446519, \
-0.00001715538499395261}, 
      {3.205489358206705, -0.6019537033150193, -0.1438816364627664, \
-0.02213385762420312, 
       -0.003028429854844643, -0.0002756163275060694, \
-7.146034607113681*^-6}, 
      {3.058584109523864, -0.6720644022231944, -0.160155014885466, \
-0.02490573979780069, 
       -0.003089764644996956, -0.00009057776887969144, \
0.00004915057002279365}, 
      {2.89459280569387, -0.7501333065857922, -0.1783528278477566, \
-0.02765297965378236, 
       -0.002939796084152192, 0.0001373303078003982, 0.00009530903069106837}, \

      {2.711577932821268, -0.8370192439954621, -0.1982939240318584, \
-0.02988430596731927, 
       -0.002118974346676943, 0.0007046073978269977, 0.0002210121450764065}, 
      {2.507419834246281, -0.9334064931990731, -0.2193616573945036, \
-0.03078066883450286, 
       -0.00017324934039016, 0.001720507297946907, 0.0004259939902614723}, 
      {2.333176578365769, -1.014848487612338, -0.2356209775075282, \
-0.02955056203988659, 
       0.003046067625084959, 0.003590992890583919, 0.0009523928302944019}, 
      {2.143848205627758, -1.101920681702815, -0.2505886562760755, \
-0.02575511118135032, 
       0.007412469595689977, 0.005279999834267802, 0.001200627403048992}, 
      {1.938485369569333, -1.193863207195709, -0.2624731147754042, \
-0.01785393108006859, 
       0.01421264256785683, 0.008004938646760551, 0.001735475227252769}, 
      {1.758830962571313, -1.271317664579598, -0.2681090316780139, \
-0.007281666470039747, 
       0.02174475645660771, 0.0108688536356707, 0.002351073320683885}, 
      {1.567802367487409, -1.349653481956006, -0.268188872479511, \
0.007755295435392438, 
       0.0301827036420186, 0.01265092926697094, 0.00222566176161852}, 
      {1.365403243795173, -1.426950375503247, -0.2606107126532319, \
0.02785477948347978, 
       0.03933120744359395, 0.01367846314950508, 0.001805331305562889}, 
      {1.151963151926062, -1.500657494999457, -0.2432082334069276, \
0.05271515132977562, 
       0.04725613334062842, 0.01217622550374163, 0.0003961626366297657}, 
      {0.9282278704402241, -1.567631620976292, -0.2141718835467336, \
0.08087467977305719, 
       0.05143956821693143, 0.006857266967903932, -0.002194884764275509}, 
      {0.7421881037049024, -1.614082941293007, -0.1818519021645309, \
0.1036386412865146, 
       0.04854414377564431, -0.004146205866459463, -0.007592259057051008}, 
      {0.5511960771660369, -1.652054171951565, -0.1417295304881716, \
0.124843461752242, 
       0.04251465568309567, -0.01247743067992465, -0.009306689016532899}, 
      {0.3563458923295473, -1.679827982442375, -0.0948726931259311, \
0.141622179310341, 
       0.03002600870600717, -0.02382706564300113, -0.01205675936916703}, 
      {0.198879241834999, -1.693747304016287, -0.05387277416312969, \
0.1504911785627649, 
       0.01707875255694182, -0.03104604604923829, -0.01239133515003333}, 
      {0.04047689459726862, -1.699822634886948, -0.01104718750557494, \
0.1544758888573003, 
       0.002904702880261381, -0.03443804746683854, -0.009858065663037937}, 
      {-0.1181171876575204, -1.697846380627478, 0.03215892912378119, \
0.1531408394626232, 
       -0.0116764414363012, -0.03485995909394402, -0.006216255397711232}, 
      {-0.2761526988332612, -1.68788638662706, 0.07426442668032267, \
0.1466405539549278, 
       -0.02502221738817387, -0.03148562379863356, -0.0013191094410794}, 
      {-0.432898314979279, -1.670279353462642, 0.1138915973378854, \
0.1355749935566489, 
       -0.03599306966383624, -0.02507391559287451, 0.003789094139049751}, 
      {-0.5876655720048651, -1.645599784467698, 0.1498871907557707, \
0.1209185026537617, 
       -0.04381962273675133, -0.01674739409262697, 0.008221969495047893}, 
      {-0.7552075236937675, -1.6111218670088, 0.1843502048429381, \
0.1019890094663604, 
       -0.04877572195107108, -0.00775362574898059, 0.01076272580347892}, 
      {-0.9188598597499566, -1.570174125339077, 0.212727886435489, \
0.0818109776818003, 
       -0.04943939032580138, 0.001581523374508793, 0.01250845439095058}, 
      {-1.078022534709271, -1.524033583488598, 0.2348480184999798, \
0.06175191229702974, 
       -0.04718113087076628, 0.008400814666395451, 0.0119251730687636}, 
      {-1.232227166787945, -1.473969841854409, 0.2509389710804551, \
0.04295018805845074, 
       -0.0428030874453577, 0.01270243669403255, 0.009943311673751807}, 
      {-1.381132413652258, -1.421173717826585, 0.261518535716545, \
0.0261500847238224, 
       -0.03724701531565022, 0.01458153990151682, 0.007183976462067189}, 
      {-1.524513206063126, -1.366709697415261, 0.267279261561885, \
0.01175092901757046, 
       -0.0312428175682931, 0.01462384494280874, 0.004337806986469865}, 
      {-1.676554319154809, -1.305608799945127, 0.2689638067204453, \
-0.001217066697896737, 
       -0.02444610144819016, 0.01402117215581368, 0.002249584287324535}, 
      {-1.821639227967704, -1.244590006468934, 0.2667220569826872, \
-0.01131288265262222, 
       -0.01864934929390575, 0.0116138843791091, -0.0000606550449465426}, 
      {-1.959823841898652, -1.184436871736238, 0.2615032016652058, \
-0.01878286991956104, 
       -0.01354137734413185, 0.009331001175103304, -0.001373911260484434}, 
      {-2.09124150940112, -1.125730698811825, 0.2541299228369151, \
-0.02404459975660059, 
       -0.009317809104619765, 0.007160118712381802, -0.002096244885645796}, 
      {-2.216081660924117, -1.068881568684947, 0.2452839862358523, \
-0.02750823233335715, 
       -0.005921776039315519, 0.005321447829323568, -0.002335005648439233}, 
      {-2.334572172168182, -1.014160155484463, 0.2355104894846171, \
-0.02955739788630845, 
       -0.00326795512716691, 0.003847435986648851, -0.00226461205399097, 
       0.00008837763572596101}, {-2.46687578954658, -0.9523954995184833, \
0.2233247710596682, 
       -0.03060924041552683, -0.0009206383469870495, 0.002668606053298254, 
       -0.001642610070119951, 0.0002789861443788303}, 
      {-2.591088839658774, -0.893947182818122, 0.2109424928172438, \
-0.03058675245030823, 
       0.0007931592662098918, 0.002021643002148082, -0.0008785609563660312, 
       0.0004563155387574655}, {-2.707659142407939, -0.8388171534125094, \
0.1987179935946615, 
       -0.02986498241193216, 0.001850572210108957, 0.001311820594940722, 
       -0.0006006832471358352, 0.0004025250199779791}, 
      {-2.817028834585003, -0.786929247217004, 0.1868844260003222, \
-0.02868642357806276, 
       0.002510880265283754, 0.0008222010400445, -0.0003592651810707385, 
       0.0003537650519824746}, {-2.919626179845429, -0.7381571237336199, \
0.1755860743965478, 
       -0.02723906625000296, 0.002875049191920511, 0.000461691132772208, 
       -0.0002051290954074212, 0.0002903775622638701}, 
      {-3.015860273274523, -0.6923446604396646, 0.1649036149650608, \
-0.02565418859126217, 
       0.003033030349275933, 0.0002014494716896885, -0.0001107918750836621, 
       0.0002269620685591554}, {-3.106118022821996, -0.6493203585953219, \
0.1548734445568969, 
       -0.02402115846269408, 0.0030555394191594, 0.00002599954687812273, 
       -0.00004758776450651884}, {-3.210090256130905, -0.5996680710089846, 
       0.1433705436953709, -0.02201677584671442, 0.002985222434903444, 
       -0.00009582951817558466, -0.00007731093447113078}, 
      {-3.30610169643832, -0.5536834335992547, 0.1328472740545951, \
-0.02011385491464471, 
       0.002763124621780684, -0.0002864118551227199, -0.0001226611847810662}, \

      {-3.394736517266693, -0.5110486866197052, 0.1232494749402491, \
-0.01832911765726452, 
       0.002545955942852513, -0.0003344654287913664, \
-0.00009282865191245674}, 
      {-3.476527633456594, -0.4714665455521749, 0.1145100311886243, \
-0.01668087005858868, 
       0.002340653762987954, -0.0003120801641259391, \
-0.00004673818857121752}, 
      {-3.551960383012207, -0.434662959975583, 0.106557087676385, \
-0.01517795597561177, 
       0.002133231737149241, -0.0002847408621510565, \
-0.00001710121196176049}, 
      {-3.621476449065297, -0.4003878785474827, 0.0993190686554886, \
-0.0138162425534255, 
       0.001932926889059752, -0.0002565845597021223, 1.007952909958655*^-6}, 
      {-3.715570901036286, -0.3532035866348083, 0.08964949653766687, \
-0.01202278319483921, 
       0.001642061477818246, -0.0002352495671928687, 6.294330923187025*^-6}, 
      {-3.798447030435564, -0.3105342207507005, 0.08122613444756144, \
-0.01048687989122842, 
       0.001408458004331654, -0.0001884038102093863, 0.00001626930069304855}, \

      {-3.87115964926848, -0.2718037463638061, 0.07386513633493672, \
-0.009179473830240553, 
       0.001204543983953414, -0.0001528026300812435, 0.00001925560864338971}, \

      {-3.934630457513367, -0.2365213412024398, 0.06740930353324277, \
-0.008065640133929692, 
       0.001029940371043064, -0.0001250577871704172, 0.0000189522862559675}, 
      {-3.98966775788067, -0.2042686120858856, 0.06172568114269968, \
-0.007114650967568952, 
       0.0008820425946357399, -0.000103040911421332, 0.00001724277374340588}, \

      {-4.036983113968759, -0.1746882420964912, 0.05670237784586927, \
-0.006300485586551056, 
       0.0007570420445356926, -0.00008565929725756392, \
0.00001498094697873395}, 
      {-4.089141717613899, -0.1388771986636778, 0.05087074562076912, \
-0.005388163262152721, 
       0.0006254980044289453, -0.0000627575761265766, \
0.00001356839347221616}, 
      {-4.12997801303025, -0.1066698067617746, 0.04586551838651159, \
-0.004640446115866872, 
       0.0005154960356511471, -0.00005002290712258556, \
0.00001068768132307815}, 
      {-4.160607132764112, -0.0775652692490399, 0.04154165032139181, \
-0.004021722011874214, 
       0.0004278763167033897, -0.00003998671700542745, \
8.419619402372424*^-6}, 
      {-4.181992298848634, -0.05114934475214061, 0.03778327912957716, \
-0.003506550310822827, 
       0.0003572086517404438, -0.0000324281285922276, 6.563318050337633*^-6}, \

      {-4.194970592149834, -0.0270771374663087, 0.03449735039422108, \
-0.003074675284054571, 
       0.0003001534217300403, -0.00002647017021963773, \
5.129447500448216*^-6}, 
      {-4.2002737647331, -0.005059601009124408, 0.0316086555055675, \
-0.002710378936356566, 
       0.0002537304163049033, -0.00002179054648691264, \
4.013487208947057*^-6}, 
      {-4.196527048672338, 0.02146128293965649, 0.02827767443709283, \
-0.002307804306443695, 
       0.0002080180206740203, -0.00001467874509540564, \
3.477095223714002*^-6}, 
      {-4.181640023586772, 0.04524851003413066, 0.02542812133012621, \
-0.001982916153664342, 
       0.000168884039675575, -0.00001193572645850835, 2.498571077157325*^-6}, \

      {-4.156736491579558, 0.06668804881233311, 0.02297121092148057, \
-0.001716366747826533, 
       0.0001387847177647564, -9.539746270203172*^-6, 1.859291872162264*^-6}, \

      {-4.122785308857059, 0.08609612555879204, 0.02083743868144931, \
-0.001496037944792133, 
       0.0001149375217927507, -7.752987070673721*^-6, 1.384149941095835*^-6}, \

      {-4.080627690968539, 0.1037340555552956, 0.0189718480004944, \
-0.001312377338097922, 
       0.00009598073578064804, -6.330000470451101*^-6, \
1.044384689243282*^-6}, 
      {-4.030999005071763, 0.11981954487259, 0.01733056483167502, \
-0.001158156484122827, 
       0.00008074312635173029, -5.20583091567802*^-6, 7.956091702418741*^-7}, \

      {-3.952475224251121, 0.1395697381295249, 0.01539195893139493, \
-0.0009845093210085519, 
       0.00006584205243282794, -3.32012246555342*^-6, 6.853159337046515*^-7}, \

      {-3.862684190756981, 0.1571524596927341, 0.01373486877910464, \
-0.0008458707886029987, 
       0.00005292157646953732, -2.717702984606006*^-6, 4.77622624694981*^-7}, \

      {-3.762840191839173, 0.1728740715812062, 0.01230547895112873, \
-0.0007329639094343789, 
       0.00004313134469130801, -2.174486953647753*^-6, \
3.464778553861074*^-7}, 
      {-3.653990544832822, 0.186983635441198, 0.01106211775331628, \
-0.0006402695924964055, 
       0.00003545443989916019, -1.769433173096024*^-6, \
2.525548635308183*^-7}, 
      {-3.537045998808625, 0.1996855333824895, 0.00997212043313665, \
-0.0005634893823564254, 
       0.00002940435516254819, -1.444925839280817*^-6, \
1.873186410422256*^-7}, 
      {-3.412804820462515, 0.2111489392640954, 0.009009587091692949, \
-0.0004994137319164026, 
       0.00002457255701597945, -1.188313735158228*^-6, \
1.406896195144427*^-7}, 
      {-3.226383882473431, 0.2254888826311526, 0.00782863750180473, \
-0.0004254398060232111, 
       0.00001981389856827268, -7.142811741814924*^-7, \
1.214518769253567*^-7}, 
      {-3.028544487881109, 0.2379623183701307, 0.006815352833850272, \
-0.0003674996173379565, 
       0.00001563490798245744, -5.863751335613544*^-7, \
8.286494890143568*^-8}, 
      {-2.820765880597218, 0.2488246391892772, 0.005935350116307164, \
-0.0003211412997870433, 
       0.00001249454221138065, -4.723074298726049*^-7, \
5.863154615276862*^-8}, 
      {-2.604332546187619, 0.2582797876857357, 0.005162225904876009, \
-0.0002838186723171345, 
       0.00001004906503633052, -3.872893960337359*^-7, \
4.182173483586232*^-8}, 
      {-2.380372588494504, 0.2664918551486892, 0.004475380456230466, \
-0.0002535926923432743, 
       8.12709168441536*^-6, -3.191385207024893*^-7, 3.041794787821806*^-8}, 
      {-2.149888011885292, 0.2735936165267895, 0.003858489366800093, \
-0.0002290448425358619, 
       6.587495878600813*^-6, -2.659371594526436*^-7, 2.240760894816552*^-8}, \

      {-1.862461605884, 0.2808796352513029, 0.003184570099944694, \
-0.0002052375870998381, 
       5.184644537276815*^-6, -1.904353620789624*^-7, 1.830161659349033*^-8}, \

      {-1.568183649848103, 0.2868392273604855, 0.0025757030229676, \
-0.0001869905842506842, 
       3.94998773499864*^-6, -1.664155042054195*^-7, 1.252617396656006*^-8}, 
      {-1.268364479171137, 0.2915909380503116, 0.002016730577406875, \
-0.0001730929569953884, 
       2.962636482403427*^-6, -1.425953219607782*^-7, 9.048063202716138*^-9}, \

      {-0.9642069570781426, 0.2952248555778643, 0.001495168943728167, 
       -0.0001628678678871044, 2.124381467147605*^-6, -1.268868848768186*^-7, \

       6.439365965054157*^-9}, {-0.6568332104269488, 0.297807265272211, 
       0.001000424284390819, -0.0001558062983484425, 1.393260971122391*^-6, 
       -1.16189498447824*^-7, 4.551785366632448*^-9}, 
      {-0.347307558153906, 0.2993839269833109, 0.0005231938290646777, 
       -0.0001515786910488678, 7.28995375392316*^-7, -1.103088648901964*^-7, 
       3.109373981185027*^-9}, {-0.02059842375429779, 0.2999868283697566, 
       0.000030899023275109, -0.0001499710125128607, 7.391649158067099*^-8, 
       -1.071809930044063*^-7, 2.056958128795419*^-9}, 
      {0.3061841755353036, 0.2995190148961492, -0.0004608033375064859, 
       -0.0001512178764561559, -5.856624301124836*^-7, \
-1.113744729117887*^-7, 
       9.776572755515083*^-10}, {0.6318703474828602, 0.2979716041301453, 
       -0.0009612776157810278, -0.0001553653182568013, \
-1.270449605527533*^-6, 
       -1.199716342928165*^-7, 6.070100997510405*^-11}, 
      {0.9552692542430992, 0.2953149127710727, -0.001480329340033508, 
       -0.0001626278763228281, -2.019707928984938*^-6, \
-1.347671599904589*^-7, 
       -8.686302949503323*^-10}, {1.275145740364751, 0.2914969434348858, 
       -0.002028718216425412, -0.0001733826790634804, -2.874541410229806*^-6, \

       -1.569598944139296*^-7, -1.878720632347947*^-9}, 
      {1.590194644440884, 0.2864406655210826, -0.002618766061970887, \
-0.000188214270772915, 
       -3.887728767417422*^-6, -1.888130086423514*^-7}, 
      {1.719200717176539, 0.2839546473654226, -0.002879240353795494, \
-0.0001958166574839798, 
       -4.424660783607618*^-6, -2.131158763880072*^-7}, 
      {1.847028317525678, 0.2812281770861862, -0.003150573903561786, \
-0.0002042535125569289, 
       -4.903989201920629*^-6, -2.125318302994974*^-7}, 
      {1.973566396290273, 0.2782508527024917, -0.003434079133738193, \
-0.0002137396999084332, 
       -5.492527310550173*^-6, -2.363847890595994*^-7}, 
      {2.098698902942336, 0.2750110202555538, -0.003731200089212459, \
-0.0002243383930475836, 
       -6.134349446904118*^-6, -2.600917420966997*^-7}, 
      {2.222304210956997, 0.2714956529899461, -0.004043533034278243, \
-0.0002361746201726475, 
       -6.84656549557008*^-6, -2.875084871034672*^-7}, 
      {2.509301560506504, 0.261941825759274, -0.004858050290339753, \
-0.0002697763886628037, 
       -8.601538101173828*^-6, -3.069398054247487*^-7}, 
      {2.785036212262984, 0.250506852060828, -0.005798055693450944, \
-0.0003137987862858671, 
       -0.0000111321040952868, -3.887737657399154*^-7}, 
      {3.047326221344314, 0.2368813319538955, -0.006902156833649126, \
-0.0003716344040980113, 
       -0.00001460502854180153, -5.173156427477049*^-7}, 
      {3.293606948170922, 0.2206586069509337, -0.008223003419873126, \
-0.0004484245623783037, 
       -0.00001941025824834546, -7.054705562777754*^-7}, 
      {3.52080802589895, 0.2012976529185134, -0.009834256852354323, \
-0.0005520223385483438, 
       -0.00002623157304107136, -9.870130347314148*^-7}, 
      {3.679602151355378, 0.1839029064921489, -0.01132896802415918, \
-0.0006588555668543106, 
       -0.00003483942700754272, -1.538650217255184*^-6}, 
      {3.822991373227639, 0.1638106375775221, -0.01312173171692769, \
-0.0007947998557900653, 
       -0.00004472925853600024, -1.970123258224091*^-6}, 
      {3.948533220669749, 0.1404586238892668, -0.0153043024567483, \
-0.0009746013399501118, 
       -0.00005916063289635405, -2.737282339665443*^-6}, 
      {4.031777572447578, 0.1196290366380755, -0.01734699562780972, \
-0.001158126231118131, 
       -0.00007691857747496719, -4.147382565268788*^-6}, 
      {4.100824681254904, 0.09594636035422936, -0.01978392282036081, \
-0.001388201114516158, 
       -0.00009721796338586393, -5.250114301798117*^-6}, 
      {4.153676526390869, 0.06883904154596772, -0.02272694928224844, \
-0.00168650971544157, 
       -0.0001260936343277482, -7.143486736710419*^-6}, 
      {4.182352468704461, 0.04459084520469134, -0.02550122298961699, \
-0.001989574400469278, 
       -0.0001608508481096105, -0.00001047400511555826}, 
      {4.198073001219317, 0.01730129047162059, -0.02878502399438811, \
-0.002364488583731567, 
       -0.0002004161127185835, -0.00001309407114050281}, 
      {4.199167199914409, -0.01360665057527977, -0.0327117971499938, \
-0.002841579989458401, 
       -0.0002551565557119169, -0.00001741766714817734}, 
      {4.188078161130304, -0.04160724136470607, -0.03645948828688974, \
-0.003327436473309326, 
       -0.000319729377285531, -0.00002463824661516657}, 
      {4.164988247240063, -0.07290219204328042, -0.04086083286392197, \
-0.003921307304897954, 
       -0.0003931821973957993, -0.00003043913544356482}, 
      {4.128446726495304, -0.1080826062285857, -0.0460738781424478, \
-0.004663722143316249, 
       -0.0004917876850318253, -0.00003954446947445713}, 
      {4.076734493947515, -0.1478864608169882, -0.05230470805108495, \
-0.005598541397674655, 
       -0.0006206597057560338, -0.00005156356114247133}, 
      {4.022906690841724, -0.1837815018162546, -0.0582195608989168, \
-0.006537690202810648, 
       -0.0007692681094240944, -0.00007147745260569692}, 
      {3.95674549182641, -0.2238407693797599, -0.06514161189013765, \
-0.00767200134791258, 
       -0.0009341422102066749, -0.0000864359456415738}, 
      {3.87678287035863, -0.2687896026177992, -0.07329590710678854, \
-0.00906628833970239, 
       -0.001148228255477591, -0.0001090473974723426}, 
      {3.781288879134894, -0.3195178138751104, -0.08296437954550393, \
-0.0107821939904451, 
       -0.001415191257698621, -0.0001366122852072013}, 
      {3.689366681020275, -0.3664903152269421, -0.09232741235472191, \
-0.01250461390800958, 
       -0.001705383285630238, -0.0001764587144684277}, 
      {3.584131921280862, -0.4188796692885778, -0.1031943462194, \
-0.01453161309219579, 
       -0.002012886285749437, -0.0002028336093085628}, 
      {3.464016859489056, -0.4775639248219542, -0.1158362542800408, \
-0.01691996057211424, 
       -0.002368302530352172, -0.0002338779932344941}, 
      {3.356810800953549, -0.5293388432083013, -0.127338118789873, \
-0.01909142897940284, 
       -0.002676851546976299, -0.0002617197114418762}, 
      {3.238026724696523, -0.5863209984165999, -0.1402944283416902, \
-0.02147936118026087, 
       -0.002939299967548655, -0.0002540087490500948}, 
      {3.106487064450911, -0.6491582333620305, -0.1548311599538908, \
-0.02403859433326652, 
       -0.003130923539280436, -0.0002169200644083593}, 
      {2.992400236411906, -0.7035307257075237, -0.1675114197163133, \
-0.02608268500348733, 
       -0.003101752565289892, -0.00009117563693514105}, 
      {2.868766039043844, -0.7623557732219106, -0.181206495277823, \
-0.02803831141525586, 
       -0.002913217639597339, 0.00006612295878468207}, 
      {2.734804975891858, -0.8259614481933265, -0.1958134695794343, \
-0.02968253919005118, 
       -0.002366813076990955, 0.0003568172936464809}, 
      {2.589686185835061, -0.8946201631935329, -0.211096367639208, \
-0.03069690166351211, 
       -0.001287144741442841, 0.0008181340902427136}, 
      {2.432541345413119, -0.9684924554229644, -0.2266144560525508, \
-0.0305913754583289, 
       0.0006013510471307832, 0.001528039201628794}, 
      {2.300593418274301, -1.029933214468378, -0.238456380190063, \
-0.02916479110295439, 
       0.003349599103632743, 0.002844659840819287}, 
      {2.160327609863259, -1.094405143526292, -0.2494639858884594, \
-0.02628322633333326, 
       0.006499189600599896, 0.003806817998923157}, 
      {2.011361963853401, -1.161596617371949, -0.2589066960280602, \
-0.0212404419240378, 
       0.01096410055870342, 0.005283698266105647}, 
      {1.853369848186211, -1.230972187385779, -0.2658187572311084, \
-0.01343769113277021, 
       0.01670022341247681, 0.006984545929630753}, 
      {1.686113651479639, -1.301707960489256, -0.2689799224426696, \
-0.002218160519983441, 
       0.02374417816589482, 0.008825101518650388}, 
      {1.548731181232636, -1.357247573041723, -0.2679020209871991, \
0.00940741679982954, 
       0.03059703966515198, 0.01104428213809055}, 
      {1.405634655823148, -1.412169206817653, -0.2628690648801824, \
0.02343749495153097, 
       0.03684135179355271, 0.01156495992438169}, 
      {1.25693271860826, -1.465574695497006, -0.2530977930358463, \
0.04000447001999595, 
       0.04309152035034375, 0.01183096626898938}, 
      {1.102835261222808, -1.516408410243351, -0.2378658845442576, \
0.0587187358630461, 
       0.04825307152958544, 0.01091047988471224}, 
      {0.9436684723900675, -1.563480107555891, -0.2166112212555796, \
0.07888114524894074, 
       0.05138970183484104, 0.008490656552075265}, 
      {0.7798866532779219, -1.605509763597865, -0.1890477929492217, \
0.09939619993963519, 
       0.05146698135166248, 0.00432011411501834}, 
      {0.6120781399897387, -1.641196767620815, -0.1552817342341247, \
0.1188116340218128, 
       0.04757830620486855, -0.00160313719289467}, 
      {0.4409629081679529, -1.669310874438585, -0.1159004793092341, \
0.135459993317429, 
       0.03923768806422279, -0.008873049254215754}, 
      {0.2978158012949262, -1.68605361171892, -0.07992819011372855, \
0.1457015152976, 
       0.02745844592972954, -0.01824601554948561}, 
      {0.1535081539561895, -1.696456674947979, -0.04173386360709466, \
0.1524863814282621, 
       0.01566014216520664, -0.02295484575509375}, 
      {0.00859453968138199, -1.700226365861708, -0.002347602463083946, \
0.15490314333977, 
       0.001853547402092851, -0.02766369724674848}, 
      {-0.1069587338581305, -1.698401421541356, 0.02914900940682379, \
0.1535764582466887, 
       -0.009764953825055494, -0.03092149338094688}, 
      {-0.2222430168665769, -1.692323572776465, 0.06011355814448043, \
0.1495775501208558, 
       -0.01993183627166685, -0.03041520647041477}, 
      {-0.336972416725825, -1.682102836145618, 0.08999732309536222, \
0.1429736928808584, 
       -0.02937921289481302, -0.0291037424380253}, 
      {-0.4508710616720182, -1.667920607708203, 0.1183050161713227, \
0.1341193448605914, 
       -0.03734566399110936, -0.02626971817298632}, 
      {-0.5636775876221324, -1.650020746248091, 0.1446160987477571, \
0.1234211841277304, 
       -0.04358008294826085, -0.02230506126357257, 0.009719351466954295}, 
      {-0.7004532191201483, -1.623370740654491, 0.1737354682969418, \
0.1085186612261423, 
       -0.04725070994856582, -0.007933997084054594, 0.01729899808617196}, 
      {-0.8348078178108716, -1.592179166592888, 0.1989318813450895, \
0.09245552157109148, 
       -0.04842030013562734, 0.00142199413181048, 0.0178450097924131}, 
      {-0.9663902314223921, -1.557119976737334, 0.2200091163294662, \
0.07583762938446136, 
       -0.04907345961015779, 0.003974617587388387, 0.01274387114795476}, 
      {-1.09490605620407, -1.518884282145483, 0.2369671538117881, \
0.05963670146004994, 
       -0.04703039102961791, 0.008410376743174083, 0.01118583564039184}, 
      {-1.220118372193815, -1.478148845586983, 0.2499677751932202, \
0.04435120735228193, 
       -0.04354375830175825, 0.01155976698727734, 0.009224556572131456}, 
      {-1.341845350624067, -1.435552704971225, 0.2592932992552991, \
0.03037082966477086, 
       -0.03918580569865634, 0.01323571045473672, 0.006872052630096301}, 
      {-1.501301551731615, -1.375782576139126, 0.2667281399284577, \
0.01397454172913804, 
       -0.03196029123648514, 0.01548364127731459, 0.005444453638994982}, 
      {-1.653905592120432, -1.314922185333134, 0.2690772341788851, \
0.0005320277113557951, 
       -0.02550054114631226, 0.01409224826575205, 0.002448880495215892}, 
      {-1.799594710622031, -1.254007726875726, 0.2673709228804413, \
-0.009952769809746019, 
       -0.01950289933890086, 0.01203011221190726, 0.0002573071710215328}, 
      {-1.938410734528628, -1.193848614656663, 0.2625667962479788, \
-0.0177853988244406, 
       -0.01429460890847003, 0.009690243406309335, -0.001220874337290213}, 
      {-2.070475444634375, -1.135050194601853, 0.2555015469458937, \
-0.02335466296565725, 
       -0.009944132621926476, 0.007484659152859317, -0.002028857453743682}, 
      {-2.195969115719297, -1.078043616596408, 0.2468733494127671, \
-0.02707053487411177, 
       -0.006423751306024532, 0.005600786828541494, -0.002324561034230447}, 
      {-2.330651715023785, -1.015905729246309, 0.2358984367689151, \
-0.02953327389417943, 
       -0.00335646775609705, 0.003861256541456969, -0.002296034146259237}, 
      {-2.457525183154825, -0.956688939581133, 0.2242597476955417, \
-0.03060100310118331, 
       -0.001120678353428142, 0.002517515192195063, -0.002073849097450261}, 
      {-2.576973651734335, -0.9005019686517965, 0.2124146953334569, \
-0.03066945677680126, 
       0.0004732830098336319, 0.001568444485955568, -0.001736048570814996}, 
      {-2.689388440796654, -0.8473540814095898, 0.2006842422842364, \
-0.03005208469696664, 
       0.001562825260253419, 0.0009098325536140439, -0.001382873735605345}, 
      {-2.79515736986823, -0.797186039496875, 0.1892846023840166, \
-0.02898492644914902, 
       0.00227016380903711, 0.000462327924589134, -0.001061588450847496}, 
      {-2.894657524298719, -0.7498935244645937, 0.1783538181056905, \
-0.02764177536121958, 
       0.002694157763361979, 0.0001626260267205313, -0.0007922367013877141}, 
      {-3.014688623616773, -0.6927497826958185, 0.1650329703903737, \
-0.02571337292194024, 
       0.002841227140736658, -0.0002775607003341802, -0.0006516041183057287}, \

      {-3.125565920048055, -0.639876877408041, 0.1527089307490415, \
-0.02367983135116684, 
       0.002924682156060442, -0.0003256700432316743, -0.0004102266903839257}, \

      {-3.227972703861205, -0.5909398816460644, 0.1413899818313346, \
-0.02168621456778556, 
       0.002848879737712004, -0.0003587414947468781, -0.0002593786747929608}, \

      {-3.3225366368389, -0.5456089247151137, 0.1310419946655227, \
-0.0197900123170401, 
       0.002699603914416779, -0.0003530118522449044, -0.0001533329085167602}, \

      {-3.409831673583012, -0.503569779539518, 0.121607604123088, \
-0.01802420978847764, 
       0.002510129892437293, -0.0003330509065441273, \
-0.00008400686858625222}, 
      {-3.490381165059254, -0.464529438464351, 0.113018314712741, \
-0.01640214573785912, 
       0.002304105395014828, -0.0003076680476477025, \
-0.00004024017100522303}, 
      {-3.59076457043769, -0.415365845486406, 0.1024791239062843, \
-0.01441937785967536, 
       0.001994836605530998, -0.0003076079050276864, \
-0.00002412654625246756}, 
      {-3.680446771882604, -0.3707188411507067, 0.09321300273622247, \
-0.01268266953034323, 
       0.001748192677912062, -0.0002479739557247041, 2.931935845064381*^-6}, 
      {-3.760395905178818, -0.3300457796733422, 0.08505229667678541, \
-0.0111808322342231, 
       0.001518620588925021, -0.0002054529772874244, 0.00001417154407232978}, \

      {-3.831464556026412, -0.292876555852942, 0.07784770167097612, \
-0.009883730440196082, 
       0.001315940696124767, -0.0001703916606468707, 0.00001873774444099621}, \

      {-3.894405409441865, -0.2588048868947212, 0.07146903295587597, \
-0.008763665360604091, 
       0.001139613389628653, -0.0001420264357081817, 0.00001952279534482811}, \

      {-3.949884833403585, -0.2274797898222587, 0.06580407885525203, \
-0.007795519969258332, 
       0.0009873662568563334, -0.0001192842345829177, \
0.00001835239793059698}, 
      {-4.013493584304105, -0.1893234179563287, 0.05917264156094475, \
-0.00669762425384019, 
       0.0008209945385447024, -0.00009109534065856145, \
0.00001715846724585162}, 
      {-4.066027179678089, -0.1549327888392722, 0.05345770038360765, \
-0.005788974431098252, 
       0.0006829201913929399, -0.00007245233463606188, \
0.00001436047891974082}, 
      {-4.108556273048988, -0.1237966057651823, 0.04850419453394615, \
-0.005032138642190716, 
       0.0005708036529388488, -0.00005816625031312334, \
0.00001173159111450683}, 
      {-4.142008765047641, -0.09548899403402597, 0.04418665826263912, \
-0.004398355800638961, 
       0.0004793594136025109, -0.00004728913349624628, \
9.410879835919191*^-6}, 
      {-4.167193290362395, -0.06965330291954775, 0.04040326599533289, \
-0.003864506578721408, 
       0.0004047814398823964, -0.00003871018420282729, 7.51730175457748*^-6}, \

      {-4.184818352852124, -0.04598916926299106, 0.03707100583528232, \
-0.003412357600368704, 
       0.0003435968234380413, -0.00003195923238499129, \
5.982531512189572*^-6}, 
      {-4.197793011794834, -0.01673492033958663, 0.03312903344071973, \
-0.0028989848075053, 
       0.0002814019044572447, -0.00002155076476827567, \
5.252087552392177*^-6}, 
      {-4.199209470629186, 0.009478342405531913, 0.02976445616968854, \
-0.002485066054622991, 
       0.0002283765303461728, -0.00001734277981675641, \
3.823403716122895*^-6}, 
      {-4.190242861991732, 0.03308597126363379, 0.02687016354225558, \
-0.002146048809494704, 
       0.0001874181340838683, -0.00001382964292657149, \
2.855203723812378*^-6}, 
      {-4.171903946960092, 0.05444413870255175, 0.02436233463434399, \
-0.001866244475187594, 
       0.0001549960187886236, -0.0000112070328621764, 2.132037815513617*^-6}, \

      {-4.145068301196802, 0.07384672454691019, 0.02217474982292821, \
-0.00163337127254611, 
       0.0001292427802781292, -9.128023651284317*^-6, 1.611307646877472*^-6}, \

      {-4.110499563327805, 0.09153818684461764, 0.02025460510089744, \
-0.001438127637438115, 
       0.0001085640170821118, -7.491878000069389*^-6, 1.228129923353623*^-6}, \

      {-4.05376779743783, 0.1127365879859242, 0.01804611063488246, \
-0.001223785860916568, 
       0.00008869669533067231, -4.880102737946071*^-6, \
1.050981215265953*^-6}, 
      {-3.985929348943403, 0.131669915837533, 0.01615693475309358, \
-0.001051963553920003, 
       0.00007153357729487435, -4.007398924347831*^-6, \
7.355438215578993*^-7}, 
      {-3.908148137896271, 0.1486573343836378, 0.014526899422336, \
-0.0009115751479213535, 
       0.00005850207049206894, -3.204534886558251*^-6, \
5.378821552519537*^-7}, 
      {-3.821428333120326, 0.163959151470326, 0.01310923535816925, \
-0.0007959787356617154, 
       0.00004824299176629502, -2.608134951952674*^-6, \
3.944548995568535*^-7}, 
      {-3.72664302916516, 0.1777896238487302, 0.0118671707885261, \
-0.0006999517379273063, 
       0.00004013406167921629, -2.130593791645412*^-6, \
2.941040816898255*^-7}, 
      {-3.624557041320632, 0.1903266194613874, 0.01077147735875866, \
-0.0006195803781930358, 
       0.00003364324483029262, -1.752694878332808*^-6, \
2.219101882651082*^-7}, 
      {-3.469932813929142, 0.2060487508926102, 0.009434158556806098, \
-0.0005267943950035608, 
       0.00002723323157458691, -1.066998862009702*^-6, \
1.917898198456191*^-7}, 
      {-3.303824618969922, 0.2198420278222464, 0.008289542866481889, \
-0.0004536683097560162, 
       0.00002162522621767483, -8.73164264777252*^-7, 1.316514700673368*^-7}, \

      {-3.127627105521437, 0.2319753705982671, 0.007299024250715211, \
-0.0003947909572829483, 
       0.00001740501536143174, -7.009952583177582*^-7, \
9.371552460709045*^-8}, 
      {-2.942546997271821, 0.2426648956489252, 0.006432933314233668, \
-0.0003470290529354679, 
       0.00001411913421664623, -5.72309305366433*^-7, 6.723509739335797*^-8}, \

      {-2.749639089603672, 0.2520858152485883, 0.005668136831225838, \
-0.0003079844303378464, 
       0.00001154114738279863, -4.69016945659777*^-7, 4.917507047933887*^-8}, \

      {-2.549834626385329, 0.2603812438251428, 0.0049863463640344, \
-0.0002758897579468243, 
       9.48477984038584*^-6, -3.878135316574036*^-7, 3.644991158183991*^-8}, 
      {-2.271744583463212, 0.2699646822855044, 0.004175117783130773, \
-0.0002411497935624411, 
       7.5171418453034*^-6, -2.462274959780172*^-7, 3.087540372444537*^-8}, 
      {-1.984463739484644, 0.2779523758002482, 0.003459752444050152, \
-0.0002145137302149091, 
       5.77173976994235*^-6, -2.096863303811778*^-7, 2.0849411321851*^-8}, 
      {-1.689567605920182, 0.2845215865633923, 0.002818579145541563, \
-0.000193897114667656, 
       4.429209448504924*^-6, -1.74605063933837*^-7, 1.474096026339627*^-8}, 
      {-1.388468129508924, 0.2898091997161635, 0.002234447928569943, \
-0.000178154064074536, 
       3.340301331502121*^-6, -1.50064337983947*^-7, 1.040546770865422*^-8}, 
      {-1.082451264333607, 0.293919711354098, 0.001693429583130022, \
-0.0001664201430090243, 
       2.437608406737254*^-6, -1.316826502819595*^-7, 7.412431899636853*^-9}, \

      {-1.043881756038607, 0.2943552540968721, 0.001628180607477966, \
-0.0001653284269372583, 
       1.914052362965552*^-6, -6.999498294552858*^-7, \
-2.844672534633187*^-7}}][t], 
  z[t] -> InterpolatingFunction[{{0., 100.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003331483023263849, 0.006662966046527698, 0.1760831648387825, 
       0.3455033636310373, 0.5149235624232922, 1.113331746264325, \
1.711739930105358, 
       2.310148113946391, 2.908556297787424, 3.549226293889243, \
4.189896289991062, 
       4.830566286092881, 5.471236282194699, 6.430795500662957, \
7.390354719131214, 
       8.34991393759947, 9.309473156067728, 10.26903237453598, \
11.41748921768868, 
       12.56594606084139, 13.71440290399409, 14.86285974714679, \
15.76992300897745, 
       16.67698627080811, 17.40746358480685, 18.13794089880559, \
18.7397959150954, 
       19.3416509313852, 19.94350594767501, 20.42463542003453, \
20.90576489239406, 
       21.38689436475359, 21.77943140165771, 22.17196843856184, \
22.49018228099118, 
       22.80839612342052, 23.12660996584985, 23.35745430632501, \
23.58829864680017, 
       23.81914298727534, 24.0499873277505, 24.22894782904176, \
24.40790833033302, 
       24.58686883162428, 24.73263871122103, 24.87840859081777, \
25.02417847041451, 
       25.16994835001125, 25.31571822960799, 25.43261488145184, \
25.54951153329568, 
       25.66640818513952, 25.75972586508166, 25.8530435450238, \
25.94636122496595, 
       26.03967890490809, 26.13299658485023, 26.22631426479237, \
26.32916699997962, 
       26.43201973516686, 26.5348724703541, 26.63772520554135, \
26.7405779407286, 
       26.84343067591584, 26.95721769562641, 27.07100471533697, \
27.18479173504754, 
       27.29857875475811, 27.41236577446868, 27.52615279417925, \
27.66074382830965, 
       27.79533486244006, 27.92992589657046, 28.06451693070087, \
28.19910796483128, 
       28.33369899896168, 28.46829003309208, 28.63486560498111, \
28.80144117687013, 
       28.96801674875915, 29.13459232064816, 29.30116789253718, \
29.4677434644262, 
       29.71773345304378, 29.96772344166136, 30.21771343027894, \
30.46770341889652, 
       30.71769340751409, 30.96768339613167, 31.3010544995537, \
31.63442560297573, 
       31.96779670639775, 32.30116780981978, 32.63453891324182, \
32.96791001666385, 
       33.4114262068452, 33.85494239702655, 34.29845858720789, \
34.74197477738924, 
       35.18549096757059, 35.62900715775194, 36.23354495905478, \
36.83808276035762, 
       37.44262056166046, 38.0471583629633, 38.65169616426614, \
39.25623396556898, 
       40.10946796733268, 40.96270196909638, 41.81593597086009, \
42.66916997262379, 
       43.52240397438749, 44.37563797615119, 45.41195670648726, \
46.44827543682334, 
       47.48459416715941, 48.52091289749548, 49.55723162783154, \
50.59355035816762, 
       51.68339887256983, 52.77324738697206, 53.86309590137428, \
54.9529444157765, 
       56.04279293017872, 57.13264144458094, 57.58494946950075, \
58.03725749442055, 
       58.48956551934037, 58.94187354426017, 59.39418156917998, \
60.46962757399835, 
       61.54507357881672, 62.62051958363509, 63.69596558845345, \
64.77141159327182, 
       65.59501642075933, 66.41862124824685, 67.24222607573437, \
67.88129038764838, 
       68.52035469956239, 69.1594190114764, 69.6629816849138, \
70.1665443583512, 
       70.6701070317886, 71.07547552469601, 71.48084401760343, \
71.88621251051085, 
       72.29158100341826, 72.61679430492302, 72.94200760642778, \
73.26722090793253, 
       73.5924342094373, 73.86075147913136, 74.12906874882543, \
74.39738601851949, 
       74.61050073963264, 74.82361546074578, 75.03673018185892, \
75.20550076096502, 
       75.37427134007112, 75.54304191917721, 75.71181249828331, \
75.8805830773894, 
       76.01266973050996, 76.1447563836305, 76.27684303675106, \
76.40892968987161, 
       76.54101634299216, 76.64435076816506, 76.74768519333794, \
76.85101961851083, 
       76.95435404368372, 77.05768846885661, 77.1610228940295, \
77.26435731920239, 
       77.36769174437528, 77.45298990779566, 77.53828807121606, \
77.62358623463645, 
       77.69157185629193, 77.75955747794741, 77.82754309960289, \
77.89552872125837, 
       77.96351434291385, 78.04706179169975, 78.13060924048564, \
78.21415668927153, 
       78.29770413805743, 78.38125158684332, 78.46479903562921, \
78.57822588435457, 
       78.69165273307991, 78.80507958180527, 78.91850643053063, \
79.03193327925598, 
       79.14536012798134, 79.27402872242009, 79.40269731685884, \
79.53136591129759, 
       79.66003450573634, 79.78870310017509, 79.91737169461384, \
80.08386115675204, 
       80.25035061889024, 80.41684008102844, 80.58332954316664, \
80.74981900530485, 
       80.91630846744305, 81.1446878201505, 81.37306717285797, \
81.60144652556544, 
       81.82982587827289, 82.05820523098037, 82.28658458368782, \
82.59230296432988, 
       82.89802134497195, 83.20373972561402, 83.50945810625608, \
83.81517648689813, 
       84.1208948675402, 84.53825979449733, 84.95562472145447, \
85.37298964841161, 
       85.79035457536873, 86.20771950232587, 86.62508442928301, \
87.17941917293771, 
       87.73375391659241, 88.28808866024713, 88.84242340390184, \
89.39675814755654, 
       89.95109289121124, 90.73059797678343, 91.5101030623556, \
92.28960814792779, 
       93.06911323349998, 93.84861831907215, 94.62812340464434, \
95.67627335203383, 
       96.72442329942333, 97.77257324681281, 98.82072319420231, \
99.86887314159179, 100.}}, 
     {{0., 0.}, {0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., \
0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., \
0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., \
0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., \
0., 0., 0., 0., 0.}}
][t]}\
\>", "\<\
{x[t] -> InterpolatingFunction[{{0., 100.}}, <>][t], 
 
  y[t] -> InterpolatingFunction[{{0., 100.}}, <>][t], 
 
  z[t] -> InterpolatingFunction[{{0., 100.}}, <>][t]}\
\>"], "Output"]
}, Open  ]],

Cell["\<\
We plot the functions x[t], y[t] and z[t] to determine the time of a complete \
revolution of the bodies.\
\>", "Text"],

Cell[CellGroupData[{

Cell["xplot = Plot[Evaluate[x[t]/. sol1], {t,0,100}]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.102997 0.0500322 [
[.21429 .0905 -6 -9 ]
[.21429 .0905 6 0 ]
[.40476 .0905 -6 -9 ]
[.40476 .0905 6 0 ]
[.59524 .0905 -6 -9 ]
[.59524 .0905 6 0 ]
[.78571 .0905 -6 -9 ]
[.78571 .0905 6 0 ]
[.97619 .0905 -9 -9 ]
[.97619 .0905 9 0 ]
[.01131 .00293 -12 -4.5 ]
[.01131 .00293 0 4.5 ]
[.01131 .20306 -6 -4.5 ]
[.01131 .20306 0 4.5 ]
[.01131 .30313 -6 -4.5 ]
[.01131 .30313 0 4.5 ]
[.01131 .40319 -6 -4.5 ]
[.01131 .40319 0 4.5 ]
[.01131 .50325 -6 -4.5 ]
[.01131 .50325 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .103 m
.21429 .10925 L
s
[(20)] .21429 .0905 0 1 Mshowa
.40476 .103 m
.40476 .10925 L
s
[(40)] .40476 .0905 0 1 Mshowa
.59524 .103 m
.59524 .10925 L
s
[(60)] .59524 .0905 0 1 Mshowa
.78571 .103 m
.78571 .10925 L
s
[(80)] .78571 .0905 0 1 Mshowa
.97619 .103 m
.97619 .10925 L
s
[(100)] .97619 .0905 0 1 Mshowa
.125 Mabswid
.07143 .103 m
.07143 .10675 L
s
.11905 .103 m
.11905 .10675 L
s
.16667 .103 m
.16667 .10675 L
s
.2619 .103 m
.2619 .10675 L
s
.30952 .103 m
.30952 .10675 L
s
.35714 .103 m
.35714 .10675 L
s
.45238 .103 m
.45238 .10675 L
s
.5 .103 m
.5 .10675 L
s
.54762 .103 m
.54762 .10675 L
s
.64286 .103 m
.64286 .10675 L
s
.69048 .103 m
.69048 .10675 L
s
.7381 .103 m
.7381 .10675 L
s
.83333 .103 m
.83333 .10675 L
s
.88095 .103 m
.88095 .10675 L
s
.92857 .103 m
.92857 .10675 L
s
.25 Mabswid
0 .103 m
1 .103 L
s
.02381 .00293 m
.03006 .00293 L
s
[(-2)] .01131 .00293 1 0 Mshowa
.02381 .20306 m
.03006 .20306 L
s
[(2)] .01131 .20306 1 0 Mshowa
.02381 .30313 m
.03006 .30313 L
s
[(4)] .01131 .30313 1 0 Mshowa
.02381 .40319 m
.03006 .40319 L
s
[(6)] .01131 .40319 1 0 Mshowa
.02381 .50325 m
.03006 .50325 L
s
[(8)] .01131 .50325 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .02795 m
.02756 .02795 L
s
.02381 .05296 m
.02756 .05296 L
s
.02381 .07798 m
.02756 .07798 L
s
.02381 .12801 m
.02756 .12801 L
s
.02381 .15303 m
.02756 .15303 L
s
.02381 .17805 m
.02756 .17805 L
s
.02381 .22808 m
.02756 .22808 L
s
.02381 .25309 m
.02756 .25309 L
s
.02381 .27811 m
.02756 .27811 L
s
.02381 .32814 m
.02756 .32814 L
s
.02381 .35316 m
.02756 .35316 L
s
.02381 .37817 m
.02756 .37817 L
s
.02381 .42821 m
.02756 .42821 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47824 m
.02756 .47824 L
s
.02381 .52827 m
.02756 .52827 L
s
.02381 .55329 m
.02756 .55329 L
s
.02381 .5783 m
.02756 .5783 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60328 L
.02729 .60322 L
.02846 .60314 L
.03053 .60294 L
.03279 .60265 L
.03527 .60223 L
.0379 .60168 L
.04262 .60039 L
.04749 .59867 L
.05205 .5967 L
.06244 .59091 L
.07305 .58311 L
.08274 .57427 L
.10458 .54823 L
.12357 .51833 L
.14429 .4774 L
.16561 .42532 L
.18493 .36822 L
.22406 .21734 L
.24493 .11426 L
.25408 .06667 L
.25893 .04361 L
.2616 .03266 L
.26413 .02415 L
.26531 .02098 L
.26656 .01827 L
.26721 .01714 L
.26793 .01614 L
.2692 .01501 L
.27035 .01472 L
.27159 .01518 L
.27275 .01636 L
.27383 .01803 L
.27492 .0203 L
.27593 .02288 L
.27823 .03018 L
.28288 .04946 L
.30268 .15096 L
.34173 .32072 L
.36307 .39157 L
.38322 .44693 L
.42169 .52647 L
.44157 .55578 L
.45171 .56791 L
.46261 .57889 L
.47284 .5873 L
.48218 .59342 L
.48668 .59584 L
Mistroke
.49158 .59808 L
.49586 .59972 L
.5005 .60114 L
.50327 .60182 L
.50583 .60234 L
.50827 .60273 L
.50951 .60289 L
.51084 .60303 L
.51205 .60313 L
.51315 .60321 L
.51426 .60326 L
.51531 .6033 L
.51653 .60331 L
.51766 .60331 L
.51889 .60327 L
.52021 .60321 L
.5215 .60312 L
.52269 .60302 L
.52536 .60269 L
.52771 .60231 L
.53019 .6018 L
.53545 .6004 L
.54119 .59834 L
.5515 .59325 L
.56084 .58709 L
.58181 .56777 L
.60103 .54313 L
.62184 .50853 L
.64136 .46798 L
.66281 .4134 L
.70227 .28015 L
.72339 .18715 L
.74266 .08882 L
.75221 .04185 L
.75483 .03136 L
.75627 .02643 L
.75761 .02246 L
.75885 .01945 L
.75999 .01731 L
.76125 .01566 L
.76192 .01512 L
.76262 .0148 L
.7638 .01485 L
.76488 .01553 L
.76612 .01707 L
.76729 .01921 L
.76938 .02454 L
.77165 .03217 L
.78154 .0781 L
.82242 .27384 L
Mistroke
.84275 .34944 L
.86179 .40874 L
.89965 .4994 L
.91991 .53512 L
.93844 .56081 L
.95649 .57982 L
.96671 .58805 L
.97619 .59408 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`0027oo0`00ogoo5Woo0008Ool00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool000=o
o`<000=oo`03001oogoo00=oo`<00?moo`moo`002Goo00<007ooOol00goo00<007ooOol0ogoo3goo
0008Ool00`00Ool00004Ool00`00Oomoo`3oOol?Ool000Uoo`03001oogoo00=oo`03001oogoo0?mo
o`moo`003goo00<007ooOol0@7oo0`00QGoo0`00@goo000?Ool00`00Oomoo`10Ool00`00Ool00025
Ool00`00Ool00013Ool000moo`03001oogoo03moo`04001oogoo0024Ool01000Oomoo`00@goo000?
Ool20010Ool01@00Oomoogoo0000Pgoo00D007ooOomoo`00049oo`003goo00<007ooOol0?goo00D0
07ooOomoo`00089oo`03001oogoo009oo`03001oogoo041oo`003goo00<007ooOol0?goo00D007oo
Oomoo`00089oo`03001oogoo009oo`03001oogoo041oo`003goo00<007ooOol0?Woo00<007ooOol0
0Woo00<007ooOol0P7oo00<007ooOol00Woo00<007ooOol0@7oo000?Ool00`00Oomoo`0nOol00`00
Oomoo`03Ool00`00Oomoo`1oOol00`00Oomoo`03Ool00`00Oomoo`0oOol000moo`03001oogoo03io
o`03001oogoo00=oo`03001oogoo07moo`03001oogoo00=oo`03001oogoo03moo`003goo00<007oo
Ool0?Goo00<007ooOol017oo00<007ooOol0Ogoo00<007ooOol00goo00<007ooOol0?goo000?Ool2
000nOol00`00Oomoo`04Ool00`00Oomoo`1nOol00`00Oomoo`04Ool00`00Oomoo`0oOol000moo`03
001oogoo03eoo`03001oogoo00Aoo`03001oogoo07ioo`03001oogoo00Eoo`03001oogoo03ioo`00
3goo00<007ooOol0;Goo0`000goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol06goo0`00
0Woo00<007ooOol0:goo0P0017oo00<007ooOol09Woo00<007ooOol017oo0P000goo00<007ooOol0
:7oo1@000Woo00<007ooOol00Woo00<007ooOol00goo000?Ool00`00Oomoo`0]Ool00`00Oomoo`02
Ool00`00Ool00007Ool00`00Oomoo`06Ool00`00Oomoo`0LOol01P00Oomoo`00Ool002aoo`03001o
o`00009oo`03001oo`0002Moo`03001oogoo00=oo`03001oo`00009oo`03001oo`0002]oo`07001o
ogooOol007oo00000Woo00<007oo000017oo000?Ool00`00Oomoo`0^Ool01`00Oomoogoo001oo`00
00Moo`03001oogoo00Ioo`03001oogoo01Yoo`@00004Ool007oo000/Ool00`00Ool00002Ool00`00
Ool0000VOol00`00Oomoo`04Ool00`00Ool00002Ool00`00Ool0000[Ool01`00Oomoogoo001oo`00
009oo`03001oo`0000Aoo`003goo00<007ooOol0;Woo00L007ooOomoo`00Ool00007Ool00`00Oomo
o`06Ool00`00Oomoo`0JOol00`00Ool00002Ool00`00Ool0000/Ool20003Ool00`00Ool0000VOol0
0`00Oomoo`05Ool01`00Ool007oo001oo`0002]oo`07001oogooOol007oo00000Woo00<007oo0000
17oo000?Ool00`00Oomoo`0]Ool00`00Ool00002Ool00`00Ool00007Ool00`00Oomoo`07Ool00`00
Oomoo`0JOol20002Ool00`00Ool0000/Ool00`00Oomoo`02Ool00`00Ool0000VOol00`00Oomoo`04
Ool02000Ool00000Ool007oo000[Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`003goo
0P00;goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol06goo00D007oo
Oomoo`0002ioo`8000=oo`03001oogoo02Eoo`03001oogoo00Eoo`03001oo`00009oo`03001oogoo
02Uoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`003goo00<007ooOol0>goo00<007ooOol0
27oo00<007ooOol0NWoo00<007ooOol027oo00<007ooOol0?Goo000?Ool00`00Oomoo`0kOol00`00
Oomoo`08Ool00`00Oomoo`1jOol00`00Oomoo`08Ool00`00Oomoo`0mOol000moo`03001oogoo03]o
o`03001oogoo00Qoo`03001oogoo07Yoo`03001oogoo00Uoo`03001oogoo03aoo`003goo00<007oo
Ool0>goo00<007ooOol02Goo00<007ooOol0NGoo00<007ooOol02Goo00<007ooOol0?7oo000?Ool0
0`00Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`1iOol00`00Oomoo`09Ool00`00Oomoo`0lOol0
00moo`03001oogoo03]oo`03001oogoo00Uoo`03001oogoo07Qoo`03001oogoo00Yoo`03001oogoo
03aoo`0027ooo`005P000goo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool2
000;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool000moo`03
001oogoo035oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo01]oo`03001oogoo035oo`03
001oogoo02Eoo`03001oogoo00Yoo`8003=oo`03001oogoo00Moo`003goo00<007ooOol0>Woo00<0
07ooOol02goo00<007ooOol0Mgoo00<007ooOol02goo00<007ooOol0>goo000?Ool00`00Oomoo`0j
Ool00`00Oomoo`0;Ool00`00Oomoo`1gOol00`00Oomoo`0;Ool00`00Oomoo`0kOol000moo`03001o
ogoo03Yoo`03001oogoo00]oo`03001oogoo07Ioo`03001oogoo00aoo`03001oogoo03]oo`003goo
00<007ooOol0>Goo00<007ooOol03Goo00<007ooOol0MGoo00<007ooOol03Goo00<007ooOol0>Woo
000?Ool2000jOol00`00Oomoo`0=Ool00`00Oomoo`1eOol00`00Oomoo`0=Ool00`00Oomoo`0jOol0
00moo`03001oogoo03Uoo`03001oogoo00eoo`03001oogoo07Eoo`03001oogoo00eoo`03001oogoo
03Yoo`003goo00<007ooOol0>Goo00<007ooOol03Goo00<007ooOol0MGoo00<007ooOol03Goo00<0
07ooOol0>Woo000?Ool00`00Oomoo`0iOol00`00Oomoo`0=Ool00`00Oomoo`1dOol00`00Oomoo`0>
Ool00`00Oomoo`0jOol000moo`03001oogoo03Qoo`03001oogoo00moo`03001oogoo07=oo`03001o
ogoo00moo`03001oogoo03Uoo`003goo00<007ooOol0>7oo00<007ooOol03goo00<007ooOol0Lgoo
00<007ooOol03goo00<007ooOol0>Goo000?Ool00`00Oomoo`0hOol00`00Oomoo`0?Ool00`00Oomo
o`1cOol00`00Oomoo`0?Ool00`00Oomoo`0iOol000moo`8003Uoo`03001oogoo00moo`03001oogoo
07=oo`03001oogoo00moo`03001oogoo03Uoo`003goo00<007ooOol0=goo00<007ooOol047oo00<0
07ooOol0LWoo00<007ooOol047oo00<007ooOol0>Goo000?Ool00`00Oomoo`0gOol00`00Oomoo`0A
Ool00`00Oomoo`1aOol00`00Oomoo`0AOol00`00Oomoo`0hOol000moo`03001oogoo03Moo`03001o
ogoo015oo`03001oogoo075oo`03001oogoo015oo`03001oogoo03Qoo`003goo00<007ooOol0=goo
00<007ooOol04Goo00<007ooOol0LGoo00<007ooOol04Goo00<007ooOol0>7oo000?Ool00`00Oomo
o`0gOol00`00Oomoo`0AOol00`00Oomoo`1aOol00`00Oomoo`0AOol00`00Oomoo`0hOol000moo`03
001oogoo03Ioo`03001oogoo01=oo`03001oogoo071oo`03001oogoo019oo`03001oogoo03Moo`00
3goo0P00=goo00<007ooOol04goo00<007ooOol0Kgoo00<007ooOol04goo00<007ooOol0=goo000?
Ool00`00Oomoo`0fOol00`00Oomoo`0COol00`00Oomoo`1_Ool00`00Oomoo`0COol00`00Oomoo`0g
Ool000moo`03001oogoo03Ioo`03001oogoo01=oo`03001oogoo06moo`03001oogoo01=oo`03001o
ogoo03Moo`003goo00<007ooOol0=Woo00<007ooOol057oo00<007ooOol0KWoo00<007ooOol04goo
00<007ooOol0=goo0008Ool30004Ool00`00Oomoo`0eOol00`00Oomoo`0EOol00`00Oomoo`1^Ool0
0`00Oomoo`0DOol00`00Oomoo`0fOol000Qoo`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo
01Eoo`03001oogoo06eoo`03001oogoo01Eoo`03001oogoo03Ioo`002Goo00<007ooOol00goo0`00
=Goo00<007ooOol05Goo00<007ooOol0KGoo00<007ooOol05Goo00<007ooOol0=Woo0009Ool00`00
Oomoo`03Ool00`00Oomoo`0eOol00`00Oomoo`0FOol00`00Oomoo`1/Ool00`00Oomoo`0EOol00`00
Oomoo`0fOol000Qoo`03001oo`0000Aoo`03001oogoo03Aoo`03001oogoo01Moo`03001oogoo06ao
o`03001oogoo01Eoo`03001oogoo03Ioo`002Goo00<007ooOol00goo00<007ooOol0=7oo00<007oo
Ool05goo00<007ooOol0Jgoo00<007ooOol05goo00<007ooOol0=Goo000?Ool00`00Oomoo`0dOol0
0`00Oomoo`0GOol00`00Oomoo`1[Ool00`00Oomoo`0GOol00`00Oomoo`0eOol000moo`03001oogoo
03Aoo`03001oogoo01Moo`03001oogoo06]oo`03001oogoo01Moo`03001oogoo03Eoo`003goo00<0
07ooOol0<goo00<007ooOol06Goo00<007ooOol0JWoo00<007ooOol05goo00<007ooOol0=Goo000?
Ool2000dOol00`00Oomoo`0IOol00`00Oomoo`1YOol00`00Oomoo`0HOol00`00Oomoo`0eOol000mo
o`03001oogoo03=oo`03001oogoo01Uoo`03001oogoo06Uoo`03001oogoo01Uoo`03001oogoo03Ao
o`003goo00<007ooOol0<goo00<007ooOol06Goo00<007ooOol0JGoo00<007ooOol06Goo00<007oo
Ool0=7oo000?Ool00`00Oomoo`0bOol00`00Oomoo`0KOol00`00Oomoo`1XOol00`00Oomoo`0IOol0
0`00Oomoo`0dOol000moo`03001oogoo039oo`03001oogoo01]oo`03001oogoo06Qoo`03001oogoo
01Uoo`03001oogoo03Aoo`003goo00<007ooOol0<Woo00<007ooOol06goo00<007ooOol0Igoo00<0
07ooOol06Woo00<007ooOol0=7oo000?Ool00`00Oomoo`0bOol00`00Oomoo`0KOol00`00Oomoo`1W
Ool00`00Oomoo`0KOol00`00Oomoo`0cOol000moo`80039oo`03001oogoo01eoo`03001oogoo06Io
o`03001oogoo01]oo`03001oogoo03=oo`003goo00<007ooOol0<Goo00<007ooOol07Goo00<007oo
Ool0IWoo00<007ooOol06goo00<007ooOol0<goo000?Ool00`00Oomoo`0aOol00`00Oomoo`0MOol0
0`00Oomoo`1UOol00`00Oomoo`0LOol00`00Oomoo`0cOol000moo`03001oogoo035oo`03001oogoo
01eoo`03001oogoo06Eoo`03001oogoo01aoo`03001oogoo03=oo`003goo00<007ooOol0<7oo00<0
07ooOol07Woo00<007ooOol0IGoo00<007ooOol07Goo00<007ooOol0<Woo000?Ool00`00Oomoo`0`
Ool00`00Oomoo`0OOol00`00Oomoo`1TOol00`00Oomoo`0MOol00`00Oomoo`0bOol000moo`03001o
ogoo031oo`03001oogoo01moo`03001oogoo06=oo`03001oogoo01ioo`03001oogoo039oo`003goo
0P00<Goo00<007ooOol07goo00<007ooOol0Hgoo00<007ooOol07Woo00<007ooOol0<Woo000?Ool0
0`00Oomoo`0_Ool00`00Oomoo`0POol00`00Oomoo`1SOol00`00Oomoo`0OOol00`00Oomoo`0aOol0
00moo`03001oogoo02moo`03001oogoo025oo`03001oogoo069oo`03001oogoo01moo`03001oogoo
035oo`003goo00<007ooOol0;goo00<007ooOol08Goo00<007ooOol0HGoo00<007ooOol087oo00<0
07ooOol0<Goo000?Ool00`00Oomoo`0_Ool00`00Oomoo`0QOol00`00Oomoo`1QOol00`00Oomoo`0P
Ool00`00Oomoo`0aOol000Uoo`<000=oo`03001oogoo02ioo`03001oogoo029oo`03001oogoo065o
o`03001oogoo025oo`03001oogoo031oo`002Woo00<007ooOol00Woo00<007ooOol0;Woo00<007oo
Ool08goo00<007ooOol0Ggoo00<007ooOol08Woo00<007ooOol0<7oo0008Ool40003Ool3000^Ool0
0`00Oomoo`0SOol00`00Oomoo`1OOol00`00Oomoo`0ROol00`00Oomoo`0`Ool000Qoo`03001oo`00
00Aoo`03001oogoo02eoo`03001oogoo02Aoo`03001oogoo05moo`03001oogoo02=oo`03001oogoo
02moo`002Goo0P0017oo00<007ooOol0;Goo00<007ooOol097oo00<007ooOol0Ggoo00<007ooOol0
8goo00<007ooOol0;goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`0UOol00`00
Oomoo`1MOol00`00Oomoo`0TOol00`00Oomoo`0_Ool000moo`03001oogoo02eoo`03001oogoo02Eo
o`03001oogoo05eoo`03001oogoo02Aoo`03001oogoo02moo`003goo00<007ooOol0;7oo00<007oo
Ool09Woo00<007ooOol0GGoo00<007ooOol09Goo00<007ooOol0;Woo000?Ool00`00Oomoo`0/Ool0
0`00Oomoo`0VOol00`00Oomoo`1LOol00`00Oomoo`0VOol00`00Oomoo`0^Ool000moo`8002eoo`03
001oogoo02Moo`03001oogoo05]oo`03001oogoo02Ioo`03001oogoo02ioo`003goo00<007ooOol0
;7oo00<007ooOol09goo00<007ooOol0Fgoo00<007ooOol09goo00<007ooOol0;Goo000?Ool00`00
Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`1JOol00`00Oomoo`0XOol00`00Oomoo`0]Ool000mo
o`03001oogoo02]oo`03001oogoo02Qoo`03001oogoo05Yoo`03001oogoo02Qoo`03001oogoo02eo
o`003goo00<007ooOol0:goo00<007ooOol0:Goo00<007ooOol0FGoo00<007ooOol0:7oo00<007oo
Ool0;Goo000?Ool00`00Oomoo`0[Ool00`00Oomoo`0YOol00`00Oomoo`1IOol00`00Oomoo`0YOol0
0`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo05Qoo`03001oogoo
02Yoo`03001oogoo02aoo`003goo0P00:goo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol0
:Woo00<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`1GOol00`00
Oomoo`0[Ool00`00Oomoo`0[Ool000moo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo05Io
o`03001oogoo02aoo`03001oogoo02]oo`003goo00<007ooOol0:Goo00<007ooOol0;7oo00<007oo
Ool0EWoo00<007ooOol0;7oo00<007ooOol0:goo000?Ool00`00Oomoo`0YOol00`00Oomoo`0/Ool0
0`00Oomoo`1FOol00`00Oomoo`0]Ool00`00Oomoo`0ZOol000moo`03001oogoo02Uoo`03001oogoo
02eoo`03001oogoo05Aoo`03001oogoo02ioo`03001oogoo02Yoo`003goo00<007ooOol0:7oo00<0
07ooOol0;Woo00<007ooOol0E7oo00<007ooOol0;Woo00<007ooOol0:Woo000?Ool2000YOol00`00
Oomoo`0^Ool00`00Oomoo`1DOol00`00Oomoo`0_Ool00`00Oomoo`0YOol000moo`03001oogoo02Qo
o`03001oogoo02ioo`03001oogoo05=oo`03001oogoo031oo`03001oogoo02Uoo`003goo00<007oo
Ool09goo00<007ooOol0<7oo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol0:Goo000?Ool0
0`00Oomoo`0WOol00`00Oomoo`0`Ool00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`0YOol0
00moo`03001oogoo02Moo`03001oogoo031oo`03001oogoo059oo`03001oogoo035oo`03001oogoo
02Qoo`0027oo0P001Goo00<007ooOol09goo00<007ooOol0<Goo00<007ooOol0D7oo00<007ooOol0
<Woo00<007ooOol0:7oo0008Ool00`00Ool00004Ool00`00Oomoo`0VOol00`00Oomoo`0bOol00`00
Oomoo`1@Ool00`00Oomoo`0bOol00`00Oomoo`0XOol000Qoo`03001oo`0000Aoo`<002Ioo`03001o
ogoo03=oo`03001oogoo04moo`03001oogoo03=oo`03001oogoo02Moo`0027oo0P001Goo00<007oo
Ool09Woo00<007ooOol0<goo00<007ooOol0CWoo00<007ooOol0=7oo00<007ooOol09goo0008Ool0
0`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0dOol00`00Oomoo`1>Ool00`00Oomoo`0dOol0
0`00Oomoo`0WOol000Uoo`8000Aoo`03001oogoo02Eoo`03001oogoo03Eoo`03001oogoo04eoo`03
001oogoo03Eoo`03001oogoo02Ioo`003goo00<007ooOol09Goo00<007ooOol0=Goo00<007ooOol0
C7oo00<007ooOol0=Woo00<007ooOol09Woo000?Ool00`00Oomoo`0TOol00`00Oomoo`0fOol00`00
Oomoo`1<Ool00`00Oomoo`0gOol00`00Oomoo`0UOol000moo`03001oogoo02Aoo`03001oogoo03Mo
o`03001oogoo04Yoo`03001oogoo03Qoo`03001oogoo02Eoo`003goo0P009Goo00<007ooOol0=goo
00<007ooOol0BWoo00<007ooOol0>7oo00<007ooOol09Goo000?Ool00`00Oomoo`0SOol00`00Oomo
o`0iOol00`00Oomoo`19Ool00`00Oomoo`0iOol00`00Oomoo`0TOol000moo`03001oogoo02=oo`03
001oogoo03Uoo`03001oogoo04Qoo`03001oogoo03Yoo`03001oogoo02Aoo`003goo00<007ooOol0
8Woo00<007ooOol0>Woo00<007ooOol0B7oo00<007ooOol0>goo00<007ooOol08goo000?Ool00`00
Oomoo`0ROol00`00Oomoo`0kOol00`00Oomoo`16Ool00`00Oomoo`0lOol00`00Oomoo`0SOol000mo
o`03001oogoo025oo`03001oogoo03aoo`03001oogoo04Ioo`03001oogoo03aoo`03001oogoo02=o
o`003goo0P008Woo00<007ooOol0?Goo00<007ooOol0AGoo00<007ooOol0?Goo00<007ooOol08Woo
000?Ool00`00Oomoo`0QOol00`00Oomoo`0mOol00`00Oomoo`14Ool00`00Oomoo`0nOol00`00Oomo
o`0ROol000moo`03001oogoo021oo`03001oogoo03moo`03001oogoo04=oo`03001oogoo03moo`03
001oogoo025oo`003goo00<007ooOol087oo00<007ooOol0?goo00<007ooOol0@Woo00<007ooOol0
@7oo00<007ooOol08Goo000?Ool00`00Oomoo`0OOol00`00Oomoo`11Ool00`00Oomoo`11Ool00`00
Oomoo`10Ool00`00Oomoo`0QOol000moo`03001oogoo01moo`03001oogoo045oo`03001oogoo045o
o`03001oogoo045oo`03001oogoo021oo`003goo00<007ooOol07Woo00<007ooOol0@goo00<007oo
Ool0?goo00<007ooOol0@Woo00<007ooOol087oo000?Ool2000OOol00`00Oomoo`13Ool00`00Oomo
o`0oOol00`00Oomoo`13Ool00`00Oomoo`0OOol000moo`03001oogoo01eoo`03001oogoo04Eoo`03
001oogoo03eoo`03001oogoo04Aoo`03001oogoo01moo`003goo00<007ooOol07Goo00<007ooOol0
AGoo00<007ooOol0?Goo00<007ooOol0A7oo00<007ooOol07goo000?Ool00`00Oomoo`0LOol00`00
Oomoo`17Ool00`00Oomoo`0lOol00`00Oomoo`15Ool00`00Oomoo`0NOol000moo`03001oogoo01ao
o`03001oogoo04Moo`03001oogoo03]oo`03001oogoo04Ioo`03001oogoo01ioo`002Goo00<007oo
Ool00goo00<007ooOol06goo00<007ooOol0BGoo00<007ooOol0>Woo00<007ooOol0Agoo00<007oo
Ool07Goo0008Ool00`00Ool00004Ool00`00Oomoo`0KOol00`00Oomoo`19Ool00`00Oomoo`0iOol0
0`00Oomoo`18Ool00`00Oomoo`0MOol000Qoo`03001oo`0000Aoo`<001Yoo`03001oogoo04]oo`03
001oogoo03Qoo`03001oogoo04Uoo`03001oogoo01aoo`002Goo00<007ooOol00goo00<007ooOol0
6Woo00<007ooOol0Bgoo00<007ooOol0=goo00<007ooOol0BWoo00<007ooOol077oo0008Ool00`00
Ool00004Ool00`00Oomoo`0IOol00`00Oomoo`1=Ool00`00Oomoo`0fOol00`00Oomoo`1;Ool00`00
Oomoo`0KOol000Uoo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo04eoo`03001oogoo03Eo
o`03001oogoo04aoo`03001oogoo01]oo`003goo00<007ooOol067oo00<007ooOol0Cgoo00<007oo
Ool0=7oo00<007ooOol0CGoo00<007ooOol06Woo000?Ool00`00Oomoo`0GOol00`00Oomoo`1@Ool0
0`00Oomoo`0cOol00`00Oomoo`1?Ool00`00Oomoo`0IOol000moo`03001oogoo01Moo`03001oogoo
055oo`03001oogoo035oo`03001oogoo051oo`03001oogoo01Uoo`003goo0P005goo00<007ooOol0
DWoo00<007ooOol0<Goo00<007ooOol0DGoo00<007ooOol067oo000?Ool00`00Oomoo`0FOol00`00
Oomoo`1COol00`00Oomoo`0_Ool00`00Oomoo`1BOol00`00Oomoo`0HOol000moo`03001oogoo01Eo
o`03001oogoo05Aoo`03001oogoo02ioo`03001oogoo05Aoo`03001oogoo01Moo`003goo00<007oo
Ool05Goo00<007ooOol0EGoo00<007ooOol0;Goo00<007ooOol0EGoo00<007ooOol05Woo000?Ool0
0`00Oomoo`0DOol00`00Oomoo`1GOol00`00Oomoo`0[Ool00`00Oomoo`1FOol00`00Oomoo`0FOol0
00moo`03001oogoo01Aoo`03001oogoo05Moo`03001oogoo02Yoo`03001oogoo05Qoo`03001oogoo
01Eoo`003goo00<007ooOol04goo00<007ooOol0FGoo00<007ooOol0:Goo00<007ooOol0FGoo00<0
07ooOol057oo000?Ool2000COol00`00Oomoo`1JOol00`00Oomoo`0XOol00`00Oomoo`1KOol00`00
Oomoo`0COol000moo`03001oogoo015oo`03001oogoo05aoo`03001oogoo02Ioo`03001oogoo05ao
o`03001oogoo01=oo`003goo00<007ooOol047oo00<007ooOol0GWoo00<007ooOol097oo00<007oo
Ool0GWoo00<007ooOol04Woo000?Ool00`00Oomoo`0@Ool00`00Oomoo`1OOol00`00Oomoo`0SOol0
0`00Oomoo`1OOol00`00Oomoo`0AOol000moo`03001oogoo00moo`03001oogoo065oo`03001oogoo
025oo`03001oogoo065oo`03001oogoo011oo`003goo00<007ooOol03Woo00<007ooOol0Hgoo00<0
07ooOol07goo00<007ooOol0Hgoo00<007ooOol03goo000?Ool00`00Oomoo`0=Ool00`00Oomoo`1U
Ool00`00Oomoo`0LOol2001WOol00`00Oomoo`0>Ool000moo`8000eoo`03001oogoo06Moo`03001o
ogoo01Yoo`03001oogoo06Qoo`03001oogoo00eoo`003goo00<007ooOol02goo00<007ooOol0JGoo
0P006Goo00<007ooOol0JWoo00<007ooOol037oo000?Ool00`00Oomoo`09Ool2001^Ool00`00Oomo
o`0EOol00`00Oomoo`1/Ool00`00Oomoo`0;Ool000moo`03001oogoo00Qoo`03001oogoo06moo`03
001oogoo019oo`80071oo`8000]oo`003goo00<007ooOol01Woo0P00Lgoo00<007ooOol03goo0P00
M7oo0P002Goo0002Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2001fOol3000<Ool20021
Ool000Aoo`07001oogooOol007oo000017oo00<007ooOol01000Ngoo0`001goo0P00Pgoo0004Ool0
1`00Oomoogoo001oo`0000Aoo`<0089oo`L008Eoo`0017oo00L007ooOomoo`00Ool00004Ool00`00
Oomoo`3oOol?Ool000Aoo`07001oogooOol007oo000017oo00<007ooOol0ogoo3goo0003Ool20004
Ool00`00Oomoo`03Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.88348, -2.41412, 
  0.380877, 0.0725014}}],

Cell[OutputFormData["\<\
Graphics[{{Line[{{4.166666666666666*^-6, 9.999999999998179}, 
      {0.1234427160348012, 9.99977108991224}, {0.2357508183498944, \
9.999165965786612}, 
      {0.3653879907386823, 9.997996938139889}, {0.4879349323828924, \
9.99642816677575}, 
      {0.705898917377676, 9.992524113246702}, {0.9424920179678974, \
9.986671588627585}, 
      {1.203044223621859, 9.978280826019176}, {1.479259081094233, \
9.967155958384243}, 
      {1.974817076302018, 9.941437168656801}, {2.486320345625892, \
9.907113206385236}, 
      {2.965503661725943, 9.867763958492746}, {4.056699157291579, \
9.752016422471356}, 
      {5.169748088920781, 9.59610829473873}, {6.188104661132567, \
9.419421239674392}, 
      {8.480879985937368, 8.898857858664367}, {10.47433744441412, \
8.301322627797441}, 
      {12.65028740624912, 7.483144068372817}, {14.88859505346948, \
6.442288119642761}, 
      {16.91805648385246, 5.301027131449559}, {21.02667305676825, \
2.285344860909571}, 
      {23.21775311301878, 0.225120308395005}, {24.17877630915226, \
-0.7260048928392796}, 
      {24.68788407116706, -1.187043562390644}, {24.96814944894381, \
-1.405837032572005}, 
      {25.23365128697562, -1.575889469713843}, {25.35731618203023, \
-1.639194877834914}, 
      {25.48869458584581, -1.693470401806359}, {25.557192317687, \
-1.716028214381404}, 
      {25.63280055798261, -1.736103464920114}, {25.76612706268513, \
-1.758659223897126}, 
      {25.88663179656726, -1.764505628753622}, {26.01653660941294, \
-1.755173572247134}, 
      {26.1391774010334, -1.731709071392257}, {26.25162412127838, \
-1.698174647426247}, 
      {26.3661612130387, -1.652885280996583}, {26.47272369051073, \
-1.601401653391521}, 
      {26.71457926178204, -1.455314258156071}, {27.20199253384476, \
-1.069971495384818}, 
      {29.28147701249545, 0.9586586289924225}, {33.38122432030615, \
4.351644818374801}, 
      {35.62254096250315, 5.767830731736181}, {37.73848579009598, \
6.87421927335033}, 
      {41.77744225051072, 8.463913276422999}, {43.86440596822265, \
9.049902738001719}, 
      {44.9295907671371, 9.292344074030259}, {46.07391287290458, \
9.511759101182075}, 
      {47.14788535783184, 9.679922404545809}, {48.12919548404136, \
9.802205485752049}, 
      {48.60114534708862, 9.850476700641962}, {49.11562164925325, \
9.895358932085519}, 
      {49.56577498411976, 9.928038887461703}, {50.05207848592336, \
9.956457906293143}, 
      {50.34374274164709, 9.97008101015311}, {50.61173435585008, \
9.980341097936973}, 
      {50.86794508041712, 9.988131099987331}, {50.99849764729293, \
9.991342002958132}, 
      {51.13826673218466, 9.994212288459552}, {51.26535537092176, \
9.996313113376487}, 
      {51.38107869446398, 9.997804407424975}, {51.49740928126711, \
9.998898505224707}, 
      {51.60746692988272, 9.999559819676797}, {51.7356009615118, \
9.999871916946997}, 
      {51.85399416872665, 9.999722468051086}, {51.98394017971881, \
9.999074350880363}, 
      {52.12180982148853, 9.997832785488197}, {52.25779187963977, \
9.99604948574445}, 
      {52.38230669353921, 9.99392982063623}, {52.66275415484842, \
9.987450749134584}, 
      {52.90998312827952, 9.979779568804932}, {53.169930897739, \
9.969731650260969}, 
      {53.72210958347891, 9.941635321903582}, {54.32532907081687, \
9.900417881338555}, 
      {55.40697404386953, 9.798826942266536}, {56.38849529862103, \
9.675584135459791}, 
      {58.5897103906053, 9.289433667642361}, {60.60813278223211, \
8.797014925238245}, 
      {62.79330086299776, 8.105501700953878}, {64.84326204658508, \
7.294920675550661}, 
      {67.09525299268179, 6.204069011103039}, {71.23805261767829, \
3.540729878766954}, 
      {73.45563445477568, 1.681976214752386}, {75.47921389996637, \
-0.2834478573306918}, 
      {76.48242822007826, -1.222139545620845}, {76.75727835745853, \
-1.431900652586906}, 
      {76.90794601448557, -1.530425167496753}, {77.0495098001721, \
-1.609789378392465}, 
      {77.17961009530113, -1.669781539872943}, {77.29899348248995, \
-1.712714252401616}, 
      {77.43156761957843, -1.745675650989419}, {77.50121410675887, \
-1.756478558054385}, 
      {77.57459973261759, -1.762874118362514}, {77.69890143111718, \
-1.761895427079044}, 
      {77.81193790972409, -1.748150342180373}, {77.94241650111047, \
-1.717454558843626}, 
      {78.06569682873346, -1.674571304619962}, {78.28502234411193, \
-1.568098599448515}, 
      {78.52297354289338, -1.415622182711301}, {79.5612226775669, \
-0.4976715633129253}, 
      {83.85430554214586, 3.414632018570046}, {85.98922228932289, \
4.925643756682028}, 
      {87.98823590203728, 6.111018888864476}, {91.96301375724114, \
7.922968118254687}, 
      {94.09057427505734, 8.636834576800978}, {96.0361532697366, \
9.150357643414709}, 
      {97.93182498371354, 9.530343359278663}, {99.00456818158907, \
9.694737379683431}, 
      {99.99999583333334, 9.815316706439757}}]}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yplot = Plot[Evaluate[y[t]/. sol1], {t,0,100}]", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"yplot\" is \
similar to existing symbol 
    \"xplot\".\
\>", "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.309006 0.0700614 [
[.21429 .29651 -6 -9 ]
[.21429 .29651 6 0 ]
[.40476 .29651 -6 -9 ]
[.40476 .29651 6 0 ]
[.59524 .29651 -6 -9 ]
[.59524 .29651 6 0 ]
[.78571 .29651 -6 -9 ]
[.78571 .29651 6 0 ]
[.97619 .29651 -9 -9 ]
[.97619 .29651 9 0 ]
[.01131 .02876 -12 -4.5 ]
[.01131 .02876 0 4.5 ]
[.01131 .16888 -12 -4.5 ]
[.01131 .16888 0 4.5 ]
[.01131 .44913 -6 -4.5 ]
[.01131 .44913 0 4.5 ]
[.01131 .58925 -6 -4.5 ]
[.01131 .58925 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .30901 m
.21429 .31526 L
s
[(20)] .21429 .29651 0 1 Mshowa
.40476 .30901 m
.40476 .31526 L
s
[(40)] .40476 .29651 0 1 Mshowa
.59524 .30901 m
.59524 .31526 L
s
[(60)] .59524 .29651 0 1 Mshowa
.78571 .30901 m
.78571 .31526 L
s
[(80)] .78571 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(100)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.2619 .30901 m
.2619 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.02381 .02876 m
.03006 .02876 L
s
[(-4)] .01131 .02876 1 0 Mshowa
.02381 .16888 m
.03006 .16888 L
s
[(-2)] .01131 .16888 1 0 Mshowa
.02381 .44913 m
.03006 .44913 L
s
[(2)] .01131 .44913 1 0 Mshowa
.02381 .58925 m
.03006 .58925 L
s
[(4)] .01131 .58925 1 0 Mshowa
.125 Mabswid
.02381 .06379 m
.02756 .06379 L
s
.02381 .09882 m
.02756 .09882 L
s
.02381 .13385 m
.02756 .13385 L
s
.02381 .20391 m
.02756 .20391 L
s
.02381 .23894 m
.02756 .23894 L
s
.02381 .27398 m
.02756 .27398 L
s
.02381 .34404 m
.02756 .34404 L
s
.02381 .37907 m
.02756 .37907 L
s
.02381 .4141 m
.02756 .4141 L
s
.02381 .48416 m
.02756 .48416 L
s
.02381 .51919 m
.02756 .51919 L
s
.02381 .55422 m
.02756 .55422 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.06244 .39356 L
.10458 .48046 L
.12507 .51856 L
.14415 .55018 L
.16371 .57713 L
.17333 .58767 L
.18221 .59538 L
.18696 .59858 L
.192 .60114 L
.19461 .60211 L
.19586 .60248 L
.19706 .60277 L
.19773 .60291 L
.19846 .60304 L
.19974 .6032 L
.20046 .60327 L
.20124 .60331 L
.20196 .60332 L
.20263 .60331 L
.20379 .60324 L
.20502 .60309 L
.20607 .6029 L
.20722 .60262 L
.20846 .60224 L
.20979 .60174 L
.21219 .60055 L
.21461 .59899 L
.2169 .59713 L
.2212 .59258 L
.22579 .58595 L
.23085 .57614 L
.23614 .56248 L
.24111 .54574 L
.24573 .52586 L
.24997 .50312 L
.25953 .43062 L
.26945 .31902 L
.27491 .25202 L
.28006 .19628 L
.28486 .15391 L
.29006 .11774 L
.29915 .07323 L
.30374 .05742 L
.30879 .04388 L
.31405 .03321 L
.31898 .02586 L
.32134 .02311 L
.32359 .02091 L
.3278 .01778 L
Mistroke
.33015 .01655 L
.33233 .0157 L
.33358 .01534 L
.33472 .01508 L
.33603 .01487 L
.33726 .01476 L
.33843 .01472 L
.33968 .01474 L
.34086 .01484 L
.34193 .01498 L
.34319 .01521 L
.34456 .01553 L
.34705 .01632 L
.34966 .0174 L
.35242 .01881 L
.35738 .02198 L
.36617 .02939 L
.37587 .0398 L
.41612 .10068 L
.45486 .17554 L
.49605 .26358 L
.53573 .35095 L
.57389 .4329 L
.6145 .51242 L
.63328 .54432 L
.6536 .57344 L
.66473 .58618 L
.66962 .59088 L
.67499 .5953 L
.67972 .59849 L
.68479 .6011 L
.68759 .60213 L
.68892 .60251 L
.69015 .6028 L
.69138 .60303 L
.69202 .60312 L
.69271 .6032 L
.69387 .60329 L
.69515 .6033 L
.69636 .60325 L
.69749 .60313 L
.69873 .60293 L
.70006 .60262 L
.70145 .60219 L
.70277 .60168 L
.70523 .60045 L
.70753 .59894 L
.70966 .59723 L
.71447 .59207 L
.71929 .58488 L
Mistroke
.7246 .57415 L
.73014 .55908 L
.73532 .54046 L
.74029 .51742 L
.74571 .48482 L
.75083 .44493 L
.75558 .39857 L
.76449 .29206 L
.77411 .18497 L
.77962 .13968 L
.78469 .10751 L
.78954 .0835 L
.79465 .06375 L
.79924 .04993 L
.80353 .03975 L
.80823 .03107 L
.81326 .02419 L
.81583 .02152 L
.81855 .01923 L
.82088 .01769 L
.82345 .01639 L
.82488 .01584 L
.8262 .01544 L
.82764 .01511 L
.82837 .01498 L
.82916 .01488 L
.82986 .01481 L
.8305 .01477 L
.83124 .01475 L
.83194 .01476 L
.83318 .01482 L
.83387 .01489 L
.83452 .01497 L
.83568 .01517 L
.83693 .01544 L
.83918 .0161 L
.84185 .01713 L
.8443 .01831 L
.84961 .02156 L
.85464 .02546 L
.8745 .047 L
.89291 .07365 L
.93211 .14411 L
.97377 .23063 L
.97619 .23587 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001o
ogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`1AOol60022Ool6000_Ool0
00moo`03001oogoo055oo`03001oogoo00=oo`8007moo`8000Aoo`8002ioo`002Goo0`000goo00<0
07ooOol0Cgoo0P0027oo00<007ooOol0Ngoo00<007ooOol01Woo0P00;7oo000:Ool00`00Oomoo`02
Ool00`00Oomoo`1>Ool00`00Oomoo`09Ool00`00Oomoo`1iOol2000:Ool00`00Oomoo`0YOol000=o
o`<0009oo`@000=oo`<004ioo`03001oogoo00Yoo`03001oogoo07Moo`03001oogoo00]oo`03001o
ogoo02Qoo`0027oo00<007oo000017oo00<007ooOol0CGoo00<007ooOol037oo00<007ooOol0MWoo
00<007ooOol037oo00<007ooOol09goo0009Ool20004Ool00`00Oomoo`1=Ool00`00Oomoo`0=Ool0
0`00Oomoo`1dOol00`00Oomoo`0>Ool00`00Oomoo`0VOol000Yoo`03001oogoo009oo`03001oogoo
04aoo`03001oogoo00moo`03001oogoo07=oo`03001oogoo00ioo`03001oogoo02Ioo`003goo00<0
07ooOol0C7oo00<007ooOol047oo00<007ooOol0LWoo00<007ooOol03goo00<007ooOol09Goo000?
Ool00`00Oomoo`1<Ool00`00Oomoo`0@Ool00`00Oomoo`1aOol00`00Oomoo`0AOol00`00Oomoo`0T
Ool000moo`03001oogoo04]oo`03001oogoo019oo`03001oogoo071oo`03001oogoo019oo`03001o
ogoo02=oo`003goo00<007ooOol0Bgoo00<007ooOol04goo00<007ooOol0KWoo00<007ooOol057oo
00<007ooOol08Woo000?Ool00`00Oomoo`1:Ool00`00Oomoo`0DOol00`00Oomoo`1^Ool00`00Oomo
o`0EOol00`00Oomoo`0QOol000moo`8004]oo`03001oogoo01Eoo`03001oogoo06aoo`03001oogoo
01Ioo`03001oogoo025oo`003goo00<007ooOol0BWoo00<007ooOol05Woo00<007ooOol0Jgoo00<0
07ooOol05goo00<007ooOol087oo000?Ool00`00Oomoo`19Ool00`00Oomoo`0GOol00`00Oomoo`1[
Ool00`00Oomoo`0HOol00`00Oomoo`0OOol000moo`03001oogoo04Uoo`03001oogoo01Qoo`03001o
ogoo06Yoo`03001oogoo01Uoo`03001oogoo01ioo`003goo00<007ooOol0BGoo00<007ooOol067oo
00<007ooOol0JGoo00<007ooOol06goo00<007ooOol07Goo000?Ool00`00Oomoo`19Ool00`00Oomo
o`0IOol00`00Oomoo`1XOol00`00Oomoo`0KOol00`00Oomoo`0MOol000moo`03001oogoo04Qoo`03
001oogoo01]oo`03001oogoo06Moo`03001oogoo01aoo`03001oogoo01aoo`003goo00<007ooOol0
B7oo00<007ooOol06goo00<007ooOol0Igoo00<007ooOol077oo00<007ooOol077oo000?Ool00`00
Oomoo`18Ool00`00Oomoo`0LOol00`00Oomoo`1VOol00`00Oomoo`0MOol00`00Oomoo`0KOol000mo
o`03001oogoo04Qoo`03001oogoo01eoo`03001oogoo06Eoo`03001oogoo01eoo`03001oogoo01]o
o`003goo0P00B7oo00<007ooOol07Woo00<007ooOol0I7oo00<007ooOol07goo00<007ooOol06Woo
000?Ool00`00Oomoo`17Ool00`00Oomoo`0OOol00`00Oomoo`1SOol00`00Oomoo`0OOol00`00Oomo
o`0JOol000moo`03001oogoo04Moo`03001oogoo021oo`03001oogoo069oo`03001oogoo021oo`03
001oogoo01Uoo`003goo00<007ooOol0Agoo00<007ooOol087oo00<007ooOol0HWoo00<007ooOol0
87oo00<007ooOol06Goo000?Ool00`00Oomoo`16Ool00`00Oomoo`0ROol00`00Oomoo`1QOol00`00
Oomoo`0QOol00`00Oomoo`0HOol000moo`03001oogoo04Ioo`03001oogoo029oo`03001oogoo061o
o`03001oogoo029oo`03001oogoo01Qoo`003goo00<007ooOol0AWoo00<007ooOol08goo00<007oo
Ool0Ggoo00<007ooOol08goo00<007ooOol05goo000?Ool00`00Oomoo`16Ool00`00Oomoo`0SOol0
0`00Oomoo`1OOol00`00Oomoo`0SOol00`00Oomoo`0GOol000moo`03001oogoo04Ioo`03001oogoo
02Aoo`03001oogoo05ioo`03001oogoo02Aoo`03001oogoo01Ioo`003goo00<007ooOol0AWoo00<0
07ooOol097oo00<007ooOol0GGoo00<007ooOol09Goo00<007ooOol05Woo000?Ool20017Ool00`00
Oomoo`0UOol00`00Oomoo`1LOol00`00Oomoo`0VOol00`00Oomoo`0EOol000moo`03001oogoo04Eo
o`03001oogoo02Moo`03001oogoo05]oo`03001oogoo02Ioo`03001oogoo01Eoo`003goo00<007oo
Ool0AGoo00<007ooOol09goo00<007ooOol0Fgoo00<007ooOol09goo00<007ooOol057oo000?Ool0
0`00Oomoo`15Ool00`00Oomoo`0XOol00`00Oomoo`1JOol00`00Oomoo`0WOol00`00Oomoo`0DOol0
00moo`03001oogoo04Eoo`03001oogoo02Qoo`03001oogoo05Yoo`03001oogoo02Qoo`03001oogoo
01=oo`003goo00<007ooOol0AGoo00<007ooOol0:Goo00<007ooOol0FGoo00<007ooOol0:7oo00<0
07ooOol04goo000?Ool00`00Oomoo`15Ool00`00Oomoo`0YOol00`00Oomoo`1IOol00`00Oomoo`0Y
Ool00`00Oomoo`0BOol000Qoo`<000Aoo`03001oogoo04Eoo`03001oogoo02Yoo`03001oogoo05Qo
o`03001oogoo02Uoo`03001oogoo019oo`0027oo00<007ooOol017oo00<007ooOol0AGoo00<007oo
Ool0:Woo00<007ooOol0Egoo00<007ooOol0:goo00<007ooOol04Goo0003Ool30003Ool00`00Oomo
o`03Ool30015Ool00`00Oomoo`0[Ool00`00Oomoo`1FOol00`00Oomoo`0[Ool00`00Oomoo`0AOol0
00Uoo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo02]oo`03001oogoo05Ioo`03001oogoo
02aoo`03001oogoo011oo`0027oo00<007oo000017oo00<007ooOol0AGoo00<007ooOol0;7oo00<0
07ooOol0EGoo00<007ooOol0;7oo00<007ooOol047oo0009Ool00`00Oomoo`03Ool00`00Oomoo`14
Ool00`00Oomoo`0]Ool00`00Oomoo`1EOol00`00Oomoo`0]Ool00`00Oomoo`0?Ool000moo`03001o
ogoo04Aoo`03001oogoo02ioo`03001oogoo05Aoo`03001oogoo02eoo`03001oogoo00moo`003goo
00<007ooOol0A7oo00<007ooOol0;Woo00<007ooOol0E7oo00<007ooOol0;Woo00<007ooOol03Woo
000?Ool00`00Oomoo`14Ool00`00Oomoo`0_Ool00`00Oomoo`1COol00`00Oomoo`0^Ool00`00Oomo
o`0>Ool000moo`03001oogoo04Aoo`03001oogoo02moo`03001oogoo05=oo`03001oogoo02moo`03
001oogoo00eoo`003goo00<007ooOol0A7oo00<007ooOol0<7oo00<007ooOol0DWoo00<007ooOol0
;goo00<007ooOol03Goo000?Ool00`00Oomoo`14Ool00`00Oomoo`0`Ool00`00Oomoo`1BOol00`00
Oomoo`0`Ool00`00Oomoo`0<Ool000moo`8004Eoo`03001oogoo035oo`03001oogoo051oo`03001o
ogoo035oo`03001oogoo00aoo`003goo00<007ooOol0A7oo00<007ooOol0<Goo00<007ooOol0D7oo
00<007ooOol0<Woo00<007ooOol02goo000?Ool00`00Oomoo`13Ool00`00Oomoo`0bOol00`00Oomo
o`1@Ool00`00Oomoo`0bOol00`00Oomoo`0;Ool000moo`03001oogoo04=oo`03001oogoo03=oo`03
001oogoo04moo`03001oogoo03=oo`03001oogoo00Yoo`003goo00<007ooOol0@goo00<007ooOol0
<goo00<007ooOol0Cgoo00<007ooOol0<goo00<007ooOol02Woo000?Ool00`00Oomoo`13Ool00`00
Oomoo`0dOol00`00Oomoo`1>Ool00`00Oomoo`0dOol00`00Oomoo`09Ool000moo`03001oogoo04=o
o`03001oogoo03Aoo`03001oogoo04ioo`03001oogoo03Aoo`03001oogoo00Uoo`003goo00<007oo
Ool0@goo00<007ooOol0=Goo00<007ooOol0CGoo00<007ooOol0=Goo00<007ooOol027oo000?Ool0
0`00Oomoo`13Ool00`00Oomoo`0eOol00`00Oomoo`1=Ool00`00Oomoo`0fOol00`00Oomoo`07Ool0
00moo`03001oogoo04=oo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo03Ioo`03001oogoo
00Moo`003goo0P00@goo00<007ooOol0=goo00<007ooOol0Bgoo00<007ooOol0@Goo000?Ool00`00
Oomoo`12Ool00`00Oomoo`0gOol00`00Oomoo`1;Ool00`00Oomoo`11Ool000moo`03001oogoo049o
o`03001oogoo03Qoo`03001oogoo04Yoo`03001oogoo045oo`003goo00<007ooOol0@Woo00<007oo
Ool0>7oo00<007ooOol0BWoo00<007ooOol0@Goo000?Ool00`00Oomoo`12Ool00`00Oomoo`0iOol0
0`00Oomoo`19Ool00`00Oomoo`11Ool000moo`03001oogoo049oo`03001oogoo03Uoo`03001oogoo
04Uoo`03001oogoo045oo`003goo00<007ooOol0@Woo00<007ooOol0>Woo00<007ooOol0B7oo00<0
07ooOol0@Goo000?Ool00`00Oomoo`12Ool00`00Oomoo`0jOol00`00Oomoo`18Ool00`00Oomoo`11
Ool000moo`03001oogoo02eoo`<000=oo`03001oogoo00aoo`03001oogoo01ioo`<0009oo`03001o
ogoo01Aoo`03001oogoo01Aoo`8000Aoo`03001oogoo02]oo`03001oo`0000Aoo`03001oogoo02Qo
o`D0009oo`03001oogoo009oo`03001oogoo00=oo`003goo0P00;Woo00<007ooOol00Woo00<007oo
00003Goo00<007ooOol07goo00H007ooOol007oo000FOol00`00Oomoo`0COol00`00Ool00002Ool0
0`00Ool0000/Ool200001goo001oogoo001oo`0002]oo`07001oogooOol007oo00000Woo00<007oo
000017oo000?Ool00`00Oomoo`0^Ool01`00Oomoogoo001oo`0000eoo`03001oogoo01eoo`@00004
Ool007oo000FOol00`00Oomoo`0COol00`00Ool00002Ool00`00Ool0000[Ool01@00Ool007oo0000
0Woo00<007oo0000:goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool000moo`03001oogoo
02ioo`07001oogooOol007oo00003Goo00<007ooOol07Goo00<007oo00000Woo00<007oo00005goo
00<007ooOol04Woo0P000goo00<007oo0000:goo00@007ooOol000=oo`03001oo`0002]oo`07001o
ogooOol007oo00000Woo00<007oo000017oo000?Ool00`00Oomoo`0]Ool00`00Ool00002Ool00`00
Ool0000=Ool00`00Oomoo`0NOol20002Ool00`00Ool0000GOol00`00Oomoo`0BOol00`00Oomoo`02
Ool00`00Ool0000[Ool01@00Ool007oo00000Woo00<007oo0000:goo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool000moo`03001oogoo02ioo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo021oo`05001oogooOol0000IOol00`00Oomoo`0BOol20003Ool00`00Oomoo`0ZOol01000Oomo
o`0017oo00<007ooOol0:Goo0P0017oo00<007ooOol00Woo00<007ooOol00goo000?Ool00`00Oomo
o`11Ool00`00Oomoo`0nOol00`00Oomoo`14Ool00`00Oomoo`12Ool000moo`03001oogoo045oo`03
001oogoo03moo`03001oogoo04=oo`03001oogoo049oo`003goo00<007ooOol0@Goo00<007ooOol0
?goo00<007ooOol0@goo00<007ooOol0@Woo000?Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00
Oomoo`12Ool00`00Oomoo`12Ool000moo`03001oogoo045oo`03001oogoo041oo`03001oogoo049o
o`03001oogoo049oo`0027ooo`005P000goo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Ool0000:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00
Oomoo`07Ool000moo`80039oo`03001oogoo00eoo`03001oogoo029oo`03001oogoo01aoo`03001o
ogoo019oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo039oo`03001oogoo00Moo`003goo
0P00@Woo00<007ooOol0@Woo00<007ooOol0?goo00<007ooOol0@goo000?Ool00`00Ool00011Ool0
0`00Oomoo`12Ool00`00Oomoo`0oOol00`00Oomoo`13Ool000moo`03001oo`00045oo`03001oogoo
04=oo`03001oogoo03ioo`03001oogoo04=oo`003goo00@007ooOol0041oo`03001oogoo04=oo`03
001oogoo03ioo`03001oogoo04=oo`003goo00@007ooOol0041oo`03001oogoo04Aoo`03001oogoo
03eoo`03001oogoo04=oo`003goo00D007ooOomoo`0003moo`03001oogoo04Aoo`03001oogoo03eo
o`03001oogoo04=oo`003goo00D007ooOomoo`0003ioo`03001oogoo04Ioo`03001oogoo03aoo`03
001oogoo04=oo`003goo0P000goo00<007ooOol0>goo00<007ooOol0AWoo00<007ooOol0?7oo00<0
07ooOol0@goo000?Ool00`00Oomoo`02Ool00`00Oomoo`0kOol00`00Oomoo`17Ool00`00Oomoo`0k
Ool00`00Oomoo`13Ool000moo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo04Moo`03001o
ogoo03]oo`03001oogoo04=oo`003goo00<007ooOol00goo00<007ooOol0>Woo00<007ooOol0B7oo
00<007ooOol0>Woo00<007ooOol0@goo000?Ool00`00Oomoo`04Ool00`00Oomoo`0iOol00`00Oomo
o`18Ool00`00Oomoo`0jOol00`00Oomoo`13Ool000moo`03001oogoo00Aoo`03001oogoo03Uoo`03
001oogoo04Uoo`03001oogoo03Uoo`03001oogoo04=oo`003goo00<007ooOol01Goo00<007ooOol0
>7oo00<007ooOol0BGoo00<007ooOol0>Goo00<007ooOol0@goo000?Ool00`00Oomoo`05Ool00`00
Oomoo`0hOol00`00Oomoo`1:Ool00`00Oomoo`0hOol00`00Oomoo`13Ool000moo`03001oogoo00Io
o`03001oogoo03Moo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo04Aoo`003goo0P001goo
00<007ooOol0=Woo00<007ooOol0C7oo00<007ooOol0=Woo00<007ooOol0A7oo000?Ool00`00Oomo
o`07Ool00`00Oomoo`0eOol00`00Oomoo`1<Ool00`00Oomoo`0fOol00`00Oomoo`14Ool000moo`03
001oogoo00Moo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo03Eoo`03001oogoo04Aoo`00
3goo00<007ooOol027oo00<007ooOol0=7oo00<007ooOol0CGoo00<007ooOol0=Goo00<007ooOol0
A7oo000?Ool00`00Oomoo`08Ool00`00Oomoo`0dOol00`00Oomoo`1>Ool00`00Oomoo`0dOol00`00
Oomoo`14Ool000moo`03001oogoo00Qoo`03001oogoo03Aoo`03001oogoo04ioo`03001oogoo03Ao
o`03001oogoo04Aoo`003goo00<007ooOol02Goo00<007ooOol0<goo00<007ooOol0Cgoo00<007oo
Ool0<goo00<007ooOol0A7oo000?Ool00`00Oomoo`09Ool00`00Oomoo`0cOol00`00Oomoo`1?Ool0
0`00Oomoo`0cOol00`00Oomoo`14Ool000moo`03001oogoo00Yoo`03001oogoo039oo`03001oogoo
051oo`03001oogoo039oo`03001oogoo04Aoo`003goo00<007ooOol02Woo00<007ooOol0<Woo00<0
07ooOol0D7oo00<007ooOol0<Woo00<007ooOol0A7oo000?Ool2000<Ool00`00Oomoo`0`Ool00`00
Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`15Ool000moo`03001oogoo00]oo`03001oogoo031o
o`03001oogoo059oo`03001oogoo031oo`03001oogoo04Eoo`003goo00<007ooOol037oo00<007oo
Ool0;goo00<007ooOol0Dgoo00<007ooOol0;goo00<007ooOol0AGoo000?Ool00`00Oomoo`0<Ool0
0`00Oomoo`0_Ool00`00Oomoo`1COol00`00Oomoo`0_Ool00`00Oomoo`15Ool000moo`03001oogoo
00eoo`03001oogoo02ioo`03001oogoo05Aoo`03001oogoo02ioo`03001oogoo04Eoo`003goo00<0
07ooOol03Goo00<007ooOol0;Woo00<007ooOol0E7oo00<007ooOol0;Woo00<007ooOol0AGoo000?
Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`1EOol00`00Oomoo`0/Ool00`00Oomoo`16
Ool000moo`03001oogoo00ioo`03001oogoo02eoo`03001oogoo05Eoo`03001oogoo02aoo`03001o
ogoo04Ioo`0027oo0`0017oo00<007ooOol03Woo00<007ooOol0;Goo00<007ooOol0EWoo00<007oo
Ool0:goo00<007ooOol0AWoo0008Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`0[Ool0
0`00Oomoo`1GOol00`00Oomoo`0[Ool00`00Oomoo`16Ool000Uoo`03001oogoo00=oo`<000moo`03
001oogoo02]oo`03001oogoo05Qoo`03001oogoo02Yoo`03001oogoo04Ioo`002Goo00<007ooOol0
0goo00<007ooOol047oo00<007ooOol0:Woo00<007ooOol0F7oo00<007ooOol0:Woo00<007ooOol0
AWoo0008Ool00`00Ool00004Ool00`00Oomoo`0@Ool00`00Oomoo`0ZOol00`00Oomoo`1IOol00`00
Oomoo`0YOol00`00Oomoo`16Ool000Uoo`03001oogoo00=oo`03001oogoo015oo`03001oogoo02Uo
o`03001oogoo05Uoo`03001oogoo02Uoo`03001oogoo04Ioo`003goo00<007ooOol04Goo00<007oo
Ool0:Goo00<007ooOol0FWoo00<007ooOol09goo00<007ooOol0Agoo000?Ool00`00Oomoo`0BOol0
0`00Oomoo`0XOol00`00Oomoo`1JOol00`00Oomoo`0WOol00`00Oomoo`17Ool000moo`03001oogoo
019oo`03001oogoo02Moo`03001oogoo05aoo`03001oogoo02Ioo`03001oogoo04Moo`003goo00<0
07ooOol04goo00<007ooOol09Woo00<007ooOol0G7oo00<007ooOol09Woo00<007ooOol0Agoo000?
Ool00`00Oomoo`0COol00`00Oomoo`0VOol00`00Oomoo`1MOol00`00Oomoo`0UOol00`00Oomoo`17
Ool000moo`8001Eoo`03001oogoo02Eoo`03001oogoo05eoo`03001oogoo02Eoo`03001oogoo04Mo
o`003goo00<007ooOol057oo00<007ooOol09Goo00<007ooOol0GWoo00<007ooOol097oo00<007oo
Ool0Agoo000?Ool00`00Oomoo`0EOol00`00Oomoo`0TOol00`00Oomoo`1NOol00`00Oomoo`0TOol0
0`00Oomoo`17Ool000moo`03001oogoo01Eoo`03001oogoo02=oo`03001oogoo061oo`03001oogoo
029oo`03001oogoo04Qoo`003goo00<007ooOol05Woo00<007ooOol08Woo00<007ooOol0H7oo00<0
07ooOol08Woo00<007ooOol0B7oo000?Ool00`00Oomoo`0FOol00`00Oomoo`0ROol00`00Oomoo`1Q
Ool00`00Oomoo`0QOol00`00Oomoo`18Ool000moo`03001oogoo01Moo`03001oogoo025oo`03001o
ogoo065oo`03001oogoo025oo`03001oogoo04Qoo`003goo00<007ooOol05goo00<007ooOol08Goo
00<007ooOol0HWoo00<007ooOol07goo00<007ooOol0BGoo000?Ool00`00Oomoo`0HOol00`00Oomo
o`0POol00`00Oomoo`1ROol00`00Oomoo`0OOol00`00Oomoo`19Ool000moo`03001oogoo01Qoo`03
001oogoo021oo`03001oogoo06=oo`03001oogoo01ioo`03001oogoo04Uoo`003goo0P006Woo00<0
07ooOol07Woo00<007ooOol0I7oo00<007ooOol07Woo00<007ooOol0BGoo000?Ool00`00Oomoo`0J
Ool00`00Oomoo`0MOol00`00Oomoo`1UOol00`00Oomoo`0MOol00`00Oomoo`19Ool000moo`03001o
ogoo01Yoo`03001oogoo01eoo`03001oogoo06Eoo`03001oogoo01eoo`03001oogoo04Uoo`003goo
00<007ooOol06goo00<007ooOol077oo00<007ooOol0IWoo00<007ooOol06goo00<007ooOol0BWoo
000?Ool00`00Oomoo`0KOol00`00Oomoo`0LOol00`00Oomoo`1VOol00`00Oomoo`0KOol00`00Oomo
o`1:Ool000moo`03001oogoo01aoo`03001oogoo01Yoo`03001oogoo06Qoo`03001oogoo01Yoo`03
001oogoo04Yoo`003goo00<007ooOol077oo00<007ooOol06Woo00<007ooOol0J7oo00<007ooOol0
6Woo00<007ooOol0BWoo000?Ool00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`1YOol00`00
Oomoo`0IOol00`00Oomoo`1:Ool000moo`03001oogoo01eoo`03001oogoo01Uoo`03001oogoo06Yo
o`03001oogoo01Qoo`03001oogoo04Yoo`003goo00<007ooOol07Woo00<007ooOol05goo00<007oo
Ool0K7oo00<007ooOol05Woo00<007ooOol0Bgoo000?Ool2000POol00`00Oomoo`0FOol00`00Oomo
o`1/Ool00`00Oomoo`0FOol00`00Oomoo`1;Ool000moo`03001oogoo021oo`03001oogoo01Aoo`03
001oogoo06ioo`03001oogoo01Eoo`03001oogoo04]oo`003goo00<007ooOol08Goo00<007ooOol0
4goo00<007ooOol0Kgoo00<007ooOol057oo00<007ooOol0Bgoo000?Ool00`00Oomoo`0QOol00`00
Oomoo`0COol00`00Oomoo`1`Ool00`00Oomoo`0BOol00`00Oomoo`1<Ool000moo`03001oogoo029o
o`03001oogoo019oo`03001oogoo071oo`03001oogoo019oo`03001oogoo04aoo`003goo00<007oo
Ool08goo00<007ooOol047oo00<007ooOol0LWoo00<007ooOol047oo00<007ooOol0CGoo000?Ool0
0`00Oomoo`0TOol00`00Oomoo`0?Ool00`00Oomoo`1cOol00`00Oomoo`0?Ool00`00Oomoo`1=Ool0
00Uoo`<000=oo`03001oogoo02Eoo`03001oogoo00ioo`03001oogoo07Aoo`03001oogoo00eoo`03
001oogoo04ioo`002Woo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol03Goo00<007ooOol0
MWoo00<007ooOol037oo00<007ooOol0CWoo0008Ool40003Ool3000VOol00`00Oomoo`0;Ool00`00
Oomoo`1hOol00`00Oomoo`0:Ool00`00Oomoo`1?Ool000Qoo`03001oo`0000Aoo`03001oogoo02Mo
o`8000Yoo`03001oogoo07Uoo`03001oogoo00Uoo`03001oogoo051oo`002Goo0P0017oo00<007oo
Ool0:Goo00<007ooOol01Woo00<007ooOol0Ngoo00<007ooOol01goo00<007ooOol0DGoo000:Ool0
0`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`04Ool2001nOol20006Ool00`00Oomoo`1BOol0
00moo`03001oogoo02]oo`H0089oo`H005Eoo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomo
o`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.88348, -4.58031, 
  0.380877, 0.0517747}}],

Cell[OutputFormData["\<\
Graphics[{{Line[{{4.166666666666666*^-6, 1.24999999981802*^-6}, 
      {4.056699157291579, 1.206861635523774}, {8.480879985937368, \
2.447122182848795}, 
      {10.63197399634091, 2.991035067799262}, {12.63593663385385, \
3.442345796335324}, 
      {14.69006171723266, 3.826982777887112}, {15.69970788902852, \
3.977442392594925}, 
      {16.6318407770828, 4.087531334283399}, {17.13082465330856, \
4.133104975842899}, 
      {17.65980409490176, 4.169747829183243}, {17.93395345752028, \
4.183535380706929}, 
      {18.06561947941579, 4.1888024158604}, {18.19078036081633, \
4.192959339527718}, 
      {18.26112895382198, 4.194922536708991}, {18.33791765960292, \
4.196751990148235}, 
      {18.47253728950319, 4.199151159208844}, {18.5486110335642, \
4.200041092003962}, 
      {18.62970892798926, 4.200610355689255}, {18.7062378356324, \
4.200781269968505}, 
      {18.77562618203061, 4.200622815162868}, {18.89781241653668, \
4.199602351093233}, 
      {19.02689794912118, 4.197467545426199}, {19.13710752180138, \
4.194758321100315}, 
      {19.25807996138942, 4.190814440574808}, {19.38834244952753, \
4.185394522771027}, 
      {19.52798478221184, 4.178183775701907}, {19.77996499962569, \
4.161320549540882}, 
      {20.03411013498991, 4.13897473332761}, {20.27486766665976, \
4.11248286661431}, 
      {20.72610657760333, 4.047452646682569}, {21.20791539611811, \
3.952870320957471}, 
      {21.7397390922847, 3.812781817872725}, {22.2951601740733, \
3.617899723242662}, 
      {22.81659620501357, 3.378907355073467}, {23.30215423731055, \
3.095263727101312}, 
      {23.74735201774708, 2.770657315836521}, {24.75071226562281, \
1.735766114353393}, 
      {25.79276722301338, 0.1428621496283818}, {26.36540557679675, \
-0.8133453946485785}, 
      {26.90601244151065, -1.608995099116092}, {27.4101371539132, \
-2.213698310920296}, 
      {27.95662818218455, -2.729916356866462}, {28.91125042082948, \
-3.365325617301162}, 
      {29.39279631405319, -3.590904758858421}, {29.92249794209964, \
-3.784235853952407}, 
      {30.47562718975883, -3.936500370063439}, {30.99312430787017, \
-4.041390745496885}, 
      {31.24118257483175, -4.080643355205632}, {31.476674969682, \
-4.111990937374955}, 
      {31.91850487466638, -4.156682381423153}, {32.16531018434435, \
-4.174337003438551}, 
      {32.39414116521874, -4.186424013065165}, {32.52593382787596, \
-4.191619005833342}, 
      {32.64527203929891, -4.195257244182652}, {32.78303071092782, \
-4.198240568873425}, 
      {32.9126360713486, -4.199897069633694}, {33.0351894144263, \
-4.200471914308782}, 
      {33.16639456053948, -4.200053451898492}, {33.2902288751731, \
-4.198708593928864}, 
      {33.40298890313766, -4.196706109613508}, {33.53537899308317, \
-4.193436735697114}, 
      {33.67920138984642, -4.188795814625598}, {33.94051956626792, \
-4.177582795433242}, 
      {34.21401746621792, -4.162202873863984}, {34.50419226422043, \
-4.142058889757255}, 
      {35.02501423229228, -4.09678054157078}, {35.94823224745165, \
-3.991020162024272}, 
      {36.96594330415861, -3.842367802172713}, {41.19275381405141, \
-2.973444545535598}, 
      {45.26041181925668, -1.904953625448793}, {49.58558398644107, \
-0.6483888713982439}, 
      {53.75160364893791, 0.5986370881219398}, {57.75847080674722, \
1.768385184251448}, 
      {62.02285212653564, 2.903363651261837}, {63.99404456727673, \
3.358637687893319}, 
      {66.12808094163653, 3.774309714630499}, {67.29716372846339, \
3.956203334871669}, 
      {67.81013068659705, 4.023177381836898}, {68.37365206183706, \
4.086327698093709}, 
      {68.87010593266065, 4.131899161130025}, {69.40274150432995, \
4.169055850419068}, 
      {69.69685958906959, 4.183833767394203}, {69.83621281570375, \
4.189301014358346}, 
      {69.96524711857652, 4.193443242035528}, {70.09441542784434, \
4.196676206191309}, 
      {70.16257133683294, 4.198003808599491}, {70.2350373716075, \
4.199122212303602}, 
      {70.35656811466122, 4.200304346221584}, {70.49082391871653, \
4.200571631289695}, 
      {70.61818126163347, 4.199785932058403}, {70.73676788687276, \
4.198113958556295}, 
      {70.86689219628927, 4.195200455730287}, {71.00601943025111, \
4.190793262744263}, 
      {71.15220727429944, 4.18466937474916}, {71.2903302040252, \
4.177421147987641}, 
      {71.54887444827412, 4.15983831946923}, {71.79106455621114, \
4.138317467742076}, 
      {72.01454856122534, 4.113806791291027}, {72.51976891019852, \
4.040196041226801}, 
      {73.02566472488145, 3.937559129770665}, {73.58260500451237, \
3.784421479971117}, 
      {74.16419636530598, 3.569289705927044}, {74.70876516350426, \
3.303547552571454}, 
      {75.23052213684154, 2.974691646302137}, {75.79975707076278, \
2.50935611276769}, 
      {76.33741667771038, 1.940045703248794}, {76.83632568132046, \
1.278413008542788}, 
      {77.77116698819835, -0.2418817295881813}, {78.7819046759997, \
-1.770389482815356}, 
      {79.36050287439066, -2.416756655929413}, {79.89257291830563, \
-2.875950975829998}, 
      {80.40123875963343, -3.218718763823846}, {80.93835646433268, \
-3.500568344124158}, 
      {81.42041857851507, -3.69779316945732}, {81.87024018600792, \
-3.843174458154951}, 
      {82.36379103073677, -3.967059040408277}, {82.89261499839076, \
-4.065187995916627}, 
      {83.16205442092632, -4.103311123645032}, {83.44815600065061, \
-4.135988018073635}, 
      {83.69240964006676, -4.158026001949814}, {83.96188261697608, \
-4.176554265417668}, 
      {84.11252867160442, -4.184431001731661}, {84.25058329747519, \
-4.190166436851748}, 
      {84.40215192016793, -4.194894157184617}, {84.47834448212427, \
-4.196670778907607}, 
      {84.56164776302918, -4.198166323103516}, {84.63555429080638, \
-4.199110262723939}, 
      {84.70267425348339, -4.199661572004898}, {84.78015219776379, \
-4.199942606715703}, 
      {84.85325950660456, -4.199865145960591}, {84.98341197774141, \
-4.19892316460319}, 
      {85.05680043153917, -4.197948354745206}, {85.12443138385734, \
-4.196773039176948}, 
      {85.24629815558354, -4.193998886428333}, {85.37715309569771, \
-4.190104644673995}, 
      {85.61347576877054, -4.18076131457949}, {85.89450350078914, \
-4.165971478291912}, 
      {86.15115489277817, -4.149174166132584}, {86.70864045470347, \
-4.102710419695411}, 
      {87.2376194452606, -4.047145610454634}, {89.32295631335183, \
-3.739699309960677}, 
      {91.25544961765028, -3.359263028989441}, {95.37164144733152, \
-2.353590131060593}, 
      {99.74534743899187, -1.118731749610049}, {99.99999583333334, \
-1.043882982518805}}]}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[Evaluate[z[t]/. sol1], {t,0,100}]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.309017 0.294302 [
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -6 -9 ]
[.59524 .29652 6 0 ]
[.78571 .29652 -6 -9 ]
[.78571 .29652 6 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .30902 m
.21429 .31527 L
s
[(20)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(40)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(60)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(80)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(100)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`004goo1@000goo00<007ooOol0ogoo0goo000EOol00`00Oomo
o`03Ool00`00Oomoo`3oOol3Ool000moo`<000=oo`03001oogoo00=oo`800?moo`Aoo`005Goo00<0
07ooOol00goo00<007ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool001Ao
o`8000Eoo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`00
6goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool000]oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo0?moo`=oo`002Woo00<007oo00001goo00<007oo0000
17oo00<007ooOol0ogoo0goo0005Ool30002Ool00`00Ool00009Ool00`00Oomoo`02Ool2003oOol4
Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo0?moo`=oo`002Woo00<007oo00001goo00<0
07ooOol017oo00<007ooOol0ogoo0goo000;Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo02]o
o`<000=oo`03001oogoo02Yoo`<0009oo`03001oogoo02Uoo`8000Aoo`03001oogoo02Yoo`03001o
ogoo009oo`03001oogoo02Ioo`D0009oo`03001oogoo009oo`03001oogoo00=oo`006goo00<007oo
Ool0:goo00<007ooOol00Woo00<007oo0000;7oo00H007ooOol007oo000ZOol00`00Ool00002Ool0
0`00Ool0000ZOol00`00Ool00002Ool00`00Ool0000YOol01`00Oomoogoo001oo`00009oo`03001o
o`0000Aoo`006goo00<007ooOol0;7oo00L007ooOomoo`00Ool0000ZOol4000017oo001oo`00:Woo
00<007oo00000Woo00<007oo0000:Woo00<007oo00000Woo00<007oo0000:Goo00L007ooOomoo`00
Ool00002Ool00`00Ool00004Ool001]oo`8002eoo`07001oogooOol007oo0000:Woo00<007oo0000
0Woo00<007oo0000:Woo0P000goo00<007oo0000:goo00L007ooOomoo`00Ool0000YOol01`00Oomo
ogoo001oo`00009oo`03001oo`0000Aoo`006goo00<007ooOol0:goo00<007oo00000Woo00<007oo
0000:goo0P000Woo00<007oo0000:Woo00<007ooOol00Woo00<007oo0000:Woo00<007oo00000Woo
00<007oo0000:Goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool001]oo`03001oogoo02ao
o`03001oogoo009oo`03001oogoo02]oo`05001oogooOol0000/Ool20003Ool00`00Oomoo`0ZOol0
0`00Oomoo`02Ool00`00Oomoo`0WOol20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000EOooo00090003Ool001]oo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Moo`006goo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;goo00<0
07ooOol0<7oo00<007ooOol01goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=o
o`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=o
o`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo
17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool000]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo0?moo`=oo`002Woo00<007oo00001goo00<007oo000017oo00<007ooOol0ogoo0goo000:
Ool00`00Ool00009Ool00`00Oomoo`02Ool2003oOol4Ool000Yoo`03001oo`0000Moo`8000Eoo`03
001oogoo0?moo`=oo`002Woo00<007oo00001goo00<007ooOol017oo00<007ooOol0ogoo0goo000;
Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00
Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00
Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<007oo
Ool0ogoo0goo000EOol00`00Oomoo`03Ool2003oOol4Ool001Eoo`03001oogoo00=oo`03001oogoo
0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0ogoo0goo000DOol20005Ool00`00Oomoo`3o
Ool3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.8859, -1.14192, 
  0.398872, 0.0129078}}],

Cell[OutputFormData["\<\
Graphics[{{Line[{{4.166666666666666*^-6, 0.}, {4.056699157291579, 0.}, 
      {8.480879985937368, 0.}, {12.63593663385385, 0.}, {16.6318407770828, \
0.}, 
      {20.88525908229088, 0.}, {24.97952488281141, 0.}, {29.33130484531106, \
0.}, 
      {33.52393230312316, 0.}, {37.55740725624772, 0.}, {41.8483963713514, \
0.}, 
      {45.98023298176754, 0.}, {49.95291708749614, 0.}, {54.18311535520386, \
0.}, 
      {58.25416111822403, 0.}, {62.58272104322333, 0.}, {66.75212846353509, \
0.}, 
      {70.7623833791593, 0.}, {75.03015245676263, 0.}, {79.13876902967842, \
0.}, 
      {83.50489976457335, 0.}, {87.71187799478072, 0.}, {91.75970372030056, \
0.}, 
      {96.0650436077995, 0.}, {99.99999583333334, 0.}}]}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[xplot,yplot]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.188823 0.0414496 [
[.21429 .17632 -6 -9 ]
[.21429 .17632 6 0 ]
[.40476 .17632 -6 -9 ]
[.40476 .17632 6 0 ]
[.59524 .17632 -6 -9 ]
[.59524 .17632 6 0 ]
[.78571 .17632 -6 -9 ]
[.78571 .17632 6 0 ]
[.97619 .17632 -9 -9 ]
[.97619 .17632 9 0 ]
[.01131 .02302 -12 -4.5 ]
[.01131 .02302 0 4.5 ]
[.01131 .10592 -12 -4.5 ]
[.01131 .10592 0 4.5 ]
[.01131 .27172 -6 -4.5 ]
[.01131 .27172 0 4.5 ]
[.01131 .35462 -6 -4.5 ]
[.01131 .35462 0 4.5 ]
[.01131 .43752 -6 -4.5 ]
[.01131 .43752 0 4.5 ]
[.01131 .52042 -6 -4.5 ]
[.01131 .52042 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .18882 m
.21429 .19507 L
s
[(20)] .21429 .17632 0 1 Mshowa
.40476 .18882 m
.40476 .19507 L
s
[(40)] .40476 .17632 0 1 Mshowa
.59524 .18882 m
.59524 .19507 L
s
[(60)] .59524 .17632 0 1 Mshowa
.78571 .18882 m
.78571 .19507 L
s
[(80)] .78571 .17632 0 1 Mshowa
.97619 .18882 m
.97619 .19507 L
s
[(100)] .97619 .17632 0 1 Mshowa
.125 Mabswid
.07143 .18882 m
.07143 .19257 L
s
.11905 .18882 m
.11905 .19257 L
s
.16667 .18882 m
.16667 .19257 L
s
.2619 .18882 m
.2619 .19257 L
s
.30952 .18882 m
.30952 .19257 L
s
.35714 .18882 m
.35714 .19257 L
s
.45238 .18882 m
.45238 .19257 L
s
.5 .18882 m
.5 .19257 L
s
.54762 .18882 m
.54762 .19257 L
s
.64286 .18882 m
.64286 .19257 L
s
.69048 .18882 m
.69048 .19257 L
s
.7381 .18882 m
.7381 .19257 L
s
.83333 .18882 m
.83333 .19257 L
s
.88095 .18882 m
.88095 .19257 L
s
.92857 .18882 m
.92857 .19257 L
s
.25 Mabswid
0 .18882 m
1 .18882 L
s
.02381 .02302 m
.03006 .02302 L
s
[(-4)] .01131 .02302 1 0 Mshowa
.02381 .10592 m
.03006 .10592 L
s
[(-2)] .01131 .10592 1 0 Mshowa
.02381 .27172 m
.03006 .27172 L
s
[(2)] .01131 .27172 1 0 Mshowa
.02381 .35462 m
.03006 .35462 L
s
[(4)] .01131 .35462 1 0 Mshowa
.02381 .43752 m
.03006 .43752 L
s
[(6)] .01131 .43752 1 0 Mshowa
.02381 .52042 m
.03006 .52042 L
s
[(8)] .01131 .52042 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04375 m
.02756 .04375 L
s
.02381 .06447 m
.02756 .06447 L
s
.02381 .0852 m
.02756 .0852 L
s
.02381 .12665 m
.02756 .12665 L
s
.02381 .14737 m
.02756 .14737 L
s
.02381 .1681 m
.02756 .1681 L
s
.02381 .20955 m
.02756 .20955 L
s
.02381 .23027 m
.02756 .23027 L
s
.02381 .251 m
.02756 .251 L
s
.02381 .29245 m
.02756 .29245 L
s
.02381 .31317 m
.02756 .31317 L
s
.02381 .3339 m
.02756 .3339 L
s
.02381 .37535 m
.02756 .37535 L
s
.02381 .39607 m
.02756 .39607 L
s
.02381 .4168 m
.02756 .4168 L
s
.02381 .45825 m
.02756 .45825 L
s
.02381 .47897 m
.02756 .47897 L
s
.02381 .49969 m
.02756 .49969 L
s
.02381 .54114 m
.02756 .54114 L
s
.02381 .56187 m
.02756 .56187 L
s
.02381 .58259 m
.02756 .58259 L
s
.02381 .0023 m
.02756 .0023 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60328 L
.02729 .60324 L
.02846 .60317 L
.03053 .60301 L
.03279 .60277 L
.03527 .60242 L
.0379 .60196 L
.04262 .60089 L
.04749 .59947 L
.05205 .59784 L
.06244 .59304 L
.07305 .58658 L
.08274 .57925 L
.10458 .55768 L
.12357 .53291 L
.14429 .499 L
.16561 .45585 L
.18493 .40855 L
.22406 .28355 L
.24493 .19815 L
.25408 .15873 L
.25893 .13962 L
.2616 .13055 L
.26413 .1235 L
.26531 .12088 L
.26656 .11863 L
.26721 .11769 L
.26793 .11686 L
.2692 .11593 L
.27035 .11568 L
.27159 .11607 L
.27275 .11704 L
.27383 .11843 L
.27492 .12031 L
.27593 .12245 L
.27823 .1285 L
.28288 .14447 L
.30268 .22856 L
.34173 .3692 L
.36307 .4279 L
.38322 .47376 L
.42169 .53965 L
.44157 .56394 L
.45171 .57399 L
.46261 .58308 L
.47284 .59005 L
.48218 .59512 L
.48668 .59712 L
Mistroke
.49158 .59898 L
.49586 .60034 L
.5005 .60151 L
.50327 .60208 L
.50583 .6025 L
.50827 .60283 L
.50951 .60296 L
.51084 .60308 L
.51205 .60317 L
.51315 .60323 L
.51426 .60327 L
.51531 .6033 L
.51653 .60331 L
.51766 .60331 L
.51889 .60328 L
.52021 .60323 L
.5215 .60316 L
.52269 .60307 L
.52536 .6028 L
.52771 .60248 L
.53019 .60206 L
.53545 .6009 L
.54119 .59919 L
.5515 .59498 L
.56084 .58987 L
.58181 .57387 L
.60103 .55346 L
.62184 .52479 L
.64136 .49119 L
.66281 .44598 L
.70227 .33558 L
.72339 .25854 L
.74266 .17707 L
.75221 .13817 L
.75483 .12947 L
.75627 .12539 L
.75761 .1221 L
.75885 .11961 L
.75999 .11783 L
.76125 .11647 L
.76192 .11602 L
.76262 .11575 L
.7638 .11579 L
.76488 .11636 L
.76612 .11764 L
.76729 .11941 L
.76938 .12383 L
.77165 .13015 L
.78154 .16819 L
.82242 .33036 L
Mistroke
.84275 .39299 L
.86179 .44212 L
.89965 .51723 L
.91991 .54682 L
.93844 .5681 L
.95649 .58385 L
.96671 .59067 L
.97619 .59566 L
Mfstroke
.02381 .18882 m
.06244 .23885 L
.10458 .29026 L
.12507 .3128 L
.14415 .33151 L
.16371 .34745 L
.17333 .35369 L
.18221 .35825 L
.18696 .36014 L
.192 .36166 L
.19461 .36223 L
.19586 .36245 L
.19706 .36262 L
.19773 .3627 L
.19846 .36278 L
.19974 .36288 L
.20046 .36291 L
.20124 .36294 L
.20196 .36294 L
.20263 .36294 L
.20379 .36289 L
.20502 .36281 L
.20607 .36269 L
.20722 .36253 L
.20846 .36231 L
.20979 .36201 L
.21219 .36131 L
.21461 .36038 L
.2169 .35928 L
.2212 .35659 L
.22579 .35267 L
.23085 .34686 L
.23614 .33878 L
.24111 .32888 L
.24573 .31712 L
.24997 .30367 L
.25953 .26077 L
.26945 .19474 L
.27491 .15511 L
.28006 .12213 L
.28486 .09707 L
.29006 .07567 L
.29915 .04933 L
.30374 .03998 L
.30879 .03197 L
.31405 .02566 L
.31898 .02131 L
.32134 .01968 L
.32359 .01838 L
.3278 .01653 L
Mistroke
.33015 .0158 L
.33233 .0153 L
.33358 .01508 L
.33472 .01493 L
.33603 .01481 L
.33726 .01474 L
.33843 .01472 L
.33968 .01473 L
.34086 .01479 L
.34193 .01487 L
.34319 .01501 L
.34456 .0152 L
.34705 .01566 L
.34966 .0163 L
.35242 .01714 L
.35738 .01901 L
.36617 .0234 L
.37587 .02956 L
.41612 .06557 L
.45486 .10986 L
.49605 .16195 L
.53573 .21364 L
.57389 .26212 L
.6145 .30917 L
.63328 .32804 L
.6536 .34527 L
.66473 .35281 L
.66962 .35558 L
.67499 .3582 L
.67972 .36009 L
.68479 .36163 L
.68759 .36224 L
.68892 .36247 L
.69015 .36264 L
.69138 .36277 L
.69202 .36283 L
.69271 .36287 L
.69387 .36292 L
.69515 .36293 L
.69636 .3629 L
.69749 .36283 L
.69873 .36271 L
.70006 .36253 L
.70145 .36228 L
.70277 .36198 L
.70523 .36125 L
.70753 .36035 L
.70966 .35934 L
.71447 .35629 L
.71929 .35203 L
Mistroke
.7246 .34569 L
.73014 .33677 L
.73532 .32575 L
.74029 .31212 L
.74571 .29283 L
.75083 .26924 L
.75558 .24181 L
.76449 .1788 L
.77411 .11544 L
.77962 .08865 L
.78469 .06962 L
.78954 .05541 L
.79465 .04373 L
.79924 .03555 L
.80353 .02952 L
.80823 .02439 L
.81326 .02032 L
.81583 .01874 L
.81855 .01739 L
.82088 .01647 L
.82345 .01571 L
.82488 .01538 L
.8262 .01514 L
.82764 .01495 L
.82837 .01487 L
.82916 .01481 L
.82986 .01477 L
.8305 .01475 L
.83124 .01474 L
.83194 .01474 L
.83318 .01478 L
.83387 .01482 L
.83452 .01487 L
.83568 .01498 L
.83693 .01514 L
.83918 .01553 L
.84185 .01615 L
.8443 .01684 L
.84961 .01877 L
.85464 .02107 L
.8745 .03381 L
.89291 .04958 L
.93211 .09127 L
.97377 .14245 L
.97619 .14555 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`003goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?mo
o`moo`003goo00<007ooOol0ogoo3goo0009Ool30003Ool00`00Oomoo`1AOol8001oOol8000^Ool0
00Yoo`03001oogoo009oo`03001oogoo04ioo`<000Qoo`03001oogoo07Yoo`8000Qoo`<002]oo`00
0goo0`000Woo10000goo0`00CWoo00<007ooOol02Goo0P00NGoo00<007ooOol02goo00<007ooOol0
:7oo0008Ool00`00Ool00004Ool00`00Oomoo`1=Ool00`00Oomoo`0<Ool2001gOol00`00Oomoo`0<
Ool2000XOol000Uoo`8000Aoo`03001oogoo04aoo`03001oogoo00moo`03001oogoo07=oo`03001o
ogoo00moo`03001oogoo02Eoo`002Woo00<007ooOol00Woo00<007ooOol0Bgoo00<007ooOol04Goo
00<007ooOol0LGoo00<007ooOol04Goo00<007ooOol097oo000?Ool00`00Oomoo`1;Ool00`00Oomo
o`0BOol00`00Oomoo`1_Ool00`00Oomoo`0COol2000TOol000moo`03001oogoo04Yoo`03001oogoo
01Aoo`03001oogoo06ioo`03001oogoo01Eoo`03001oogoo025oo`003goo0P00Bgoo00<007ooOol0
5Goo00<007ooOol0K7oo00<007ooOol05goo0P008Goo000?Ool00`00Oomoo`19Ool00`00Oomoo`0G
Ool2001/Ool00`00Oomoo`0IOol00`00Oomoo`0NOol000moo`03001oogoo04Uoo`03001oogoo01Uo
o`03001oogoo06Qoo`03001oogoo01]oo`03001oogoo01eoo`003goo00<007ooOol0B7oo00<007oo
Ool06goo00<007ooOol0Igoo00<007ooOol077oo00<007ooOol077oo000?Ool00`00Oomoo`18Ool0
0`00Oomoo`0LOol00`00Oomoo`1VOol00`00Oomoo`0MOol00`00Oomoo`0KOol000moo`8004Qoo`03
001oogoo01ioo`03001oogoo06Eoo`03001oogoo01eoo`03001oogoo01]oo`003goo00<007ooOol0
Agoo00<007ooOol07goo00<007ooOol0Hgoo00<007ooOol07goo00<007ooOol06Woo000?Ool00`00
Oomoo`16Ool00`00Oomoo`0QOol00`00Oomoo`1ROol00`00Oomoo`0POol00`00Oomoo`0IOol000mo
o`03001oogoo04Ioo`03001oogoo029oo`03001oogoo065oo`03001oogoo025oo`03001oogoo01Qo
o`003goo00<007ooOol0AWoo00<007ooOol08goo00<007ooOol0Ggoo00<007ooOol08goo00<007oo
Ool05goo000?Ool00`00Oomoo`16Ool00`00Oomoo`0TOol00`00Oomoo`1NOol00`00Oomoo`0TOol0
0`00Oomoo`0FOol000moo`8004Moo`03001oogoo02Eoo`03001oogoo05aoo`03001oogoo02Eoo`03
001oogoo01Ioo`003goo00<007ooOol0AGoo00<007ooOol09goo00<007ooOol0Fgoo00<007ooOol0
9Woo00<007ooOol05Goo000?Ool00`00Oomoo`15Ool00`00Oomoo`0WOol00`00Oomoo`1KOol00`00
Oomoo`0WOol00`00Oomoo`0DOol000moo`03001oogoo04Eoo`03001oogoo02Qoo`03001oogoo05Yo
o`03001oogoo02Qoo`03001oogoo01=oo`0027oo0`0017oo00<007ooOol0AGoo00<007ooOol0:Goo
00<007ooOol0FGoo00<007ooOol0:Goo00<007ooOol04Woo0008Ool00`00Oomoo`04Ool00`00Oomo
o`15Ool00`00Oomoo`0ZOol00`00Oomoo`1GOol00`00Oomoo`0[Ool00`00Oomoo`0AOol000=oo`<0
00=oo`03001oogoo00=oo`<004Eoo`03001oogoo02]oo`03001oogoo05Ioo`03001oogoo02]oo`03
001oogoo015oo`002Goo00<007ooOol00goo00<007ooOol0A7oo00<007ooOol0;Goo00<007ooOol0
EGoo00<007ooOol0;7oo00<007ooOol047oo0008Ool00`00Ool00004Ool00`00Oomoo`14Ool00`00
Oomoo`0^Ool00`00Oomoo`1DOol00`00Oomoo`0]Ool00`00Oomoo`0?Ool000Uoo`03001oogoo00=o
o`03001oogoo041oo`<00003Ool007oo031oo`03001oogoo04moo`<00003Ool007oo02moo`03001o
ogoo00ioo`003goo00<007ooOol0@7oo00D007oo001oo`00035oo`03001oogoo04ioo`800004Ool0
07oo000aOol00`00Oomoo`0=Ool000moo`03001oogoo03moo`04001oogooOol2000bOol00`00Oomo
o`1=Ool01P00Oomoo`00Ool0039oo`03001oogoo00aoo`003goo0P00@7oo00@007ooOomoo`8003=o
o`03001oogoo04]oo`03001oogoo009oo`03001oogoo039oo`03001oogoo00]oo`003goo00<007oo
Ool0?goo00D007ooOomoo`0003Eoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo039oo`03
001oogoo00]oo`003goo00<007ooOol0?goo00@007ooOomoo`8003Eoo`03001oogoo04Uoo`03001o
ogoo009oo`8003Aoo`03001oogoo00Yoo`003goo00<007ooOol0?Woo00<007ooOol00Woo0P00=Goo
00<007ooOol0BGoo00<007ooOol00Woo0P00=Goo00<007ooOol02Goo000?Ool00`00Oomoo`0nOol0
0`00Oomoo`02Ool2000fOol00`00Oomoo`18Ool00`00Oomoo`02Ool2000fOol00`00Oomoo`08Ool0
00moo`8002ioo`<000=oo`03001oogoo00Moo`03001oogoo009oo`03001oo`0001ioo`<0009oo`03
001oogoo015oo`03001oogoo01Moo`8000Aoo`03001oogoo02Ioo`03001oogoo00=oo`8000Aoo`03
001oogoo02Qoo`D0009oo`8000=oo`03001oogoo00=oo`003goo00<007ooOol0;Goo00<007ooOol0
0Woo00<007oo000027oo00<007ooOol00Woo00@007ooOol001ioo`06001oogoo001oo`004goo00<0
07ooOol05Woo00<007oo00000Woo00<007oo00009goo00<007ooOol00Woo0P0000Moo`00Oomoo`00
Ool0000[Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`003goo00<007ooOol0;Woo00L0
07ooOomoo`00Ool00007Ool00`00Oomoo`03Ool01000Oomoo`0077oo100000Aoo`00Ool001=oo`03
001oogoo01Ioo`03001oo`00009oo`03001oo`0002Moo`03001oogoo009oo`800007Ool007ooOol0
07oo0000:goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool000moo`03001oogoo02ioo`07
001oogooOol007oo00001goo00<007ooOol00goo00@007ooOol001aoo`03001oo`00009oo`03001o
o`0001Aoo`03001oogoo01Eoo`8000=oo`03001oo`0002Moo`03001oogoo009oo`04001oo`000002
Ool00`00Ool0000[Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`003goo00<007ooOol0
;Goo00<007oo00000Woo00<007oo00001goo00<007ooOol00goo00@007ooOol001eoo`80009oo`03
001oo`0001Eoo`03001oogoo01Aoo`03001oogoo009oo`03001oo`0002Ioo`03001oogoo00=oo`80
0007Ool007ooOol007oo0000:goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool000moo`03
001oogoo02ioo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol0000M
Ool01@00Oomoogoo00005goo00<007ooOol057oo0P000goo00<007ooOol09Goo00<007ooOol00goo
00D007oo001oo`00009oo`03001oogoo02Uoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`00
3goo0P00?7oo00<007ooOol017oo00D007ooOomoo`0003Uoo`03001oogoo045oo`03001oogoo00=o
o`05001oogooOol0000oOol000moo`03001oogoo03]oo`03001oogoo00Aoo`05001oogooOol0000j
Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0mOol000moo`03001o
ogoo03]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03Uoo`03001oogoo03ioo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo03eoo`003goo00<007ooOol0>goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol0>Goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol0?7oo000?Ool00`00Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`0iOol00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0lOol000moo`03
001oogoo03]oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo03]oo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo03aoo`0027ooo`005P000goo000?Ool2000;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Ool00006Ool01@00Oomoogoo000037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00goo0P002goo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol01goo000?Ool00`00Ool0000jOol00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`0kOol00`00Oomoo`0iOol00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`0kOol000moo`04001oogoo000iOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`0lOol00`00Oomoo`0gOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0kOol000mo
o`04001oogoo000iOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`0f
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0kOol000moo`80009oo`03001oogoo03Eo
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo03eoo`03001oogoo03Eoo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo03Yoo`003goo00<007ooOol00Woo00<007ooOol0=7oo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol0=Goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol0>Woo000?Ool00`00Oomoo`03Ool00`00Oomoo`0cOol00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`0dOol00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`0jOol000moo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo03moo`03001oogoo039oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
03Yoo`003goo00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol0?goo00<007ooOol0<Goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0>Goo000?
Ool00`00Oomoo`05Ool00`00Oomoo`0`Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`10
Ool00`00Oomoo`0`Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0iOol000moo`8000Mo
o`03001oogoo02moo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo041oo`03001oogoo031o
o`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo03Uoo`003goo00<007ooOol01goo00<007oo
Ool0;Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol0@Goo00<007ooOol0;goo00<007oo
Ool017oo00<007ooOol027oo00<007ooOol0>Goo000?Ool00`00Oomoo`08Ool00`00Oomoo`0/Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`11Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0hOol000moo`03001oogoo00Uoo`03001oogoo02]oo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo049oo`03001oogoo02aoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo03Qoo`003goo00<007ooOol02Goo00<007ooOol0:goo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol0@goo00<007ooOol0:goo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol0>7oo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`14Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0h
Ool000moo`8000aoo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo04=o
o`03001oogoo02Uoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo03Moo`003goo00<007oo
Ool037oo00<007ooOol09goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol0A7oo00<007oo
Ool0:7oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol0=goo000?Ool00`00Oomoo`0<Ool0
0`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`15Ool00`00Oomoo`0WOol0
0`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol000moo`03001oogoo00eoo`03001oogoo
02Ioo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo04Eoo`03001oogoo02Ioo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo03Moo`0027oo0`0017oo00<007ooOol03Woo00<007ooOol0
97oo00<007ooOol01Woo00<007ooOol037oo00<007ooOol0AWoo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol03Goo00<007ooOol0=Woo0008Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00
Oomoo`0SOol00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`17Ool00`00Oomoo`0SOol00`00
Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`0fOol000Uoo`03001oogoo00=oo`<000moo`03001o
ogoo02=oo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo04Qoo`03001oogoo029oo`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo03Ioo`002Goo00<007ooOol00goo00<007ooOol047oo
00<007ooOol08Woo00<007ooOol01Goo00<007ooOol03Woo00<007ooOol0Agoo00<007ooOol08Woo
00<007ooOol01Goo00<007ooOol03Goo00<007ooOol0=Woo0008Ool00`00Ool00004Ool00`00Oomo
o`0AOol00`00Oomoo`0POol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomo
o`0POol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0eOol000Uoo`03001oogoo00=oo`03
001oogoo019oo`03001oogoo01moo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo04Uoo`03
001oogoo01moo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo03Eoo`003goo00<007ooOol0
4Woo00<007ooOol07goo00<007ooOol01Goo00<007ooOol047oo00<007ooOol0BGoo00<007ooOol0
7Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol0=Goo000?Ool2000DOol00`00Oomoo`0M
Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`1:Ool00`00Oomoo`0LOol00`00Oomoo`06
Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol000moo`03001oogoo01Aoo`03001oogoo01aoo`03001o
ogoo00Ioo`03001oogoo011oo`03001oogoo04]oo`03001oogoo01]oo`03001oogoo00Ioo`03001o
ogoo011oo`03001oogoo03Aoo`003goo00<007ooOol05Goo00<007ooOol06goo00<007ooOol01Goo
00<007ooOol04Woo00<007ooOol0BWoo00<007ooOol06goo00<007ooOol01Goo00<007ooOol04Goo
00<007ooOol0=7oo000?Ool00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomo
o`0BOol00`00Oomoo`1;Ool00`00Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomo
o`0dOol000moo`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo00Ioo`03001oogoo019oo`03
001oogoo04aoo`03001oogoo01Qoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo03Aoo`00
3goo00<007ooOol067oo00<007ooOol05goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol0
CGoo00<007ooOol05goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol0<goo000?Ool2000J
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`1=Ool00`00Oomoo`0F
Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`0cOol000moo`03001oogoo01Yoo`03001o
ogoo01Aoo`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo04ioo`03001oogoo01Aoo`03001o
ogoo00Ioo`03001oogoo01=oo`03001oogoo03=oo`003goo00<007ooOol06goo00<007ooOol04goo
00<007ooOol01Woo00<007ooOol057oo00<007ooOol0Cgoo00<007ooOol04goo00<007ooOol01Goo
00<007ooOol057oo00<007ooOol0<goo000?Ool00`00Oomoo`0LOol00`00Oomoo`0AOol00`00Oomo
o`06Ool00`00Oomoo`0FOol00`00Oomoo`1?Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomo
o`0EOol00`00Oomoo`0bOol000moo`03001oogoo01eoo`03001oogoo011oo`03001oogoo00Ioo`03
001oogoo01Ioo`03001oogoo051oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo01Eoo`03
001oogoo039oo`003goo00<007ooOol07Woo00<007ooOol03goo00<007ooOol01Goo00<007ooOol0
5goo00<007ooOol0DGoo00<007ooOol03goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol0
<Woo000?Ool2000POol2000>Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`1BOol00`00
Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`0bOol000moo`03001oogoo025o
o`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo01Uoo`03001oogoo059oo`8000ioo`03001o
ogoo00Aoo`03001oogoo01Qoo`03001oogoo035oo`003goo00<007ooOol08Woo0P002goo00<007oo
Ool01Goo00<007ooOol06Goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool067oo00<007ooOol0<Goo0009Ool30003Ool00`00Oomoo`0TOol00`00Oomoo`08Ool00`00Oomo
o`04Ool00`00Oomoo`0JOol00`00Oomoo`1EOol00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomo
o`0IOol00`00Oomoo`0aOol000Yoo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo01]oo`03001oogoo05Eoo`8000Uoo`03001oogoo00Aoo`03001oogoo
01Yoo`03001oogoo031oo`0027oo10000goo0`009Woo0P001Woo00<007ooOol00goo0P007Woo00<0
07ooOol0Egoo00<007ooOol01Goo00<007ooOol00goo0P007Goo00<007ooOol0<7oo0008Ool00`00
Ool00004Ool00`00Oomoo`0XOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`1H
Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`0`Ool000Uoo`8000Aoo`03001o
ogoo02Yoo`@0009oo`<0025oo`03001oogoo05Yoo`@00003Ool007oo00<0025oo`03001oogoo02mo
o`002Woo00<007ooOol00Woo00<007ooOol0;7oo1@0097oo00<007ooOol0G7oo100097oo00<007oo
Ool0;goo000?Ool00`00Oomoo`0]Ool00`00Oomoo`0UOol00`00Oomoo`1MOol00`00Oomoo`0UOol0
0`00Oomoo`0^Ool000moo`03001oogoo02aoo`03001oogoo02Ioo`03001oogoo05aoo`03001oogoo
02Ioo`03001oogoo02ioo`003goo0P00;Goo00<007ooOol09goo00<007ooOol0Fgoo00<007ooOol0
9Woo00<007ooOol0;Woo000?Ool00`00Oomoo`0/Ool00`00Oomoo`0WOol00`00Oomoo`1KOol00`00
Oomoo`0WOol00`00Oomoo`0]Ool000moo`03001oogoo02]oo`03001oogoo02Qoo`03001oogoo05Yo
o`03001oogoo02Qoo`03001oogoo02eoo`003goo00<007ooOol0:goo00<007ooOol0:7oo00<007oo
Ool0FWoo00<007ooOol0:7oo00<007ooOol0;Goo000?Ool00`00Oomoo`0[Ool00`00Oomoo`0YOol0
0`00Oomoo`1IOol00`00Oomoo`0YOol00`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001oogoo
02Yoo`03001oogoo05Qoo`03001oogoo02Yoo`03001oogoo02aoo`003goo0P00:goo00<007ooOol0
:Woo00<007ooOol0F7oo00<007ooOol0:Woo00<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00
Oomoo`0[Ool00`00Oomoo`1GOol00`00Oomoo`0[Ool00`00Oomoo`0[Ool000moo`03001oogoo02Uo
o`03001oogoo02aoo`03001oogoo05Ioo`03001oogoo02aoo`03001oogoo02]oo`003goo00<007oo
Ool0:Goo00<007ooOol0;7oo00<007ooOol0EWoo00<007ooOol0;7oo00<007ooOol0:goo000?Ool0
0`00Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomoo`1EOol00`00Oomoo`0]Ool00`00Oomoo`0ZOol0
00moo`03001oogoo02Qoo`03001oogoo02ioo`03001oogoo05Aoo`03001oogoo02ioo`03001oogoo
02Yoo`003goo0P00:Goo00<007ooOol0;Woo00<007ooOol0E7oo00<007ooOol0;goo00<007ooOol0
:Goo000?Ool00`00Oomoo`0WOol00`00Oomoo`0_Ool00`00Oomoo`1COol00`00Oomoo`0`Ool00`00
Oomoo`0YOol000moo`03001oogoo02Moo`03001oogoo031oo`03001oogoo059oo`03001oogoo031o
o`03001oogoo02Uoo`0027oo0P001Goo00<007ooOol09goo00<007ooOol0<7oo00<007ooOol0DWoo
00<007ooOol0<Goo00<007ooOol0:7oo0008Ool00`00Ool00004Ool00`00Oomoo`0VOol00`00Oomo
o`0bOol00`00Oomoo`1@Ool00`00Oomoo`0bOol00`00Oomoo`0XOol000Qoo`03001oo`0000Aoo`<0
02Ioo`03001oogoo039oo`03001oogoo051oo`03001oogoo039oo`03001oogoo02Qoo`0027oo0P00
1Goo00<007ooOol09Woo00<007ooOol0<goo00<007ooOol0Cgoo00<007ooOol0<goo00<007ooOol0
9goo0008Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0dOol00`00Oomoo`1>Ool00`00
Oomoo`0dOol00`00Oomoo`0WOol000Uoo`8000Aoo`03001oogoo02Eoo`03001oogoo03Eoo`03001o
ogoo04eoo`03001oogoo03Eoo`03001oogoo02Ioo`003goo00<007ooOol097oo00<007ooOol0=Woo
00<007ooOol0CGoo00<007ooOol0=Goo00<007ooOol09Woo000?Ool00`00Oomoo`0TOol00`00Oomo
o`0gOol00`00Oomoo`1;Ool00`00Oomoo`0gOol00`00Oomoo`0UOol000moo`8002Eoo`03001oogoo
03Moo`03001oogoo04]oo`03001oogoo03Moo`03001oogoo02Eoo`003goo00<007ooOol08goo00<0
07ooOol0>Goo00<007ooOol0BGoo00<007ooOol0>Goo00<007ooOol097oo000?Ool00`00Oomoo`0S
Ool00`00Oomoo`0iOol00`00Oomoo`19Ool00`00Oomoo`0iOol00`00Oomoo`0TOol000moo`03001o
ogoo029oo`03001oogoo03]oo`03001oogoo04Moo`03001oogoo03]oo`03001oogoo02=oo`003goo
00<007ooOol08Woo00<007ooOol0>goo00<007ooOol0Agoo00<007ooOol0>goo00<007ooOol08goo
000?Ool00`00Oomoo`0QOol00`00Oomoo`0mOol00`00Oomoo`15Ool00`00Oomoo`0mOol00`00Oomo
o`0ROol000moo`80029oo`03001oogoo03eoo`03001oogoo04Eoo`03001oogoo03eoo`03001oogoo
029oo`003goo00<007ooOol087oo00<007ooOol0?goo00<007ooOol0@goo00<007ooOol0?goo00<0
07ooOol08Goo000?Ool00`00Oomoo`0POol00`00Oomoo`0oOol00`00Oomoo`13Ool00`00Oomoo`0o
Ool00`00Oomoo`0QOol000moo`03001oogoo01moo`03001oogoo045oo`03001oogoo045oo`03001o
ogoo045oo`03001oogoo021oo`003goo00<007ooOol07goo00<007ooOol0@Woo00<007ooOol0?goo
00<007ooOol0@Woo00<007ooOol087oo000?Ool2000OOol00`00Oomoo`13Ool00`00Oomoo`0oOol0
0`00Oomoo`13Ool00`00Oomoo`0OOol000moo`03001oogoo01eoo`03001oogoo04Eoo`03001oogoo
03eoo`03001oogoo04Aoo`03001oogoo01moo`003goo00<007ooOol07Goo00<007ooOol0AWoo00<0
07ooOol0?7oo00<007ooOol0AGoo00<007ooOol07Woo000?Ool00`00Oomoo`0LOol00`00Oomoo`17
Ool00`00Oomoo`0kOol00`00Oomoo`16Ool00`00Oomoo`0NOol000Uoo`03001oogoo00=oo`03001o
ogoo01aoo`03001oogoo04Qoo`03001oogoo03Yoo`03001oogoo04Moo`03001oogoo01eoo`0027oo
00<007oo000017oo00<007ooOol06goo00<007ooOol0BGoo00<007ooOol0>Goo00<007ooOol0B7oo
00<007ooOol07Goo0008Ool00`00Ool00004Ool3000JOol00`00Oomoo`1;Ool00`00Oomoo`0hOol0
0`00Oomoo`19Ool00`00Oomoo`0LOol000Uoo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo
04aoo`03001oogoo03Ioo`03001oogoo04]oo`03001oogoo01]oo`0027oo00<007oo000017oo00<0
07ooOol06Goo00<007ooOol0CGoo00<007ooOol0=Goo00<007ooOol0C7oo00<007ooOol06goo0009
Ool00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`1>Ool00`00Oomoo`0dOol00`00Oomoo`1=
Ool00`00Oomoo`0JOol000moo`03001oogoo01Qoo`03001oogoo04moo`03001oogoo03=oo`03001o
ogoo04moo`03001oogoo01Uoo`003goo00<007ooOol05goo00<007ooOol0DGoo00<007ooOol0<Goo
00<007ooOol0DGoo00<007ooOol067oo000?Ool2000GOol00`00Oomoo`1COol00`00Oomoo`0_Ool0
0`00Oomoo`1BOol00`00Oomoo`0HOol000moo`03001oogoo01Ioo`03001oogoo05=oo`03001oogoo
02moo`03001oogoo05=oo`03001oogoo01Moo`003goo00<007ooOol05Goo00<007ooOol0EGoo00<0
07ooOol0;Goo00<007ooOol0EGoo00<007ooOol05Woo000?Ool00`00Oomoo`0DOol00`00Oomoo`1G
Ool00`00Oomoo`0[Ool00`00Oomoo`1GOol00`00Oomoo`0EOol000moo`03001oogoo01=oo`03001o
ogoo05Uoo`03001oogoo02Uoo`03001oogoo05Uoo`03001oogoo01Aoo`003goo00<007ooOol04Woo
00<007ooOol0FWoo00<007ooOol0:7oo00<007ooOol0FWoo00<007ooOol057oo000?Ool2000BOol0
0`00Oomoo`1LOol00`00Oomoo`0WOol00`00Oomoo`1KOol00`00Oomoo`0COol000moo`03001oogoo
011oo`03001oogoo05ioo`03001oogoo02Eoo`03001oogoo05eoo`03001oogoo019oo`003goo00<0
07ooOol03goo00<007ooOol0H7oo00<007ooOol08goo00<007ooOol0Ggoo00<007ooOol04Goo000?
Ool00`00Oomoo`0>Ool00`00Oomoo`1ROol00`00Oomoo`0QOol00`00Oomoo`1QOol00`00Oomoo`0@
Ool000moo`03001oogoo00eoo`03001oogoo06Aoo`8001moo`8006Eoo`03001oogoo00moo`003goo
0P003Goo00<007ooOol0Igoo00<007ooOol06goo00<007ooOol0IWoo00<007ooOol03Woo000?Ool0
0`00Oomoo`0;Ool00`00Oomoo`1YOol2000IOol2001ZOol2000>Ool000moo`03001oogoo00Uoo`80
06ioo`03001oogoo01Eoo`03001oogoo06aoo`8000aoo`003goo00<007ooOol01goo0P00LGoo00<0
07ooOol04Woo0P00LGoo0P002Woo0002Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool3001d
Ool3000?Ool2001eOol00`00Oomoo`07Ool000Aoo`07001oogooOol007oo000017oo00<007ooOol0
0Woo0P00NWoo0`002Goo0`00PGoo0004Ool01`00Oomoogoo001oo`0000Aoo`D007moo`T008Aoo`00
17oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3oOol?Ool000Aoo`07001oogooOol007oo0000
17oo00<007ooOol0ogoo3goo0003Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3oOol?Ool000mo
o`03001oogoo0?moo`moo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.88348, -4.82305, 
  0.380877, 0.0875136}}],

Cell[OutputFormData["\<\
Graphics[{{{Line[{{4.166666666666666*^-6, 9.999999999998179}, 
       {0.1234427160348012, 9.99977108991224}, {0.2357508183498944, \
9.999165965786612}, 
       {0.3653879907386823, 9.997996938139889}, {0.4879349323828924, \
9.99642816677575}, 
       {0.705898917377676, 9.992524113246702}, {0.9424920179678974, \
9.986671588627585}, 
       {1.203044223621859, 9.978280826019176}, {1.479259081094233, \
9.967155958384243}, 
       {1.974817076302018, 9.941437168656801}, {2.486320345625892, \
9.907113206385236}, 
       {2.965503661725943, 9.867763958492746}, {4.056699157291579, \
9.752016422471356}, 
       {5.169748088920781, 9.59610829473873}, {6.188104661132567, \
9.419421239674392}, 
       {8.480879985937368, 8.898857858664367}, {10.47433744441412, \
8.301322627797441}, 
       {12.65028740624912, 7.483144068372817}, {14.88859505346948, \
6.442288119642761}, 
       {16.91805648385246, 5.301027131449559}, {21.02667305676825, \
2.285344860909571}, 
       {23.21775311301878, 0.225120308395005}, {24.17877630915226, \
-0.7260048928392796}, 
       {24.68788407116706, -1.187043562390644}, {24.96814944894381, \
-1.405837032572005}, 
       {25.23365128697562, -1.575889469713843}, {25.35731618203023, \
-1.639194877834914}, 
       {25.48869458584581, -1.693470401806359}, {25.557192317687, \
-1.716028214381404}, 
       {25.63280055798261, -1.736103464920114}, {25.76612706268513, \
-1.758659223897126}, 
       {25.88663179656726, -1.764505628753622}, {26.01653660941294, \
-1.755173572247134}, 
       {26.1391774010334, -1.731709071392257}, {26.25162412127838, \
-1.698174647426247}, 
       {26.3661612130387, -1.652885280996583}, {26.47272369051073, \
-1.601401653391521}, 
       {26.71457926178204, -1.455314258156071}, {27.20199253384476, \
-1.069971495384818}, 
       {29.28147701249545, 0.9586586289924225}, {33.38122432030615, \
4.351644818374801}, 
       {35.62254096250315, 5.767830731736181}, {37.73848579009598, \
6.87421927335033}, 
       {41.77744225051072, 8.463913276422999}, {43.86440596822265, \
9.049902738001719}, 
       {44.9295907671371, 9.292344074030259}, {46.07391287290458, \
9.511759101182075}, 
       {47.14788535783184, 9.679922404545809}, {48.12919548404136, \
9.802205485752049}, 
       {48.60114534708862, 9.850476700641962}, {49.11562164925325, \
9.895358932085519}, 
       {49.56577498411976, 9.928038887461703}, {50.05207848592336, \
9.956457906293143}, 
       {50.34374274164709, 9.97008101015311}, {50.61173435585008, \
9.980341097936973}, 
       {50.86794508041712, 9.988131099987331}, {50.99849764729293, \
9.991342002958132}, 
       {51.13826673218466, 9.994212288459552}, {51.26535537092176, \
9.996313113376487}, 
       {51.38107869446398, 9.997804407424975}, {51.49740928126711, \
9.998898505224707}, 
       {51.60746692988272, 9.999559819676797}, {51.7356009615118, \
9.999871916946997}, 
       {51.85399416872665, 9.999722468051086}, {51.98394017971881, \
9.999074350880363}, 
       {52.12180982148853, 9.997832785488197}, {52.25779187963977, \
9.99604948574445}, 
       {52.38230669353921, 9.99392982063623}, {52.66275415484842, \
9.987450749134584}, 
       {52.90998312827952, 9.979779568804932}, {53.169930897739, \
9.969731650260969}, 
       {53.72210958347891, 9.941635321903582}, {54.32532907081687, \
9.900417881338555}, 
       {55.40697404386953, 9.798826942266536}, {56.38849529862103, \
9.675584135459791}, 
       {58.5897103906053, 9.289433667642361}, {60.60813278223211, \
8.797014925238245}, 
       {62.79330086299776, 8.105501700953878}, {64.84326204658508, \
7.294920675550661}, 
       {67.09525299268179, 6.204069011103039}, {71.23805261767829, \
3.540729878766954}, 
       {73.45563445477568, 1.681976214752386}, {75.47921389996637, \
-0.2834478573306918}, 
       {76.48242822007826, -1.222139545620845}, {76.75727835745853, \
-1.431900652586906}, 
       {76.90794601448557, -1.530425167496753}, {77.0495098001721, \
-1.609789378392465}, 
       {77.17961009530113, -1.669781539872943}, {77.29899348248995, \
-1.712714252401616}, 
       {77.43156761957843, -1.745675650989419}, {77.50121410675887, \
-1.756478558054385}, 
       {77.57459973261759, -1.762874118362514}, {77.69890143111718, \
-1.761895427079044}, 
       {77.81193790972409, -1.748150342180373}, {77.94241650111047, \
-1.717454558843626}, 
       {78.06569682873346, -1.674571304619962}, {78.28502234411193, \
-1.568098599448515}, 
       {78.52297354289338, -1.415622182711301}, {79.5612226775669, \
-0.4976715633129253}, 
       {83.85430554214586, 3.414632018570046}, {85.98922228932289, \
4.925643756682028}, 
       {87.98823590203728, 6.111018888864476}, {91.96301375724114, \
7.922968118254687}, 
       {94.09057427505734, 8.636834576800978}, {96.0361532697366, \
9.150357643414709}, 
       {97.93182498371354, 9.530343359278663}, {99.00456818158907, \
9.694737379683431}, 
       {99.99999583333334, 9.815316706439757}}]}}, 
   {{Line[{{4.166666666666666*^-6, 1.24999999981802*^-6}, 
       {4.056699157291579, 1.206861635523774}, {8.480879985937368, \
2.447122182848795}, 
       {10.63197399634091, 2.991035067799262}, {12.63593663385385, \
3.442345796335324}, 
       {14.69006171723266, 3.826982777887112}, {15.69970788902852, \
3.977442392594925}, 
       {16.6318407770828, 4.087531334283399}, {17.13082465330856, \
4.133104975842899}, 
       {17.65980409490176, 4.169747829183243}, {17.93395345752028, \
4.183535380706929}, 
       {18.06561947941579, 4.1888024158604}, {18.19078036081633, \
4.192959339527718}, 
       {18.26112895382198, 4.194922536708991}, {18.33791765960292, \
4.196751990148235}, 
       {18.47253728950319, 4.199151159208844}, {18.5486110335642, \
4.200041092003962}, 
       {18.62970892798926, 4.200610355689255}, {18.7062378356324, \
4.200781269968505}, 
       {18.77562618203061, 4.200622815162868}, {18.89781241653668, \
4.199602351093233}, 
       {19.02689794912118, 4.197467545426199}, {19.13710752180138, \
4.194758321100315}, 
       {19.25807996138942, 4.190814440574808}, {19.38834244952753, \
4.185394522771027}, 
       {19.52798478221184, 4.178183775701907}, {19.77996499962569, \
4.161320549540882}, 
       {20.03411013498991, 4.13897473332761}, {20.27486766665976, \
4.11248286661431}, 
       {20.72610657760333, 4.047452646682569}, {21.20791539611811, \
3.952870320957471}, 
       {21.7397390922847, 3.812781817872725}, {22.2951601740733, \
3.617899723242662}, 
       {22.81659620501357, 3.378907355073467}, {23.30215423731055, \
3.095263727101312}, 
       {23.74735201774708, 2.770657315836521}, {24.75071226562281, \
1.735766114353393}, 
       {25.79276722301338, 0.1428621496283818}, {26.36540557679675, \
-0.8133453946485785}, 
       {26.90601244151065, -1.608995099116092}, {27.4101371539132, \
-2.213698310920296}, 
       {27.95662818218455, -2.729916356866462}, {28.91125042082948, \
-3.365325617301162}, 
       {29.39279631405319, -3.590904758858421}, {29.92249794209964, \
-3.784235853952407}, 
       {30.47562718975883, -3.936500370063439}, {30.99312430787017, \
-4.041390745496885}, 
       {31.24118257483175, -4.080643355205632}, {31.476674969682, \
-4.111990937374955}, 
       {31.91850487466638, -4.156682381423153}, {32.16531018434435, \
-4.174337003438551}, 
       {32.39414116521874, -4.186424013065165}, {32.52593382787596, \
-4.191619005833342}, 
       {32.64527203929891, -4.195257244182652}, {32.78303071092782, \
-4.198240568873425}, 
       {32.9126360713486, -4.199897069633694}, {33.0351894144263, \
-4.200471914308782}, 
       {33.16639456053948, -4.200053451898492}, {33.2902288751731, \
-4.198708593928864}, 
       {33.40298890313766, -4.196706109613508}, {33.53537899308317, \
-4.193436735697114}, 
       {33.67920138984642, -4.188795814625598}, {33.94051956626792, \
-4.177582795433242}, 
       {34.21401746621792, -4.162202873863984}, {34.50419226422043, \
-4.142058889757255}, 
       {35.02501423229228, -4.09678054157078}, {35.94823224745165, \
-3.991020162024272}, 
       {36.96594330415861, -3.842367802172713}, {41.19275381405141, \
-2.973444545535598}, 
       {45.26041181925668, -1.904953625448793}, {49.58558398644107, \
-0.6483888713982439}, 
       {53.75160364893791, 0.5986370881219398}, {57.75847080674722, \
1.768385184251448}, 
       {62.02285212653564, 2.903363651261837}, {63.99404456727673, \
3.358637687893319}, 
       {66.12808094163653, 3.774309714630499}, {67.29716372846339, \
3.956203334871669}, 
       {67.81013068659705, 4.023177381836898}, {68.37365206183706, \
4.086327698093709}, 
       {68.87010593266065, 4.131899161130025}, {69.40274150432995, \
4.169055850419068}, 
       {69.69685958906959, 4.183833767394203}, {69.83621281570375, \
4.189301014358346}, 
       {69.96524711857652, 4.193443242035528}, {70.09441542784434, \
4.196676206191309}, 
       {70.16257133683294, 4.198003808599491}, {70.2350373716075, \
4.199122212303602}, 
       {70.35656811466122, 4.200304346221584}, {70.49082391871653, \
4.200571631289695}, 
       {70.61818126163347, 4.199785932058403}, {70.73676788687276, \
4.198113958556295}, 
       {70.86689219628927, 4.195200455730287}, {71.00601943025111, \
4.190793262744263}, 
       {71.15220727429944, 4.18466937474916}, {71.2903302040252, \
4.177421147987641}, 
       {71.54887444827412, 4.15983831946923}, {71.79106455621114, \
4.138317467742076}, 
       {72.01454856122534, 4.113806791291027}, {72.51976891019852, \
4.040196041226801}, 
       {73.02566472488145, 3.937559129770665}, {73.58260500451237, \
3.784421479971117}, 
       {74.16419636530598, 3.569289705927044}, {74.70876516350426, \
3.303547552571454}, 
       {75.23052213684154, 2.974691646302137}, {75.79975707076278, \
2.50935611276769}, 
       {76.33741667771038, 1.940045703248794}, {76.83632568132046, \
1.278413008542788}, 
       {77.77116698819835, -0.2418817295881813}, {78.7819046759997, \
-1.770389482815356}, 
       {79.36050287439066, -2.416756655929413}, {79.89257291830563, \
-2.875950975829998}, 
       {80.40123875963343, -3.218718763823846}, {80.93835646433268, \
-3.500568344124158}, 
       {81.42041857851507, -3.69779316945732}, {81.87024018600792, \
-3.843174458154951}, 
       {82.36379103073677, -3.967059040408277}, {82.89261499839076, \
-4.065187995916627}, 
       {83.16205442092632, -4.103311123645032}, {83.44815600065061, \
-4.135988018073635}, 
       {83.69240964006676, -4.158026001949814}, {83.96188261697608, \
-4.176554265417668}, 
       {84.11252867160442, -4.184431001731661}, {84.25058329747519, \
-4.190166436851748}, 
       {84.40215192016793, -4.194894157184617}, {84.47834448212427, \
-4.196670778907607}, 
       {84.56164776302918, -4.198166323103516}, {84.63555429080638, \
-4.199110262723939}, 
       {84.70267425348339, -4.199661572004898}, {84.78015219776379, \
-4.199942606715703}, 
       {84.85325950660456, -4.199865145960591}, {84.98341197774141, \
-4.19892316460319}, 
       {85.05680043153917, -4.197948354745206}, {85.12443138385734, \
-4.196773039176948}, 
       {85.24629815558354, -4.193998886428333}, {85.37715309569771, \
-4.190104644673995}, 
       {85.61347576877054, -4.18076131457949}, {85.89450350078914, \
-4.165971478291912}, 
       {86.15115489277817, -4.149174166132584}, {86.70864045470347, \
-4.102710419695411}, 
       {87.2376194452606, -4.047145610454634}, {89.32295631335183, \
-3.739699309960677}, 
       {91.25544961765028, -3.359263028989441}, {95.37164144733152, \
-2.353590131060593}, 
       {99.74534743899187, -1.118731749610049}, {99.99999583333334, \
-1.043882982518805}}]}}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[TextData[
"A complete revolution needs approximately 0 \[LessEqual]  t \[LessEqual]  \
52. We solve the initial value problem for 0 \[LessEqual]  t \[LessEqual]  \
52."], "Text"],

Cell[CellGroupData[{

Cell["sol2 = NDSolve[awp, {x[t], y[t], z[t]}, {t,0,52}][[1]]", "Input"],

Cell[OutputFormData["\<\
{x[t] -> InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
       0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
       2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
       4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
       8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
       12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
       16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
       19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
       21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
       22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
       23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
       24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
       25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
       25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
       26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
       26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
       26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
       27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
       27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
       28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
       28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
       29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
       30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
       31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
       33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
       35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
       37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
       40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
       43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
       47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
       51.68339752171315, 52.}}, {{10., 0.}, 
      {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, 
      {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
       -1.322286343058508*^-7}, {9.999534630881093, -0.005282323784489644, 
       -0.01500076832270247, -1.507556879980259*^-6}, 
      {9.998209098094816, -0.0103655576280027, -0.01500295585112121, \
-4.303953042407377*^-6}, 
      {9.996022280142259, -0.01544977367720093, -0.01500656577947253, 
       -7.102518978703048*^-6, -4.12962510774654*^-6}, 
      {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
       -0.00001911254788268681, -4.721536529157213*^-6}, 
      {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
       -0.00002843965797539134, -4.17160237245598*^-6}, 
      {9.919829422265767, -0.0695083794671598, -0.0151330970744481, \
-0.00003863663157999305, 
       -4.230562589262589*^-6}, {9.872806607521704, -0.08766523133166012, 
       -0.01521192543463029, -0.00004907835452562485, \
-4.318382798300356*^-6}, 
      {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
       -0.00006058324022271351, -4.43239809319311*^-6}, 
      {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
       -0.00007254388067269821, -4.588965459026183*^-6}, 
      {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
       -0.00008504165353778693, -4.780886831038984*^-6}, 
      {9.547220374825469, -0.1669099648103735, -0.01577361976315558, \
-0.0000981827009109115, 
       -5.012205194280729*^-6, -7.221154665556483*^-8}, 
      {9.372446221713216, -0.1974722204799199, -0.01608694927728915, \
-0.0001195926414170735, 
       -5.787011173022882*^-6, -1.168521118499263*^-7}, 
      {9.16803848329466, -0.2286962212754445, -0.01646431261357922, \
-0.0001429398422662282, 
       -6.364539735664658*^-6, -1.186131454734799*^-7}, 
      {8.9333000040121, -0.260711383344569, -0.0169126745304145, \
-0.0001688916601208405, 
       -7.056168354057571*^-6, -1.313845897946621*^-7}, 
      {8.667404587672008, -0.2936619157657202, -0.01744069182536042, \
-0.0001982621290127823, 
       -7.992802614714835*^-6, -1.633035539189112*^-7}, 
      {8.369378216107282, -0.3277105940602582, -0.01805905837960469, \
-0.0002317412492909662, 
       -9.145034320510493*^-6, -2.017315052072494*^-7, \
-6.674609404533344*^-9}, 
      {7.968828654203694, -0.3701677267394483, -0.01893656311738351, \
-0.0002787120557484119, 
       -0.00001107459120877045, -3.431225329765139*^-7, \
-1.221235206138657*^-8}, 
      {7.518288034053902, -0.414837109722486, -0.01999077203536757, \
-0.0003349565845911475, 
       -0.0000134310000281622, -4.488420368790152*^-7, \
-1.346430675352864*^-8}, 
      {7.014966306469673, -0.4621643951747192, -0.02125743383726544, \
-0.0004024832669310073, 
       -0.00001612207743260069, -5.188299501191256*^-7, \
-1.214130185849565*^-8}, 
      {6.455512902890977, -0.5126865555719547, -0.02278077919181758, \
-0.0004842873768802196, 
       -0.00001950339211749401, -6.266494605200327*^-7, \
-1.354357959188541*^-8}, 
      {5.971354327636086, -0.5552694173247879, -0.02419934375167602, \
-0.0005601240439740879, 
       -0.00002240270713257671, -6.795896221578519*^-7, \
-1.201709349193833*^-8}, 
      {5.447344756733164, -0.6006203860064261, -0.02583679655234428, \
-0.0006452311021927112, 
       -0.00002488203251787149, -6.030303672602093*^-7, \
-1.583376666742293*^-9}, 
      {4.994559169969892, -0.6394373103400424, -0.02732862996656363, \
-0.0007171994723376593, 
       -0.00002519742550426964, -1.641290240708912*^-7, \
3.910597107780506*^-8}, 
      {4.512594792329623, -0.6805479316610102, -0.02897566532185714, \
-0.0007858734411303971, 
       -0.00002283819031739034, 6.281580292262645*^-7, \
9.577105762745674*^-8}, 
      {4.092333097008952, -0.7162958456331559, -0.03043328001834313, \
-0.0008273002171360841, 
       -0.00001411116814184291, 2.773103753343612*^-6, \
2.950546781062066*^-7}, 
      {3.650020866463042, -0.7538337447048592, -0.03194053384702654, \
-0.000837781640951464, 
       2.907707968555054*^-6, 5.852540359820091*^-6, 5.181368394863152*^-7}, 
      {3.184571840689228, -0.7931742380695744, -0.03340796215459502, \
-0.0007783073126224044, 
       0.00004020831399575819, 0.00001252969451950441, \
1.050499280912101*^-6}, 
      {2.795135498386905, -0.825830794134082, -0.03443182974317923, \
-0.0006278837202671806, 
       0.0001043308691637567, 0.00002636995433250329, 2.548041348411085*^-6}, \

      {2.38977107808601, -0.8593358948133683, -0.03513375184134562, \
-0.000319913380216462, 
       0.0002060515099388112, 0.00004421380258099794, 4.001314036998032*^-6}, \

      {1.968166385363971, -0.8932395940637682, -0.03519115346953409, \
0.0002827427630627121, 
       0.0003953025819406979, 0.00008034764600886729, 7.407586137339988*^-6}, \

      {1.612143333988495, -0.9206107463009619, -0.03436732147393313, \
0.001167408375879762, 
       0.0006871165481036591, 0.0001488881693373802, 0.00001608512153778298}, \

      {1.245564862078643, -0.9468476617076561, -0.03218992389889563, \
0.002621839915004895, 
       0.001129466927246893, 0.0002361002834123236, 0.00002446272968897194}, 
      {0.9411036630779808, -0.9663582346870491, -0.02882442468204031, \
0.004524953127547926, 
       0.001773934206673067, 0.0004076052929450417, 0.00005060830769685972}, 
      {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, \
0.007385850858260214, 
       0.002672644657907155, 0.0005975972454227846, 0.00007016870897342483}, 
      {0.3159401433660997, -0.9951819807516075, -0.0141810564371504, \
0.01177969329600485, 
       0.004105758348508652, 0.0009339734047126293, 0.0001125727572013773}, 
      {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, \
0.01642148422154501, 
       0.005766813443267503, 0.001456041061702653, 0.0002183132824744149}, 
      {-0.1451655451007285, -0.9987483123162489, 0.008944489593331621, \
0.02264330478484971, 
       0.007723831164850311, 0.001834097872355712, 0.0002401682337663385}, 
      {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, \
0.03107584026681068, 
       0.01043305827566561, 0.002464002718034116, 0.0003260132232436369}, 
      {-0.6017366959356142, -0.9723927003509583, 0.05264297022337499, \
0.04225298673259487, 
       0.01376536310562221, 0.003084637463279821, 0.0003748430742714523}, 
      {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, \
0.0530975554303808, 
       0.01662705757449755, 0.003411909325867013, 0.0003468215640078723}, 
      {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, \
0.06584191092106879, 
       0.01927853582407632, 0.003240100434734713, 0.0001440904775641987}, 
      {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, \
0.08005627726477126, 
       0.02099483499621253, 0.002195345619101353, -0.0003027390708880932}, 
      {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
       0.02021543417588093, -0.000754274587538044, -0.001530626941211491}, 
      {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
       0.01746781961115515, -0.004103986580530314, -0.002450338209772962}, 
      {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
       0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, 
      {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
       -0.0007350026571956852, -0.01685438505251352, -0.005671350902054768}, 
      {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
       -0.01688511860132406, -0.02423508582492491, -0.006778310725377359}, 
      {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, \
0.09666214457796037, 
       -0.03204065521875401, -0.02840436636139767, -0.006444744621113192}, 
      {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, \
0.0785742469749175, 
       -0.0470257534782241, -0.02861634111365265, -0.00398773686340812}, 
      {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, \
0.05414735876830688, 
       -0.05977983902013911, -0.02439011013378813, 0.00001759514469461788}, 
      {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, \
0.03131763081762755, 
       -0.0651267030424638, -0.01330108771073375, 0.007932614219398512}, 
      {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, \
0.006382340077340566, 
       -0.06878153330095417, -0.00607622203589427, 0.009921051344796055}, 
      {-1.762223869805497, 0.0669098889538212, 0.4797874360581084, \
-0.01881564820658439, 
       -0.06715504466041756, 0.0052941015385649, 0.014075650991735}, 
      {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, \
-0.04290594361192289, 
       -0.06177008484910881, 0.01515215349206186, 0.01548803581768913}, 
      {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, \
-0.06450374890421965, 
       -0.05309737444319933, 0.02305207122611793, 0.01493656511780418}, 
      {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
       -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
      {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, \
-0.09760253037063431, 
       -0.02888818242959219, 0.0306691934708478, 0.009224953760383584}, 
      {-1.622080963140679, 0.4929301210117905, 0.3755325162049182, \
-0.1074178334999123, 
       -0.01633310637884133, 0.02856039286749514, 0.004168099462073743}, 
      {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
       -0.005160721979258902, 0.02417131244294108, -0.0003440345314113444}, 
      {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
       0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, 
      {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
       0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
      {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
       0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, 
      {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
       0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
      {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, \
-0.08779459299724857, 
       0.01979767319192345, -0.0003066249582991479, -0.006028282943382096}, 
      {-1.085063458885453, 0.8749251188130202, 0.144782245099154, \
-0.07854258397670186, 
       0.01986264568980367, -0.002297713136917443, -0.004783528255310104}, 
      {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, \
-0.06946500901627999, 
       0.01908920268180254, -0.003359677058435248, -0.003492310907858758}, 
      {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, \
-0.0608924971492783, 
       0.01779753275101055, -0.003788394790891112, -0.002346567941738405}, 
      {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, \
-0.05301145859825892, 
       0.01623278484580223, -0.003814067204285791, -0.00142298197321629, 
       0.001159542229646304}, {-0.6433048170868872, 0.9677057910471042, \
0.05823802142742399, 
       -0.04468096904705857, 0.01441045900308664, -0.002783953394204672, 
       0.001188784376355514, 0.001697085509141072}, 
      {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, \
-0.03741547808128195, 
       0.0128042870890071, -0.001516085052811469, 0.002492470180502037, \
0.001592641575583569}\\
, {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, \
-0.03126812679688145, 
       0.01073262941726728, -0.002037579725773561, 0.001248140166443795, 
       0.000621510220514931}, {-0.2456664780092288, 0.9962859463080013, \
0.01629774299047672, 
       -0.02604465129166512, 0.008980331918121603, -0.002095510898895228, 
       0.0006953458839076041, 0.0002187584774474667}, 
      {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, \
-0.02163335504587148, 
       0.007533052625606419, -0.001862875274342468, 0.0005412212424280951, 
       0.00009130883576918053}, {0.02323242649556178, 1.000037398259186, 
       -0.001270322947428585, -0.01793006544947133, 0.006305477814234636, 
       -0.001607987009029117, 0.0004376460542311089, 0.00002422708367731202}, \

      {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, \
-0.01483069730268437, 
       0.00526623201595544, -0.001376927490964432, 0.0003454596158002636}, 
      {0.3238530675731096, 0.995016345930049, -0.0144640796213406, \
-0.0116871546883609, 
       0.004231198363091821, -0.001064594641186693, 0.0003322772383557684}, 
      {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, \
-0.00917301401911442, 
       0.003397859160363781, -0.000819933720088739, 0.0002972842358494771}, 
      {0.6533538559313423, 0.9820447155621451, -0.02372070399070088, \
-0.007162526259702596, 
       0.002726309336887593, -0.0006384642833766479, 0.0002509980162091398}, 
      {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, \
-0.005553834168748899, 
       0.002185764859300605, -0.0005041528357430196, 0.000204352772054328}, 
      {0.9776558814470167, 0.9642105857215122, -0.02932920777076483, \
-0.004264733145196217, 
       0.001753679572068895, -0.0003999863031745657, 0.0001643010647412814}, 
      {1.137437570202047, 0.9541144596710516, -0.03119425522545939, \
-0.003230475051281675, 
       0.001408187583593927, -0.000318863443275577, 0.0001310475300282612}, 
      {1.373962009270192, 0.9379913626951294, -0.03315104071340928, \
-0.002035992528092278, 
       0.001055017058722285, -0.0001754137530066389, 0.0001168833024258509}, 
      {1.606350517388015, 0.9210897263708773, -0.03435027793903866, \
-0.001185643298369978, 
       0.0007611892730192848, -0.0001263674244384825, \
0.00008320952677836924}, 
      {1.834451124462977, 0.9037326412745143, -0.03500295728260755, \
-0.0005720113774542266, 
       0.0005488589661374675, -0.0000923366591773421, \
0.00005900095063806828}, 
      {2.05818068749326, 0.8861532298832889, -0.03526139771076708, \
-0.0001299066826636304, 
       0.0003943010523705895, -0.00006860755394809425, \
0.00004172858547342076}, 
      {2.277505796363031, 0.8685194772734156, -0.03523617500405487, \
0.0001875161539186697, 
       0.0002818251856303586, -0.0000511645549180407, \
0.00002968880418123365}, 
      {2.492428788195139, 0.8509519705097273, -0.03500799092175404, \
0.0004136601693357046, 
       0.0001995415136804703, -0.00003828804738911866, \
0.00002124715551700476}, 
      {2.772238550718317, 0.8277725006882704, -0.03448789441543038, \
0.0006187349731000154, 
       0.0001352320034684956, -0.00001425422529863956, \
0.00001755451345997014}, 
      {3.044385230797065, 0.8049972229139195, -0.03380947075089432, \
0.0007368050289671234, 
       0.00007834634628596583, -0.00001122391314621417, \
0.00001113870188222071}, 
      {3.309018587737515, 0.7827080320625583, -0.03303896113559139, \
0.0008026315339952361, 
       0.00004206218440122728, -7.530342783184703*^-6, \
7.421851557590777*^-6}, 
      {3.566309067033361, 0.7609505320860362, -0.0322207398277254, \
0.0008326581797725729, 
       0.00001753263227045104, -5.206456476998877*^-6, 4.91783556921768*^-6}, \

      {3.81643803262864, 0.7397459514613501, -0.03138449367913013, \
0.000838939799644164, 
       1.35077760291538*^-6, -3.443913900758643*^-6, 3.303169942357289*^-6}, 
      {4.059591012015883, 0.7190992617954302, -0.03054996995098544, \
0.0008294710638224421, 
       -9.266693762532051*^-6, -2.176304405457542*^-6, \
2.235395158274695*^-6}, 
      {4.372585721165242, 0.6924846048814831, -0.02946402757201999, \
0.0008029885517503858, 
       -0.00001512205360717179, 8.250783523782558*^-7, 1.79238678863533*^-6}, \

      {4.673987267678016, 0.6668147871373053, -0.02842204472668379, \
0.0007647138190854807, 
       -0.00002078611834098472, 6.541365780799917*^-7, \
1.049737140101165*^-6}, 
      {4.964205394312013, 0.6420460382904659, -0.02743350214751175, \
0.0007221979607514677, 
       -0.00002314976507814556, 7.761061031756697*^-7, \
6.481760049899586*^-7}, 
      {5.243628875125201, 0.6181288506037192, -0.02650242749678078, \
0.0006781875255987336, 
       -0.00002393452362995146, 7.931800302684875*^-7, \
3.914720523938617*^-7}, 
      {5.5126240130368, 0.5950117248664654, -0.0256295578461628, \
0.0006345834841070335, 
       -0.00002369251940469708, 8.021342089770415*^-7, \
2.362291693947091*^-7}, 
      {5.771534255654154, 0.5726434521487585, -0.02481369104364359, \
0.0005924255277376992, 
       -0.00002288648698303586, 7.853559496375988*^-7, \
1.392154952244304*^-7}, 
      {6.108778136511332, 0.5432709949881284, -0.02378916494031363, \
0.0005385767396017946, 
       -0.00002090222196923115, 9.634231569526953*^-7, \
1.031660310217783*^-7}, 
      {6.428627940347904, 0.5150795809575441, -0.02285881763700148, \
0.000488650474985677, 
       -0.00001936889068213984, 7.862704461763962*^-7, \
4.236373274532015*^-8}, 
      {6.731764237016638, 0.4879601358421129, -0.02201464865538692, \
0.0004432614671721073, 
       -0.00001769376947598321, 6.751452578811216*^-7, \
1.316367698170899*^-8}, 
      {7.018804533876454, 0.4618132537833407, -0.02124878476612005, \
0.000402127590503264, 
       -0.00001608643168964409, 5.795259274427188*^-7, \
-2.64641555573496*^-9}, 
      {7.29030909335201, 0.4365487805184312, -0.02055383300618015, \
0.0003649289266705499, 
       -0.00001458398933991611, 5.033512661358331*^-7, \
-9.988169502319166*^-9}, 
      {7.546786291865488, 0.4120851279505025, -0.01992303747611581, \
0.0003312779634424161, 
       -0.00001322154918966636, 4.37551534672063*^-7, \
-1.324910477258141*^-8}, 
      {7.884086056271611, 0.3787788434178949, -0.01913029312120552, \
0.0002891023262879505, 
       -0.0000115291594594324, 3.63777393971772*^-7, -1.371373898326033*^-8}, \

      {8.193519584742434, 0.3467373043198655, -0.01843847943647414, \
0.0002522379007700076, 
       -0.00001012456090970589, 2.940570752419515*^-7, \
-1.367577777664127*^-8}, 
      {8.476095686537853, 0.3157992553430406, -0.01783509007823322, \
0.0002198514717341092, 
       -8.938518663488416*^-6, 2.402965656917715*^-7, \
-1.240599571914663*^-8}, 
      {8.732694164207696, 0.2858229861605473, -0.01730967605233079, \
0.0001911921984056844, 
       -7.945451424014868*^-6, 1.975592634101514*^-7, \
-1.078283810070344*^-8}, 
      {8.964081092156048, 0.2566830884024056, -0.01685353056247505, \
0.0001656356738916059, 
       -7.115162259841*^-6, 1.634975150107237*^-7, -9.131086931191294*^-9}, 
      {9.170921496420231, 0.2282677220189242, -0.01645941987193715, \
0.0001426479705924626, 
       -6.427511170842572*^-6, 1.348052317356517*^-7, \
-7.720497902122285*^-9}, 
      {9.389954355144068, 0.1945852773909356, -0.01605562025513275, \
0.000117523846926549, 
       -5.77104513440084*^-6, 1.004193245520244*^-7, -6.84435365281206*^-9}, 
      {9.574487972549572, 0.1616616916001712, -0.01572586742018316, \
0.00009490549903810554, 
       -5.233270606636592*^-6, 7.898604003413424*^-8, \
-5.485421307730566*^-9}, 
      {9.725231796860384, 0.1293508421880767, -0.01546336168132292, \
0.00007419723225491459, 
       -4.824923276518464*^-6, 5.934261569317994*^-8, \
-4.554919700878265*^-9}, 
      {9.842750599262039, 0.09751900870274404, -0.01526288472030978, \
0.000054940201293084, 
       -4.52067132704201*^-6, 4.262303874918333*^-8, -3.808526825726381*^-9}, \

      {9.927475673864893, 0.06604185470753681, -0.0151205676271804, \
0.00003672919236845725, 
       -4.308672419068996*^-6, 2.762596707450741*^-8, \
-3.249881860652005*^-9}, 
      {9.979713178406525, 0.03480181166196349, -0.01503372618961092, \
0.00001920328638020516, 
       -4.180602396326156*^-6, 1.358486971789759*^-8, \
-2.853196789546286*^-9}, 
      {9.999804221413857, 0.002079784470556782, -0.01500049198937566, \
1.146333605182019*^-6, 
       -4.131571602154404*^-6, -1.008292044867596*^-9, \
-2.604590129466682*^-9}, 
      {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
       -4.065399346041674*^-6, -4.111443091414769*^-6, 7.927537361729354*^-9, \

       3.188545681628212*^-10}}][t], y[t] -> 
   InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
       0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
       2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
       4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
       8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
       12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
       16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
       19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
       21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
       22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
       23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
       24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
       25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
       25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
       26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
       26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
       26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
       27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
       27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
       28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
       28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
       29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
       30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
       31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
       33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
       35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
       37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
       40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
       43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
       47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
       51.68339752171315, 52.}}, {{0., 0.3}, 
      {0.0009979517077872255, 0.2999999900409223, -1.496927738092378*^-6}, 
      {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
       -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, 
       -0.00007923886649939536, -0.0001500117406492253}, 
      {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
       -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, 
       -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
      {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
       -0.0001512573923248744, -3.56926535101178*^-7}, 
      {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
       -0.0001532344335889719, -6.696147194160083*^-7}, 
      {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
       -0.0001561772311865011, -1.0428234784246*^-6}, 
      {0.868848049581404, 0.2961496636728365, -0.001338713029291882, \
-0.0001600680606887075, 
       -1.43126921114028*^-6}, {1.05798950032964, 0.2942346427695965, \
-0.001651893195715194, 
       -0.0001652995935706142, -1.838046254173493*^-6}, 
      {1.245773954048422, 0.2919112807621309, -0.001976470827894482, \
-0.000171839413657207, 
       -2.313982825558378*^-6}, {1.431934770245561, 0.2891633697453571, 
       -0.002314981271114216, -0.0001797480698000253, \
-2.828724047048563*^-6}, 
      {1.616193851195026, 0.28597129085274, -0.002670225693750562, \
-0.0001891832977074768, 
       -3.397434289546612*^-6, -1.775364723929283*^-7}, 
      {1.887969116886099, 0.2803076374177811, -0.003240529009765943, \
-0.0002072780859326736, 
       -5.221261131605496*^-6, -2.788381938828235*^-7}, 
      {2.153768380769201, 0.2734970220318928, -0.003867818935861487, \
-0.0002294381802057415, 
       -6.431829724465898*^-6, -2.655783988637725*^-7}, 
      {2.412433330554526, 0.2654158466017701, -0.004567259996799199, \
-0.0002572619737618737, 
       -7.902611695922691*^-6, -2.860666162534704*^-7}, 
      {2.662673326125159, 0.2559082295468512, -0.005357876121799781, \
-0.0002926858378040523, 
       -9.973696094715828*^-6, -3.588711908498042*^-7}, 
      {2.903028607000796, 0.244776794952918, -0.006264023860191164, \
-0.0003376675751241998, 
       -0.00001266075107069725, -4.594667989404502*^-7, \
-1.747260442740121*^-8}, 
      {3.175344187221096, 0.2289633086353855, -0.007545671364715371, \
-0.0004088562867722723, 
       -0.00001760680137464635, -8.727270794121078*^-7, \
-3.447284626861373*^-8}, 
      {3.427693211989913, 0.2098940230544755, -0.009114079092598725, \
-0.0005060976270138674, 
       -0.00002445938672013374, -1.283289477521906*^-6, \
-4.451638240754114*^-8}, 
      {3.65591142716557, 0.186792033285195, -0.01107850554171452, \
-0.0006407044351002397, 
       -0.00003391896655161902, -1.770630454265917*^-6, \
-5.499941220723898*^-8}, 
      {3.85478077194519, 0.1585724953229884, -0.01360311058181845, \
-0.0008339122439545453, 
       -0.0000489443172128367, -2.712322351006786*^-6, \
-8.766377802768383*^-8}, 
      {3.986763005165946, 0.131667061984029, -0.01615666214412804, \
-0.001051626041925007, 
       -0.00006869661225566872, -4.393137681215513*^-6, \
-1.761332361311671*^-7}, 
      {4.092061561834391, 0.0995298917764175, -0.01940869599958157, \
-0.001352395704445139, 
       -0.00009571282431003663, -6.281214100632805*^-6, \
-2.444479897469488*^-7}, 
      {4.153850886158325, 0.06883885260811142, -0.02272856290784795, \
-0.001690501313216549, 
       -0.0001316398123092309, -9.940863233820019*^-6, \
-4.806638869588175*^-7}, 
      {4.191306423956496, 0.03269842564989161, -0.02691267068137347, \
-0.002148302610858181, 
       -0.0001796379888607316, -0.00001388813348710936, \
-6.486429479295039*^-7}, 
      {4.200742249681569, -0.002208228754422552, -0.0312395051651517, \
-0.002663840093236035, 
       -0.0002423648979153841, -0.00002118918286358118, \
-1.197910773667203*^-6}, 
      {4.187480484699273, -0.04294029965292303, -0.03664374955205367, \
-0.003351432661554625, 
       -0.0003255129417403924, -0.00002918221867922413, \
-1.604121647400555*^-6}, 
      {4.147582708325752, -0.09101196819194772, -0.04351056025037764, \
-0.004295458408425854, 
       -0.0004497713933866242, -0.00004287189467316768, \
-2.47885545821094*^-6}, 
      {4.093216338662262, -0.1360882405850764, -0.05042227215046736, \
-0.005319578435935783, 
       -0.0006006220945709141, -0.00006396231737026914, \
-4.409656157769888*^-6}, 
      {4.015439499996313, -0.1885954484836499, -0.05903393771043326, \
-0.006668642152566507, 
       -0.0007954597141818747, -0.00008583296722324174, \
-5.6762468467354*^-6}, 
      {3.910243506625146, -0.2504281729333795, -0.06991601053462865, \
-0.008485369119217001, 
       -0.001075857440459364, -0.0001215320852716722, \
-8.352309163308866*^-6}, 
      {3.800626326934144, -0.3095265512549151, -0.0810211001084475, \
-0.01044535109360783, 
       -0.001399096395540943, -0.0001697669761996192, \
-0.00001320335121470718}, 
      {3.665972999146803, -0.378327542653802, -0.09474229302615215, \
-0.01295459443587661, 
       -0.001793921254600053, -0.0002144492937412613, \
-0.00001551062565886725}, 
      {3.535553015059292, -0.4428061177064114, -0.1082883390327763, \
-0.01550358393254631, 
       -0.00220095651893553, -0.0002668360165914096, \
-0.00002028150696806179}, 
      {3.383157176300779, -0.5167289059824787, -0.1245035267716008, \
-0.01856317910150786, 
       -0.00262862077236768, -0.0002906382154606718, \
-0.00001715551624775262}, 
      {3.20549373901541, -0.6019516096016301, -0.1438811536990364, \
-0.02213377125985196, 
       -0.003028422675279043, -0.0002756180044960396, \
-7.146543113549753*^-6}, 
      {3.058588130827458, -0.6720624861181122, -0.1601545679841135, \
-0.02490566730718879, 
       -0.003089766360970424, -0.00009058479323536484, \
0.00004914842109632001}, 
      {2.894596323375797, -0.7501316342604838, -0.1783524392815316, \
-0.02765292754581667, 
       -0.002939806242666361, 0.0001373209277761948, 0.00009530669209766431}, \

      {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
       -0.002118996299412064, 0.0007045924544449787, 0.0002210082169551333}, 
      {2.507421795656775, -0.9334055715055376, -0.2193614638360956, \
-0.03078067221328464, 
       -0.0001732800370884182, 0.001720488442029996, 0.000425988858941995}, 
      {2.33317849523205, -1.014847597695069, -0.2356208100425164, \
-0.02955058544284709, 
       0.003046032316439744, 0.003590979279397424, 0.0009523908779487415}, 
      {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
       0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, 
      {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
       0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
      {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
       0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
      {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
       0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
      {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
       0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
      {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
       0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
      {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
       0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, 
      {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
       0.04854416792859499, -0.004146149653291475, -0.007592239941335828}, 
      {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
       0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
      {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
       0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
      {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
       0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
      {0.04047800614247131, -1.699822619873736, -0.01104749066017452, \
0.1544758791615086, 
       0.002904805753834867, -0.03443803199776515, -0.009858086267061791}, 
      {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, \
0.1531408660534355, 
       -0.01167634603044878, -0.03485997177461622, -0.006216287801323393}, 
      {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
       -0.02502213731263542, -0.03148565897311392, -0.001319145505838771}, 
      {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
       -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, 
      {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
       -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
      {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
       -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, 
      {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
       -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
      {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
       -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
      {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
       -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
      {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
       -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
      {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
       -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
      {-1.676554155554152, -1.305608867189375, 0.2689638069601199, \
-0.001217053979193587, 
       -0.02444610851301589, 0.01402117366548132, 0.00224958656739477}, 
      {-1.821639069964926, -1.244590074076928, 0.2667220610870114, \
-0.0113128728396274, 
       -0.01864935539868304, 0.01161388704344243, -0.00006065302064348859}, 
      {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
       -0.01354138262907623, 0.009331003691403976, -0.001373910151833233}, 
      {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
       -0.009317813474587454, 0.007160120981883526, -0.002096244383309918}, 
      {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
       -0.005921779540154439, 0.005321449744103576, -0.002335005570329405}, 
      {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
       -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
       0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, 
       0.2233247841202344, -0.03060923986977494, -0.0009206404428521231, 
       0.002668607114008318, -0.001642610820709008, 0.0002789857387758132}, 
      {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
       0.0007931576405303536, 0.002021643534149319, -0.0008785619396256485, 
       0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, \
0.1987180081228845, 
       -0.02986498356771943, 0.001850571136714643, 0.001311821166285018, 
       -0.0006006837699262708, 0.0004025249678476842}, 
      {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, \
-0.02868642525878178, 
       0.002510879609608891, 0.0008222015537418208, -0.0003592654655979457, 
       0.000353765107692091}, {-2.919626045506723, -0.7381571877771078, \
0.175586089260012, 
       -0.02723906829815367, 0.002875048835861939, 0.0004616915237353225, 
       -0.0002051292907194143, 0.0002903776349041168}, 
      {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, \
-0.02565419087941412, 
       0.003033030217916483, 0.0002014497612882507, -0.0001107920060412756, 
       0.0002269621421637012}, {-3.106117892072866, -0.6493204211172826, \
0.1548734590809113, 
       -0.02402116089273098, 0.003055539450422462, 0.00002599975151483897, 
       -0.00004758785347185354}, {-3.210090129745036, -0.5996681315994481, 
       0.1433705576419095, -0.02201677832120685, 0.002985222599816919, 
       -0.0000958294047673527, -0.00007731102712422072}, 
      {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, \
-0.02011385735927098, 
       0.002763124856175378, -0.0002864118307802861, -0.0001226612803402779}, \

      {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, \
-0.01832912002286514, 
       0.002545956219616085, -0.0003344654449797207, \
-0.00009282872655880584}, 
      {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
       0.002340654063149804, -0.0003120801939574286, \
-0.00004673823831166822}, 
      {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, \
-0.01517795810854488, 
       0.00213323204377452, -0.0002847408987506403, -0.0000171012438948165}, 
      {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, \
-0.01381624455578609, 
       0.0019329271910969, -0.000256584599016029, 1.007933302260962*^-6}, 
      {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, \
-0.01202278498544689, 
       0.001642061747291683, -0.000235249621043713, 6.294315540307676*^-6}, 
      {-3.798446943438669, -0.3105342664181361, 0.08122614330861257, \
-0.01048688148137613, 
       0.001408458250699894, -0.0001884038544520576, 0.00001626929459300319}, \

      {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, \
-0.00917947523972208, 
       0.001204544204314665, -0.0001528026664484259, 0.00001925560751478185}, \

      {-3.934630385946802, -0.2365213821444215, 0.06740931090421369, \
-0.008065641383147081, 
       0.001029940565630871, -0.0001250578171946844, 0.0000189522876063627}, 
      {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, \
-0.007114652075869174, 
       0.000882042765250185, -0.0001030409363367319, 0.00001724277618273266}, \

      {-4.036983057207475, -0.1746882790891004, 0.05670238403676125, \
-0.006300486571572722, 
       0.0007570421935068591, -0.00008565931813226637, \
0.00001498094973042025}, 
      {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, \
-0.005388164125577655, 
       0.0006254981305204854, -0.00006275759347351894, \
0.00001356839613907586}, 
      {-4.129977973626481, -0.1066698407990083, 0.04586552357996159, \
-0.004640446873950072, 
       0.0005154961431997248, -0.00005002292097234296, \
0.00001068768379513849}, 
      {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, \
-0.004021722679494938, 
       0.0004278764083609402, -0.00003998672821139463, \
8.419621550322354*^-6}, 
      {-4.181992277724197, -0.05114937617478823, 0.03778328353121347, \
-0.003506550900720839, 
       0.0003572087299784264, -0.00003242813775361963, \
6.563319850414154*^-6}, 
      {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, \
-0.003074675807083444, 
       0.0003001534886949304, -0.00002647017776461171, \
5.129448984486421*^-6}, 
      {-4.200273762534801, -0.005059630122047486, 0.03160865927633907, 
       -0.002710379401726163, 0.0002537304737997015, -0.00002179055275345088, \

       4.013488418448823*^-6}, {-4.196527059133943, 0.02146125572686395, 
       0.02827767779621063, -0.002307804699369244, 0.0002080180677235468, 
       -0.00001467874931531174, 3.477096307713213*^-6}, 
      {-4.181640046440592, 0.04524848451510998, 0.02542812434125149, \
-0.001982916488272914, 
       0.0001688840778693765, -0.00001193572980333215, \
2.498571878633773*^-6}, 
      {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, \
-0.001716367034850311, 
       0.0001387847490468397, -9.539748932217889*^-6, 1.859292472751585*^-6}, \

      {-4.122785355809635, 0.0860961029326029, 0.02083744114211, \
-0.001496038192667138, 
       0.0001149375476116196, -7.752989220148379*^-6, 1.384150391219296*^-6}, \

      {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, \
-0.001312377553500777, 
       0.00009598075726336363, -6.330002216054171*^-6, \
1.044385030161512*^-6}, 
      {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, \
-0.001158156672391711, 
       0.00008074314435794473, -5.205832344760582*^-6, \
7.956094303782612*^-7}, 
      {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, \
-0.0009845094817148179, 
       0.00006584206721644325, -3.320123427647478*^-6, \
6.853161548526208*^-7}, 
      {-3.862684295208088, 0.1571524415300303, 0.01373487047827056, \
-0.0008458709268748281, 
       0.00005292158849075478, -2.717703778739206*^-6, \
4.776227802405111*^-7}, 
      {-3.762840313497239, 0.172874054360284, 0.01230548051000591, \
-0.000732964029147417, 
       0.00004313135460575885, -2.174487587840614*^-6, \
3.464779702597154*^-7}, 
      {-3.653990683732458, 0.186983619109208, 0.01106211919053541, \
-0.0006402696967549964, 
       0.0000354544481395366, -1.769433689206584*^-6, 2.525549483911888*^-7}, \

      {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, \
-0.0005634894736334127, 
       0.00002940436207093559, -1.444926260924889*^-6, \
1.873187047108245*^-7}, 
      {-3.412804993833292, 0.2111489245800355, 0.009009588330419845, \
-0.0004994138122043501, 
       0.00002457256285304119, -1.188314081952184*^-6, \
1.406896678162243*^-7}, 
      {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, \
-0.0004254398735934686, 
       0.00001981390334171221, -7.142813890569568*^-7, \
1.214519187305689*^-7}, 
      {-3.028544710651558, 0.2379623057313892, 0.006815353873336178, \
-0.0003674996746395192, 
       0.00001563491183483192, -5.86375308215994*^-7, 8.286497780628049*^-8}, \

      {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, \
-0.0003211413486115556, 
       0.00001249454537016901, -4.723075689651174*^-7, \
5.863156687991705*^-8}, 
      {-2.604332817704375, 0.2582797769625237, 0.005162226805369295, \
-0.0002838187140553005, 
       0.00001004906765736633, -3.87289508354963*^-7, 4.18217498152932*^-8}, 
      {-2.380372883980649, 0.2664918453580231, 0.004475381304397052, \
-0.0002535927280720157, 
       8.127093887680922*^-6, -3.191386114183283*^-7, 3.041795891583185*^-8}, \

      {-2.149888330991454, 0.273593607663118, 0.00385849017216741, \
-0.0002290448730929102, 
       6.587497754854157*^-6, -2.659372328911577*^-7, 2.240761720314729*^-8}, \

      {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, \
-0.0002052376119308477, 
       5.184646117813377*^-6, -1.904354091683055*^-7, 1.830162350662408*^-8}, \

      {-1.568184016554942, 0.2868392209174812, 0.002575703742891957, \
-0.0001869906042160404, 
       3.949989067622175*^-6, -1.664155420757597*^-7, 1.252617879183773*^-8}, \

      {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, \
-0.0001730929726651855, 
       2.962637641249672*^-6, -1.425953503160539*^-7, 9.048066793624791*^-9}, \

      {-0.9642073675986177, 0.2952248515659734, 0.001495169624718867, 
       -0.0001628678796415216, 2.124382504834869*^-6, -1.268869055338464*^-7, \

       6.439368669983838*^-9}, {-0.6568336412300838, 0.2978072625251313, 
       0.001000424961613838, -0.0001558063063980045, 1.393261933326278*^-6, 
       -1.16189512124211*^-7, 4.551787476216529*^-9}, 
      {-0.3473080080181212, 0.2993839255588992, 0.0005231945129639924, 
       -0.0001515786954507069, 7.289963028536484*^-7, -1.10308871975636*^-7, 
       3.109375691580504*^-9}, {-0.02059882830471778, 0.2999868284345344, 
       0.00003089963017686534, -0.0001499710129035118, 7.391732362642512*^-8, \

       -1.071809864811129*^-7, 2.056959960532262*^-9}, 
      {0.07437607712204962, 0.2999612878079299, -0.0001115897022763641, 
       -0.0001501074630631385, -2.296620186836703*^-7, \
-1.774557747218172*^-7, 
       -1.356351577917269*^-8}}][t], z[t] -> 
   InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
     {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
       0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
       2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
       4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
       8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
       12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
       16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
       19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
       21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
       22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
       23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
       24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
       25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
       25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
       26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
       26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
       26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
       27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
       27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
       28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
       28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
       29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
       30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
       31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
       33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
       35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
       37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
       40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
       43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
       47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
       51.68339752171315, 52.}}, {{0., 0.}, {0., 0., 0.}, {0., 0., 0., 0.}, \
{0., 0., 0., 0.}, 
      {0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., \
0., 0., 0.}, 
      {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., \
0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., \
0.}, 
      {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
      {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}}][t]}\
\>", "\<\
{x[t] -> InterpolatingFunction[{{0., 52.}}, <>][t], 
 
  y[t] -> InterpolatingFunction[{{0., 52.}}, <>][t], 
 
  z[t] -> InterpolatingFunction[{{0., 52.}}, <>][t]}\
\>"], "Output"]
}, Open  ]],

Cell["\<\
Now we define vectors which describe the orbits of the bodies.\
\>", "Text"],

Cell[CellGroupData[{

Cell["relorbit[t_] = relvect /. sol2", "Input"],

Cell[OutputFormData["\<\
{InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
    {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
      0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
      2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
      4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
      8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
      12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
      16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
      19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
      21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
      22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
      23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
      24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
      25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
      25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
      26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
      26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
      26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
      27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
      27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
      28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
      28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
      29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
      30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
      31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
      33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
      35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
      37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
      40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
      43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
      47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
      51.68339752171315, 52.}}, {{10., 0.}, 
     {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, 
     {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
      -1.322286343058508*^-7}, {9.999534630881093, -0.005282323784489644, 
      -0.01500076832270247, -1.507556879980259*^-6}, 
     {9.998209098094816, -0.0103655576280027, -0.01500295585112121, \
-4.303953042407377*^-6}, 
     {9.996022280142259, -0.01544977367720093, -0.01500656577947253, \
-7.102518978703048*^-6, 
      -4.12962510774654*^-6}, {9.981400593490121, -0.03342230820498616, 
      -0.01503073261230838, -0.00001911254788268681, -4.721536529157213*^-6}, \

     {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
      -0.00002843965797539134, -4.17160237245598*^-6}, 
     {9.919829422265767, -0.0695083794671598, -0.0151330970744481, \
-0.00003863663157999305, 
      -4.230562589262589*^-6}, {9.872806607521704, -0.08766523133166012, 
      -0.01521192543463029, -0.00004907835452562485, -4.318382798300356*^-6}, \

     {9.810383964650146, -0.1072221139199094, -0.01531745094498254, \
-0.00006058324022271351, 
      -4.43239809319311*^-6}, {9.735385449078862, -0.1269286088610892, \
-0.01544557929235542, 
      -0.00007254388067269821, -4.588965459026183*^-6}, 
     {9.647705787368241, -0.1468142650452391, -0.01559725578076811, \
-0.00008504165353778693, 
      -4.780886831038984*^-6}, {9.547220374825469, -0.1669099648103735, 
      -0.01577361976315558, -0.0000981827009109115, -5.012205194280729*^-6, 
      -7.221154665556483*^-8}, {9.372446221713216, -0.1974722204799199, 
      -0.01608694927728915, -0.0001195926414170735, -5.787011173022882*^-6, 
      -1.168521118499263*^-7}, {9.16803848329466, -0.2286962212754445, \
-0.01646431261357922, 
      -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
     {8.9333000040121, -0.260711383344569, -0.0169126745304145, \
-0.0001688916601208405, 
      -7.056168354057571*^-6, -1.313845897946621*^-7}, 
     {8.667404587672008, -0.2936619157657202, -0.01744069182536042, \
-0.0001982621290127823, 
      -7.992802614714835*^-6, -1.633035539189112*^-7}, 
     {8.369378216107282, -0.3277105940602582, -0.01805905837960469, \
-0.0002317412492909662, 
      -9.145034320510493*^-6, -2.017315052072494*^-7, \
-6.674609404533344*^-9}, 
     {7.968828654203694, -0.3701677267394483, -0.01893656311738351, \
-0.0002787120557484119, 
      -0.00001107459120877045, -3.431225329765139*^-7, \
-1.221235206138657*^-8}, 
     {7.518288034053902, -0.414837109722486, -0.01999077203536757, \
-0.0003349565845911475, 
      -0.0000134310000281622, -4.488420368790152*^-7, \
-1.346430675352864*^-8}, 
     {7.014966306469673, -0.4621643951747192, -0.02125743383726544, \
-0.0004024832669310073, 
      -0.00001612207743260069, -5.188299501191256*^-7, \
-1.214130185849565*^-8}, 
     {6.455512902890977, -0.5126865555719547, -0.02278077919181758, \
-0.0004842873768802196, 
      -0.00001950339211749401, -6.266494605200327*^-7, \
-1.354357959188541*^-8}, 
     {5.971354327636086, -0.5552694173247879, -0.02419934375167602, \
-0.0005601240439740879, 
      -0.00002240270713257671, -6.795896221578519*^-7, \
-1.201709349193833*^-8}, 
     {5.447344756733164, -0.6006203860064261, -0.02583679655234428, \
-0.0006452311021927112, 
      -0.00002488203251787149, -6.030303672602093*^-7, \
-1.583376666742293*^-9}, 
     {4.994559169969892, -0.6394373103400424, -0.02732862996656363, \
-0.0007171994723376593, 
      -0.00002519742550426964, -1.641290240708912*^-7, \
3.910597107780506*^-8}, 
     {4.512594792329623, -0.6805479316610102, -0.02897566532185714, \
-0.0007858734411303971, 
      -0.00002283819031739034, 6.281580292262645*^-7, 9.577105762745674*^-8}, \

     {4.092333097008952, -0.7162958456331559, -0.03043328001834313, \
-0.0008273002171360841, 
      -0.00001411116814184291, 2.773103753343612*^-6, 2.950546781062066*^-7}, \

     {3.650020866463042, -0.7538337447048592, -0.03194053384702654, \
-0.000837781640951464, 
      2.907707968555054*^-6, 5.852540359820091*^-6, 5.181368394863152*^-7}, 
     {3.184571840689228, -0.7931742380695744, -0.03340796215459502, \
-0.0007783073126224044, 
      0.00004020831399575819, 0.00001252969451950441, 1.050499280912101*^-6}, \

     {2.795135498386905, -0.825830794134082, -0.03443182974317923, \
-0.0006278837202671806, 
      0.0001043308691637567, 0.00002636995433250329, 2.548041348411085*^-6}, 
     {2.38977107808601, -0.8593358948133683, -0.03513375184134562, \
-0.000319913380216462, 
      0.0002060515099388112, 0.00004421380258099794, 4.001314036998032*^-6}, 
     {1.968166385363971, -0.8932395940637682, -0.03519115346953409, \
0.0002827427630627121, 
      0.0003953025819406979, 0.00008034764600886729, 7.407586137339988*^-6}, 
     {1.612143333988495, -0.9206107463009619, -0.03436732147393313, \
0.001167408375879762, 
      0.0006871165481036591, 0.0001488881693373802, 0.00001608512153778298}, 
     {1.245564862078643, -0.9468476617076561, -0.03218992389889563, \
0.002621839915004895, 
      0.001129466927246893, 0.0002361002834123236, 0.00002446272968897194}, 
     {0.9411036630779808, -0.9663582346870491, -0.02882442468204031, \
0.004524953127547926, 
      0.001773934206673067, 0.0004076052929450417, 0.00005060830769685972}, 
     {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, \
0.007385850858260214, 
      0.002672644657907155, 0.0005975972454227846, 0.00007016870897342483}, 
     {0.3159401433660997, -0.9951819807516075, -0.0141810564371504, \
0.01177969329600485, 
      0.004105758348508652, 0.0009339734047126293, 0.0001125727572013773}, 
     {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, \
0.01642148422154501, 
      0.005766813443267503, 0.001456041061702653, 0.0002183132824744149}, 
     {-0.1451655451007285, -0.9987483123162489, 0.008944489593331621, \
0.02264330478484971, 
      0.007723831164850311, 0.001834097872355712, 0.0002401682337663385}, 
     {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, \
0.03107584026681068, 
      0.01043305827566561, 0.002464002718034116, 0.0003260132232436369}, 
     {-0.6017366959356142, -0.9723927003509583, 0.05264297022337499, \
0.04225298673259487, 
      0.01376536310562221, 0.003084637463279821, 0.0003748430742714523}, 
     {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, \
0.0530975554303808, 
      0.01662705757449755, 0.003411909325867013, 0.0003468215640078723}, 
     {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, \
0.06584191092106879, 
      0.01927853582407632, 0.003240100434734713, 0.0001440904775641987}, 
     {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, \
0.08005627726477126, 
      0.02099483499621253, 0.002195345619101353, -0.0003027390708880932}, 
     {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
      0.02021543417588093, -0.000754274587538044, -0.001530626941211491}, 
     {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
      0.01746781961115515, -0.004103986580530314, -0.002450338209772962}, 
     {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
      0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, 
     {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
      -0.0007350026571956852, -0.01685438505251352, -0.005671350902054768}, 
     {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
      -0.01688511860132406, -0.02423508582492491, -0.006778310725377359}, 
     {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, \
0.09666214457796037, 
      -0.03204065521875401, -0.02840436636139767, -0.006444744621113192}, 
     {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, \
0.0785742469749175, 
      -0.0470257534782241, -0.02861634111365265, -0.00398773686340812}, 
     {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, \
0.05414735876830688, 
      -0.05977983902013911, -0.02439011013378813, 0.00001759514469461788}, 
     {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, \
0.03131763081762755, 
      -0.0651267030424638, -0.01330108771073375, 0.007932614219398512}, 
     {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, \
0.006382340077340566, 
      -0.06878153330095417, -0.00607622203589427, 0.009921051344796055}, 
     {-1.762223869805497, 0.0669098889538212, 0.4797874360581084, \
-0.01881564820658439, 
      -0.06715504466041756, 0.0052941015385649, 0.014075650991735}, 
     {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, \
-0.04290594361192289, 
      -0.06177008484910881, 0.01515215349206186, 0.01548803581768913}, 
     {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, \
-0.06450374890421965, 
      -0.05309737444319933, 0.02305207122611793, 0.01493656511780418}, 
     {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
      -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
     {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, \
-0.09760253037063431, 
      -0.02888818242959219, 0.0306691934708478, 0.009224953760383584}, 
     {-1.622080963140679, 0.4929301210117905, 0.3755325162049182, \
-0.1074178334999123, 
      -0.01633310637884133, 0.02856039286749514, 0.004168099462073743}, 
     {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
      -0.005160721979258902, 0.02417131244294108, -0.0003440345314113444}, 
     {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
      0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, 
     {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
      0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
     {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
      0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, 
     {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
      0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
     {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, \
-0.08779459299724857, 
      0.01979767319192345, -0.0003066249582991479, -0.006028282943382096}, 
     {-1.085063458885453, 0.8749251188130202, 0.144782245099154, \
-0.07854258397670186, 
      0.01986264568980367, -0.002297713136917443, -0.004783528255310104}, 
     {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, \
-0.06946500901627999, 
      0.01908920268180254, -0.003359677058435248, -0.003492310907858758}, 
     {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, \
-0.0608924971492783, 
      0.01779753275101055, -0.003788394790891112, -0.002346567941738405}, 
     {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, \
-0.05301145859825892, 
      0.01623278484580223, -0.003814067204285791, -0.00142298197321629, \
0.001159542229646304}\\
, {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, \
-0.04468096904705857, 
      0.01441045900308664, -0.002783953394204672, 0.001188784376355514, \
0.001697085509141072}\\
, {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, \
-0.03741547808128195, 
      0.0128042870890071, -0.001516085052811469, 0.002492470180502037, \
0.001592641575583569}, 
     {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, \
-0.03126812679688145, 
      0.01073262941726728, -0.002037579725773561, 0.001248140166443795, \
0.000621510220514931}\\
, {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, \
-0.02604465129166512, 
      0.008980331918121603, -0.002095510898895228, 0.0006953458839076041, 
      0.0002187584774474667}, {-0.1113407854287719, 0.9993407044576816, 
      0.006696023109974216, -0.02163335504587148, 0.007533052625606419, 
      -0.001862875274342468, 0.0005412212424280951, 0.00009130883576918053}, 
     {0.02323242649556178, 1.000037398259186, -0.001270322947428585, \
-0.01793006544947133, 
      0.006305477814234636, -0.001607987009029117, 0.0004376460542311089, 
      0.00002422708367731202}, {0.1577637429652595, 0.9987796241790409, 
      -0.007866224138143035, -0.01483069730268437, 0.00526623201595544, 
      -0.001376927490964432, 0.0003454596158002636}, 
     {0.3238530675731096, 0.995016345930049, -0.0144640796213406, \
-0.0116871546883609, 
      0.004231198363091821, -0.001064594641186693, 0.0003322772383557684}, 
     {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, \
-0.00917301401911442, 
      0.003397859160363781, -0.000819933720088739, 0.0002972842358494771}, 
     {0.6533538559313423, 0.9820447155621451, -0.02372070399070088, \
-0.007162526259702596, 
      0.002726309336887593, -0.0006384642833766479, 0.0002509980162091398}, 
     {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, \
-0.005553834168748899, 
      0.002185764859300605, -0.0005041528357430196, 0.000204352772054328}, 
     {0.9776558814470167, 0.9642105857215122, -0.02932920777076483, \
-0.004264733145196217, 
      0.001753679572068895, -0.0003999863031745657, 0.0001643010647412814}, 
     {1.137437570202047, 0.9541144596710516, -0.03119425522545939, \
-0.003230475051281675, 
      0.001408187583593927, -0.000318863443275577, 0.0001310475300282612}, 
     {1.373962009270192, 0.9379913626951294, -0.03315104071340928, \
-0.002035992528092278, 
      0.001055017058722285, -0.0001754137530066389, 0.0001168833024258509}, 
     {1.606350517388015, 0.9210897263708773, -0.03435027793903866, \
-0.001185643298369978, 
      0.0007611892730192848, -0.0001263674244384825, 0.00008320952677836924}, \

     {1.834451124462977, 0.9037326412745143, -0.03500295728260755, \
-0.0005720113774542266, 
      0.0005488589661374675, -0.0000923366591773421, 0.00005900095063806828}, \

     {2.05818068749326, 0.8861532298832889, -0.03526139771076708, \
-0.0001299066826636304, 
      0.0003943010523705895, -0.00006860755394809425, \
0.00004172858547342076}, 
     {2.277505796363031, 0.8685194772734156, -0.03523617500405487, \
0.0001875161539186697, 
      0.0002818251856303586, -0.0000511645549180407, 0.00002968880418123365}, \

     {2.492428788195139, 0.8509519705097273, -0.03500799092175404, \
0.0004136601693357046, 
      0.0001995415136804703, -0.00003828804738911866, \
0.00002124715551700476}, 
     {2.772238550718317, 0.8277725006882704, -0.03448789441543038, \
0.0006187349731000154, 
      0.0001352320034684956, -0.00001425422529863956, \
0.00001755451345997014}, 
     {3.044385230797065, 0.8049972229139195, -0.03380947075089432, \
0.0007368050289671234, 
      0.00007834634628596583, -0.00001122391314621417, \
0.00001113870188222071}, 
     {3.309018587737515, 0.7827080320625583, -0.03303896113559139, \
0.0008026315339952361, 
      0.00004206218440122728, -7.530342783184703*^-6, 7.421851557590777*^-6}, \

     {3.566309067033361, 0.7609505320860362, -0.0322207398277254, \
0.0008326581797725729, 
      0.00001753263227045104, -5.206456476998877*^-6, 4.91783556921768*^-6}, 
     {3.81643803262864, 0.7397459514613501, -0.03138449367913013, \
0.000838939799644164, 
      1.35077760291538*^-6, -3.443913900758643*^-6, 3.303169942357289*^-6}, 
     {4.059591012015883, 0.7190992617954302, -0.03054996995098544, \
0.0008294710638224421, 
      -9.266693762532051*^-6, -2.176304405457542*^-6, 2.235395158274695*^-6}, \

     {4.372585721165242, 0.6924846048814831, -0.02946402757201999, \
0.0008029885517503858, 
      -0.00001512205360717179, 8.250783523782558*^-7, 1.79238678863533*^-6}, 
     {4.673987267678016, 0.6668147871373053, -0.02842204472668379, \
0.0007647138190854807, 
      -0.00002078611834098472, 6.541365780799917*^-7, 1.049737140101165*^-6}, \

     {4.964205394312013, 0.6420460382904659, -0.02743350214751175, \
0.0007221979607514677, 
      -0.00002314976507814556, 7.761061031756697*^-7, 6.481760049899586*^-7}, \

     {5.243628875125201, 0.6181288506037192, -0.02650242749678078, \
0.0006781875255987336, 
      -0.00002393452362995146, 7.931800302684875*^-7, 3.914720523938617*^-7}, \

     {5.5126240130368, 0.5950117248664654, -0.0256295578461628, \
0.0006345834841070335, 
      -0.00002369251940469708, 8.021342089770415*^-7, 2.362291693947091*^-7}, \

     {5.771534255654154, 0.5726434521487585, -0.02481369104364359, \
0.0005924255277376992, 
      -0.00002288648698303586, 7.853559496375988*^-7, 1.392154952244304*^-7}, \

     {6.108778136511332, 0.5432709949881284, -0.02378916494031363, \
0.0005385767396017946, 
      -0.00002090222196923115, 9.634231569526953*^-7, 1.031660310217783*^-7}, \

     {6.428627940347904, 0.5150795809575441, -0.02285881763700148, \
0.000488650474985677, 
      -0.00001936889068213984, 7.862704461763962*^-7, 4.236373274532015*^-8}, \

     {6.731764237016638, 0.4879601358421129, -0.02201464865538692, \
0.0004432614671721073, 
      -0.00001769376947598321, 6.751452578811216*^-7, 1.316367698170899*^-8}, \

     {7.018804533876454, 0.4618132537833407, -0.02124878476612005, \
0.000402127590503264, 
      -0.00001608643168964409, 5.795259274427188*^-7, -2.64641555573496*^-9}, \

     {7.29030909335201, 0.4365487805184312, -0.02055383300618015, \
0.0003649289266705499, 
      -0.00001458398933991611, 5.033512661358331*^-7, \
-9.988169502319166*^-9}, 
     {7.546786291865488, 0.4120851279505025, -0.01992303747611581, \
0.0003312779634424161, 
      -0.00001322154918966636, 4.37551534672063*^-7, -1.324910477258141*^-8}, \

     {7.884086056271611, 0.3787788434178949, -0.01913029312120552, \
0.0002891023262879505, 
      -0.0000115291594594324, 3.63777393971772*^-7, -1.371373898326033*^-8}, 
     {8.193519584742434, 0.3467373043198655, -0.01843847943647414, \
0.0002522379007700076, 
      -0.00001012456090970589, 2.940570752419515*^-7, \
-1.367577777664127*^-8}, 
     {8.476095686537853, 0.3157992553430406, -0.01783509007823322, \
0.0002198514717341092, 
      -8.938518663488416*^-6, 2.402965656917715*^-7, -1.240599571914663*^-8}, \

     {8.732694164207696, 0.2858229861605473, -0.01730967605233079, \
0.0001911921984056844, 
      -7.945451424014868*^-6, 1.975592634101514*^-7, -1.078283810070344*^-8}, \

     {8.964081092156048, 0.2566830884024056, -0.01685353056247505, \
0.0001656356738916059, 
      -7.115162259841*^-6, 1.634975150107237*^-7, -9.131086931191294*^-9}, 
     {9.170921496420231, 0.2282677220189242, -0.01645941987193715, \
0.0001426479705924626, 
      -6.427511170842572*^-6, 1.348052317356517*^-7, -7.720497902122285*^-9}, \

     {9.389954355144068, 0.1945852773909356, -0.01605562025513275, \
0.000117523846926549, 
      -5.77104513440084*^-6, 1.004193245520244*^-7, -6.84435365281206*^-9}, 
     {9.574487972549572, 0.1616616916001712, -0.01572586742018316, \
0.00009490549903810554, 
      -5.233270606636592*^-6, 7.898604003413424*^-8, -5.485421307730566*^-9}, \

     {9.725231796860384, 0.1293508421880767, -0.01546336168132292, \
0.00007419723225491459, 
      -4.824923276518464*^-6, 5.934261569317994*^-8, -4.554919700878265*^-9}, \

     {9.842750599262039, 0.09751900870274404, -0.01526288472030978, \
0.000054940201293084, 
      -4.52067132704201*^-6, 4.262303874918333*^-8, -3.808526825726381*^-9}, 
     {9.927475673864893, 0.06604185470753681, -0.0151205676271804, \
0.00003672919236845725, 
      -4.308672419068996*^-6, 2.762596707450741*^-8, -3.249881860652005*^-9}, \

     {9.979713178406525, 0.03480181166196349, -0.01503372618961092, \
0.00001920328638020516, 
      -4.180602396326156*^-6, 1.358486971789759*^-8, -2.853196789546286*^-9}, \

     {9.999804221413857, 0.002079784470556782, -0.01500049198937566, \
1.146333605182019*^-6, 
      -4.131571602154404*^-6, -1.008292044867596*^-9, \
-2.604590129466682*^-9}, 
     {9.998959082774867, -0.007418778925791529, -0.01500187815261033, \
-4.065399346041674*^-6, 
      -4.111443091414769*^-6, 7.927537361729354*^-9, \
3.188545681628212*^-10}}][t], 
  InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
    {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
      0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
      2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
      4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
      8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
      12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
      16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
      19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
      21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
      22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
      23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
      24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
      25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
      25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
      26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
      26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
      26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
      27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
      27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
      28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
      28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
      29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
      30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
      31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
      33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
      35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
      37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
      40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
      43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
      47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
      51.68339752171315, 52.}}, {{0., 0.3}, 
     {0.0009979517077872255, 0.2999999900409223, -1.496927738092378*^-6}, 
     {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
      -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, 
      -0.00007923886649939536, -0.0001500117406492253}, 
     {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, \
-0.0001500829092720493}, 
     {0.1544524067542601, 0.2998806333275119, -0.0002318722535893141, 
      -0.0001502226433836075, -2.061947113752874*^-7}, 
     {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
      -0.0001512573923248744, -3.56926535101178*^-7}, 
     {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
      -0.0001532344335889719, -6.696147194160083*^-7}, 
     {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, \
-0.0001561772311865011, 
      -1.0428234784246*^-6}, {0.868848049581404, 0.2961496636728365, \
-0.001338713029291882, 
      -0.0001600680606887075, -1.43126921114028*^-6}, 
     {1.05798950032964, 0.2942346427695965, -0.001651893195715194, \
-0.0001652995935706142, 
      -1.838046254173493*^-6}, {1.245773954048422, 0.2919112807621309, 
      -0.001976470827894482, -0.000171839413657207, -2.313982825558378*^-6}, 
     {1.431934770245561, 0.2891633697453571, -0.002314981271114216, \
-0.0001797480698000253, 
      -2.828724047048563*^-6}, {1.616193851195026, 0.28597129085274, \
-0.002670225693750562, 
      -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
     {1.887969116886099, 0.2803076374177811, -0.003240529009765943, \
-0.0002072780859326736, 
      -5.221261131605496*^-6, -2.788381938828235*^-7}, 
     {2.153768380769201, 0.2734970220318928, -0.003867818935861487, \
-0.0002294381802057415, 
      -6.431829724465898*^-6, -2.655783988637725*^-7}, 
     {2.412433330554526, 0.2654158466017701, -0.004567259996799199, \
-0.0002572619737618737, 
      -7.902611695922691*^-6, -2.860666162534704*^-7}, 
     {2.662673326125159, 0.2559082295468512, -0.005357876121799781, \
-0.0002926858378040523, 
      -9.973696094715828*^-6, -3.588711908498042*^-7}, 
     {2.903028607000796, 0.244776794952918, -0.006264023860191164, \
-0.0003376675751241998, 
      -0.00001266075107069725, -4.594667989404502*^-7, \
-1.747260442740121*^-8}, 
     {3.175344187221096, 0.2289633086353855, -0.007545671364715371, \
-0.0004088562867722723, 
      -0.00001760680137464635, -8.727270794121078*^-7, \
-3.447284626861373*^-8}, 
     {3.427693211989913, 0.2098940230544755, -0.009114079092598725, \
-0.0005060976270138674, 
      -0.00002445938672013374, -1.283289477521906*^-6, \
-4.451638240754114*^-8}, 
     {3.65591142716557, 0.186792033285195, -0.01107850554171452, \
-0.0006407044351002397, 
      -0.00003391896655161902, -1.770630454265917*^-6, \
-5.499941220723898*^-8}, 
     {3.85478077194519, 0.1585724953229884, -0.01360311058181845, \
-0.0008339122439545453, 
      -0.0000489443172128367, -2.712322351006786*^-6, \
-8.766377802768383*^-8}, 
     {3.986763005165946, 0.131667061984029, -0.01615666214412804, \
-0.001051626041925007, 
      -0.00006869661225566872, -4.393137681215513*^-6, \
-1.761332361311671*^-7}, 
     {4.092061561834391, 0.0995298917764175, -0.01940869599958157, \
-0.001352395704445139, 
      -0.00009571282431003663, -6.281214100632805*^-6, \
-2.444479897469488*^-7}, 
     {4.153850886158325, 0.06883885260811142, -0.02272856290784795, \
-0.001690501313216549, 
      -0.0001316398123092309, -9.940863233820019*^-6, \
-4.806638869588175*^-7}, 
     {4.191306423956496, 0.03269842564989161, -0.02691267068137347, \
-0.002148302610858181, 
      -0.0001796379888607316, -0.00001388813348710936, \
-6.486429479295039*^-7}, 
     {4.200742249681569, -0.002208228754422552, -0.0312395051651517, \
-0.002663840093236035, 
      -0.0002423648979153841, -0.00002118918286358118, \
-1.197910773667203*^-6}, 
     {4.187480484699273, -0.04294029965292303, -0.03664374955205367, \
-0.003351432661554625, 
      -0.0003255129417403924, -0.00002918221867922413, \
-1.604121647400555*^-6}, 
     {4.147582708325752, -0.09101196819194772, -0.04351056025037764, \
-0.004295458408425854, 
      -0.0004497713933866242, -0.00004287189467316768, \
-2.47885545821094*^-6}, 
     {4.093216338662262, -0.1360882405850764, -0.05042227215046736, \
-0.005319578435935783, 
      -0.0006006220945709141, -0.00006396231737026914, \
-4.409656157769888*^-6}, 
     {4.015439499996313, -0.1885954484836499, -0.05903393771043326, \
-0.006668642152566507, 
      -0.0007954597141818747, -0.00008583296722324174, -5.6762468467354*^-6}, \

     {3.910243506625146, -0.2504281729333795, -0.06991601053462865, \
-0.008485369119217001, 
      -0.001075857440459364, -0.0001215320852716722, -8.352309163308866*^-6}, \

     {3.800626326934144, -0.3095265512549151, -0.0810211001084475, \
-0.01044535109360783, 
      -0.001399096395540943, -0.0001697669761996192, \
-0.00001320335121470718}, 
     {3.665972999146803, -0.378327542653802, -0.09474229302615215, \
-0.01295459443587661, 
      -0.001793921254600053, -0.0002144492937412613, \
-0.00001551062565886725}, 
     {3.535553015059292, -0.4428061177064114, -0.1082883390327763, \
-0.01550358393254631, 
      -0.00220095651893553, -0.0002668360165914096, -0.00002028150696806179}, \

     {3.383157176300779, -0.5167289059824787, -0.1245035267716008, \
-0.01856317910150786, 
      -0.00262862077236768, -0.0002906382154606718, -0.00001715551624775262}, \

     {3.20549373901541, -0.6019516096016301, -0.1438811536990364, \
-0.02213377125985196, 
      -0.003028422675279043, -0.0002756180044960396, -7.146543113549753*^-6}, \

     {3.058588130827458, -0.6720624861181122, -0.1601545679841135, \
-0.02490566730718879, 
      -0.003089766360970424, -0.00009058479323536484, \
0.00004914842109632001}, 
     {2.894596323375797, -0.7501316342604838, -0.1783524392815316, \
-0.02765292754581667, 
      -0.002939806242666361, 0.0001373209277761948, 0.00009530669209766431}, 
     {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
      -0.002118996299412064, 0.0007045924544449787, 0.0002210082169551333}, 
     {2.507421795656775, -0.9334055715055376, -0.2193614638360956, \
-0.03078067221328464, 
      -0.0001732800370884182, 0.001720488442029996, 0.000425988858941995}, 
     {2.33317849523205, -1.014847597695069, -0.2356208100425164, \
-0.02955058544284709, 
      0.003046032316439744, 0.003590979279397424, 0.0009523908779487415}, 
     {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
      0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, 
     {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
      0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
     {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
      0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
     {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
      0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
     {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
      0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
     {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
      0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
     {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
      0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, 
     {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
      0.04854416792859499, -0.004146149653291475, -0.007592239941335828}, 
     {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
      0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
     {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
      0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
     {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
      0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
     {0.04047800614247131, -1.699822619873736, -0.01104749066017452, \
0.1544758791615086, 
      0.002904805753834867, -0.03443803199776515, -0.009858086267061791}, 
     {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, \
0.1531408660534355, 
      -0.01167634603044878, -0.03485997177461622, -0.006216287801323393}, 
     {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
      -0.02502213731263542, -0.03148565897311392, -0.001319145505838771}, 
     {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
      -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, 
     {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
      -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
     {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
      -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, 
     {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
      -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
     {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
      -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
     {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
      -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
     {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
      -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
     {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
      -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
     {-1.676554155554152, -1.305608867189375, 0.2689638069601199, \
-0.001217053979193587, 
      -0.02444610851301589, 0.01402117366548132, 0.00224958656739477}, 
     {-1.821639069964926, -1.244590074076928, 0.2667220610870114, \
-0.0113128728396274, 
      -0.01864935539868304, 0.01161388704344243, -0.00006065302064348859}, 
     {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
      -0.01354138262907623, 0.009331003691403976, -0.001373910151833233}, 
     {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
      -0.009317813474587454, 0.007160120981883526, -0.002096244383309918}, 
     {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
      -0.005921779540154439, 0.005321449744103576, -0.002335005570329405}, 
     {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
      -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
      0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, \
0.2233247841202344, 
      -0.03060923986977494, -0.0009206404428521231, 0.002668607114008318, 
      -0.001642610820709008, 0.0002789857387758132}, 
     {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
      0.0007931576405303536, 0.002021643534149319, -0.0008785619396256485, 
      0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, \
0.1987180081228845, 
      -0.02986498356771943, 0.001850571136714643, 0.001311821166285018, 
      -0.0006006837699262708, 0.0004025249678476842}, 
     {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, \
-0.02868642525878178, 
      0.002510879609608891, 0.0008222015537418208, -0.0003592654655979457, 
      0.000353765107692091}, {-2.919626045506723, -0.7381571877771078, \
0.175586089260012, 
      -0.02723906829815367, 0.002875048835861939, 0.0004616915237353225, 
      -0.0002051292907194143, 0.0002903776349041168}, 
     {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, \
-0.02565419087941412, 
      0.003033030217916483, 0.0002014497612882507, -0.0001107920060412756, 
      0.0002269621421637012}, {-3.106117892072866, -0.6493204211172826, \
0.1548734590809113, 
      -0.02402116089273098, 0.003055539450422462, 0.00002599975151483897, 
      -0.00004758785347185354}, {-3.210090129745036, -0.5996681315994481, 
      0.1433705576419095, -0.02201677832120685, 0.002985222599816919, 
      -0.0000958294047673527, -0.00007731102712422072}, 
     {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, \
-0.02011385735927098, 
      0.002763124856175378, -0.0002864118307802861, -0.0001226612803402779}, 
     {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, \
-0.01832912002286514, 
      0.002545956219616085, -0.0003344654449797207, -0.00009282872655880584}, \

     {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
      0.002340654063149804, -0.0003120801939574286, -0.00004673823831166822}, \

     {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, \
-0.01517795810854488, 
      0.00213323204377452, -0.0002847408987506403, -0.0000171012438948165}, 
     {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, \
-0.01381624455578609, 
      0.0019329271910969, -0.000256584599016029, 1.007933302260962*^-6}, 
     {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, \
-0.01202278498544689, 
      0.001642061747291683, -0.000235249621043713, 6.294315540307676*^-6}, 
     {-3.798446943438669, -0.3105342664181361, 0.08122614330861257, \
-0.01048688148137613, 
      0.001408458250699894, -0.0001884038544520576, 0.00001626929459300319}, 
     {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, \
-0.00917947523972208, 
      0.001204544204314665, -0.0001528026664484259, 0.00001925560751478185}, 
     {-3.934630385946802, -0.2365213821444215, 0.06740931090421369, \
-0.008065641383147081, 
      0.001029940565630871, -0.0001250578171946844, 0.0000189522876063627}, 
     {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, \
-0.007114652075869174, 
      0.000882042765250185, -0.0001030409363367319, 0.00001724277618273266}, 
     {-4.036983057207475, -0.1746882790891004, 0.05670238403676125, \
-0.006300486571572722, 
      0.0007570421935068591, -0.00008565931813226637, \
0.00001498094973042025}, 
     {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, \
-0.005388164125577655, 
      0.0006254981305204854, -0.00006275759347351894, \
0.00001356839613907586}, 
     {-4.129977973626481, -0.1066698407990083, 0.04586552357996159, \
-0.004640446873950072, 
      0.0005154961431997248, -0.00005002292097234296, \
0.00001068768379513849}, 
     {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, \
-0.004021722679494938, 
      0.0004278764083609402, -0.00003998672821139463, 8.419621550322354*^-6}, \

     {-4.181992277724197, -0.05114937617478823, 0.03778328353121347, \
-0.003506550900720839, 
      0.0003572087299784264, -0.00003242813775361963, 6.563319850414154*^-6}, \

     {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, \
-0.003074675807083444, 
      0.0003001534886949304, -0.00002647017776461171, 5.129448984486421*^-6}, \

     {-4.200273762534801, -0.005059630122047486, 0.03160865927633907, \
-0.002710379401726163, 
      0.0002537304737997015, -0.00002179055275345088, 4.013488418448823*^-6}, \

     {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, \
-0.002307804699369244, 
      0.0002080180677235468, -0.00001467874931531174, 3.477096307713213*^-6}, \

     {-4.181640046440592, 0.04524848451510998, 0.02542812434125149, \
-0.001982916488272914, 
      0.0001688840778693765, -0.00001193572980333215, 2.498571878633773*^-6}, \

     {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, \
-0.001716367034850311, 
      0.0001387847490468397, -9.539748932217889*^-6, 1.859292472751585*^-6}, 
     {-4.122785355809635, 0.0860961029326029, 0.02083744114211, \
-0.001496038192667138, 
      0.0001149375476116196, -7.752989220148379*^-6, 1.384150391219296*^-6}, 
     {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, \
-0.001312377553500777, 
      0.00009598075726336363, -6.330002216054171*^-6, 1.044385030161512*^-6}, \

     {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, \
-0.001158156672391711, 
      0.00008074314435794473, -5.205832344760582*^-6, 7.956094303782612*^-7}, \

     {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, \
-0.0009845094817148179, 
      0.00006584206721644325, -3.320123427647478*^-6, 6.853161548526208*^-7}, \

     {-3.862684295208088, 0.1571524415300303, 0.01373487047827056, \
-0.0008458709268748281, 
      0.00005292158849075478, -2.717703778739206*^-6, 4.776227802405111*^-7}, \

     {-3.762840313497239, 0.172874054360284, 0.01230548051000591, \
-0.000732964029147417, 
      0.00004313135460575885, -2.174487587840614*^-6, 3.464779702597154*^-7}, \

     {-3.653990683732458, 0.186983619109208, 0.01106211919053541, \
-0.0006402696967549964, 
      0.0000354544481395366, -1.769433689206584*^-6, 2.525549483911888*^-7}, 
     {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, \
-0.0005634894736334127, 
      0.00002940436207093559, -1.444926260924889*^-6, 1.873187047108245*^-7}, \

     {-3.412804993833292, 0.2111489245800355, 0.009009588330419845, \
-0.0004994138122043501, 
      0.00002457256285304119, -1.188314081952184*^-6, 1.406896678162243*^-7}, \

     {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, \
-0.0004254398735934686, 
      0.00001981390334171221, -7.142813890569568*^-7, 1.214519187305689*^-7}, \

     {-3.028544710651558, 0.2379623057313892, 0.006815353873336178, \
-0.0003674996746395192, 
      0.00001563491183483192, -5.86375308215994*^-7, 8.286497780628049*^-8}, 
     {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, \
-0.0003211413486115556, 
      0.00001249454537016901, -4.723075689651174*^-7, 5.863156687991705*^-8}, \

     {-2.604332817704375, 0.2582797769625237, 0.005162226805369295, \
-0.0002838187140553005, 
      0.00001004906765736633, -3.87289508354963*^-7, 4.18217498152932*^-8}, 
     {-2.380372883980649, 0.2664918453580231, 0.004475381304397052, \
-0.0002535927280720157, 
      8.127093887680922*^-6, -3.191386114183283*^-7, 3.041795891583185*^-8}, 
     {-2.149888330991454, 0.273593607663118, 0.00385849017216741, \
-0.0002290448730929102, 
      6.587497754854157*^-6, -2.659372328911577*^-7, 2.240761720314729*^-8}, 
     {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, \
-0.0002052376119308477, 
      5.184646117813377*^-6, -1.904354091683055*^-7, 1.830162350662408*^-8}, 
     {-1.568184016554942, 0.2868392209174812, 0.002575703742891957, \
-0.0001869906042160404, 
      3.949989067622175*^-6, -1.664155420757597*^-7, 1.252617879183773*^-8}, 
     {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, \
-0.0001730929726651855, 
      2.962637641249672*^-6, -1.425953503160539*^-7, 9.048066793624791*^-9}, 
     {-0.9642073675986177, 0.2952248515659734, 0.001495169624718867, \
-0.0001628678796415216, 
      2.124382504834869*^-6, -1.268869055338464*^-7, 6.439368669983838*^-9}, 
     {-0.6568336412300838, 0.2978072625251313, 0.001000424961613838, \
-0.0001558063063980045, 
      1.393261933326278*^-6, -1.16189512124211*^-7, 4.551787476216529*^-9}, 
     {-0.3473080080181212, 0.2993839255588992, 0.0005231945129639924, 
      -0.0001515786954507069, 7.289963028536484*^-7, -1.10308871975636*^-7, 
      3.109375691580504*^-9}, {-0.02059882830471778, 0.2999868284345344, 
      0.00003089963017686534, -0.0001499710129035118, 7.391732362642512*^-8, 
      -1.071809864811129*^-7, 2.056959960532262*^-9}, 
     {0.07437607712204962, 0.2999612878079299, -0.0001115897022763641, 
      -0.0001501074630631385, -2.296620186836703*^-7, -1.774557747218172*^-7, \

      -1.356351577917269*^-8}}][t], InterpolatingFunction[{{0., 52.}}, 
    {1, 7, False, Real, {1}, {0}}, {{0., 0.003326505803053839, \
0.006653011606107678, 
      0.1760731080602622, 0.3454932045144168, 0.5149133009685714, \
1.113321247101875, 
      1.711729193235179, 2.310137139368483, 2.908545085501787, \
3.549213715257329, 
      4.189882345012872, 4.830550974768414, 5.471219604523957, \
6.430775161993191, 
      7.390330719462426, 8.349886276931659, 9.309441834400892, \
10.26899739187012, 
      11.41745542047073, 12.56591344907135, 13.71437147767196, \
14.86282950627257, 
      15.76989538380499, 16.6769612613374, 17.40744088188177, \
18.13792050242614, 
      18.7397772796289, 19.34163405683166, 19.94349083403443, \
20.42462129550812, 
      20.90575175698181, 21.3868822184555, 21.77942040848143, \
22.17195859850736, 
      22.49017329751688, 22.80838799652641, 23.12660269553594, \
23.35744832997994, 
      23.58829396442394, 23.81913959886794, 24.04998523331195, \
24.22894594708866, 
      24.40790666086538, 24.5868673746421, 24.73263739132645, \
24.87840740801079, 
      25.02417742469514, 25.16994744137948, 25.31571745806383, \
25.43261413721928, 
      25.54951081637472, 25.66640749553017, 25.75972519687526, \
25.85304289822035, 
      25.94636059956543, 26.03967830091052, 26.1329960022556, \
26.22631370360069, 
      26.32916651294125, 26.43201932228183, 26.5348721316224, \
26.63772494096296, 
      26.74057775030353, 26.8434305596441, 26.95721757772128, \
27.07100459579846, 
      27.18479161387564, 27.29857863195281, 27.41236565002999, \
27.52615266810717, 
      27.6607436925243, 27.79533471694143, 27.92992574135857, \
28.0645167657757, 
      28.19910779019284, 28.33369881460997, 28.4682898390271, \
28.63486540147832, 
      28.80144096392953, 28.96801652638075, 29.13459208883196, \
29.30116765128317, 
      29.46774321373439, 29.7177331909978, 29.9677231682612, \
30.2177131455246, 
      30.46770312278801, 30.71769310005141, 30.96768307731482, \
31.30105415814421, 
      31.6344252389736, 31.967796319803, 32.30116740063239, \
32.63453848146179, 
      32.96790956229118, 33.41142573145399, 33.85494190061679, \
34.2984580697796, 
      34.7419742389424, 35.18549040810521, 35.62900657726801, \
36.23354433912698, 
      36.83808210098595, 37.44261986284493, 38.0471576247039, \
38.65169538656287, 
      39.25623314842184, 40.10946709220665, 40.96270103599147, \
41.81593497977629, 
      42.6691689235611, 43.52240286734591, 44.37563681113073, \
45.41195548490509, 
      46.44827415867943, 47.48459283245379, 48.52091150622815, \
49.5572301800025, 
      50.59354885377685, 51.68339752171315, 52.}}, 
    {{0., 0.}, {0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., 0., \
0.}, 
     {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., \
0.}, 
     {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., \
0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0., 0., 0.}, 
     {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}}][t]}\
\>", "\<\
{InterpolatingFunction[{{0., 52.}}, <>][t], InterpolatingFunction[{{0., \
52.}}, <>][t], 
 
  InterpolatingFunction[{{0., 52.}}, <>][t]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["orbitm[t_] = M/(m+M) relorbit[t] /.const1", "Input"],

Cell[OutputFormData["\<\
{(3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
       {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
         0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
         2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
         4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
         8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
         12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
         16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
         19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
         21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
         22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
         23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
         24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
         25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
         25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
         26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
         26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
         26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
         27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
         27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
         28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
         28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
         29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
         30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
         31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
         33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
         35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
         37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
         40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
         43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
         47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
         51.68339752171315, 52.}}, {{10., 0.}, 
        {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, 
        {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
         -1.322286343058508*^-7}, {9.999534630881093, -0.005282323784489644, 
         -0.01500076832270247, -1.507556879980259*^-6}, 
        {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
         -4.303953042407377*^-6}, {9.996022280142259, -0.01544977367720093, 
         -0.01500656577947253, -7.102518978703048*^-6, \
-4.12962510774654*^-6}, 
        {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
         -0.00001911254788268681, -4.721536529157213*^-6}, 
        {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
         -0.00002843965797539134, -4.17160237245598*^-6}, 
        {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
         -0.00003863663157999305, -4.230562589262589*^-6}, 
        {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
         -0.00004907835452562485, -4.318382798300356*^-6}, 
        {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
         -0.00006058324022271351, -4.43239809319311*^-6}, 
        {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
         -0.00007254388067269821, -4.588965459026183*^-6}, 
        {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
         -0.00008504165353778693, -4.780886831038984*^-6}, 
        {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
         -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
        {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
         -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
        {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
         -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
        {8.9333000040121, -0.260711383344569, -0.0169126745304145, \
-0.0001688916601208405, 
         -7.056168354057571*^-6, -1.313845897946621*^-7}, 
        {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
         -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
        {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
         -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
         -6.674609404533344*^-9}, {7.968828654203694, -0.3701677267394483, 
         -0.01893656311738351, -0.0002787120557484119, \
-0.00001107459120877045, 
         -3.431225329765139*^-7, -1.221235206138657*^-8}, 
        {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
         -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
         -1.346430675352864*^-8}, {7.014966306469673, -0.4621643951747192, 
         -0.02125743383726544, -0.0004024832669310073, \
-0.00001612207743260069, 
         -5.188299501191256*^-7, -1.214130185849565*^-8}, 
        {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
         -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
         -1.354357959188541*^-8}, {5.971354327636086, -0.5552694173247879, 
         -0.02419934375167602, -0.0005601240439740879, \
-0.00002240270713257671, 
         -6.795896221578519*^-7, -1.201709349193833*^-8}, 
        {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
         -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
         -1.583376666742293*^-9}, {4.994559169969892, -0.6394373103400424, 
         -0.02732862996656363, -0.0007171994723376593, \
-0.00002519742550426964, 
         -1.641290240708912*^-7, 3.910597107780506*^-8}, 
        {4.512594792329623, -0.6805479316610102, -0.02897566532185714, 
         -0.0007858734411303971, -0.00002283819031739034, \
6.281580292262645*^-7, 
         9.577105762745674*^-8}, {4.092333097008952, -0.7162958456331559, 
         -0.03043328001834313, -0.0008273002171360841, \
-0.00001411116814184291, 
         2.773103753343612*^-6, 2.950546781062066*^-7}, 
        {3.650020866463042, -0.7538337447048592, -0.03194053384702654, 
         -0.000837781640951464, 2.907707968555054*^-6, 5.852540359820091*^-6, \

         5.181368394863152*^-7}, {3.184571840689228, -0.7931742380695744, 
         -0.03340796215459502, -0.0007783073126224044, \
0.00004020831399575819, 
         0.00001252969451950441, 1.050499280912101*^-6}, 
        {2.795135498386905, -0.825830794134082, -0.03443182974317923, 
         -0.0006278837202671806, 0.0001043308691637567, \
0.00002636995433250329, 
         2.548041348411085*^-6}, {2.38977107808601, -0.8593358948133683, 
         -0.03513375184134562, -0.000319913380216462, 0.0002060515099388112, 
         0.00004421380258099794, 4.001314036998032*^-6}, 
        {1.968166385363971, -0.8932395940637682, -0.03519115346953409, 
         0.0002827427630627121, 0.0003953025819406979, \
0.00008034764600886729, 
         7.407586137339988*^-6}, {1.612143333988495, -0.9206107463009619, 
         -0.03436732147393313, 0.001167408375879762, 0.0006871165481036591, 
         0.0001488881693373802, 0.00001608512153778298}, 
        {1.245564862078643, -0.9468476617076561, -0.03218992389889563, 
         0.002621839915004895, 0.001129466927246893, 0.0002361002834123236, 
         0.00002446272968897194}, {0.9411036630779808, -0.9663582346870491, 
         -0.02882442468204031, 0.004524953127547926, 0.001773934206673067, 
         0.0004076052929450417, 0.00005060830769685972}, 
        {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, 
         0.007385850858260214, 0.002672644657907155, 0.0005975972454227846, 
         0.00007016870897342483}, {0.3159401433660997, -0.9951819807516075, 
         -0.0141810564371504, 0.01177969329600485, 0.004105758348508652, 
         0.0009339734047126293, 0.0001125727572013773}, 
        {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, 
         0.01642148422154501, 0.005766813443267503, 0.001456041061702653, 
         0.0002183132824744149}, {-0.1451655451007285, -0.9987483123162489, 
         0.008944489593331621, 0.02264330478484971, 0.007723831164850311, 
         0.001834097872355712, 0.0002401682337663385}, 
        {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, 
         0.03107584026681068, 0.01043305827566561, 0.002464002718034116, 
         0.0003260132232436369}, {-0.6017366959356142, -0.9723927003509583, 
         0.05264297022337499, 0.04225298673259487, 0.01376536310562221, 
         0.003084637463279821, 0.0003748430742714523}, 
        {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, \
0.0530975554303808, 
         0.01662705757449755, 0.003411909325867013, 0.0003468215640078723}, 
        {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, \
0.06584191092106879, 
         0.01927853582407632, 0.003240100434734713, 0.0001440904775641987}, 
        {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, \
0.08005627726477126, 
         0.02099483499621253, 0.002195345619101353, -0.0003027390708880932}, 
        {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
         0.02021543417588093, -0.000754274587538044, -0.001530626941211491}, 
        {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
         0.01746781961115515, -0.004103986580530314, -0.002450338209772962}, 
        {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
         0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, 
        {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
         -0.0007350026571956852, -0.01685438505251352, \
-0.005671350902054768}, 
        {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
         -0.01688511860132406, -0.02423508582492491, -0.006778310725377359}, 
        {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, \
0.09666214457796037, 
         -0.03204065521875401, -0.02840436636139767, -0.006444744621113192}, 
        {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, \
0.0785742469749175, 
         -0.0470257534782241, -0.02861634111365265, -0.00398773686340812}, 
        {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, \
0.05414735876830688, 
         -0.05977983902013911, -0.02439011013378813, 0.00001759514469461788}, \

        {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, \
0.03131763081762755, 
         -0.0651267030424638, -0.01330108771073375, 0.007932614219398512}, 
        {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, 
         0.006382340077340566, -0.06878153330095417, -0.00607622203589427, 
         0.009921051344796055}, {-1.762223869805497, 0.0669098889538212, 
         0.4797874360581084, -0.01881564820658439, -0.06715504466041756, 
         0.0052941015385649, 0.014075650991735}, 
        {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, \
-0.04290594361192289, 
         -0.06177008484910881, 0.01515215349206186, 0.01548803581768913}, 
        {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, \
-0.06450374890421965, 
         -0.05309737444319933, 0.02305207122611793, 0.01493656511780418}, 
        {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
         -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
        {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, \
-0.09760253037063431, 
         -0.02888818242959219, 0.0306691934708478, 0.009224953760383584}, 
        {-1.622080963140679, 0.4929301210117905, 0.3755325162049182, \
-0.1074178334999123, 
         -0.01633310637884133, 0.02856039286749514, 0.004168099462073743}, 
        {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
         -0.005160721979258902, 0.02417131244294108, -0.0003440345314113444}, \

        {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
         0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, 
        {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
         0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
        {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
         0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, 
        {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
         0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
        {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, \
-0.08779459299724857, 
         0.01979767319192345, -0.0003066249582991479, -0.006028282943382096}, \

        {-1.085063458885453, 0.8749251188130202, 0.144782245099154, \
-0.07854258397670186, 
         0.01986264568980367, -0.002297713136917443, -0.004783528255310104}, 
        {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, \
-0.06946500901627999, 
         0.01908920268180254, -0.003359677058435248, -0.003492310907858758}, 
        {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, \
-0.0608924971492783, 
         0.01779753275101055, -0.003788394790891112, -0.002346567941738405}, 
        {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, 
         -0.05301145859825892, 0.01623278484580223, -0.003814067204285791, 
         -0.00142298197321629, 0.001159542229646304}, 
        {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, 
         -0.04468096904705857, 0.01441045900308664, -0.002783953394204672, 
         0.001188784376355514, 0.001697085509141072}, 
        {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, 
         -0.03741547808128195, 0.0128042870890071, -0.001516085052811469, 
         0.002492470180502037, 0.001592641575583569}, 
        {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, 
         -0.03126812679688145, 0.01073262941726728, -0.002037579725773561, 
         0.001248140166443795, 0.000621510220514931}, 
        {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, 
         -0.02604465129166512, 0.008980331918121603, -0.002095510898895228, 
         0.0006953458839076041, 0.0002187584774474667}, 
        {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, 
         -0.02163335504587148, 0.007533052625606419, -0.001862875274342468, 
         0.0005412212424280951, 0.00009130883576918053}, 
        {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
         -0.01793006544947133, 0.006305477814234636, -0.001607987009029117, 
         0.0004376460542311089, 0.00002422708367731202}, 
        {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
         -0.01483069730268437, 0.00526623201595544, -0.001376927490964432, 
         0.0003454596158002636}, {0.3238530675731096, 0.995016345930049, 
         -0.0144640796213406, -0.0116871546883609, 0.004231198363091821, 
         -0.001064594641186693, 0.0003322772383557684}, 
        {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, 
         -0.00917301401911442, 0.003397859160363781, -0.000819933720088739, 
         0.0002972842358494771}, {0.6533538559313423, 0.9820447155621451, 
         -0.02372070399070088, -0.007162526259702596, 0.002726309336887593, 
         -0.0006384642833766479, 0.0002509980162091398}, 
        {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, 
         -0.005553834168748899, 0.002185764859300605, -0.0005041528357430196, \

         0.000204352772054328}, {0.9776558814470167, 0.9642105857215122, 
         -0.02932920777076483, -0.004264733145196217, 0.001753679572068895, 
         -0.0003999863031745657, 0.0001643010647412814}, 
        {1.137437570202047, 0.9541144596710516, -0.03119425522545939, 
         -0.003230475051281675, 0.001408187583593927, -0.000318863443275577, 
         0.0001310475300282612}, {1.373962009270192, 0.9379913626951294, 
         -0.03315104071340928, -0.002035992528092278, 0.001055017058722285, 
         -0.0001754137530066389, 0.0001168833024258509}, 
        {1.606350517388015, 0.9210897263708773, -0.03435027793903866, 
         -0.001185643298369978, 0.0007611892730192848, \
-0.0001263674244384825, 
         0.00008320952677836924}, {1.834451124462977, 0.9037326412745143, 
         -0.03500295728260755, -0.0005720113774542266, 0.0005488589661374675, \

         -0.0000923366591773421, 0.00005900095063806828}, 
        {2.05818068749326, 0.8861532298832889, -0.03526139771076708, 
         -0.0001299066826636304, 0.0003943010523705895, \
-0.00006860755394809425, 
         0.00004172858547342076}, {2.277505796363031, 0.8685194772734156, 
         -0.03523617500405487, 0.0001875161539186697, 0.0002818251856303586, 
         -0.0000511645549180407, 0.00002968880418123365}, 
        {2.492428788195139, 0.8509519705097273, -0.03500799092175404, 
         0.0004136601693357046, 0.0001995415136804703, \
-0.00003828804738911866, 
         0.00002124715551700476}, {2.772238550718317, 0.8277725006882704, 
         -0.03448789441543038, 0.0006187349731000154, 0.0001352320034684956, 
         -0.00001425422529863956, 0.00001755451345997014}, 
        {3.044385230797065, 0.8049972229139195, -0.03380947075089432, 
         0.0007368050289671234, 0.00007834634628596583, \
-0.00001122391314621417, 
         0.00001113870188222071}, {3.309018587737515, 0.7827080320625583, 
         -0.03303896113559139, 0.0008026315339952361, 0.00004206218440122728, \

         -7.530342783184703*^-6, 7.421851557590777*^-6}, 
        {3.566309067033361, 0.7609505320860362, -0.0322207398277254, \
0.0008326581797725729, 
         0.00001753263227045104, -5.206456476998877*^-6, \
4.91783556921768*^-6}, 
        {3.81643803262864, 0.7397459514613501, -0.03138449367913013, \
0.000838939799644164, 
         1.35077760291538*^-6, -3.443913900758643*^-6, \
3.303169942357289*^-6}, 
        {4.059591012015883, 0.7190992617954302, -0.03054996995098544, 
         0.0008294710638224421, -9.266693762532051*^-6, \
-2.176304405457542*^-6, 
         2.235395158274695*^-6}, {4.372585721165242, 0.6924846048814831, 
         -0.02946402757201999, 0.0008029885517503858, \
-0.00001512205360717179, 
         8.250783523782558*^-7, 1.79238678863533*^-6}, 
        {4.673987267678016, 0.6668147871373053, -0.02842204472668379, 
         0.0007647138190854807, -0.00002078611834098472, \
6.541365780799917*^-7, 
         1.049737140101165*^-6}, {4.964205394312013, 0.6420460382904659, 
         -0.02743350214751175, 0.0007221979607514677, \
-0.00002314976507814556, 
         7.761061031756697*^-7, 6.481760049899586*^-7}, 
        {5.243628875125201, 0.6181288506037192, -0.02650242749678078, 
         0.0006781875255987336, -0.00002393452362995146, \
7.931800302684875*^-7, 
         3.914720523938617*^-7}, {5.5126240130368, 0.5950117248664654, \
-0.0256295578461628, 
         0.0006345834841070335, -0.00002369251940469708, \
8.021342089770415*^-7, 
         2.362291693947091*^-7}, {5.771534255654154, 0.5726434521487585, 
         -0.02481369104364359, 0.0005924255277376992, \
-0.00002288648698303586, 
         7.853559496375988*^-7, 1.392154952244304*^-7}, 
        {6.108778136511332, 0.5432709949881284, -0.02378916494031363, 
         0.0005385767396017946, -0.00002090222196923115, \
9.634231569526953*^-7, 
         1.031660310217783*^-7}, {6.428627940347904, 0.5150795809575441, 
         -0.02285881763700148, 0.000488650474985677, -0.00001936889068213984, \

         7.862704461763962*^-7, 4.236373274532015*^-8}, 
        {6.731764237016638, 0.4879601358421129, -0.02201464865538692, 
         0.0004432614671721073, -0.00001769376947598321, \
6.751452578811216*^-7, 
         1.316367698170899*^-8}, {7.018804533876454, 0.4618132537833407, 
         -0.02124878476612005, 0.000402127590503264, -0.00001608643168964409, \

         5.795259274427188*^-7, -2.64641555573496*^-9}, 
        {7.29030909335201, 0.4365487805184312, -0.02055383300618015, \
0.0003649289266705499, 
         -0.00001458398933991611, 5.033512661358331*^-7, \
-9.988169502319166*^-9}, 
        {7.546786291865488, 0.4120851279505025, -0.01992303747611581, 
         0.0003312779634424161, -0.00001322154918966636, \
4.37551534672063*^-7, 
         -1.324910477258141*^-8}, {7.884086056271611, 0.3787788434178949, 
         -0.01913029312120552, 0.0002891023262879505, -0.0000115291594594324, \

         3.63777393971772*^-7, -1.371373898326033*^-8}, 
        {8.193519584742434, 0.3467373043198655, -0.01843847943647414, 
         0.0002522379007700076, -0.00001012456090970589, \
2.940570752419515*^-7, 
         -1.367577777664127*^-8}, {8.476095686537853, 0.3157992553430406, 
         -0.01783509007823322, 0.0002198514717341092, -8.938518663488416*^-6, \

         2.402965656917715*^-7, -1.240599571914663*^-8}, 
        {8.732694164207696, 0.2858229861605473, -0.01730967605233079, 
         0.0001911921984056844, -7.945451424014868*^-6, \
1.975592634101514*^-7, 
         -1.078283810070344*^-8}, {8.964081092156048, 0.2566830884024056, 
         -0.01685353056247505, 0.0001656356738916059, -7.115162259841*^-6, 
         1.634975150107237*^-7, -9.131086931191294*^-9}, 
        {9.170921496420231, 0.2282677220189242, -0.01645941987193715, 
         0.0001426479705924626, -6.427511170842572*^-6, \
1.348052317356517*^-7, 
         -7.720497902122285*^-9}, {9.389954355144068, 0.1945852773909356, 
         -0.01605562025513275, 0.000117523846926549, -5.77104513440084*^-6, 
         1.004193245520244*^-7, -6.84435365281206*^-9}, 
        {9.574487972549572, 0.1616616916001712, -0.01572586742018316, 
         0.00009490549903810554, -5.233270606636592*^-6, \
7.898604003413424*^-8, 
         -5.485421307730566*^-9}, {9.725231796860384, 0.1293508421880767, 
         -0.01546336168132292, 0.00007419723225491459, \
-4.824923276518464*^-6, 
         5.934261569317994*^-8, -4.554919700878265*^-9}, 
        {9.842750599262039, 0.09751900870274404, -0.01526288472030978, 
         0.000054940201293084, -4.52067132704201*^-6, 4.262303874918333*^-8, 
         -3.808526825726381*^-9}, {9.927475673864893, 0.06604185470753681, 
         -0.0151205676271804, 0.00003672919236845725, -4.308672419068996*^-6, \

         2.762596707450741*^-8, -3.249881860652005*^-9}, 
        {9.979713178406525, 0.03480181166196349, -0.01503372618961092, 
         0.00001920328638020516, -4.180602396326156*^-6, \
1.358486971789759*^-8, 
         -2.853196789546286*^-9}, {9.999804221413857, 0.002079784470556782, 
         -0.01500049198937566, 1.146333605182019*^-6, -4.131571602154404*^-6, \

         -1.008292044867596*^-9, -2.604590129466682*^-9}, 
        {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
         -4.065399346041674*^-6, -4.111443091414769*^-6, \
7.927537361729354*^-9, 
         3.188545681628212*^-10}}][t])/4, 
  (3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
       {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
         0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
         2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
         4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
         8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
         12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
         16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
         19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
         21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
         22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
         23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
         24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
         25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
         25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
         26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
         26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
         26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
         27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
         27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
         28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
         28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
         29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
         30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
         31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
         33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
         35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
         37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
         40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
         43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
         47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
         51.68339752171315, 52.}}, {{0., 0.3}, 
        {0.0009979517077872255, 0.2999999900409223, -1.496927738092378*^-6}, 
        {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
         -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, 
         -0.00007923886649939536, -0.0001500117406492253}, 
        {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
         -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, 
         -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
        {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
         -0.0001512573923248744, -3.56926535101178*^-7}, 
        {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
         -0.0001532344335889719, -6.696147194160083*^-7}, 
        {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
         -0.0001561772311865011, -1.0428234784246*^-6}, 
        {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
         -0.0001600680606887075, -1.43126921114028*^-6}, 
        {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
         -0.0001652995935706142, -1.838046254173493*^-6}, 
        {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
         -0.000171839413657207, -2.313982825558378*^-6}, 
        {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
         -0.0001797480698000253, -2.828724047048563*^-6}, 
        {1.616193851195026, 0.28597129085274, -0.002670225693750562, 
         -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
        {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
         -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
        {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
         -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
        {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
         -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
        {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
         -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
        {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
         -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
         -1.747260442740121*^-8}, {3.175344187221096, 0.2289633086353855, 
         -0.007545671364715371, -0.0004088562867722723, \
-0.00001760680137464635, 
         -8.727270794121078*^-7, -3.447284626861373*^-8}, 
        {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
         -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
         -4.451638240754114*^-8}, {3.65591142716557, 0.186792033285195, 
         -0.01107850554171452, -0.0006407044351002397, \
-0.00003391896655161902, 
         -1.770630454265917*^-6, -5.499941220723898*^-8}, 
        {3.85478077194519, 0.1585724953229884, -0.01360311058181845, 
         -0.0008339122439545453, -0.0000489443172128367, \
-2.712322351006786*^-6, 
         -8.766377802768383*^-8}, {3.986763005165946, 0.131667061984029, 
         -0.01615666214412804, -0.001051626041925007, \
-0.00006869661225566872, 
         -4.393137681215513*^-6, -1.761332361311671*^-7}, 
        {4.092061561834391, 0.0995298917764175, -0.01940869599958157, 
         -0.001352395704445139, -0.00009571282431003663, \
-6.281214100632805*^-6, 
         -2.444479897469488*^-7}, {4.153850886158325, 0.06883885260811142, 
         -0.02272856290784795, -0.001690501313216549, -0.0001316398123092309, \

         -9.940863233820019*^-6, -4.806638869588175*^-7}, 
        {4.191306423956496, 0.03269842564989161, -0.02691267068137347, 
         -0.002148302610858181, -0.0001796379888607316, \
-0.00001388813348710936, 
         -6.486429479295039*^-7}, {4.200742249681569, -0.002208228754422552, 
         -0.0312395051651517, -0.002663840093236035, -0.0002423648979153841, 
         -0.00002118918286358118, -1.197910773667203*^-6}, 
        {4.187480484699273, -0.04294029965292303, -0.03664374955205367, 
         -0.003351432661554625, -0.0003255129417403924, \
-0.00002918221867922413, 
         -1.604121647400555*^-6}, {4.147582708325752, -0.09101196819194772, 
         -0.04351056025037764, -0.004295458408425854, -0.0004497713933866242, \

         -0.00004287189467316768, -2.47885545821094*^-6}, 
        {4.093216338662262, -0.1360882405850764, -0.05042227215046736, 
         -0.005319578435935783, -0.0006006220945709141, \
-0.00006396231737026914, 
         -4.409656157769888*^-6}, {4.015439499996313, -0.1885954484836499, 
         -0.05903393771043326, -0.006668642152566507, -0.0007954597141818747, \

         -0.00008583296722324174, -5.6762468467354*^-6}, 
        {3.910243506625146, -0.2504281729333795, -0.06991601053462865, 
         -0.008485369119217001, -0.001075857440459364, \
-0.0001215320852716722, 
         -8.352309163308866*^-6}, {3.800626326934144, -0.3095265512549151, 
         -0.0810211001084475, -0.01044535109360783, -0.001399096395540943, 
         -0.0001697669761996192, -0.00001320335121470718}, 
        {3.665972999146803, -0.378327542653802, -0.09474229302615215, \
-0.01295459443587661, 
         -0.001793921254600053, -0.0002144492937412613, \
-0.00001551062565886725}, 
        {3.535553015059292, -0.4428061177064114, -0.1082883390327763, \
-0.01550358393254631, 
         -0.00220095651893553, -0.0002668360165914096, \
-0.00002028150696806179}, 
        {3.383157176300779, -0.5167289059824787, -0.1245035267716008, \
-0.01856317910150786, 
         -0.00262862077236768, -0.0002906382154606718, \
-0.00001715551624775262}, 
        {3.20549373901541, -0.6019516096016301, -0.1438811536990364, \
-0.02213377125985196, 
         -0.003028422675279043, -0.0002756180044960396, \
-7.146543113549753*^-6}, 
        {3.058588130827458, -0.6720624861181122, -0.1601545679841135, \
-0.02490566730718879, 
         -0.003089766360970424, -0.00009058479323536484, \
0.00004914842109632001}, 
        {2.894596323375797, -0.7501316342604838, -0.1783524392815316, \
-0.02765292754581667, 
         -0.002939806242666361, 0.0001373209277761948, \
0.00009530669209766431}, 
        {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
         -0.002118996299412064, 0.0007045924544449787, \
0.0002210082169551333}, 
        {2.507421795656775, -0.9334055715055376, -0.2193614638360956, \
-0.03078067221328464, 
         -0.0001732800370884182, 0.001720488442029996, 0.000425988858941995}, \

        {2.33317849523205, -1.014847597695069, -0.2356208100425164, \
-0.02955058544284709, 
         0.003046032316439744, 0.003590979279397424, 0.0009523908779487415}, 
        {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
         0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, 
        {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
         0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
        {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
         0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
        {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
         0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
        {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
         0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
        {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
         0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
        {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
         0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, 
        {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
         0.04854416792859499, -0.004146149653291475, -0.007592239941335828}, 
        {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
         0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
        {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
         0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
        {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
         0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
        {0.04047800614247131, -1.699822619873736, -0.01104749066017452, \
0.1544758791615086, 
         0.002904805753834867, -0.03443803199776515, -0.009858086267061791}, 
        {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, \
0.1531408660534355, 
         -0.01167634603044878, -0.03485997177461622, -0.006216287801323393}, 
        {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
         -0.02502213731263542, -0.03148565897311392, -0.001319145505838771}, 
        {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
         -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, 
        {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
         -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
        {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
         -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, 
        {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
         -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
        {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
         -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
        {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
         -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
        {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
         -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
        {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
         -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
        {-1.676554155554152, -1.305608867189375, 0.2689638069601199, \
-0.001217053979193587, 
         -0.02444610851301589, 0.01402117366548132, 0.00224958656739477}, 
        {-1.821639069964926, -1.244590074076928, 0.2667220610870114, \
-0.0113128728396274, 
         -0.01864935539868304, 0.01161388704344243, -0.00006065302064348859}, \

        {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
         -0.01354138262907623, 0.009331003691403976, -0.001373910151833233}, 
        {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
         -0.009317813474587454, 0.007160120981883526, -0.002096244383309918}, \

        {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
         -0.005921779540154439, 0.005321449744103576, -0.002335005570329405}, \

        {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
         -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
         0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, 
         0.2233247841202344, -0.03060923986977494, -0.0009206404428521231, 
         0.002668607114008318, -0.001642610820709008, 0.0002789857387758132}, \

        {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
         0.0007931576405303536, 0.002021643534149319, -0.0008785619396256485, \

         0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, 
         0.1987180081228845, -0.02986498356771943, 0.001850571136714643, 
         0.001311821166285018, -0.0006006837699262708, \
0.0004025249678476842}, 
        {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, \
-0.02868642525878178, 
         0.002510879609608891, 0.0008222015537418208, -0.0003592654655979457, \

         0.000353765107692091}, {-2.919626045506723, -0.7381571877771078, 
         0.175586089260012, -0.02723906829815367, 0.002875048835861939, 
         0.0004616915237353225, -0.0002051292907194143, \
0.0002903776349041168}, 
        {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, \
-0.02565419087941412, 
         0.003033030217916483, 0.0002014497612882507, -0.0001107920060412756, \

         0.0002269621421637012}, {-3.106117892072866, -0.6493204211172826, 
         0.1548734590809113, -0.02402116089273098, 0.003055539450422462, 
         0.00002599975151483897, -0.00004758785347185354}, 
        {-3.210090129745036, -0.5996681315994481, 0.1433705576419095, \
-0.02201677832120685, 
         0.002985222599816919, -0.0000958294047673527, \
-0.00007731102712422072}, 
        {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, \
-0.02011385735927098, 
         0.002763124856175378, -0.0002864118307802861, \
-0.0001226612803402779}, 
        {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, \
-0.01832912002286514, 
         0.002545956219616085, -0.0003344654449797207, \
-0.00009282872655880584}, 
        {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
         0.002340654063149804, -0.0003120801939574286, \
-0.00004673823831166822}, 
        {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, \
-0.01517795810854488, 
         0.00213323204377452, -0.0002847408987506403, \
-0.0000171012438948165}, 
        {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, \
-0.01381624455578609, 
         0.0019329271910969, -0.000256584599016029, 1.007933302260962*^-6}, 
        {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, 
         -0.01202278498544689, 0.001642061747291683, -0.000235249621043713, 
         6.294315540307676*^-6}, {-3.798446943438669, -0.3105342664181361, 
         0.08122614330861257, -0.01048688148137613, 0.001408458250699894, 
         -0.0001884038544520576, 0.00001626929459300319}, 
        {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, 
         -0.00917947523972208, 0.001204544204314665, -0.0001528026664484259, 
         0.00001925560751478185}, {-3.934630385946802, -0.2365213821444215, 
         0.06740931090421369, -0.008065641383147081, 0.001029940565630871, 
         -0.0001250578171946844, 0.0000189522876063627}, 
        {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, 
         -0.007114652075869174, 0.000882042765250185, -0.0001030409363367319, \

         0.00001724277618273266}, {-4.036983057207475, -0.1746882790891004, 
         0.05670238403676125, -0.006300486571572722, 0.0007570421935068591, 
         -0.00008565931813226637, 0.00001498094973042025}, 
        {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, 
         -0.005388164125577655, 0.0006254981305204854, \
-0.00006275759347351894, 
         0.00001356839613907586}, {-4.129977973626481, -0.1066698407990083, 
         0.04586552357996159, -0.004640446873950072, 0.0005154961431997248, 
         -0.00005002292097234296, 0.00001068768379513849}, 
        {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, 
         -0.004021722679494938, 0.0004278764083609402, \
-0.00003998672821139463, 
         8.419621550322354*^-6}, {-4.181992277724197, -0.05114937617478823, 
         0.03778328353121347, -0.003506550900720839, 0.0003572087299784264, 
         -0.00003242813775361963, 6.563319850414154*^-6}, 
        {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, 
         -0.003074675807083444, 0.0003001534886949304, \
-0.00002647017776461171, 
         5.129448984486421*^-6}, {-4.200273762534801, -0.005059630122047486, 
         0.03160865927633907, -0.002710379401726163, 0.0002537304737997015, 
         -0.00002179055275345088, 4.013488418448823*^-6}, 
        {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, 
         -0.002307804699369244, 0.0002080180677235468, \
-0.00001467874931531174, 
         3.477096307713213*^-6}, {-4.181640046440592, 0.04524848451510998, 
         0.02542812434125149, -0.001982916488272914, 0.0001688840778693765, 
         -0.00001193572980333215, 2.498571878633773*^-6}, 
        {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, 
         -0.001716367034850311, 0.0001387847490468397, \
-9.539748932217889*^-6, 
         1.859292472751585*^-6}, {-4.122785355809635, 0.0860961029326029, \
0.02083744114211, 
         -0.001496038192667138, 0.0001149375476116196, \
-7.752989220148379*^-6, 
         1.384150391219296*^-6}, {-4.080627749673199, 0.1037340341763129, 
         0.0189718502418653, -0.001312377553500777, 0.00009598075726336363, 
         -6.330002216054171*^-6, 1.044385030161512*^-6}, 
        {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, \
-0.001158156672391711, 
         0.00008074314435794473, -5.205832344760582*^-6, \
7.956094303782612*^-7}, 
        {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
         -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
         6.853161548526208*^-7}, {-3.862684295208088, 0.1571524415300303, 
         0.01373487047827056, -0.0008458709268748281, 0.00005292158849075478, \

         -2.717703778739206*^-6, 4.776227802405111*^-7}, 
        {-3.762840313497239, 0.172874054360284, 0.01230548051000591, \
-0.000732964029147417, 
         0.00004313135460575885, -2.174487587840614*^-6, \
3.464779702597154*^-7}, 
        {-3.653990683732458, 0.186983619109208, 0.01106211919053541, 
         -0.0006402696967549964, 0.0000354544481395366, \
-1.769433689206584*^-6, 
         2.525549483911888*^-7}, {-3.537046154954697, 0.1996855178939522, 
         0.009972121764422109, -0.0005634894736334127, \
0.00002940436207093559, 
         -1.444926260924889*^-6, 1.873187047108245*^-7}, 
        {-3.412804993833292, 0.2111489245800355, 0.009009588330419845, 
         -0.0004994138122043501, 0.00002457256285304119, \
-1.188314081952184*^-6, 
         1.406896678162243*^-7}, {-3.226384080591982, 0.2254888689910921, 
         0.00782863863198294, -0.0004254398735934686, 0.00001981390334171221, \

         -7.142813890569568*^-7, 1.214519187305689*^-7}, 
        {-3.028544710651558, 0.2379623057313892, 0.006815353873336178, 
         -0.0003674996746395192, 0.00001563491183483192, \
-5.86375308215994*^-7, 
         8.286497780628049*^-8}, {-2.820766127855042, 0.2488246275196445, 
         0.005935351079990573, -0.0003211413486115556, \
0.00001249454537016901, 
         -4.723075689651174*^-7, 5.863156687991705*^-8}, 
        {-2.604332817704375, 0.2582797769625237, 0.005162226805369295, 
         -0.0002838187140553005, 0.00001004906765736633, \
-3.87289508354963*^-7, 
         4.18217498152932*^-8}, {-2.380372883980649, 0.2664918453580231, 
         0.004475381304397052, -0.0002535927280720157, 8.127093887680922*^-6, \

         -3.191386114183283*^-7, 3.041795891583185*^-8}, 
        {-2.149888330991454, 0.273593607663118, 0.00385849017216741, 
         -0.0002290448730929102, 6.587497754854157*^-6, \
-2.659372328911577*^-7, 
         2.240761720314729*^-8}, {-1.862461949229833, 0.2808796276058946, 
         0.003184570856174013, -0.0002052376119308477, 5.184646117813377*^-6, \

         -1.904354091683055*^-7, 1.830162350662408*^-8}, 
        {-1.568184016554942, 0.2868392209174812, 0.002575703742891957, 
         -0.0001869906042160404, 3.949989067622175*^-6, \
-1.664155420757597*^-7, 
         1.252617879183773*^-8}, {-1.268364868295478, 0.2915909328124841, 
         0.002016731272518744, -0.0001730929726651855, 2.962637641249672*^-6, \

         -1.425953503160539*^-7, 9.048066793624791*^-9}, 
        {-0.9642073675986177, 0.2952248515659734, 0.001495169624718867, 
         -0.0001628678796415216, 2.124382504834869*^-6, \
-1.268869055338464*^-7, 
         6.439368669983838*^-9}, {-0.6568336412300838, 0.2978072625251313, 
         0.001000424961613838, -0.0001558063063980045, 1.393261933326278*^-6, \

         -1.16189512124211*^-7, 4.551787476216529*^-9}, 
        {-0.3473080080181212, 0.2993839255588992, 0.0005231945129639924, 
         -0.0001515786954507069, 7.289963028536484*^-7, \
-1.10308871975636*^-7, 
         3.109375691580504*^-9}, {-0.02059882830471778, 0.2999868284345344, 
         0.00003089963017686534, -0.0001499710129035118, \
7.391732362642512*^-8, 
         -1.071809864811129*^-7, 2.056959960532262*^-9}, 
        {0.07437607712204962, 0.2999612878079299, -0.0001115897022763641, 
         -0.0001501074630631385, -2.296620186836703*^-7, \
-1.774557747218172*^-7, 
         -1.356351577917269*^-8}}][t])/4, 
  (3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
       {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
         0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
         2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
         4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
         8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
         12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
         16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
         19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
         21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
         22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
         23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
         24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
         25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
         25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
         26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
         26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
         26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
         27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
         27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
         28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
         28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
         29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
         30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
         31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
         33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
         35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
         37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
         40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
         43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
         47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
         51.68339752171315, 52.}}, {{0., 0.}, {0., 0., 0.}, {0., 0., 0., 0.}, \

        {0., 0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., \
0., 0., 0.}, 
        {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
        {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
        {0., 0., 0., 0., 0., 0., 0.}}][t])/4}\
\>", "\<\
 3 InterpolatingFunction[{{0., 52.}}, <>][t]  3 InterpolatingFunction[{{0., \
52.}}, <>][t]
{-------------------------------------------, \
-------------------------------------------, 
                      4                                            4
 
  3 InterpolatingFunction[{{0., 52.}}, <>][t]
  -------------------------------------------}
                       4\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["orbitM[t_] = -m/(m+M) relorbit[t] /.const1", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"orbitM\"
     is similar to existing symbol \"orbitm\".\
\>", "Message"],

Cell[OutputFormData["\<\
{-InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
      {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
        0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
        2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
        4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
        8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
        12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
        16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
        19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
        21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
        22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
        23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
        24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
        25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
        25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
        26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
        26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
        26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
        27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
        27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
        28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
        28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
        29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
        30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
        31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
        33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
        35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
        37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
        40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
        43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
        47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
        51.68339752171315, 52.}}, {{10., 0.}, 
       {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, 
       {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
        -1.322286343058508*^-7}, {9.999534630881093, -0.005282323784489644, 
        -0.01500076832270247, -1.507556879980259*^-6}, 
       {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
        -4.303953042407377*^-6}, {9.996022280142259, -0.01544977367720093, 
        -0.01500656577947253, -7.102518978703048*^-6, -4.12962510774654*^-6}, \

       {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
        -0.00001911254788268681, -4.721536529157213*^-6}, 
       {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
        -0.00002843965797539134, -4.17160237245598*^-6}, 
       {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
        -0.00003863663157999305, -4.230562589262589*^-6}, 
       {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
        -0.00004907835452562485, -4.318382798300356*^-6}, 
       {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
        -0.00006058324022271351, -4.43239809319311*^-6}, 
       {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
        -0.00007254388067269821, -4.588965459026183*^-6}, 
       {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
        -0.00008504165353778693, -4.780886831038984*^-6}, 
       {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
        -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
       {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
        -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
       {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
        -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
       {8.9333000040121, -0.260711383344569, -0.0169126745304145, \
-0.0001688916601208405, 
        -7.056168354057571*^-6, -1.313845897946621*^-7}, 
       {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
        -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
       {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
        -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
        -6.674609404533344*^-9}, {7.968828654203694, -0.3701677267394483, 
        -0.01893656311738351, -0.0002787120557484119, \
-0.00001107459120877045, 
        -3.431225329765139*^-7, -1.221235206138657*^-8}, 
       {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
        -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
        -1.346430675352864*^-8}, {7.014966306469673, -0.4621643951747192, 
        -0.02125743383726544, -0.0004024832669310073, \
-0.00001612207743260069, 
        -5.188299501191256*^-7, -1.214130185849565*^-8}, 
       {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
        -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
        -1.354357959188541*^-8}, {5.971354327636086, -0.5552694173247879, 
        -0.02419934375167602, -0.0005601240439740879, \
-0.00002240270713257671, 
        -6.795896221578519*^-7, -1.201709349193833*^-8}, 
       {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
        -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
        -1.583376666742293*^-9}, {4.994559169969892, -0.6394373103400424, 
        -0.02732862996656363, -0.0007171994723376593, \
-0.00002519742550426964, 
        -1.641290240708912*^-7, 3.910597107780506*^-8}, 
       {4.512594792329623, -0.6805479316610102, -0.02897566532185714, 
        -0.0007858734411303971, -0.00002283819031739034, \
6.281580292262645*^-7, 
        9.577105762745674*^-8}, {4.092333097008952, -0.7162958456331559, 
        -0.03043328001834313, -0.0008273002171360841, \
-0.00001411116814184291, 
        2.773103753343612*^-6, 2.950546781062066*^-7}, 
       {3.650020866463042, -0.7538337447048592, -0.03194053384702654, 
        -0.000837781640951464, 2.907707968555054*^-6, 5.852540359820091*^-6, 
        5.181368394863152*^-7}, {3.184571840689228, -0.7931742380695744, 
        -0.03340796215459502, -0.0007783073126224044, 0.00004020831399575819, \

        0.00001252969451950441, 1.050499280912101*^-6}, 
       {2.795135498386905, -0.825830794134082, -0.03443182974317923, 
        -0.0006278837202671806, 0.0001043308691637567, \
0.00002636995433250329, 
        2.548041348411085*^-6}, {2.38977107808601, -0.8593358948133683, 
        -0.03513375184134562, -0.000319913380216462, 0.0002060515099388112, 
        0.00004421380258099794, 4.001314036998032*^-6}, 
       {1.968166385363971, -0.8932395940637682, -0.03519115346953409, 
        0.0002827427630627121, 0.0003953025819406979, 0.00008034764600886729, \

        7.407586137339988*^-6}, {1.612143333988495, -0.9206107463009619, 
        -0.03436732147393313, 0.001167408375879762, 0.0006871165481036591, 
        0.0001488881693373802, 0.00001608512153778298}, 
       {1.245564862078643, -0.9468476617076561, -0.03218992389889563, \
0.002621839915004895, 
        0.001129466927246893, 0.0002361002834123236, 0.00002446272968897194}, \

       {0.9411036630779808, -0.9663582346870491, -0.02882442468204031, 
        0.004524953127547926, 0.001773934206673067, 0.0004076052929450417, 
        0.00005060830769685972}, {0.6308434436758507, -0.9830617967058087, 
        -0.02321559819713965, 0.007385850858260214, 0.002672644657907155, 
        0.0005975972454227846, 0.00007016870897342483}, 
       {0.3159401433660997, -0.9951819807516075, -0.0141810564371504, \
0.01177969329600485, 
        0.004105758348508652, 0.0009339734047126293, 0.0001125727572013773}, 
       {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, 
        0.01642148422154501, 0.005766813443267503, 0.001456041061702653, 
        0.0002183132824744149}, {-0.1451655451007285, -0.9987483123162489, 
        0.008944489593331621, 0.02264330478484971, 0.007723831164850311, 
        0.001834097872355712, 0.0002401682337663385}, 
       {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, \
0.03107584026681068, 
        0.01043305827566561, 0.002464002718034116, 0.0003260132232436369}, 
       {-0.6017366959356142, -0.9723927003509583, 0.05264297022337499, \
0.04225298673259487, 
        0.01376536310562221, 0.003084637463279821, 0.0003748430742714523}, 
       {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, \
0.0530975554303808, 
        0.01662705757449755, 0.003411909325867013, 0.0003468215640078723}, 
       {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, \
0.06584191092106879, 
        0.01927853582407632, 0.003240100434734713, 0.0001440904775641987}, 
       {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, \
0.08005627726477126, 
        0.02099483499621253, 0.002195345619101353, -0.0003027390708880932}, 
       {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
        0.02021543417588093, -0.000754274587538044, -0.001530626941211491}, 
       {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
        0.01746781961115515, -0.004103986580530314, -0.002450338209772962}, 
       {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
        0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, 
       {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
        -0.0007350026571956852, -0.01685438505251352, -0.005671350902054768}, \

       {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
        -0.01688511860132406, -0.02423508582492491, -0.006778310725377359}, 
       {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, \
0.09666214457796037, 
        -0.03204065521875401, -0.02840436636139767, -0.006444744621113192}, 
       {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, \
0.0785742469749175, 
        -0.0470257534782241, -0.02861634111365265, -0.00398773686340812}, 
       {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, \
0.05414735876830688, 
        -0.05977983902013911, -0.02439011013378813, 0.00001759514469461788}, 
       {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, \
0.03131763081762755, 
        -0.0651267030424638, -0.01330108771073375, 0.007932614219398512}, 
       {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, \
0.006382340077340566, 
        -0.06878153330095417, -0.00607622203589427, 0.009921051344796055}, 
       {-1.762223869805497, 0.0669098889538212, 0.4797874360581084, \
-0.01881564820658439, 
        -0.06715504466041756, 0.0052941015385649, 0.014075650991735}, 
       {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, \
-0.04290594361192289, 
        -0.06177008484910881, 0.01515215349206186, 0.01548803581768913}, 
       {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, \
-0.06450374890421965, 
        -0.05309737444319933, 0.02305207122611793, 0.01493656511780418}, 
       {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
        -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
       {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, \
-0.09760253037063431, 
        -0.02888818242959219, 0.0306691934708478, 0.009224953760383584}, 
       {-1.622080963140679, 0.4929301210117905, 0.3755325162049182, \
-0.1074178334999123, 
        -0.01633310637884133, 0.02856039286749514, 0.004168099462073743}, 
       {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
        -0.005160721979258902, 0.02417131244294108, -0.0003440345314113444}, 
       {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
        0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, 
       {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
        0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
       {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
        0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, 
       {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
        0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
       {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, \
-0.08779459299724857, 
        0.01979767319192345, -0.0003066249582991479, -0.006028282943382096}, 
       {-1.085063458885453, 0.8749251188130202, 0.144782245099154, \
-0.07854258397670186, 
        0.01986264568980367, -0.002297713136917443, -0.004783528255310104}, 
       {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, \
-0.06946500901627999, 
        0.01908920268180254, -0.003359677058435248, -0.003492310907858758}, 
       {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, \
-0.0608924971492783, 
        0.01779753275101055, -0.003788394790891112, -0.002346567941738405}, 
       {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, \
-0.05301145859825892, 
        0.01623278484580223, -0.003814067204285791, -0.00142298197321629, 
        0.001159542229646304}, {-0.6433048170868872, 0.9677057910471042, 
        0.05823802142742399, -0.04468096904705857, 0.01441045900308664, 
        -0.002783953394204672, 0.001188784376355514, 0.001697085509141072}, 
       {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, \
-0.03741547808128195, 
        0.0128042870890071, -0.001516085052811469, 0.002492470180502037, 
        0.001592641575583569}, {-0.3793958721349377, 0.9903923174534956, 
        0.02784424034262888, -0.03126812679688145, 0.01073262941726728, 
        -0.002037579725773561, 0.001248140166443795, 0.000621510220514931}, 
       {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, \
-0.02604465129166512, 
        0.008980331918121603, -0.002095510898895228, 0.0006953458839076041, 
        0.0002187584774474667}, {-0.1113407854287719, 0.9993407044576816, 
        0.006696023109974216, -0.02163335504587148, 0.007533052625606419, 
        -0.001862875274342468, 0.0005412212424280951, \
0.00009130883576918053}, 
       {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
        -0.01793006544947133, 0.006305477814234636, -0.001607987009029117, 
        0.0004376460542311089, 0.00002422708367731202}, 
       {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
        -0.01483069730268437, 0.00526623201595544, -0.001376927490964432, 
        0.0003454596158002636}, {0.3238530675731096, 0.995016345930049, 
        -0.0144640796213406, -0.0116871546883609, 0.004231198363091821, 
        -0.001064594641186693, 0.0003322772383557684}, 
       {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, \
-0.00917301401911442, 
        0.003397859160363781, -0.000819933720088739, 0.0002972842358494771}, 
       {0.6533538559313423, 0.9820447155621451, -0.02372070399070088, 
        -0.007162526259702596, 0.002726309336887593, -0.0006384642833766479, 
        0.0002509980162091398}, {0.8162492234476889, 0.9735925497470967, 
        -0.02688566131071034, -0.005553834168748899, 0.002185764859300605, 
        -0.0005041528357430196, 0.000204352772054328}, 
       {0.9776558814470167, 0.9642105857215122, -0.02932920777076483, 
        -0.004264733145196217, 0.001753679572068895, -0.0003999863031745657, 
        0.0001643010647412814}, {1.137437570202047, 0.9541144596710516, 
        -0.03119425522545939, -0.003230475051281675, 0.001408187583593927, 
        -0.000318863443275577, 0.0001310475300282612}, 
       {1.373962009270192, 0.9379913626951294, -0.03315104071340928, \
-0.002035992528092278, 
        0.001055017058722285, -0.0001754137530066389, 0.0001168833024258509}, \

       {1.606350517388015, 0.9210897263708773, -0.03435027793903866, \
-0.001185643298369978, 
        0.0007611892730192848, -0.0001263674244384825, \
0.00008320952677836924}, 
       {1.834451124462977, 0.9037326412745143, -0.03500295728260755, 
        -0.0005720113774542266, 0.0005488589661374675, \
-0.0000923366591773421, 
        0.00005900095063806828}, {2.05818068749326, 0.8861532298832889, 
        -0.03526139771076708, -0.0001299066826636304, 0.0003943010523705895, 
        -0.00006860755394809425, 0.00004172858547342076}, 
       {2.277505796363031, 0.8685194772734156, -0.03523617500405487, \
0.0001875161539186697, 
        0.0002818251856303586, -0.0000511645549180407, \
0.00002968880418123365}, 
       {2.492428788195139, 0.8509519705097273, -0.03500799092175404, \
0.0004136601693357046, 
        0.0001995415136804703, -0.00003828804738911866, \
0.00002124715551700476}, 
       {2.772238550718317, 0.8277725006882704, -0.03448789441543038, \
0.0006187349731000154, 
        0.0001352320034684956, -0.00001425422529863956, \
0.00001755451345997014}, 
       {3.044385230797065, 0.8049972229139195, -0.03380947075089432, \
0.0007368050289671234, 
        0.00007834634628596583, -0.00001122391314621417, \
0.00001113870188222071}, 
       {3.309018587737515, 0.7827080320625583, -0.03303896113559139, \
0.0008026315339952361, 
        0.00004206218440122728, -7.530342783184703*^-6, \
7.421851557590777*^-6}, 
       {3.566309067033361, 0.7609505320860362, -0.0322207398277254, \
0.0008326581797725729, 
        0.00001753263227045104, -5.206456476998877*^-6, \
4.91783556921768*^-6}, 
       {3.81643803262864, 0.7397459514613501, -0.03138449367913013, \
0.000838939799644164, 
        1.35077760291538*^-6, -3.443913900758643*^-6, 3.303169942357289*^-6}, \

       {4.059591012015883, 0.7190992617954302, -0.03054996995098544, \
0.0008294710638224421, 
        -9.266693762532051*^-6, -2.176304405457542*^-6, \
2.235395158274695*^-6}, 
       {4.372585721165242, 0.6924846048814831, -0.02946402757201999, \
0.0008029885517503858, 
        -0.00001512205360717179, 8.250783523782558*^-7, \
1.79238678863533*^-6}, 
       {4.673987267678016, 0.6668147871373053, -0.02842204472668379, \
0.0007647138190854807, 
        -0.00002078611834098472, 6.541365780799917*^-7, \
1.049737140101165*^-6}, 
       {4.964205394312013, 0.6420460382904659, -0.02743350214751175, \
0.0007221979607514677, 
        -0.00002314976507814556, 7.761061031756697*^-7, \
6.481760049899586*^-7}, 
       {5.243628875125201, 0.6181288506037192, -0.02650242749678078, \
0.0006781875255987336, 
        -0.00002393452362995146, 7.931800302684875*^-7, \
3.914720523938617*^-7}, 
       {5.5126240130368, 0.5950117248664654, -0.0256295578461628, \
0.0006345834841070335, 
        -0.00002369251940469708, 8.021342089770415*^-7, \
2.362291693947091*^-7}, 
       {5.771534255654154, 0.5726434521487585, -0.02481369104364359, \
0.0005924255277376992, 
        -0.00002288648698303586, 7.853559496375988*^-7, \
1.392154952244304*^-7}, 
       {6.108778136511332, 0.5432709949881284, -0.02378916494031363, \
0.0005385767396017946, 
        -0.00002090222196923115, 9.634231569526953*^-7, \
1.031660310217783*^-7}, 
       {6.428627940347904, 0.5150795809575441, -0.02285881763700148, \
0.000488650474985677, 
        -0.00001936889068213984, 7.862704461763962*^-7, \
4.236373274532015*^-8}, 
       {6.731764237016638, 0.4879601358421129, -0.02201464865538692, \
0.0004432614671721073, 
        -0.00001769376947598321, 6.751452578811216*^-7, \
1.316367698170899*^-8}, 
       {7.018804533876454, 0.4618132537833407, -0.02124878476612005, \
0.000402127590503264, 
        -0.00001608643168964409, 5.795259274427188*^-7, \
-2.64641555573496*^-9}, 
       {7.29030909335201, 0.4365487805184312, -0.02055383300618015, \
0.0003649289266705499, 
        -0.00001458398933991611, 5.033512661358331*^-7, \
-9.988169502319166*^-9}, 
       {7.546786291865488, 0.4120851279505025, -0.01992303747611581, \
0.0003312779634424161, 
        -0.00001322154918966636, 4.37551534672063*^-7, \
-1.324910477258141*^-8}, 
       {7.884086056271611, 0.3787788434178949, -0.01913029312120552, \
0.0002891023262879505, 
        -0.0000115291594594324, 3.63777393971772*^-7, \
-1.371373898326033*^-8}, 
       {8.193519584742434, 0.3467373043198655, -0.01843847943647414, \
0.0002522379007700076, 
        -0.00001012456090970589, 2.940570752419515*^-7, \
-1.367577777664127*^-8}, 
       {8.476095686537853, 0.3157992553430406, -0.01783509007823322, \
0.0002198514717341092, 
        -8.938518663488416*^-6, 2.402965656917715*^-7, \
-1.240599571914663*^-8}, 
       {8.732694164207696, 0.2858229861605473, -0.01730967605233079, \
0.0001911921984056844, 
        -7.945451424014868*^-6, 1.975592634101514*^-7, \
-1.078283810070344*^-8}, 
       {8.964081092156048, 0.2566830884024056, -0.01685353056247505, \
0.0001656356738916059, 
        -7.115162259841*^-6, 1.634975150107237*^-7, -9.131086931191294*^-9}, 
       {9.170921496420231, 0.2282677220189242, -0.01645941987193715, \
0.0001426479705924626, 
        -6.427511170842572*^-6, 1.348052317356517*^-7, \
-7.720497902122285*^-9}, 
       {9.389954355144068, 0.1945852773909356, -0.01605562025513275, \
0.000117523846926549, 
        -5.77104513440084*^-6, 1.004193245520244*^-7, -6.84435365281206*^-9}, \

       {9.574487972549572, 0.1616616916001712, -0.01572586742018316, 
        0.00009490549903810554, -5.233270606636592*^-6, \
7.898604003413424*^-8, 
        -5.485421307730566*^-9}, {9.725231796860384, 0.1293508421880767, 
        -0.01546336168132292, 0.00007419723225491459, -4.824923276518464*^-6, \

        5.934261569317994*^-8, -4.554919700878265*^-9}, 
       {9.842750599262039, 0.09751900870274404, -0.01526288472030978, \
0.000054940201293084, 
        -4.52067132704201*^-6, 4.262303874918333*^-8, \
-3.808526825726381*^-9}, 
       {9.927475673864893, 0.06604185470753681, -0.0151205676271804, 
        0.00003672919236845725, -4.308672419068996*^-6, \
2.762596707450741*^-8, 
        -3.249881860652005*^-9}, {9.979713178406525, 0.03480181166196349, 
        -0.01503372618961092, 0.00001920328638020516, -4.180602396326156*^-6, \

        1.358486971789759*^-8, -2.853196789546286*^-9}, 
       {9.999804221413857, 0.002079784470556782, -0.01500049198937566, 
        1.146333605182019*^-6, -4.131571602154404*^-6, \
-1.008292044867596*^-9, 
        -2.604590129466682*^-9}, {9.998959082774867, -0.007418778925791529, 
        -0.01500187815261033, -4.065399346041674*^-6, -4.111443091414769*^-6, \

        7.927537361729354*^-9, 3.188545681628212*^-10}}][t]/4, 
  -InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
      {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
        0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
        2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
        4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
        8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
        12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
        16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
        19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
        21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
        22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
        23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
        24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
        25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
        25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
        26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
        26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
        26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
        27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
        27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
        28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
        28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
        29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
        30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
        31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
        33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
        35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
        37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
        40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
        43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
        47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
        51.68339752171315, 52.}}, {{0., 0.3}, 
       {0.0009979517077872255, 0.2999999900409223, -1.496927738092378*^-6}, 
       {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
        -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, 
        -0.00007923886649939536, -0.0001500117406492253}, 
       {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
        -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, 
        -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
       {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
        -0.0001512573923248744, -3.56926535101178*^-7}, 
       {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
        -0.0001532344335889719, -6.696147194160083*^-7}, 
       {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
        -0.0001561772311865011, -1.0428234784246*^-6}, 
       {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
        -0.0001600680606887075, -1.43126921114028*^-6}, 
       {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
        -0.0001652995935706142, -1.838046254173493*^-6}, 
       {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
        -0.000171839413657207, -2.313982825558378*^-6}, 
       {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
        -0.0001797480698000253, -2.828724047048563*^-6}, 
       {1.616193851195026, 0.28597129085274, -0.002670225693750562, \
-0.0001891832977074768, 
        -3.397434289546612*^-6, -1.775364723929283*^-7}, 
       {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
        -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
       {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
        -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
       {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
        -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
       {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
        -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
       {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
        -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
        -1.747260442740121*^-8}, {3.175344187221096, 0.2289633086353855, 
        -0.007545671364715371, -0.0004088562867722723, \
-0.00001760680137464635, 
        -8.727270794121078*^-7, -3.447284626861373*^-8}, 
       {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
        -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
        -4.451638240754114*^-8}, {3.65591142716557, 0.186792033285195, 
        -0.01107850554171452, -0.0006407044351002397, \
-0.00003391896655161902, 
        -1.770630454265917*^-6, -5.499941220723898*^-8}, 
       {3.85478077194519, 0.1585724953229884, -0.01360311058181845, \
-0.0008339122439545453, 
        -0.0000489443172128367, -2.712322351006786*^-6, \
-8.766377802768383*^-8}, 
       {3.986763005165946, 0.131667061984029, -0.01615666214412804, \
-0.001051626041925007, 
        -0.00006869661225566872, -4.393137681215513*^-6, \
-1.761332361311671*^-7}, 
       {4.092061561834391, 0.0995298917764175, -0.01940869599958157, \
-0.001352395704445139, 
        -0.00009571282431003663, -6.281214100632805*^-6, \
-2.444479897469488*^-7}, 
       {4.153850886158325, 0.06883885260811142, -0.02272856290784795, 
        -0.001690501313216549, -0.0001316398123092309, \
-9.940863233820019*^-6, 
        -4.806638869588175*^-7}, {4.191306423956496, 0.03269842564989161, 
        -0.02691267068137347, -0.002148302610858181, -0.0001796379888607316, 
        -0.00001388813348710936, -6.486429479295039*^-7}, 
       {4.200742249681569, -0.002208228754422552, -0.0312395051651517, 
        -0.002663840093236035, -0.0002423648979153841, \
-0.00002118918286358118, 
        -1.197910773667203*^-6}, {4.187480484699273, -0.04294029965292303, 
        -0.03664374955205367, -0.003351432661554625, -0.0003255129417403924, 
        -0.00002918221867922413, -1.604121647400555*^-6}, 
       {4.147582708325752, -0.09101196819194772, -0.04351056025037764, 
        -0.004295458408425854, -0.0004497713933866242, \
-0.00004287189467316768, 
        -2.47885545821094*^-6}, {4.093216338662262, -0.1360882405850764, 
        -0.05042227215046736, -0.005319578435935783, -0.0006006220945709141, 
        -0.00006396231737026914, -4.409656157769888*^-6}, 
       {4.015439499996313, -0.1885954484836499, -0.05903393771043326, 
        -0.006668642152566507, -0.0007954597141818747, \
-0.00008583296722324174, 
        -5.6762468467354*^-6}, {3.910243506625146, -0.2504281729333795, 
        -0.06991601053462865, -0.008485369119217001, -0.001075857440459364, 
        -0.0001215320852716722, -8.352309163308866*^-6}, 
       {3.800626326934144, -0.3095265512549151, -0.0810211001084475, \
-0.01044535109360783, 
        -0.001399096395540943, -0.0001697669761996192, \
-0.00001320335121470718}, 
       {3.665972999146803, -0.378327542653802, -0.09474229302615215, \
-0.01295459443587661, 
        -0.001793921254600053, -0.0002144492937412613, \
-0.00001551062565886725}, 
       {3.535553015059292, -0.4428061177064114, -0.1082883390327763, \
-0.01550358393254631, 
        -0.00220095651893553, -0.0002668360165914096, \
-0.00002028150696806179}, 
       {3.383157176300779, -0.5167289059824787, -0.1245035267716008, \
-0.01856317910150786, 
        -0.00262862077236768, -0.0002906382154606718, \
-0.00001715551624775262}, 
       {3.20549373901541, -0.6019516096016301, -0.1438811536990364, \
-0.02213377125985196, 
        -0.003028422675279043, -0.0002756180044960396, \
-7.146543113549753*^-6}, 
       {3.058588130827458, -0.6720624861181122, -0.1601545679841135, \
-0.02490566730718879, 
        -0.003089766360970424, -0.00009058479323536484, \
0.00004914842109632001}, 
       {2.894596323375797, -0.7501316342604838, -0.1783524392815316, \
-0.02765292754581667, 
        -0.002939806242666361, 0.0001373209277761948, \
0.00009530669209766431}, 
       {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
        -0.002118996299412064, 0.0007045924544449787, 0.0002210082169551333}, \

       {2.507421795656775, -0.9334055715055376, -0.2193614638360956, \
-0.03078067221328464, 
        -0.0001732800370884182, 0.001720488442029996, 0.000425988858941995}, 
       {2.33317849523205, -1.014847597695069, -0.2356208100425164, \
-0.02955058544284709, 
        0.003046032316439744, 0.003590979279397424, 0.0009523908779487415}, 
       {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
        0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, 
       {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
        0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
       {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
        0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
       {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
        0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
       {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
        0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
       {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
        0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
       {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
        0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, 
       {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
        0.04854416792859499, -0.004146149653291475, -0.007592239941335828}, 
       {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
        0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
       {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
        0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
       {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
        0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
       {0.04047800614247131, -1.699822619873736, -0.01104749066017452, \
0.1544758791615086, 
        0.002904805753834867, -0.03443803199776515, -0.009858086267061791}, 
       {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, \
0.1531408660534355, 
        -0.01167634603044878, -0.03485997177461622, -0.006216287801323393}, 
       {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
        -0.02502213731263542, -0.03148565897311392, -0.001319145505838771}, 
       {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
        -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, 
       {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
        -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
       {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
        -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, 
       {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
        -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
       {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
        -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
       {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
        -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
       {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
        -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
       {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
        -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
       {-1.676554155554152, -1.305608867189375, 0.2689638069601199, \
-0.001217053979193587, 
        -0.02444610851301589, 0.01402117366548132, 0.00224958656739477}, 
       {-1.821639069964926, -1.244590074076928, 0.2667220610870114, \
-0.0113128728396274, 
        -0.01864935539868304, 0.01161388704344243, -0.00006065302064348859}, 
       {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
        -0.01354138262907623, 0.009331003691403976, -0.001373910151833233}, 
       {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
        -0.009317813474587454, 0.007160120981883526, -0.002096244383309918}, 
       {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
        -0.005921779540154439, 0.005321449744103576, -0.002335005570329405}, 
       {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
        -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
        0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, 
        0.2233247841202344, -0.03060923986977494, -0.0009206404428521231, 
        0.002668607114008318, -0.001642610820709008, 0.0002789857387758132}, 
       {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
        0.0007931576405303536, 0.002021643534149319, -0.0008785619396256485, 
        0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, 
        0.1987180081228845, -0.02986498356771943, 0.001850571136714643, 
        0.001311821166285018, -0.0006006837699262708, 0.0004025249678476842}, \

       {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, \
-0.02868642525878178, 
        0.002510879609608891, 0.0008222015537418208, -0.0003592654655979457, 
        0.000353765107692091}, {-2.919626045506723, -0.7381571877771078, \
0.175586089260012, 
        -0.02723906829815367, 0.002875048835861939, 0.0004616915237353225, 
        -0.0002051292907194143, 0.0002903776349041168}, 
       {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, \
-0.02565419087941412, 
        0.003033030217916483, 0.0002014497612882507, -0.0001107920060412756, 
        0.0002269621421637012}, {-3.106117892072866, -0.6493204211172826, 
        0.1548734590809113, -0.02402116089273098, 0.003055539450422462, 
        0.00002599975151483897, -0.00004758785347185354}, 
       {-3.210090129745036, -0.5996681315994481, 0.1433705576419095, \
-0.02201677832120685, 
        0.002985222599816919, -0.0000958294047673527, \
-0.00007731102712422072}, 
       {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, \
-0.02011385735927098, 
        0.002763124856175378, -0.0002864118307802861, \
-0.0001226612803402779}, 
       {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, \
-0.01832912002286514, 
        0.002545956219616085, -0.0003344654449797207, \
-0.00009282872655880584}, 
       {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
        0.002340654063149804, -0.0003120801939574286, \
-0.00004673823831166822}, 
       {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, \
-0.01517795810854488, 
        0.00213323204377452, -0.0002847408987506403, -0.0000171012438948165}, \

       {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, \
-0.01381624455578609, 
        0.0019329271910969, -0.000256584599016029, 1.007933302260962*^-6}, 
       {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, \
-0.01202278498544689, 
        0.001642061747291683, -0.000235249621043713, 6.294315540307676*^-6}, 
       {-3.798446943438669, -0.3105342664181361, 0.08122614330861257, \
-0.01048688148137613, 
        0.001408458250699894, -0.0001884038544520576, \
0.00001626929459300319}, 
       {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, \
-0.00917947523972208, 
        0.001204544204314665, -0.0001528026664484259, \
0.00001925560751478185}, 
       {-3.934630385946802, -0.2365213821444215, 0.06740931090421369, 
        -0.008065641383147081, 0.001029940565630871, -0.0001250578171946844, 
        0.0000189522876063627}, {-3.989667693788011, -0.2042686509665383, 
        0.06172568788923138, -0.007114652075869174, 0.000882042765250185, 
        -0.0001030409363367319, 0.00001724277618273266}, 
       {-4.036983057207475, -0.1746882790891004, 0.05670238403676125, 
        -0.006300486571572722, 0.0007570421935068591, \
-0.00008565931813226637, 
        0.00001498094973042025}, {-4.089141669394019, -0.1388772341346019, 
        0.05087075128427734, -0.005388164125577655, 0.0006254981305204854, 
        -0.00006275759347351894, 0.00001356839613907586}, 
       {-4.129977973626481, -0.1066698407990083, 0.04586552357996159, 
        -0.004640446873950072, 0.0005154961431997248, \
-0.00005002292097234296, 
        0.00001068768379513849}, {-4.160607102404618, -0.07756530193825572, 
        0.04154165509616745, -0.004021722679494938, 0.0004278764083609402, 
        -0.00003998672821139463, 8.419621550322354*^-6}, 
       {-4.181992277724197, -0.05114937617478823, 0.03778328353121347, 
        -0.003506550900720839, 0.0003572087299784264, \
-0.00003242813775361963, 
        6.563319850414154*^-6}, {-4.194970580420816, -0.02707716769868808, 
        0.03449735446282021, -0.003074675807083444, 0.0003001534886949304, 
        -0.00002647017776461171, 5.129448984486421*^-6}, 
       {-4.200273762534801, -0.005059630122047486, 0.03160865927633907, 
        -0.002710379401726163, 0.0002537304737997015, \
-0.00002179055275345088, 
        4.013488418448823*^-6}, {-4.196527059133943, 0.02146125572686395, 
        0.02827767779621063, -0.002307804699369244, 0.0002080180677235468, 
        -0.00001467874931531174, 3.477096307713213*^-6}, 
       {-4.181640046440592, 0.04524848451510998, 0.02542812434125149, 
        -0.001982916488272914, 0.0001688840778693765, \
-0.00001193572980333215, 
        2.498571878633773*^-6}, {-4.15673652658868, 0.06668802481335287, 
        0.02297121363625496, -0.001716367034850311, 0.0001387847490468397, 
        -9.539748932217889*^-6, 1.859292472751585*^-6}, 
       {-4.122785355809635, 0.0860961029326029, 0.02083744114211, \
-0.001496038192667138, 
        0.0001149375476116196, -7.752989220148379*^-6, \
1.384150391219296*^-6}, 
       {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, \
-0.001312377553500777, 
        0.00009598075726336363, -6.330002216054171*^-6, \
1.044385030161512*^-6}, 
       {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, \
-0.001158156672391711, 
        0.00008074314435794473, -5.205832344760582*^-6, \
7.956094303782612*^-7}, 
       {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
        -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
        6.853161548526208*^-7}, {-3.862684295208088, 0.1571524415300303, 
        0.01373487047827056, -0.0008458709268748281, 0.00005292158849075478, 
        -2.717703778739206*^-6, 4.776227802405111*^-7}, 
       {-3.762840313497239, 0.172874054360284, 0.01230548051000591, \
-0.000732964029147417, 
        0.00004313135460575885, -2.174487587840614*^-6, \
3.464779702597154*^-7}, 
       {-3.653990683732458, 0.186983619109208, 0.01106211919053541, \
-0.0006402696967549964, 
        0.0000354544481395366, -1.769433689206584*^-6, \
2.525549483911888*^-7}, 
       {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, 
        -0.0005634894736334127, 0.00002940436207093559, \
-1.444926260924889*^-6, 
        1.873187047108245*^-7}, {-3.412804993833292, 0.2111489245800355, 
        0.009009588330419845, -0.0004994138122043501, 0.00002457256285304119, \

        -1.188314081952184*^-6, 1.406896678162243*^-7}, 
       {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, 
        -0.0004254398735934686, 0.00001981390334171221, \
-7.142813890569568*^-7, 
        1.214519187305689*^-7}, {-3.028544710651558, 0.2379623057313892, 
        0.006815353873336178, -0.0003674996746395192, 0.00001563491183483192, \

        -5.86375308215994*^-7, 8.286497780628049*^-8}, 
       {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, 
        -0.0003211413486115556, 0.00001249454537016901, \
-4.723075689651174*^-7, 
        5.863156687991705*^-8}, {-2.604332817704375, 0.2582797769625237, 
        0.005162226805369295, -0.0002838187140553005, 0.00001004906765736633, \

        -3.87289508354963*^-7, 4.18217498152932*^-8}, 
       {-2.380372883980649, 0.2664918453580231, 0.004475381304397052, 
        -0.0002535927280720157, 8.127093887680922*^-6, \
-3.191386114183283*^-7, 
        3.041795891583185*^-8}, {-2.149888330991454, 0.273593607663118, 
        0.00385849017216741, -0.0002290448730929102, 6.587497754854157*^-6, 
        -2.659372328911577*^-7, 2.240761720314729*^-8}, 
       {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, 
        -0.0002052376119308477, 5.184646117813377*^-6, \
-1.904354091683055*^-7, 
        1.830162350662408*^-8}, {-1.568184016554942, 0.2868392209174812, 
        0.002575703742891957, -0.0001869906042160404, 3.949989067622175*^-6, 
        -1.664155420757597*^-7, 1.252617879183773*^-8}, 
       {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, 
        -0.0001730929726651855, 2.962637641249672*^-6, \
-1.425953503160539*^-7, 
        9.048066793624791*^-9}, {-0.9642073675986177, 0.2952248515659734, 
        0.001495169624718867, -0.0001628678796415216, 2.124382504834869*^-6, 
        -1.268869055338464*^-7, 6.439368669983838*^-9}, 
       {-0.6568336412300838, 0.2978072625251313, 0.001000424961613838, 
        -0.0001558063063980045, 1.393261933326278*^-6, -1.16189512124211*^-7, \

        4.551787476216529*^-9}, {-0.3473080080181212, 0.2993839255588992, 
        0.0005231945129639924, -0.0001515786954507069, 7.289963028536484*^-7, \

        -1.10308871975636*^-7, 3.109375691580504*^-9}, 
       {-0.02059882830471778, 0.2999868284345344, 0.00003089963017686534, 
        -0.0001499710129035118, 7.391732362642512*^-8, \
-1.071809864811129*^-7, 
        2.056959960532262*^-9}, {0.07437607712204962, 0.2999612878079299, 
        -0.0001115897022763641, -0.0001501074630631385, \
-2.296620186836703*^-7, 
        -1.774557747218172*^-7, -1.356351577917269*^-8}}][t]/4, 
  -InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
      {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, 
        0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
        2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
        4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
        8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
        12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
        16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
        19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
        21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
        22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
        23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
        24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
        25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
        25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
        26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
        26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
        26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
        27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
        27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
        28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
        28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
        29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
        30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
        31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
        33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
        35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
        37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
        40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
        43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
        47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
        51.68339752171315, 52.}}, {{0., 0.}, {0., 0., 0.}, {0., 0., 0., 0.}, 
       {0., 0., 0., 0.}, {0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., \
0., 0.}, 
       {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0.}, 
       {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., \
0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}, {0., 0., 0., 0., 0., 0., 0.}, 
       {0., 0., 0., 0., 0., 0., 0.}}][t]/4}\
\>", "\<\
 -InterpolatingFunction[{{0., 52.}}, <>][t]  -InterpolatingFunction[{{0., \
52.}}, <>][t]
{------------------------------------------, \
------------------------------------------, 
                     4                                           4
 
  -InterpolatingFunction[{{0., 52.}}, <>][t]
  ------------------------------------------}
                      4\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally we calculate the exact time of the end of the first revolution. It \
is equal to the root of ",
  StyleBox["relorbit[t][[2]] == 0 ",
    FontWeight->"Bold"],
  "in a neighbourhood of",
  StyleBox[" t = 52",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["revol = FindRoot[relorbit[t][[2]] == 0, {t,51,52}]", "Input"],

Cell[OutputFormData["\<\
{t -> 51.75206297534902}\
\>", "\<\
{t -> 51.7521}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t0 = t /. revol", "Input"],

Cell[OutputFormData["\<\
51.75206297534902\
\>", "\<\
51.7521\
\>"], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics of the movement of the bodies", "Section"],

Cell[CellGroupData[{

Cell["Graphics objects of the bodies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
objm[t_] = {RGBColor[1,0,0],
                    PointSize[0.02],
                    Point[{orbitm[t][[1]], orbitm[t][[2]]}]
                   }\
\>", "Input"],

Cell[OutputFormData["\<\
{RGBColor[1, 0, 0], PointSize[0.02], Point[{(3*
       InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
         {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
           0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
           2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
           4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
           8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
           12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
           16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
           19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
           21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
           22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
           23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
           24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
           25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
           25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
           26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
           26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
           26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
           27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
           27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
           28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
           28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
           29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
           30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
           31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
           33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
           35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
           37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
           40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
           43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
           47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
           51.68339752171315, 52.}}, {{10., 0.}, 
          {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, \

          {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
           -1.322286343058508*^-7}, {9.999534630881093, \
-0.005282323784489644, 
           -0.01500076832270247, -1.507556879980259*^-6}, 
          {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
           -4.303953042407377*^-6}, {9.996022280142259, -0.01544977367720093, \

           -0.01500656577947253, -7.102518978703048*^-6, \
-4.12962510774654*^-6}, 
          {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
           -0.00001911254788268681, -4.721536529157213*^-6}, 
          {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
           -0.00002843965797539134, -4.17160237245598*^-6}, 
          {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
           -0.00003863663157999305, -4.230562589262589*^-6}, 
          {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
           -0.00004907835452562485, -4.318382798300356*^-6}, 
          {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
           -0.00006058324022271351, -4.43239809319311*^-6}, 
          {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
           -0.00007254388067269821, -4.588965459026183*^-6}, 
          {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
           -0.00008504165353778693, -4.780886831038984*^-6}, 
          {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
           -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
          {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
           -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
          {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
           -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
          {8.9333000040121, -0.260711383344569, -0.0169126745304145, 
           -0.0001688916601208405, -7.056168354057571*^-6, \
-1.313845897946621*^-7}, 
          {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
           -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
          {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
           -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
           -6.674609404533344*^-9}, {7.968828654203694, -0.3701677267394483, 
           -0.01893656311738351, -0.0002787120557484119, \
-0.00001107459120877045, 
           -3.431225329765139*^-7, -1.221235206138657*^-8}, 
          {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
           -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
           -1.346430675352864*^-8}, {7.014966306469673, -0.4621643951747192, 
           -0.02125743383726544, -0.0004024832669310073, \
-0.00001612207743260069, 
           -5.188299501191256*^-7, -1.214130185849565*^-8}, 
          {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
           -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
           -1.354357959188541*^-8}, {5.971354327636086, -0.5552694173247879, 
           -0.02419934375167602, -0.0005601240439740879, \
-0.00002240270713257671, 
           -6.795896221578519*^-7, -1.201709349193833*^-8}, 
          {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
           -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
           -1.583376666742293*^-9}, {4.994559169969892, -0.6394373103400424, 
           -0.02732862996656363, -0.0007171994723376593, \
-0.00002519742550426964, 
           -1.641290240708912*^-7, 3.910597107780506*^-8}, 
          {4.512594792329623, -0.6805479316610102, -0.02897566532185714, 
           -0.0007858734411303971, -0.00002283819031739034, \
6.281580292262645*^-7, 
           9.577105762745674*^-8}, {4.092333097008952, -0.7162958456331559, 
           -0.03043328001834313, -0.0008273002171360841, \
-0.00001411116814184291, 
           2.773103753343612*^-6, 2.950546781062066*^-7}, 
          {3.650020866463042, -0.7538337447048592, -0.03194053384702654, 
           -0.000837781640951464, 2.907707968555054*^-6, \
5.852540359820091*^-6, 
           5.181368394863152*^-7}, {3.184571840689228, -0.7931742380695744, 
           -0.03340796215459502, -0.0007783073126224044, \
0.00004020831399575819, 
           0.00001252969451950441, 1.050499280912101*^-6}, 
          {2.795135498386905, -0.825830794134082, -0.03443182974317923, 
           -0.0006278837202671806, 0.0001043308691637567, \
0.00002636995433250329, 
           2.548041348411085*^-6}, {2.38977107808601, -0.8593358948133683, 
           -0.03513375184134562, -0.000319913380216462, \
0.0002060515099388112, 
           0.00004421380258099794, 4.001314036998032*^-6}, 
          {1.968166385363971, -0.8932395940637682, -0.03519115346953409, 
           0.0002827427630627121, 0.0003953025819406979, \
0.00008034764600886729, 
           7.407586137339988*^-6}, {1.612143333988495, -0.9206107463009619, 
           -0.03436732147393313, 0.001167408375879762, 0.0006871165481036591, \

           0.0001488881693373802, 0.00001608512153778298}, 
          {1.245564862078643, -0.9468476617076561, -0.03218992389889563, 
           0.002621839915004895, 0.001129466927246893, 0.0002361002834123236, \

           0.00002446272968897194}, {0.9411036630779808, -0.9663582346870491, \

           -0.02882442468204031, 0.004524953127547926, 0.001773934206673067, 
           0.0004076052929450417, 0.00005060830769685972}, 
          {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, 
           0.007385850858260214, 0.002672644657907155, 0.0005975972454227846, \

           0.00007016870897342483}, {0.3159401433660997, -0.9951819807516075, \

           -0.0141810564371504, 0.01177969329600485, 0.004105758348508652, 
           0.0009339734047126293, 0.0001125727572013773}, 
          {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, 
           0.01642148422154501, 0.005766813443267503, 0.001456041061702653, 
           0.0002183132824744149}, {-0.1451655451007285, -0.9987483123162489, \

           0.008944489593331621, 0.02264330478484971, 0.007723831164850311, 
           0.001834097872355712, 0.0002401682337663385}, 
          {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, 
           0.03107584026681068, 0.01043305827566561, 0.002464002718034116, 
           0.0003260132232436369}, {-0.6017366959356142, -0.9723927003509583, \

           0.05264297022337499, 0.04225298673259487, 0.01376536310562221, 
           0.003084637463279821, 0.0003748430742714523}, 
          {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, 
           0.0530975554303808, 0.01662705757449755, 0.003411909325867013, 
           0.0003468215640078723}, {-0.9408520004092066, -0.9156991754896342, \

           0.1099734795798445, 0.06584191092106879, 0.01927853582407632, 
           0.003240100434734713, 0.0001440904775641987}, 
          {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, 
           0.08005627726477126, 0.02099483499621253, 0.002195345619101353, 
           -0.0003027390708880932}, {-1.22414138467131, -0.82077085304674, 
           0.1866028279478249, 0.09179484841508957, 0.02021543417588093, 
           -0.000754274587538044, -0.001530626941211491}, 
          {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
           0.01746781961115515, -0.004103986580530314, \
-0.002450338209772962}, 
          {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
           0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, \

          {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
           -0.0007350026571956852, -0.01685438505251352, \
-0.005671350902054768}, 
          {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
           -0.01688511860132406, -0.02423508582492491, \
-0.006778310725377359}, 
          {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, 
           0.09666214457796037, -0.03204065521875401, -0.02840436636139767, 
           -0.006444744621113192}, {-1.713702367726152, -0.3061747204096225, 
           0.4406455090291952, 0.0785742469749175, -0.0470257534782241, 
           -0.02861634111365265, -0.00398773686340812}, 
          {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, 
           0.05414735876830688, -0.05977983902013911, -0.02439011013378813, 
           0.00001759514469461788}, {-1.757959254457417, -0.1123882156998269, \

           0.4761992589402015, 0.03131763081762755, -0.0651267030424638, 
           -0.01330108771073375, 0.007932614219398512}, 
          {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, 
           0.006382340077340566, -0.06878153330095417, -0.00607622203589427, 
           0.009921051344796055}, {-1.762223869805497, 0.0669098889538212, 
           0.4797874360581084, -0.01881564820658439, -0.06715504466041756, 
           0.0052941015385649, 0.014075650991735}, 
          {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, 
           -0.04290594361192289, -0.06177008484910881, 0.01515215349206186, 
           0.01548803581768913}, {-1.733224604791979, 0.2423597914699506, 
           0.4559953383181955, -0.06450374890421965, -0.05309737444319933, 
           0.02305207122611793, 0.01493656511780418}, 
          {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
           -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
          {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, 
           -0.09760253037063431, -0.02888818242959219, 0.0306691934708478, 
           0.009224953760383584}, {-1.622080963140679, 0.4929301210117905, 
           0.3755325162049182, -0.1074178334999123, -0.01633310637884133, 
           0.02856039286749514, 0.004168099462073743}, 
          {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
           -0.005160721979258902, 0.02417131244294108, \
-0.0003440345314113444}, 
          {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
           0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, \

          {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
           0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
          {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
           0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, \

          {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
           0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
          {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, 
           -0.08779459299724857, 0.01979767319192345, -0.0003066249582991479, \

           -0.006028282943382096}, {-1.085063458885453, 0.8749251188130202, 
           0.144782245099154, -0.07854258397670186, 0.01986264568980367, 
           -0.002297713136917443, -0.004783528255310104}, 
          {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, 
           -0.06946500901627999, 0.01908920268180254, -0.003359677058435248, 
           -0.003492310907858758}, {-0.8793265410504286, 0.9295658946373885, 
           0.09732709937304962, -0.0608924971492783, 0.01779753275101055, 
           -0.003788394790891112, -0.002346567941738405}, 
          {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, 
           -0.05301145859825892, 0.01623278484580223, -0.003814067204285791, 
           -0.00142298197321629, 0.001159542229646304}, 
          {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, 
           -0.04468096904705857, 0.01441045900308664, -0.002783953394204672, 
           0.001188784376355514, 0.001697085509141072}, 
          {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, 
           -0.03741547808128195, 0.0128042870890071, -0.001516085052811469, 
           0.002492470180502037, 0.001592641575583569}, 
          {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, 
           -0.03126812679688145, 0.01073262941726728, -0.002037579725773561, 
           0.001248140166443795, 0.000621510220514931}, 
          {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, 
           -0.02604465129166512, 0.008980331918121603, -0.002095510898895228, \

           0.0006953458839076041, 0.0002187584774474667}, 
          {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, 
           -0.02163335504587148, 0.007533052625606419, -0.001862875274342468, \

           0.0005412212424280951, 0.00009130883576918053}, 
          {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
           -0.01793006544947133, 0.006305477814234636, -0.001607987009029117, \

           0.0004376460542311089, 0.00002422708367731202}, 
          {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
           -0.01483069730268437, 0.00526623201595544, -0.001376927490964432, 
           0.0003454596158002636}, {0.3238530675731096, 0.995016345930049, 
           -0.0144640796213406, -0.0116871546883609, 0.004231198363091821, 
           -0.001064594641186693, 0.0003322772383557684}, 
          {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, 
           -0.00917301401911442, 0.003397859160363781, -0.000819933720088739, \

           0.0002972842358494771}, {0.6533538559313423, 0.9820447155621451, 
           -0.02372070399070088, -0.007162526259702596, 0.002726309336887593, \

           -0.0006384642833766479, 0.0002509980162091398}, 
          {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, 
           -0.005553834168748899, 0.002185764859300605, \
-0.0005041528357430196, 
           0.000204352772054328}, {0.9776558814470167, 0.9642105857215122, 
           -0.02932920777076483, -0.004264733145196217, 0.001753679572068895, \

           -0.0003999863031745657, 0.0001643010647412814}, 
          {1.137437570202047, 0.9541144596710516, -0.03119425522545939, 
           -0.003230475051281675, 0.001408187583593927, \
-0.000318863443275577, 
           0.0001310475300282612}, {1.373962009270192, 0.9379913626951294, 
           -0.03315104071340928, -0.002035992528092278, 0.001055017058722285, \

           -0.0001754137530066389, 0.0001168833024258509}, 
          {1.606350517388015, 0.9210897263708773, -0.03435027793903866, 
           -0.001185643298369978, 0.0007611892730192848, \
-0.0001263674244384825, 
           0.00008320952677836924}, {1.834451124462977, 0.9037326412745143, 
           -0.03500295728260755, -0.0005720113774542266, \
0.0005488589661374675, 
           -0.0000923366591773421, 0.00005900095063806828}, 
          {2.05818068749326, 0.8861532298832889, -0.03526139771076708, 
           -0.0001299066826636304, 0.0003943010523705895, \
-0.00006860755394809425, 
           0.00004172858547342076}, {2.277505796363031, 0.8685194772734156, 
           -0.03523617500405487, 0.0001875161539186697, \
0.0002818251856303586, 
           -0.0000511645549180407, 0.00002968880418123365}, 
          {2.492428788195139, 0.8509519705097273, -0.03500799092175404, 
           0.0004136601693357046, 0.0001995415136804703, \
-0.00003828804738911866, 
           0.00002124715551700476}, {2.772238550718317, 0.8277725006882704, 
           -0.03448789441543038, 0.0006187349731000154, \
0.0001352320034684956, 
           -0.00001425422529863956, 0.00001755451345997014}, 
          {3.044385230797065, 0.8049972229139195, -0.03380947075089432, 
           0.0007368050289671234, 0.00007834634628596583, \
-0.00001122391314621417, 
           0.00001113870188222071}, {3.309018587737515, 0.7827080320625583, 
           -0.03303896113559139, 0.0008026315339952361, \
0.00004206218440122728, 
           -7.530342783184703*^-6, 7.421851557590777*^-6}, 
          {3.566309067033361, 0.7609505320860362, -0.0322207398277254, 
           0.0008326581797725729, 0.00001753263227045104, \
-5.206456476998877*^-6, 
           4.91783556921768*^-6}, {3.81643803262864, 0.7397459514613501, 
           -0.03138449367913013, 0.000838939799644164, 1.35077760291538*^-6, 
           -3.443913900758643*^-6, 3.303169942357289*^-6}, 
          {4.059591012015883, 0.7190992617954302, -0.03054996995098544, 
           0.0008294710638224421, -9.266693762532051*^-6, \
-2.176304405457542*^-6, 
           2.235395158274695*^-6}, {4.372585721165242, 0.6924846048814831, 
           -0.02946402757201999, 0.0008029885517503858, \
-0.00001512205360717179, 
           8.250783523782558*^-7, 1.79238678863533*^-6}, 
          {4.673987267678016, 0.6668147871373053, -0.02842204472668379, 
           0.0007647138190854807, -0.00002078611834098472, \
6.541365780799917*^-7, 
           1.049737140101165*^-6}, {4.964205394312013, 0.6420460382904659, 
           -0.02743350214751175, 0.0007221979607514677, \
-0.00002314976507814556, 
           7.761061031756697*^-7, 6.481760049899586*^-7}, 
          {5.243628875125201, 0.6181288506037192, -0.02650242749678078, 
           0.0006781875255987336, -0.00002393452362995146, \
7.931800302684875*^-7, 
           3.914720523938617*^-7}, {5.5126240130368, 0.5950117248664654, 
           -0.0256295578461628, 0.0006345834841070335, \
-0.00002369251940469708, 
           8.021342089770415*^-7, 2.362291693947091*^-7}, 
          {5.771534255654154, 0.5726434521487585, -0.02481369104364359, 
           0.0005924255277376992, -0.00002288648698303586, \
7.853559496375988*^-7, 
           1.392154952244304*^-7}, {6.108778136511332, 0.5432709949881284, 
           -0.02378916494031363, 0.0005385767396017946, \
-0.00002090222196923115, 
           9.634231569526953*^-7, 1.031660310217783*^-7}, 
          {6.428627940347904, 0.5150795809575441, -0.02285881763700148, 
           0.000488650474985677, -0.00001936889068213984, \
7.862704461763962*^-7, 
           4.236373274532015*^-8}, {6.731764237016638, 0.4879601358421129, 
           -0.02201464865538692, 0.0004432614671721073, \
-0.00001769376947598321, 
           6.751452578811216*^-7, 1.316367698170899*^-8}, 
          {7.018804533876454, 0.4618132537833407, -0.02124878476612005, 
           0.000402127590503264, -0.00001608643168964409, \
5.795259274427188*^-7, 
           -2.64641555573496*^-9}, {7.29030909335201, 0.4365487805184312, 
           -0.02055383300618015, 0.0003649289266705499, \
-0.00001458398933991611, 
           5.033512661358331*^-7, -9.988169502319166*^-9}, 
          {7.546786291865488, 0.4120851279505025, -0.01992303747611581, 
           0.0003312779634424161, -0.00001322154918966636, \
4.37551534672063*^-7, 
           -1.324910477258141*^-8}, {7.884086056271611, 0.3787788434178949, 
           -0.01913029312120552, 0.0002891023262879505, \
-0.0000115291594594324, 
           3.63777393971772*^-7, -1.371373898326033*^-8}, 
          {8.193519584742434, 0.3467373043198655, -0.01843847943647414, 
           0.0002522379007700076, -0.00001012456090970589, \
2.940570752419515*^-7, 
           -1.367577777664127*^-8}, {8.476095686537853, 0.3157992553430406, 
           -0.01783509007823322, 0.0002198514717341092, \
-8.938518663488416*^-6, 
           2.402965656917715*^-7, -1.240599571914663*^-8}, 
          {8.732694164207696, 0.2858229861605473, -0.01730967605233079, 
           0.0001911921984056844, -7.945451424014868*^-6, \
1.975592634101514*^-7, 
           -1.078283810070344*^-8}, {8.964081092156048, 0.2566830884024056, 
           -0.01685353056247505, 0.0001656356738916059, -7.115162259841*^-6, 
           1.634975150107237*^-7, -9.131086931191294*^-9}, 
          {9.170921496420231, 0.2282677220189242, -0.01645941987193715, 
           0.0001426479705924626, -6.427511170842572*^-6, \
1.348052317356517*^-7, 
           -7.720497902122285*^-9}, {9.389954355144068, 0.1945852773909356, 
           -0.01605562025513275, 0.000117523846926549, -5.77104513440084*^-6, \

           1.004193245520244*^-7, -6.84435365281206*^-9}, 
          {9.574487972549572, 0.1616616916001712, -0.01572586742018316, 
           0.00009490549903810554, -5.233270606636592*^-6, \
7.898604003413424*^-8, 
           -5.485421307730566*^-9}, {9.725231796860384, 0.1293508421880767, 
           -0.01546336168132292, 0.00007419723225491459, \
-4.824923276518464*^-6, 
           5.934261569317994*^-8, -4.554919700878265*^-9}, 
          {9.842750599262039, 0.09751900870274404, -0.01526288472030978, 
           0.000054940201293084, -4.52067132704201*^-6, \
4.262303874918333*^-8, 
           -3.808526825726381*^-9}, {9.927475673864893, 0.06604185470753681, 
           -0.0151205676271804, 0.00003672919236845725, \
-4.308672419068996*^-6, 
           2.762596707450741*^-8, -3.249881860652005*^-9}, 
          {9.979713178406525, 0.03480181166196349, -0.01503372618961092, 
           0.00001920328638020516, -4.180602396326156*^-6, \
1.358486971789759*^-8, 
           -2.853196789546286*^-9}, {9.999804221413857, 0.002079784470556782, \

           -0.01500049198937566, 1.146333605182019*^-6, \
-4.131571602154404*^-6, 
           -1.008292044867596*^-9, -2.604590129466682*^-9}, 
          {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
           -4.065399346041674*^-6, -4.111443091414769*^-6, \
7.927537361729354*^-9, 
           3.188545681628212*^-10}}][t])/4, 
    (3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
         {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
           0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
           2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
           4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
           8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
           12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
           16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
           19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
           21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
           22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
           23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
           24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
           25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
           25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
           26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
           26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
           26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
           27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
           27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
           28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
           28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
           29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
           30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
           31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
           33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
           35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
           37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
           40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
           43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
           47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
           51.68339752171315, 52.}}, {{0., 0.3}, 
          {0.0009979517077872255, 0.2999999900409223, \
-1.496927738092378*^-6}, 
          {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
           -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, \

           -0.00007923886649939536, -0.0001500117406492253}, 
          {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
           -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, 
           -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
          {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
           -0.0001512573923248744, -3.56926535101178*^-7}, 
          {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
           -0.0001532344335889719, -6.696147194160083*^-7}, 
          {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
           -0.0001561772311865011, -1.0428234784246*^-6}, 
          {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
           -0.0001600680606887075, -1.43126921114028*^-6}, 
          {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
           -0.0001652995935706142, -1.838046254173493*^-6}, 
          {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
           -0.000171839413657207, -2.313982825558378*^-6}, 
          {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
           -0.0001797480698000253, -2.828724047048563*^-6}, 
          {1.616193851195026, 0.28597129085274, -0.002670225693750562, 
           -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
          {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
           -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
          {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
           -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
          {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
           -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
          {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
           -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
          {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
           -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
           -1.747260442740121*^-8}, {3.175344187221096, 0.2289633086353855, 
           -0.007545671364715371, -0.0004088562867722723, \
-0.00001760680137464635, 
           -8.727270794121078*^-7, -3.447284626861373*^-8}, 
          {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
           -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
           -4.451638240754114*^-8}, {3.65591142716557, 0.186792033285195, 
           -0.01107850554171452, -0.0006407044351002397, \
-0.00003391896655161902, 
           -1.770630454265917*^-6, -5.499941220723898*^-8}, 
          {3.85478077194519, 0.1585724953229884, -0.01360311058181845, 
           -0.0008339122439545453, -0.0000489443172128367, \
-2.712322351006786*^-6, 
           -8.766377802768383*^-8}, {3.986763005165946, 0.131667061984029, 
           -0.01615666214412804, -0.001051626041925007, \
-0.00006869661225566872, 
           -4.393137681215513*^-6, -1.761332361311671*^-7}, 
          {4.092061561834391, 0.0995298917764175, -0.01940869599958157, 
           -0.001352395704445139, -0.00009571282431003663, \
-6.281214100632805*^-6, 
           -2.444479897469488*^-7}, {4.153850886158325, 0.06883885260811142, 
           -0.02272856290784795, -0.001690501313216549, \
-0.0001316398123092309, 
           -9.940863233820019*^-6, -4.806638869588175*^-7}, 
          {4.191306423956496, 0.03269842564989161, -0.02691267068137347, 
           -0.002148302610858181, -0.0001796379888607316, \
-0.00001388813348710936, 
           -6.486429479295039*^-7}, {4.200742249681569, \
-0.002208228754422552, 
           -0.0312395051651517, -0.002663840093236035, \
-0.0002423648979153841, 
           -0.00002118918286358118, -1.197910773667203*^-6}, 
          {4.187480484699273, -0.04294029965292303, -0.03664374955205367, 
           -0.003351432661554625, -0.0003255129417403924, \
-0.00002918221867922413, 
           -1.604121647400555*^-6}, {4.147582708325752, -0.09101196819194772, \

           -0.04351056025037764, -0.004295458408425854, \
-0.0004497713933866242, 
           -0.00004287189467316768, -2.47885545821094*^-6}, 
          {4.093216338662262, -0.1360882405850764, -0.05042227215046736, 
           -0.005319578435935783, -0.0006006220945709141, \
-0.00006396231737026914, 
           -4.409656157769888*^-6}, {4.015439499996313, -0.1885954484836499, 
           -0.05903393771043326, -0.006668642152566507, \
-0.0007954597141818747, 
           -0.00008583296722324174, -5.6762468467354*^-6}, 
          {3.910243506625146, -0.2504281729333795, -0.06991601053462865, 
           -0.008485369119217001, -0.001075857440459364, \
-0.0001215320852716722, 
           -8.352309163308866*^-6}, {3.800626326934144, -0.3095265512549151, 
           -0.0810211001084475, -0.01044535109360783, -0.001399096395540943, 
           -0.0001697669761996192, -0.00001320335121470718}, 
          {3.665972999146803, -0.378327542653802, -0.09474229302615215, 
           -0.01295459443587661, -0.001793921254600053, \
-0.0002144492937412613, 
           -0.00001551062565886725}, {3.535553015059292, -0.4428061177064114, \

           -0.1082883390327763, -0.01550358393254631, -0.00220095651893553, 
           -0.0002668360165914096, -0.00002028150696806179}, 
          {3.383157176300779, -0.5167289059824787, -0.1245035267716008, 
           -0.01856317910150786, -0.00262862077236768, \
-0.0002906382154606718, 
           -0.00001715551624775262}, {3.20549373901541, -0.6019516096016301, 
           -0.1438811536990364, -0.02213377125985196, -0.003028422675279043, 
           -0.0002756180044960396, -7.146543113549753*^-6}, 
          {3.058588130827458, -0.6720624861181122, -0.1601545679841135, 
           -0.02490566730718879, -0.003089766360970424, \
-0.00009058479323536484, 
           0.00004914842109632001}, {2.894596323375797, -0.7501316342604838, 
           -0.1783524392815316, -0.02765292754581667, -0.002939806242666361, 
           0.0001373209277761948, 0.00009530669209766431}, 
          {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
           -0.002118996299412064, 0.0007045924544449787, \
0.0002210082169551333}, 
          {2.507421795656775, -0.9334055715055376, -0.2193614638360956, 
           -0.03078067221328464, -0.0001732800370884182, \
0.001720488442029996, 
           0.000425988858941995}, {2.33317849523205, -1.014847597695069, 
           -0.2356208100425164, -0.02955058544284709, 0.003046032316439744, 
           0.003590979279397424, 0.0009523908779487415}, 
          {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
           0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, \

          {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
           0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
          {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
           0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
          {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
           0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
          {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
           0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
          {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
           0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
          {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
           0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, \

          {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
           0.04854416792859499, -0.004146149653291475, \
-0.007592239941335828}, 
          {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
           0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
          {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
           0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
          {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
           0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
          {0.04047800614247131, -1.699822619873736, -0.01104749066017452, 
           0.1544758791615086, 0.002904805753834867, -0.03443803199776515, 
           -0.009858086267061791}, {-0.1181161136909721, -1.697846420748768, 
           0.03215863828671498, 0.1531408660534355, -0.01167634603044878, 
           -0.03485997177461622, -0.006216287801323393}, 
          {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
           -0.02502213731263542, -0.03148565897311392, \
-0.001319145505838771}, 
          {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
           -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, \

          {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
           -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
          {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
           -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, \

          {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
           -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
          {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
           -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
          {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
           -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
          {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
           -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
          {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
           -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
          {-1.676554155554152, -1.305608867189375, 0.2689638069601199, 
           -0.001217053979193587, -0.02444610851301589, 0.01402117366548132, 
           0.00224958656739477}, {-1.821639069964926, -1.244590074076928, 
           0.2667220610870114, -0.0113128728396274, -0.01864935539868304, 
           0.01161388704344243, -0.00006065302064348859}, 
          {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
           -0.01354138262907623, 0.009331003691403976, \
-0.001373910151833233}, 
          {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
           -0.009317813474587454, 0.007160120981883526, \
-0.002096244383309918}, 
          {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
           -0.005921779540154439, 0.005321449744103576, \
-0.002335005570329405}, 
          {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
           -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
           0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, \

           0.2233247841202344, -0.03060923986977494, -0.0009206404428521231, 
           0.002668607114008318, -0.001642610820709008, \
0.0002789857387758132}, 
          {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
           0.0007931576405303536, 0.002021643534149319, \
-0.0008785619396256485, 
           0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, 
           0.1987180081228845, -0.02986498356771943, 0.001850571136714643, 
           0.001311821166285018, -0.0006006837699262708, \
0.0004025249678476842}, 
          {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, 
           -0.02868642525878178, 0.002510879609608891, 0.0008222015537418208, \

           -0.0003592654655979457, 0.000353765107692091}, 
          {-2.919626045506723, -0.7381571877771078, 0.175586089260012, \
-0.02723906829815367, 
           0.002875048835861939, 0.0004616915237353225, \
-0.0002051292907194143, 
           0.0002903776349041168}, {-3.015860140566406, -0.6923447237997232, 
           0.1649036297205248, -0.02565419087941412, 0.003033030217916483, 
           0.0002014497612882507, -0.0001107920060412756, \
0.0002269621421637012}, 
          {-3.106117892072866, -0.6493204211172826, 0.1548734590809113, 
           -0.02402116089273098, 0.003055539450422462, \
0.00002599975151483897, 
           -0.00004758785347185354}, {-3.210090129745036, \
-0.5996681315994481, 
           0.1433705576419095, -0.02201677832120685, 0.002985222599816919, 
           -0.0000958294047673527, -0.00007731102712422072}, 
          {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, 
           -0.02011385735927098, 0.002763124856175378, \
-0.0002864118307802861, 
           -0.0001226612803402779}, {-3.394736399961399, -0.5110487433641276, \

           0.1232494875931549, -0.01832912002286514, 0.002545956219616085, 
           -0.0003344654449797207, -0.00009282872655880584}, 
          {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
           0.002340654063149804, -0.0003120801939574286, \
-0.00004673823831166822}, 
          {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, 
           -0.01517795810854488, 0.00213323204377452, -0.0002847408987506403, \

           -0.0000171012438948165}, {-3.62147634589714, -0.4003879298933642, 
           0.09931907937959756, -0.01381624455578609, 0.0019329271910969, 
           -0.000256584599016029, 1.007933302260962*^-6}, 
          {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, 
           -0.01202278498544689, 0.001642061747291683, -0.000235249621043713, \

           6.294315540307676*^-6}, {-3.798446943438669, -0.3105342664181361, 
           0.08122614330861257, -0.01048688148137613, 0.001408458250699894, 
           -0.0001884038544520576, 0.00001626929459300319}, 
          {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, 
           -0.00917947523972208, 0.001204544204314665, \
-0.0001528026664484259, 
           0.00001925560751478185}, {-3.934630385946802, -0.2365213821444215, \

           0.06740931090421369, -0.008065641383147081, 0.001029940565630871, 
           -0.0001250578171946844, 0.0000189522876063627}, 
          {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, 
           -0.007114652075869174, 0.000882042765250185, \
-0.0001030409363367319, 
           0.00001724277618273266}, {-4.036983057207475, -0.1746882790891004, \

           0.05670238403676125, -0.006300486571572722, 0.0007570421935068591, \

           -0.00008565931813226637, 0.00001498094973042025}, 
          {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, 
           -0.005388164125577655, 0.0006254981305204854, \
-0.00006275759347351894, 
           0.00001356839613907586}, {-4.129977973626481, -0.1066698407990083, \

           0.04586552357996159, -0.004640446873950072, 0.0005154961431997248, \

           -0.00005002292097234296, 0.00001068768379513849}, 
          {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, 
           -0.004021722679494938, 0.0004278764083609402, \
-0.00003998672821139463, 
           8.419621550322354*^-6}, {-4.181992277724197, -0.05114937617478823, \

           0.03778328353121347, -0.003506550900720839, 0.0003572087299784264, \

           -0.00003242813775361963, 6.563319850414154*^-6}, 
          {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, 
           -0.003074675807083444, 0.0003001534886949304, \
-0.00002647017776461171, 
           5.129448984486421*^-6}, {-4.200273762534801, \
-0.005059630122047486, 
           0.03160865927633907, -0.002710379401726163, 0.0002537304737997015, \

           -0.00002179055275345088, 4.013488418448823*^-6}, 
          {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, 
           -0.002307804699369244, 0.0002080180677235468, \
-0.00001467874931531174, 
           3.477096307713213*^-6}, {-4.181640046440592, 0.04524848451510998, 
           0.02542812434125149, -0.001982916488272914, 0.0001688840778693765, \

           -0.00001193572980333215, 2.498571878633773*^-6}, 
          {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, 
           -0.001716367034850311, 0.0001387847490468397, \
-9.539748932217889*^-6, 
           1.859292472751585*^-6}, {-4.122785355809635, 0.0860961029326029, 
           0.02083744114211, -0.001496038192667138, 0.0001149375476116196, 
           -7.752989220148379*^-6, 1.384150391219296*^-6}, 
          {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, 
           -0.001312377553500777, 0.00009598075726336363, \
-6.330002216054171*^-6, 
           1.044385030161512*^-6}, {-4.0309990753539, 0.1198195246330904, 
           0.01733056688268946, -0.001158156672391711, \
0.00008074314435794473, 
           -5.205832344760582*^-6, 7.956094303782612*^-7}, 
          {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
           -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
           6.853161548526208*^-7}, {-3.862684295208088, 0.1571524415300303, 
           0.01373487047827056, -0.0008458709268748281, \
0.00005292158849075478, 
           -2.717703778739206*^-6, 4.776227802405111*^-7}, 
          {-3.762840313497239, 0.172874054360284, 0.01230548051000591, 
           -0.000732964029147417, 0.00004313135460575885, \
-2.174487587840614*^-6, 
           3.464779702597154*^-7}, {-3.653990683732458, 0.186983619109208, 
           0.01106211919053541, -0.0006402696967549964, \
0.0000354544481395366, 
           -1.769433689206584*^-6, 2.525549483911888*^-7}, 
          {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, 
           -0.0005634894736334127, 0.00002940436207093559, \
-1.444926260924889*^-6, 
           1.873187047108245*^-7}, {-3.412804993833292, 0.2111489245800355, 
           0.009009588330419845, -0.0004994138122043501, \
0.00002457256285304119, 
           -1.188314081952184*^-6, 1.406896678162243*^-7}, 
          {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, 
           -0.0004254398735934686, 0.00001981390334171221, \
-7.142813890569568*^-7, 
           1.214519187305689*^-7}, {-3.028544710651558, 0.2379623057313892, 
           0.006815353873336178, -0.0003674996746395192, \
0.00001563491183483192, 
           -5.86375308215994*^-7, 8.286497780628049*^-8}, 
          {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, 
           -0.0003211413486115556, 0.00001249454537016901, \
-4.723075689651174*^-7, 
           5.863156687991705*^-8}, {-2.604332817704375, 0.2582797769625237, 
           0.005162226805369295, -0.0002838187140553005, \
0.00001004906765736633, 
           -3.87289508354963*^-7, 4.18217498152932*^-8}, 
          {-2.380372883980649, 0.2664918453580231, 0.004475381304397052, 
           -0.0002535927280720157, 8.127093887680922*^-6, \
-3.191386114183283*^-7, 
           3.041795891583185*^-8}, {-2.149888330991454, 0.273593607663118, 
           0.00385849017216741, -0.0002290448730929102, \
6.587497754854157*^-6, 
           -2.659372328911577*^-7, 2.240761720314729*^-8}, 
          {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, 
           -0.0002052376119308477, 5.184646117813377*^-6, \
-1.904354091683055*^-7, 
           1.830162350662408*^-8}, {-1.568184016554942, 0.2868392209174812, 
           0.002575703742891957, -0.0001869906042160404, \
3.949989067622175*^-6, 
           -1.664155420757597*^-7, 1.252617879183773*^-8}, 
          {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, 
           -0.0001730929726651855, 2.962637641249672*^-6, \
-1.425953503160539*^-7, 
           9.048066793624791*^-9}, {-0.9642073675986177, 0.2952248515659734, 
           0.001495169624718867, -0.0001628678796415216, \
2.124382504834869*^-6, 
           -1.268869055338464*^-7, 6.439368669983838*^-9}, 
          {-0.6568336412300838, 0.2978072625251313, 0.001000424961613838, 
           -0.0001558063063980045, 1.393261933326278*^-6, \
-1.16189512124211*^-7, 
           4.551787476216529*^-9}, {-0.3473080080181212, 0.2993839255588992, 
           0.0005231945129639924, -0.0001515786954507069, \
7.289963028536484*^-7, 
           -1.10308871975636*^-7, 3.109375691580504*^-9}, 
          {-0.02059882830471778, 0.2999868284345344, 0.00003089963017686534, 
           -0.0001499710129035118, 7.391732362642512*^-8, \
-1.071809864811129*^-7, 
           2.056959960532262*^-9}, {0.07437607712204962, 0.2999612878079299, 
           -0.0001115897022763641, -0.0001501074630631385, \
-2.296620186836703*^-7, 
           -1.774557747218172*^-7, -1.356351577917269*^-8}}][t])/4}]}\
\>", "\<\
                                            3 InterpolatingFunction[{{0., \
52.}}, <>][t]
{RGBColor[1, 0, 0], PointSize[0.02], \
Point[{-------------------------------------------, 
                                                                 4
 
    3 InterpolatingFunction[{{0., 52.}}, <>][t]
    -------------------------------------------}]}
                         4\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
objM[t_] = {RGBColor[1,0,0],
                    PointSize[0.06],
                    Point[{orbitM[t][[1]], orbitM[t][[2]]}]
                   }\
\>", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"objM\" is similar \
to existing symbol 
    \"objm\".\
\>", "Message"],

Cell[OutputFormData["\<\
{RGBColor[1, 0, 0], PointSize[0.06], Point[{-InterpolatingFunction[{{0., \
52.}}, 
        {1, 7, False, Real, {1}, {0}}, 
        {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, \

          0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
          2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
          4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
          8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
          12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
          16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
          19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
          21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
          22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
          23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
          24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
          25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
          25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
          26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
          26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
          26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
          27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
          27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
          28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
          28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
          29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
          30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
          31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
          33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
          35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
          37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
          40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
          43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
          47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
          51.68339752171315, 52.}}, {{10., 0.}, 
         {9.999999668030779, -0.00009979517922659892, -0.01500000077182846}, 
         {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
          -1.322286343058508*^-7}, {9.999534630881093, -0.005282323784489644, \

          -0.01500076832270247, -1.507556879980259*^-6}, 
         {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
          -4.303953042407377*^-6}, {9.996022280142259, -0.01544977367720093, 
          -0.01500656577947253, -7.102518978703048*^-6, \
-4.12962510774654*^-6}, 
         {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
          -0.00001911254788268681, -4.721536529157213*^-6}, 
         {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
          -0.00002843965797539134, -4.17160237245598*^-6}, 
         {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
          -0.00003863663157999305, -4.230562589262589*^-6}, 
         {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
          -0.00004907835452562485, -4.318382798300356*^-6}, 
         {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
          -0.00006058324022271351, -4.43239809319311*^-6}, 
         {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
          -0.00007254388067269821, -4.588965459026183*^-6}, 
         {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
          -0.00008504165353778693, -4.780886831038984*^-6}, 
         {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
          -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
         {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
          -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
         {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
          -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
         {8.9333000040121, -0.260711383344569, -0.0169126745304145, \
-0.0001688916601208405, 
          -7.056168354057571*^-6, -1.313845897946621*^-7}, 
         {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
          -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
         {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
          -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
          -6.674609404533344*^-9}, {7.968828654203694, -0.3701677267394483, 
          -0.01893656311738351, -0.0002787120557484119, \
-0.00001107459120877045, 
          -3.431225329765139*^-7, -1.221235206138657*^-8}, 
         {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
          -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
          -1.346430675352864*^-8}, {7.014966306469673, -0.4621643951747192, 
          -0.02125743383726544, -0.0004024832669310073, \
-0.00001612207743260069, 
          -5.188299501191256*^-7, -1.214130185849565*^-8}, 
         {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
          -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
          -1.354357959188541*^-8}, {5.971354327636086, -0.5552694173247879, 
          -0.02419934375167602, -0.0005601240439740879, \
-0.00002240270713257671, 
          -6.795896221578519*^-7, -1.201709349193833*^-8}, 
         {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
          -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
          -1.583376666742293*^-9}, {4.994559169969892, -0.6394373103400424, 
          -0.02732862996656363, -0.0007171994723376593, \
-0.00002519742550426964, 
          -1.641290240708912*^-7, 3.910597107780506*^-8}, 
         {4.512594792329623, -0.6805479316610102, -0.02897566532185714, 
          -0.0007858734411303971, -0.00002283819031739034, \
6.281580292262645*^-7, 
          9.577105762745674*^-8}, {4.092333097008952, -0.7162958456331559, 
          -0.03043328001834313, -0.0008273002171360841, \
-0.00001411116814184291, 
          2.773103753343612*^-6, 2.950546781062066*^-7}, 
         {3.650020866463042, -0.7538337447048592, -0.03194053384702654, 
          -0.000837781640951464, 2.907707968555054*^-6, \
5.852540359820091*^-6, 
          5.181368394863152*^-7}, {3.184571840689228, -0.7931742380695744, 
          -0.03340796215459502, -0.0007783073126224044, \
0.00004020831399575819, 
          0.00001252969451950441, 1.050499280912101*^-6}, 
         {2.795135498386905, -0.825830794134082, -0.03443182974317923, 
          -0.0006278837202671806, 0.0001043308691637567, \
0.00002636995433250329, 
          2.548041348411085*^-6}, {2.38977107808601, -0.8593358948133683, 
          -0.03513375184134562, -0.000319913380216462, 0.0002060515099388112, \

          0.00004421380258099794, 4.001314036998032*^-6}, 
         {1.968166385363971, -0.8932395940637682, -0.03519115346953409, 
          0.0002827427630627121, 0.0003953025819406979, \
0.00008034764600886729, 
          7.407586137339988*^-6}, {1.612143333988495, -0.9206107463009619, 
          -0.03436732147393313, 0.001167408375879762, 0.0006871165481036591, 
          0.0001488881693373802, 0.00001608512153778298}, 
         {1.245564862078643, -0.9468476617076561, -0.03218992389889563, 
          0.002621839915004895, 0.001129466927246893, 0.0002361002834123236, 
          0.00002446272968897194}, {0.9411036630779808, -0.9663582346870491, 
          -0.02882442468204031, 0.004524953127547926, 0.001773934206673067, 
          0.0004076052929450417, 0.00005060830769685972}, 
         {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, 
          0.007385850858260214, 0.002672644657907155, 0.0005975972454227846, 
          0.00007016870897342483}, {0.3159401433660997, -0.9951819807516075, 
          -0.0141810564371504, 0.01177969329600485, 0.004105758348508652, 
          0.0009339734047126293, 0.0001125727572013773}, 
         {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, 
          0.01642148422154501, 0.005766813443267503, 0.001456041061702653, 
          0.0002183132824744149}, {-0.1451655451007285, -0.9987483123162489, 
          0.008944489593331621, 0.02264330478484971, 0.007723831164850311, 
          0.001834097872355712, 0.0002401682337663385}, 
         {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, 
          0.03107584026681068, 0.01043305827566561, 0.002464002718034116, 
          0.0003260132232436369}, {-0.6017366959356142, -0.9723927003509583, 
          0.05264297022337499, 0.04225298673259487, 0.01376536310562221, 
          0.003084637463279821, 0.0003748430742714523}, 
         {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, 
          0.0530975554303808, 0.01662705757449755, 0.003411909325867013, 
          0.0003468215640078723}, {-0.9408520004092066, -0.9156991754896342, 
          0.1099734795798445, 0.06584191092106879, 0.01927853582407632, 
          0.003240100434734713, 0.0001440904775641987}, 
         {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, \
0.08005627726477126, 
          0.02099483499621253, 0.002195345619101353, -0.0003027390708880932}, \

         {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
          0.02021543417588093, -0.000754274587538044, -0.001530626941211491}, \

         {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, \
0.1026147787935418, 
          0.01746781961115515, -0.004103986580530314, -0.002450338209772962}, \

         {-1.44516147054655, -0.686759968869766, 0.2758334004910389, \
0.1105177241750504, 
          0.0106742864278701, -0.009800257288146374, -0.004075343469478164}, 
         {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, \
0.1131708883596251, 
          -0.0007350026571956852, -0.01685438505251352, \
-0.005671350902054768}, 
         {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, \
0.1079524283682205, 
          -0.01688511860132406, -0.02423508582492491, -0.006778310725377359}, \

         {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, \
0.09666214457796037, 
          -0.03204065521875401, -0.02840436636139767, -0.006444744621113192}, \

         {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, \
0.0785742469749175, 
          -0.0470257534782241, -0.02861634111365265, -0.00398773686340812}, 
         {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, \
0.05414735876830688, 
          -0.05977983902013911, -0.02439011013378813, \
0.00001759514469461788}, 
         {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, \
0.03131763081762755, 
          -0.0651267030424638, -0.01330108771073375, 0.007932614219398512}, 
         {-1.764279633198327, -0.02290728516546019, 0.4815191300064316, 
          0.006382340077340566, -0.06878153330095417, -0.00607622203589427, 
          0.009921051344796055}, {-1.762223869805497, 0.0669098889538212, 
          0.4797874360581084, -0.01881564820658439, -0.06715504466041756, 
          0.0052941015385649, 0.014075650991735}, 
         {-1.751822051888362, 0.1557504845998194, 0.4711087322811719, \
-0.04290594361192289, 
          -0.06177008484910881, 0.01515215349206186, 0.01548803581768913}, 
         {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, \
-0.06450374890421965, 
          -0.05309737444319933, 0.02305207122611793, 0.01493656511780418}, 
         {-1.706693534600896, 0.325611997587172, 0.4353010176743601, \
-0.08256681154941546, 
          -0.04224156850021461, 0.02801462883846634, 0.01250721686243972}, 
         {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, \
-0.09760253037063431, 
          -0.02888818242959219, 0.0306691934708478, 0.009224953760383584}, 
         {-1.622080963140679, 0.4929301210117905, 0.3755325162049182, \
-0.1074178334999123, 
          -0.01633310637884133, 0.02856039286749514, 0.004168099462073743}, 
         {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, \
-0.1122527924612216, 
          -0.005160721979258902, 0.02417131244294108, \
-0.0003440345314113444}, 
         {-1.505751224868501, 0.6333664485834628, 0.306641269066246, \
-0.1127997113966985, 
          0.003903182359577255, 0.01843886863229986, -0.003922050103786528}, 
         {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, \
-0.1099263646846194, 
          0.01072931196339118, 0.01262842140521531, -0.006119419347288539}, 
         {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, \
-0.1045481470172331, 
          0.01544034474959015, 0.007498171284307598, -0.006996953823451097}, 
         {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, \
-0.0967041517292661, 
          0.0185064284735578, 0.002960749536155133, -0.006856601949068641}, 
         {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, \
-0.08779459299724857, 
          0.01979767319192345, -0.0003066249582991479, \
-0.006028282943382096}, 
         {-1.085063458885453, 0.8749251188130202, 0.144782245099154, \
-0.07854258397670186, 
          0.01986264568980367, -0.002297713136917443, -0.004783528255310104}, \

         {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, \
-0.06946500901627999, 
          0.01908920268180254, -0.003359677058435248, -0.003492310907858758}, \

         {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, 
          -0.0608924971492783, 0.01779753275101055, -0.003788394790891112, 
          -0.002346567941738405}, {-0.7723805707186532, 0.9494556605823984, 
          0.07791739671236562, -0.05301145859825892, 0.01623278484580223, 
          -0.003814067204285791, -0.00142298197321629, 0.001159542229646304}, \

         {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, 
          -0.04468096904705857, 0.01441045900308664, -0.002783953394204672, 
          0.001188784376355514, 0.001697085509141072}, 
         {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, 
          -0.03741547808128195, 0.0128042870890071, -0.001516085052811469, 
          0.002492470180502037, 0.001592641575583569}, 
         {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, 
          -0.03126812679688145, 0.01073262941726728, -0.002037579725773561, 
          0.001248140166443795, 0.000621510220514931}, 
         {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, 
          -0.02604465129166512, 0.008980331918121603, -0.002095510898895228, 
          0.0006953458839076041, 0.0002187584774474667}, 
         {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, 
          -0.02163335504587148, 0.007533052625606419, -0.001862875274342468, 
          0.0005412212424280951, 0.00009130883576918053}, 
         {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
          -0.01793006544947133, 0.006305477814234636, -0.001607987009029117, 
          0.0004376460542311089, 0.00002422708367731202}, 
         {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
          -0.01483069730268437, 0.00526623201595544, -0.001376927490964432, 
          0.0003454596158002636}, {0.3238530675731096, 0.995016345930049, 
          -0.0144640796213406, -0.0116871546883609, 0.004231198363091821, 
          -0.001064594641186693, 0.0003322772383557684}, 
         {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, 
          -0.00917301401911442, 0.003397859160363781, -0.000819933720088739, 
          0.0002972842358494771}, {0.6533538559313423, 0.9820447155621451, 
          -0.02372070399070088, -0.007162526259702596, 0.002726309336887593, 
          -0.0006384642833766479, 0.0002509980162091398}, 
         {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, 
          -0.005553834168748899, 0.002185764859300605, \
-0.0005041528357430196, 
          0.000204352772054328}, {0.9776558814470167, 0.9642105857215122, 
          -0.02932920777076483, -0.004264733145196217, 0.001753679572068895, 
          -0.0003999863031745657, 0.0001643010647412814}, 
         {1.137437570202047, 0.9541144596710516, -0.03119425522545939, 
          -0.003230475051281675, 0.001408187583593927, -0.000318863443275577, \

          0.0001310475300282612}, {1.373962009270192, 0.9379913626951294, 
          -0.03315104071340928, -0.002035992528092278, 0.001055017058722285, 
          -0.0001754137530066389, 0.0001168833024258509}, 
         {1.606350517388015, 0.9210897263708773, -0.03435027793903866, 
          -0.001185643298369978, 0.0007611892730192848, \
-0.0001263674244384825, 
          0.00008320952677836924}, {1.834451124462977, 0.9037326412745143, 
          -0.03500295728260755, -0.0005720113774542266, \
0.0005488589661374675, 
          -0.0000923366591773421, 0.00005900095063806828}, 
         {2.05818068749326, 0.8861532298832889, -0.03526139771076708, 
          -0.0001299066826636304, 0.0003943010523705895, \
-0.00006860755394809425, 
          0.00004172858547342076}, {2.277505796363031, 0.8685194772734156, 
          -0.03523617500405487, 0.0001875161539186697, 0.0002818251856303586, \

          -0.0000511645549180407, 0.00002968880418123365}, 
         {2.492428788195139, 0.8509519705097273, -0.03500799092175404, 
          0.0004136601693357046, 0.0001995415136804703, \
-0.00003828804738911866, 
          0.00002124715551700476}, {2.772238550718317, 0.8277725006882704, 
          -0.03448789441543038, 0.0006187349731000154, 0.0001352320034684956, \

          -0.00001425422529863956, 0.00001755451345997014}, 
         {3.044385230797065, 0.8049972229139195, -0.03380947075089432, 
          0.0007368050289671234, 0.00007834634628596583, \
-0.00001122391314621417, 
          0.00001113870188222071}, {3.309018587737515, 0.7827080320625583, 
          -0.03303896113559139, 0.0008026315339952361, \
0.00004206218440122728, 
          -7.530342783184703*^-6, 7.421851557590777*^-6}, 
         {3.566309067033361, 0.7609505320860362, -0.0322207398277254, 
          0.0008326581797725729, 0.00001753263227045104, \
-5.206456476998877*^-6, 
          4.91783556921768*^-6}, {3.81643803262864, 0.7397459514613501, 
          -0.03138449367913013, 0.000838939799644164, 1.35077760291538*^-6, 
          -3.443913900758643*^-6, 3.303169942357289*^-6}, 
         {4.059591012015883, 0.7190992617954302, -0.03054996995098544, 
          0.0008294710638224421, -9.266693762532051*^-6, \
-2.176304405457542*^-6, 
          2.235395158274695*^-6}, {4.372585721165242, 0.6924846048814831, 
          -0.02946402757201999, 0.0008029885517503858, \
-0.00001512205360717179, 
          8.250783523782558*^-7, 1.79238678863533*^-6}, 
         {4.673987267678016, 0.6668147871373053, -0.02842204472668379, 
          0.0007647138190854807, -0.00002078611834098472, \
6.541365780799917*^-7, 
          1.049737140101165*^-6}, {4.964205394312013, 0.6420460382904659, 
          -0.02743350214751175, 0.0007221979607514677, \
-0.00002314976507814556, 
          7.761061031756697*^-7, 6.481760049899586*^-7}, 
         {5.243628875125201, 0.6181288506037192, -0.02650242749678078, 
          0.0006781875255987336, -0.00002393452362995146, \
7.931800302684875*^-7, 
          3.914720523938617*^-7}, {5.5126240130368, 0.5950117248664654, 
          -0.0256295578461628, 0.0006345834841070335, \
-0.00002369251940469708, 
          8.021342089770415*^-7, 2.362291693947091*^-7}, 
         {5.771534255654154, 0.5726434521487585, -0.02481369104364359, 
          0.0005924255277376992, -0.00002288648698303586, \
7.853559496375988*^-7, 
          1.392154952244304*^-7}, {6.108778136511332, 0.5432709949881284, 
          -0.02378916494031363, 0.0005385767396017946, \
-0.00002090222196923115, 
          9.634231569526953*^-7, 1.031660310217783*^-7}, 
         {6.428627940347904, 0.5150795809575441, -0.02285881763700148, 
          0.000488650474985677, -0.00001936889068213984, \
7.862704461763962*^-7, 
          4.236373274532015*^-8}, {6.731764237016638, 0.4879601358421129, 
          -0.02201464865538692, 0.0004432614671721073, \
-0.00001769376947598321, 
          6.751452578811216*^-7, 1.316367698170899*^-8}, 
         {7.018804533876454, 0.4618132537833407, -0.02124878476612005, 
          0.000402127590503264, -0.00001608643168964409, \
5.795259274427188*^-7, 
          -2.64641555573496*^-9}, {7.29030909335201, 0.4365487805184312, 
          -0.02055383300618015, 0.0003649289266705499, \
-0.00001458398933991611, 
          5.033512661358331*^-7, -9.988169502319166*^-9}, 
         {7.546786291865488, 0.4120851279505025, -0.01992303747611581, 
          0.0003312779634424161, -0.00001322154918966636, \
4.37551534672063*^-7, 
          -1.324910477258141*^-8}, {7.884086056271611, 0.3787788434178949, 
          -0.01913029312120552, 0.0002891023262879505, \
-0.0000115291594594324, 
          3.63777393971772*^-7, -1.371373898326033*^-8}, 
         {8.193519584742434, 0.3467373043198655, -0.01843847943647414, 
          0.0002522379007700076, -0.00001012456090970589, \
2.940570752419515*^-7, 
          -1.367577777664127*^-8}, {8.476095686537853, 0.3157992553430406, 
          -0.01783509007823322, 0.0002198514717341092, \
-8.938518663488416*^-6, 
          2.402965656917715*^-7, -1.240599571914663*^-8}, 
         {8.732694164207696, 0.2858229861605473, -0.01730967605233079, 
          0.0001911921984056844, -7.945451424014868*^-6, \
1.975592634101514*^-7, 
          -1.078283810070344*^-8}, {8.964081092156048, 0.2566830884024056, 
          -0.01685353056247505, 0.0001656356738916059, -7.115162259841*^-6, 
          1.634975150107237*^-7, -9.131086931191294*^-9}, 
         {9.170921496420231, 0.2282677220189242, -0.01645941987193715, 
          0.0001426479705924626, -6.427511170842572*^-6, \
1.348052317356517*^-7, 
          -7.720497902122285*^-9}, {9.389954355144068, 0.1945852773909356, 
          -0.01605562025513275, 0.000117523846926549, -5.77104513440084*^-6, 
          1.004193245520244*^-7, -6.84435365281206*^-9}, 
         {9.574487972549572, 0.1616616916001712, -0.01572586742018316, 
          0.00009490549903810554, -5.233270606636592*^-6, \
7.898604003413424*^-8, 
          -5.485421307730566*^-9}, {9.725231796860384, 0.1293508421880767, 
          -0.01546336168132292, 0.00007419723225491459, \
-4.824923276518464*^-6, 
          5.934261569317994*^-8, -4.554919700878265*^-9}, 
         {9.842750599262039, 0.09751900870274404, -0.01526288472030978, 
          0.000054940201293084, -4.52067132704201*^-6, 4.262303874918333*^-8, \

          -3.808526825726381*^-9}, {9.927475673864893, 0.06604185470753681, 
          -0.0151205676271804, 0.00003672919236845725, \
-4.308672419068996*^-6, 
          2.762596707450741*^-8, -3.249881860652005*^-9}, 
         {9.979713178406525, 0.03480181166196349, -0.01503372618961092, 
          0.00001920328638020516, -4.180602396326156*^-6, \
1.358486971789759*^-8, 
          -2.853196789546286*^-9}, {9.999804221413857, 0.002079784470556782, 
          -0.01500049198937566, 1.146333605182019*^-6, \
-4.131571602154404*^-6, 
          -1.008292044867596*^-9, -2.604590129466682*^-9}, 
         {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
          -4.065399346041674*^-6, -4.111443091414769*^-6, \
7.927537361729354*^-9, 
          3.188545681628212*^-10}}][t]/4, 
    -InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
        {{0., 0.003326505803053839, 0.006653011606107678, 0.1760731080602622, \

          0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
          2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
          4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
          8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
          12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
          16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
          19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
          21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
          22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
          23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
          24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
          25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
          25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
          26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
          26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
          26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
          27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
          27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
          28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
          28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
          29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
          30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
          31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
          33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
          35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
          37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
          40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
          43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
          47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
          51.68339752171315, 52.}}, {{0., 0.3}, 
         {0.0009979517077872255, 0.2999999900409223, -1.496927738092378*^-6}, \

         {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
          -0.0001500000440689237}, {0.05282074703033888, 0.2999860382470232, 
          -0.00007923886649939536, -0.0001500117406492253}, 
         {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
          -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, 
          -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
         {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
          -0.0001512573923248744, -3.56926535101178*^-7}, 
         {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
          -0.0001532344335889719, -6.696147194160083*^-7}, 
         {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
          -0.0001561772311865011, -1.0428234784246*^-6}, 
         {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
          -0.0001600680606887075, -1.43126921114028*^-6}, 
         {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
          -0.0001652995935706142, -1.838046254173493*^-6}, 
         {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
          -0.000171839413657207, -2.313982825558378*^-6}, 
         {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
          -0.0001797480698000253, -2.828724047048563*^-6}, 
         {1.616193851195026, 0.28597129085274, -0.002670225693750562, 
          -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
         {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
          -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
         {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
          -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
         {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
          -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
         {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
          -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
         {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
          -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
          -1.747260442740121*^-8}, {3.175344187221096, 0.2289633086353855, 
          -0.007545671364715371, -0.0004088562867722723, \
-0.00001760680137464635, 
          -8.727270794121078*^-7, -3.447284626861373*^-8}, 
         {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
          -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
          -4.451638240754114*^-8}, {3.65591142716557, 0.186792033285195, 
          -0.01107850554171452, -0.0006407044351002397, \
-0.00003391896655161902, 
          -1.770630454265917*^-6, -5.499941220723898*^-8}, 
         {3.85478077194519, 0.1585724953229884, -0.01360311058181845, 
          -0.0008339122439545453, -0.0000489443172128367, \
-2.712322351006786*^-6, 
          -8.766377802768383*^-8}, {3.986763005165946, 0.131667061984029, 
          -0.01615666214412804, -0.001051626041925007, \
-0.00006869661225566872, 
          -4.393137681215513*^-6, -1.761332361311671*^-7}, 
         {4.092061561834391, 0.0995298917764175, -0.01940869599958157, 
          -0.001352395704445139, -0.00009571282431003663, \
-6.281214100632805*^-6, 
          -2.444479897469488*^-7}, {4.153850886158325, 0.06883885260811142, 
          -0.02272856290784795, -0.001690501313216549, \
-0.0001316398123092309, 
          -9.940863233820019*^-6, -4.806638869588175*^-7}, 
         {4.191306423956496, 0.03269842564989161, -0.02691267068137347, 
          -0.002148302610858181, -0.0001796379888607316, \
-0.00001388813348710936, 
          -6.486429479295039*^-7}, {4.200742249681569, -0.002208228754422552, \

          -0.0312395051651517, -0.002663840093236035, -0.0002423648979153841, \

          -0.00002118918286358118, -1.197910773667203*^-6}, 
         {4.187480484699273, -0.04294029965292303, -0.03664374955205367, 
          -0.003351432661554625, -0.0003255129417403924, \
-0.00002918221867922413, 
          -1.604121647400555*^-6}, {4.147582708325752, -0.09101196819194772, 
          -0.04351056025037764, -0.004295458408425854, \
-0.0004497713933866242, 
          -0.00004287189467316768, -2.47885545821094*^-6}, 
         {4.093216338662262, -0.1360882405850764, -0.05042227215046736, 
          -0.005319578435935783, -0.0006006220945709141, \
-0.00006396231737026914, 
          -4.409656157769888*^-6}, {4.015439499996313, -0.1885954484836499, 
          -0.05903393771043326, -0.006668642152566507, \
-0.0007954597141818747, 
          -0.00008583296722324174, -5.6762468467354*^-6}, 
         {3.910243506625146, -0.2504281729333795, -0.06991601053462865, 
          -0.008485369119217001, -0.001075857440459364, \
-0.0001215320852716722, 
          -8.352309163308866*^-6}, {3.800626326934144, -0.3095265512549151, 
          -0.0810211001084475, -0.01044535109360783, -0.001399096395540943, 
          -0.0001697669761996192, -0.00001320335121470718}, 
         {3.665972999146803, -0.378327542653802, -0.09474229302615215, \
-0.01295459443587661, 
          -0.001793921254600053, -0.0002144492937412613, \
-0.00001551062565886725}, 
         {3.535553015059292, -0.4428061177064114, -0.1082883390327763, \
-0.01550358393254631, 
          -0.00220095651893553, -0.0002668360165914096, \
-0.00002028150696806179}, 
         {3.383157176300779, -0.5167289059824787, -0.1245035267716008, \
-0.01856317910150786, 
          -0.00262862077236768, -0.0002906382154606718, \
-0.00001715551624775262}, 
         {3.20549373901541, -0.6019516096016301, -0.1438811536990364, \
-0.02213377125985196, 
          -0.003028422675279043, -0.0002756180044960396, \
-7.146543113549753*^-6}, 
         {3.058588130827458, -0.6720624861181122, -0.1601545679841135, \
-0.02490566730718879, 
          -0.003089766360970424, -0.00009058479323536484, \
0.00004914842109632001}, 
         {2.894596323375797, -0.7501316342604838, -0.1783524392815316, \
-0.02765292754581667, 
          -0.002939806242666361, 0.0001373209277761948, \
0.00009530669209766431}, 
         {2.71158077479672, -0.8370178977712138, -0.1982936201330007, \
-0.02988428120237179, 
          -0.002118996299412064, 0.0007045924544449787, \
0.0002210082169551333}, 
         {2.507421795656775, -0.9334055715055376, -0.2193614638360956, \
-0.03078067221328464, 
          -0.0001732800370884182, 0.001720488442029996, \
0.000425988858941995}, 
         {2.33317849523205, -1.014847597695069, -0.2356208100425164, \
-0.02955058544284709, 
          0.003046032316439744, 0.003590979279397424, 0.0009523908779487415}, \

         {2.143850052796314, -1.101919841659889, -0.2505885269406052, \
-0.0257551642988426, 
          0.007412414361894901, 0.005279973333030467, 0.001200620682765593}, 
         {1.938487117181982, -1.193862438764723, -0.2624730364011236, \
-0.0178540166471961, 
          0.01421257642856188, 0.008004913431379991, 0.001735470468834257}, 
         {1.75883264928784, -1.271316953078838, -0.2681090023709465, \
-0.007281781650419494, 
          0.02174468381572495, 0.01086883249466218, 0.002351071097237822}, 
         {1.567803973134603, -1.34965284368106, -0.2681888997706034, \
0.007755152293289466, 
          0.03018262959327178, 0.01265091525278751, 0.002225662920469842}, 
         {1.365404745815049, -1.426949826614714, -0.2606107999898968, \
0.02785461651196843, 
          0.03933114451231477, 0.01367846572910126, 0.001805339147952605}, 
         {1.151964525852244, -1.500657049331877, -0.2432083773649155, \
0.05271498302494613, 
          0.04725609485920589, 0.0121762506290482, 0.0003961782992654656}, 
         {0.9282290908341909, -1.567631287112038, -0.2141720714913058, \
0.08087452593462236, 
          0.05143956554555599, 0.006857316057938279, -0.002194862118939511}, 
         {0.7421893162287318, -1.614082667611147, -0.1818521353382827, \
0.1036384967185181, 
          0.04854416792859499, -0.004146149653291475, -0.007592239941335828}, \

         {0.5511972731511882, -1.652053966237579, -0.1417298011263864, \
0.1248433419007408, 
          0.04251471658064646, -0.01247735974733354, -0.00930666804245882}, 
         {0.3563470626035425, -1.679827849714072, -0.0948729889153013, \
0.1416220962583256, 
          0.03002609653483467, -0.02382700420146366, -0.01205675068522526}, 
         {0.1988803856063542, -1.693747230698574, -0.05387307904427518, \
0.1504911307725392, 
          0.01707885010501343, -0.03104601206841266, -0.01239134837489694}, 
         {0.04047800614247131, -1.699822619873736, -0.01104749066017452, \
0.1544758791615086, 
          0.002904805753834867, -0.03443803199776515, -0.009858086267061791}, \

         {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, \
0.1531408660534355, 
          -0.01167634603044878, -0.03485997177461622, -0.006216287801323393}, \

         {-0.27615166724078, -1.687886476853531, 0.07426415750684713, \
0.1466406120061692, 
          -0.02502213731263542, -0.03148565897311392, -0.001319145505838771}, \

         {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, \
0.1355750756867236, 
          -0.03599301035345136, -0.02507396577743876, 0.003789060726332308}, 
         {-0.5876646366009311, -1.645599954367274, 0.149886984217886, \
0.1209186002645799, 
          -0.04381958582674411, -0.0167474495269128, 0.008221944332663039}, 
         {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, \
0.1019891041979152, 
          -0.04877571161287061, -0.007753678783690814, 0.01076270805849416}, 
         {-0.9188591999930354, -1.57017430368858, 0.2127277830279036, \
0.0818110606661343, 
          -0.04943939416432463, 0.001581489445512773, 0.01250845176538342}, 
         {-1.078022007311201, -1.524033745659761, 0.2348479541369871, \
0.06175197825101608, 
          -0.04718114182999041, 0.008400797491673479, 0.01192517916639287}, 
         {-1.23222676597908, -1.473969978010766, 0.2509389357975537, \
0.04295023556381035, 
          -0.0428030994569332, 0.01270243240769841, 0.009943321676064535}, 
         {-1.381132132554967, -1.421173821015353, 0.2615185199513495, \
0.02615011505720406, 
          -0.0372470249172224, 0.01458154268469676, 0.007183986167612035}, 
         {-1.52451303706018, -1.366709763304248, 0.2672792569516805, \
0.01175094508843675, 
          -0.03124282318580188, 0.01462385001478342, 0.004337814273567681}, 
         {-1.676554155554152, -1.305608867189375, 0.2689638069601199, \
-0.001217053979193587, 
          -0.02444610851301589, 0.01402117366548132, 0.00224958656739477}, 
         {-1.821639069964926, -1.244590074076928, 0.2667220610870114, \
-0.0113128728396274, 
          -0.01864935539868304, 0.01161388704344243, \
-0.00006065302064348859}, 
         {-1.959823689587621, -1.184436938921008, 0.2615032087283585, \
-0.01878286271819812, 
          -0.01354138262907623, 0.009331003691403976, -0.001373910151833233}, \

         {-2.091241362794932, -1.125730764971378, 0.2541299320700626, \
-0.02404459475853125, 
          -0.009317813474587454, 0.007160120981883526, \
-0.002096244383309918}, 
         {-2.216081519973962, -1.068881633376215, 0.2452839969799536, \
-0.02750822913116375, 
          -0.005921779540154439, 0.005321449744103576, \
-0.002335005570329405}, 
         {-2.334572036779301, -1.014160218395938, 0.2355105012068567, \
-0.02955739610497582, 
          -0.003267957858955671, 0.003847437519762102, -0.0022646122431367, 
          0.00008837730146102579}, {-2.466875653158295, -0.9523955635414637, 
          0.2233247841202344, -0.03060923986977494, -0.0009206404428521231, 
          0.002668607114008318, -0.001642610820709008, \
0.0002789857387758132}, 
         {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, \
-0.0305867528862542, 
          0.0007931576405303536, 0.002021643534149319, \
-0.0008785619396256485, 
          0.0004563152055443385}, {-2.707659006010745, -0.8388172181424984, 
          0.1987180081228845, -0.02986498356771943, 0.001850571136714643, 
          0.001311821166285018, -0.0006006837699262708, \
0.0004025249678476842}, 
         {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, \
-0.02868642525878178, 
          0.002510879609608891, 0.0008222015537418208, \
-0.0003592654655979457, 
          0.000353765107692091}, {-2.919626045506723, -0.7381571877771078, 
          0.175586089260012, -0.02723906829815367, 0.002875048835861939, 
          0.0004616915237353225, -0.0002051292907194143, \
0.0002903776349041168}, 
         {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, \
-0.02565419087941412, 
          0.003033030217916483, 0.0002014497612882507, \
-0.0001107920060412756, 
          0.0002269621421637012}, {-3.106117892072866, -0.6493204211172826, 
          0.1548734590809113, -0.02402116089273098, 0.003055539450422462, 
          0.00002599975151483897, -0.00004758785347185354}, 
         {-3.210090129745036, -0.5996681315994481, 0.1433705576419095, \
-0.02201677832120685, 
          0.002985222599816919, -0.0000958294047673527, \
-0.00007731102712422072}, 
         {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, \
-0.02011385735927098, 
          0.002763124856175378, -0.0002864118307802861, \
-0.0001226612803402779}, 
         {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, \
-0.01832912002286514, 
          0.002545956219616085, -0.0003344654449797207, \
-0.00009282872655880584}, 
         {-3.476527520813544, -0.471466600434013, 0.1145100431816513, \
-0.01668087231558483, 
          0.002340654063149804, -0.0003120801939574286, \
-0.00004673823831166822}, 
         {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, \
-0.01517795810854488, 
          0.00213323204377452, -0.0002847408987506403, \
-0.0000171012438948165}, 
         {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, \
-0.01381624455578609, 
          0.0019329271910969, -0.000256584599016029, 1.007933302260962*^-6}, 
         {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, 
          -0.01202278498544689, 0.001642061747291683, -0.000235249621043713, 
          6.294315540307676*^-6}, {-3.798446943438669, -0.3105342664181361, 
          0.08122614330861257, -0.01048688148137613, 0.001408458250699894, 
          -0.0001884038544520576, 0.00001626929459300319}, 
         {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, 
          -0.00917947523972208, 0.001204544204314665, -0.0001528026664484259, \

          0.00001925560751478185}, {-3.934630385946802, -0.2365213821444215, 
          0.06740931090421369, -0.008065641383147081, 0.001029940565630871, 
          -0.0001250578171946844, 0.0000189522876063627}, 
         {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, 
          -0.007114652075869174, 0.000882042765250185, \
-0.0001030409363367319, 
          0.00001724277618273266}, {-4.036983057207475, -0.1746882790891004, 
          0.05670238403676125, -0.006300486571572722, 0.0007570421935068591, 
          -0.00008565931813226637, 0.00001498094973042025}, 
         {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, 
          -0.005388164125577655, 0.0006254981305204854, \
-0.00006275759347351894, 
          0.00001356839613907586}, {-4.129977973626481, -0.1066698407990083, 
          0.04586552357996159, -0.004640446873950072, 0.0005154961431997248, 
          -0.00005002292097234296, 0.00001068768379513849}, 
         {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, 
          -0.004021722679494938, 0.0004278764083609402, \
-0.00003998672821139463, 
          8.419621550322354*^-6}, {-4.181992277724197, -0.05114937617478823, 
          0.03778328353121347, -0.003506550900720839, 0.0003572087299784264, 
          -0.00003242813775361963, 6.563319850414154*^-6}, 
         {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, 
          -0.003074675807083444, 0.0003001534886949304, \
-0.00002647017776461171, 
          5.129448984486421*^-6}, {-4.200273762534801, -0.005059630122047486, \

          0.03160865927633907, -0.002710379401726163, 0.0002537304737997015, 
          -0.00002179055275345088, 4.013488418448823*^-6}, 
         {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, 
          -0.002307804699369244, 0.0002080180677235468, \
-0.00001467874931531174, 
          3.477096307713213*^-6}, {-4.181640046440592, 0.04524848451510998, 
          0.02542812434125149, -0.001982916488272914, 0.0001688840778693765, 
          -0.00001193572980333215, 2.498571878633773*^-6}, 
         {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, 
          -0.001716367034850311, 0.0001387847490468397, \
-9.539748932217889*^-6, 
          1.859292472751585*^-6}, {-4.122785355809635, 0.0860961029326029, \
0.02083744114211, 
          -0.001496038192667138, 0.0001149375476116196, \
-7.752989220148379*^-6, 
          1.384150391219296*^-6}, {-4.080627749673199, 0.1037340341763129, 
          0.0189718502418653, -0.001312377553500777, 0.00009598075726336363, 
          -6.330002216054171*^-6, 1.044385030161512*^-6}, 
         {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, \
-0.001158156672391711, 
          0.00008074314435794473, -5.205832344760582*^-6, \
7.956094303782612*^-7}, 
         {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
          -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
          6.853161548526208*^-7}, {-3.862684295208088, 0.1571524415300303, 
          0.01373487047827056, -0.0008458709268748281, \
0.00005292158849075478, 
          -2.717703778739206*^-6, 4.776227802405111*^-7}, 
         {-3.762840313497239, 0.172874054360284, 0.01230548051000591, \
-0.000732964029147417, 
          0.00004313135460575885, -2.174487587840614*^-6, \
3.464779702597154*^-7}, 
         {-3.653990683732458, 0.186983619109208, 0.01106211919053541, 
          -0.0006402696967549964, 0.0000354544481395366, \
-1.769433689206584*^-6, 
          2.525549483911888*^-7}, {-3.537046154954697, 0.1996855178939522, 
          0.009972121764422109, -0.0005634894736334127, \
0.00002940436207093559, 
          -1.444926260924889*^-6, 1.873187047108245*^-7}, 
         {-3.412804993833292, 0.2111489245800355, 0.009009588330419845, 
          -0.0004994138122043501, 0.00002457256285304119, \
-1.188314081952184*^-6, 
          1.406896678162243*^-7}, {-3.226384080591982, 0.2254888689910921, 
          0.00782863863198294, -0.0004254398735934686, \
0.00001981390334171221, 
          -7.142813890569568*^-7, 1.214519187305689*^-7}, 
         {-3.028544710651558, 0.2379623057313892, 0.006815353873336178, 
          -0.0003674996746395192, 0.00001563491183483192, \
-5.86375308215994*^-7, 
          8.286497780628049*^-8}, {-2.820766127855042, 0.2488246275196445, 
          0.005935351079990573, -0.0003211413486115556, \
0.00001249454537016901, 
          -4.723075689651174*^-7, 5.863156687991705*^-8}, 
         {-2.604332817704375, 0.2582797769625237, 0.005162226805369295, 
          -0.0002838187140553005, 0.00001004906765736633, \
-3.87289508354963*^-7, 
          4.18217498152932*^-8}, {-2.380372883980649, 0.2664918453580231, 
          0.004475381304397052, -0.0002535927280720157, \
8.127093887680922*^-6, 
          -3.191386114183283*^-7, 3.041795891583185*^-8}, 
         {-2.149888330991454, 0.273593607663118, 0.00385849017216741, 
          -0.0002290448730929102, 6.587497754854157*^-6, \
-2.659372328911577*^-7, 
          2.240761720314729*^-8}, {-1.862461949229833, 0.2808796276058946, 
          0.003184570856174013, -0.0002052376119308477, \
5.184646117813377*^-6, 
          -1.904354091683055*^-7, 1.830162350662408*^-8}, 
         {-1.568184016554942, 0.2868392209174812, 0.002575703742891957, 
          -0.0001869906042160404, 3.949989067622175*^-6, \
-1.664155420757597*^-7, 
          1.252617879183773*^-8}, {-1.268364868295478, 0.2915909328124841, 
          0.002016731272518744, -0.0001730929726651855, \
2.962637641249672*^-6, 
          -1.425953503160539*^-7, 9.048066793624791*^-9}, 
         {-0.9642073675986177, 0.2952248515659734, 0.001495169624718867, 
          -0.0001628678796415216, 2.124382504834869*^-6, \
-1.268869055338464*^-7, 
          6.439368669983838*^-9}, {-0.6568336412300838, 0.2978072625251313, 
          0.001000424961613838, -0.0001558063063980045, \
1.393261933326278*^-6, 
          -1.16189512124211*^-7, 4.551787476216529*^-9}, 
         {-0.3473080080181212, 0.2993839255588992, 0.0005231945129639924, 
          -0.0001515786954507069, 7.289963028536484*^-7, \
-1.10308871975636*^-7, 
          3.109375691580504*^-9}, {-0.02059882830471778, 0.2999868284345344, 
          0.00003089963017686534, -0.0001499710129035118, \
7.391732362642512*^-8, 
          -1.071809864811129*^-7, 2.056959960532262*^-9}, 
         {0.07437607712204962, 0.2999612878079299, -0.0001115897022763641, 
          -0.0001501074630631385, -2.296620186836703*^-7, \
-1.774557747218172*^-7, 
          -1.356351577917269*^-8}}][t]/4}]}\
\>", "\<\
                                            -InterpolatingFunction[{{0., \
52.}}, <>][t]
{RGBColor[1, 0, 0], PointSize[0.06], \
Point[{------------------------------------------, 
                                                                4
 
    -InterpolatingFunction[{{0., 52.}}, <>][t]
    ------------------------------------------}]}
                        4\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A graphics object for the two orbits of the bodies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
ellipsem = ParametricPlot[{orbitm[t][[1]], orbitm[t][[2]]}, {t,0,t0}]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166656 0.107938 0.309007 0.0934155 [
[.38253 .29651 -3 -9 ]
[.38253 .29651 3 0 ]
[.59841 .29651 -3 -9 ]
[.59841 .29651 3 0 ]
[.81428 .29651 -3 -9 ]
[.81428 .29651 3 0 ]
[.15416 .02876 -12 -4.5 ]
[.15416 .02876 0 4.5 ]
[.15416 .12218 -12 -4.5 ]
[.15416 .12218 0 4.5 ]
[.15416 .21559 -12 -4.5 ]
[.15416 .21559 0 4.5 ]
[.15416 .40242 -6 -4.5 ]
[.15416 .40242 0 4.5 ]
[.15416 .49584 -6 -4.5 ]
[.15416 .49584 0 4.5 ]
[.15416 .58925 -6 -4.5 ]
[.15416 .58925 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.38253 .30901 m
.38253 .31526 L
s
[(2)] .38253 .29651 0 1 Mshowa
.59841 .30901 m
.59841 .31526 L
s
[(4)] .59841 .29651 0 1 Mshowa
.81428 .30901 m
.81428 .31526 L
s
[(6)] .81428 .29651 0 1 Mshowa
.125 Mabswid
.22062 .30901 m
.22062 .31276 L
s
.27459 .30901 m
.27459 .31276 L
s
.32856 .30901 m
.32856 .31276 L
s
.4365 .30901 m
.4365 .31276 L
s
.49047 .30901 m
.49047 .31276 L
s
.54444 .30901 m
.54444 .31276 L
s
.65238 .30901 m
.65238 .31276 L
s
.70635 .30901 m
.70635 .31276 L
s
.76031 .30901 m
.76031 .31276 L
s
.11269 .30901 m
.11269 .31276 L
s
.05872 .30901 m
.05872 .31276 L
s
.00475 .30901 m
.00475 .31276 L
s
.86825 .30901 m
.86825 .31276 L
s
.92222 .30901 m
.92222 .31276 L
s
.97619 .30901 m
.97619 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.16666 .02876 m
.17291 .02876 L
s
[(-3)] .15416 .02876 1 0 Mshowa
.16666 .12218 m
.17291 .12218 L
s
[(-2)] .15416 .12218 1 0 Mshowa
.16666 .21559 m
.17291 .21559 L
s
[(-1)] .15416 .21559 1 0 Mshowa
.16666 .40242 m
.17291 .40242 L
s
[(1)] .15416 .40242 1 0 Mshowa
.16666 .49584 m
.17291 .49584 L
s
[(2)] .15416 .49584 1 0 Mshowa
.16666 .58925 m
.17291 .58925 L
s
[(3)] .15416 .58925 1 0 Mshowa
.125 Mabswid
.16666 .04744 m
.17041 .04744 L
s
.16666 .06613 m
.17041 .06613 L
s
.16666 .08481 m
.17041 .08481 L
s
.16666 .10349 m
.17041 .10349 L
s
.16666 .14086 m
.17041 .14086 L
s
.16666 .15954 m
.17041 .15954 L
s
.16666 .17823 m
.17041 .17823 L
s
.16666 .19691 m
.17041 .19691 L
s
.16666 .23427 m
.17041 .23427 L
s
.16666 .25296 m
.17041 .25296 L
s
.16666 .27164 m
.17041 .27164 L
s
.16666 .29032 m
.17041 .29032 L
s
.16666 .32769 m
.17041 .32769 L
s
.16666 .34637 m
.17041 .34637 L
s
.16666 .36506 m
.17041 .36506 L
s
.16666 .38374 m
.17041 .38374 L
s
.16666 .42111 m
.17041 .42111 L
s
.16666 .43979 m
.17041 .43979 L
s
.16666 .45847 m
.17041 .45847 L
s
.16666 .47715 m
.17041 .47715 L
s
.16666 .51452 m
.17041 .51452 L
s
.16666 .5332 m
.17041 .5332 L
s
.16666 .55189 m
.17041 .55189 L
s
.16666 .57057 m
.17041 .57057 L
s
.16666 .01008 m
.17041 .01008 L
s
.16666 .60794 m
.17041 .60794 L
s
.25 Mabswid
.16666 0 m
.16666 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .30901 m
.97619 .31035 L
.97617 .31157 L
.97615 .31298 L
.97611 .31431 L
.97603 .31668 L
.9759 .31926 L
.97572 .32209 L
.97548 .32509 L
.97492 .33048 L
.97418 .33603 L
.97333 .34123 L
.97083 .35304 L
.96748 .36504 L
.9637 .37597 L
.95267 .40036 L
.94022 .42123 L
.92352 .44356 L
.90288 .46591 L
.88105 .48551 L
.82738 .52274 L
.79607 .53952 L
.75833 .55625 L
.71904 .57034 L
.67131 .58362 L
.64768 .58881 L
.6211 .59364 L
.59477 .59743 L
.56967 .60015 L
.55597 .60128 L
.54107 .60222 L
.53485 .60253 L
.52807 .60281 L
.52416 .60294 L
.52056 .60305 L
.51683 .60314 L
.51342 .6032 L
.50968 .60326 L
.50567 .6033 L
.50193 .60332 L
.49838 .60332 L
.49421 .6033 L
.49035 .60326 L
.48832 .60323 L
.48608 .60319 L
.48154 .6031 L
.47293 .60284 L
.46356 .60246 L
.4546 .60198 L
.44632 .60144 L
Mistroke
.42994 .60012 L
.4121 .59826 L
.37897 .59366 L
.33776 .58571 L
.29872 .57574 L
.25727 .56221 L
.21788 .54611 L
.17359 .5233 L
.12676 .49178 L
.08702 .45553 L
.06678 .43119 L
.05058 .4063 L
.0382 .38083 L
.03269 .36557 L
.02868 .35102 L
.02613 .33802 L
.02508 .33053 L
.02438 .32347 L
.02394 .31601 L
.02381 .30918 L
.02396 .30167 L
.02445 .29379 L
.02529 .28582 L
.02592 .28135 L
.02659 .27726 L
.02993 .26197 L
.03401 .24842 L
.0393 .23455 L
.05307 .20744 L
.07151 .18062 L
.10953 .14056 L
.14789 .11088 L
.19372 .08366 L
.23654 .06386 L
.27364 .05009 L
.3132 .0383 L
.35081 .02953 L
.38909 .02281 L
.40559 .02055 L
.42301 .01859 L
.43793 .01722 L
.45356 .01612 L
.46221 .01564 L
.46998 .0153 L
.47771 .01504 L
.48116 .01494 L
.48493 .01486 L
.48899 .01479 L
.4912 .01476 L
.49326 .01474 L
Mistroke
.49693 .01472 L
.50086 .01472 L
.50304 .01472 L
.50542 .01473 L
.50765 .01475 L
.50972 .01478 L
.51361 .01484 L
.51773 .01492 L
.52605 .01516 L
.53493 .01551 L
.55073 .01639 L
.56573 .01753 L
.57921 .01882 L
.60564 .02205 L
.62925 .02577 L
.67928 .03637 L
.72395 .0493 L
.76092 .06283 L
.7982 .07957 L
.82915 .09635 L
.8815 .1329 L
.90425 .15349 L
.92264 .17344 L
.93777 .19322 L
.95093 .21445 L
.96168 .23695 L
.96892 .25781 L
.97168 .26864 L
.97291 .27461 L
.9739 .28024 L
.97466 .28551 L
.97531 .29122 L
.97554 .29374 L
.97574 .29641 L
.97589 .29872 L
.97601 .3012 L
.97606 .30228 L
.97609 .30331 L
.97612 .30431 L
.97614 .30523 L
.97616 .30611 L
.97617 .30704 L
.97618 .30807 L
.97618 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O<7oo00<007ooOol0
kGoo000`Ool00`00Oomoo`3]Ool0031oo`800>ioo`00<7oo00<007ooOol0kGoo000`Ool00`00Oomo
o`18OolU0020Ool0031oo`03001oogoo03moo`T002Eoo`X007Ioo`00:7oo0P001Woo00<007ooOol0
>Woo1@00>7oo1`00Kgoo000ZOol00`00Oomoo`03Ool00`00Oomoo`0dOol60014Ool6001YOol002=o
o`<000=oo`03001oogoo00Aoo`80035oo`@0051oo`@006Eoo`00:Woo00<007ooOol00goo00<007oo
Ool0;7oo1000F7oo1@00H7oo000XOol00`00Ool00005Ool00`00Oomoo`0YOol3001QOol4001LOol0
02Uoo`03001oogoo00Aoo`03001oogoo02Eoo`@006Qoo`<005Uoo`00<7oo00<007ooOol08Goo1000
Kgoo1000EGoo000`Ool2000NOol4001gOol3001BOol0031oo`03001oogoo01Yoo`<007ioo`<004mo
o`00<7oo00<007ooOol067oo0P00Q7oo0`00C7oo000`Ool00`00Oomoo`0EOol30029Ool2001:Ool0
031oo`03001oogoo01=oo`8008ioo`<004Moo`00<7oo0P004Goo0`00Tgoo0`00A7oo000`Ool00`00
Oomoo`0>Ool2002IOol20012Ool0031oo`03001oogoo00aoo`8009eoo`<003moo`00<7oo00<007oo
Ool02Woo0P00XWoo0P00?Goo000`Ool00`00Oomoo`08Ool2002VOol2000kOol0031oo`03001oogoo
00Ioo`800:Yoo`8003Uoo`00<7oo0P001Goo0P00[Woo0P00=goo000`Ool00`00Oomoo`02Ool2002b
Ool2000eOol0031oo`03001oogoo00800;Ioo`8003=oo`00<7oo0`00^Woo00<007ooOol0<7oo000_
Ool2002mOol2000`Ool002eoo`800003Ool000000;ioo`03001oogoo02eoo`00:goo0P000goo00<0
07ooOol0_Woo00<007ooOol0;7oo000ZOol00`00Oomoo`03Ool00`00Oomoo`2oOol2000/Ool002Uo
o`03001oogoo00Aoo`03001oogoo0<5oo`03001oogoo02Uoo`009goo10001Goo00<007ooOol0`Woo
00<007ooOol0:7oo000VOol00`00Ool00007Ool00`00Oomoo`33Ool2000XOol002=oo`<000=oo`03
001oogoo00Aoo`800<Ioo`03001oogoo02Eoo`0097oo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol0aWoo00<007ooOol097oo000SOol00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`37
Ool2000TOol0025oo`8000Ioo`03001oogoo00Aoo`03001oogoo0<Uoo`03001oogoo025oo`0087oo
00<007ooOol03Goo00<007ooOol0bWoo00<007ooOol087oo000OOol00`00Oomoo`0>Ool2003<Ool0
0`00Oomoo`0OOol001ioo`03001oogoo00moo`03001oogoo0<aoo`8001moo`007Goo00<007ooOol0
47oo00<007ooOol0cWoo00<007ooOol077oo000LOol00`00Oomoo`0AOol00`00Oomoo`3?Ool00`00
Oomoo`0KOol001]oo`03001oogoo019oo`03001oogoo0=1oo`03001oogoo01Yoo`006Woo00<007oo
Ool04goo0P00dWoo00<007ooOol06Goo000IOol00`00Oomoo`0DOol00`00Oomoo`3BOol00`00Oomo
o`0HOol001Qoo`03001oogoo01Eoo`03001oogoo0==oo`03001oogoo01Moo`005goo00<007ooOol0
5Woo00<007ooOol0e7oo00<007ooOol05Woo000FOol00`00Oomoo`0GOol00`00Oomoo`3EOol00`00
Oomoo`0EOol001Eoo`03001oogoo01Qoo`03001oogoo0=Ioo`03001oogoo01Aoo`0057oo00<007oo
Ool06Goo0P00egoo00<007ooOol057oo000COol00`00Oomoo`0JOol00`00Oomoo`3GOol00`00Oomo
o`0COol001=oo`03001oogoo01Yoo`03001oogoo0=Qoo`03001oogoo019oo`004Woo00<007ooOol0
6goo00<007ooOol0f7oo00<007ooOol04Woo000BOol00`00Oomoo`0KOol00`00Oomoo`3IOol00`00
Oomoo`0AOol0015oo`03001oogoo01aoo`800=]oo`03001oogoo011oo`0047oo00<007ooOol07Goo
00<007ooOol0fWoo00<007ooOol047oo000@Ool00`00Oomoo`0MOol00`00Oomoo`3KOol00`00Oomo
o`0?Ool000moo`03001oogoo01Eoo`D000Aoo`03001oogoo0=aoo`03001oogoo00ioo`003goo00<0
07ooOol05goo00<007ooOol017oo00<007ooOol0g7oo00<007ooOol03Woo000>Ool00`00Oomoo`0B
Ool30003Ool00`00Oomoo`04Ool2003NOol00`00Oomoo`0=Ool000ioo`03001oogoo01Qoo`03001o
ogoo00Aoo`03001oogoo0=ioo`03001oogoo00aoo`003Goo00<007ooOol06Goo00<007ooOol017oo
00<007ooOol0gWoo00<007ooOol037oo000=Ool00`00Oomoo`0HOol20006Ool00`00Oomoo`3OOol0
0`00Oomoo`0;Ool000aoo`03001oogoo025oo`03001oogoo0=moo`03001oogoo00]oo`0037oo00<0
07ooOol08Goo00<007ooOol0h7oo00<007ooOol02Woo000;Ool00`00Oomoo`0ROol2003QOol00`00
Oomoo`0:Ool000]oo`03001oogoo029oo`03001oogoo0>1oo`03001oogoo00Yoo`002goo00<007oo
Ool08Woo00<007ooOol0hGoo00<007ooOol02Goo000:Ool00`00Oomoo`0SOol00`00Oomoo`3QOol0
0`00Oomoo`09Ool000Yoo`03001oogoo02=oo`03001oogoo0>5oo`03001oogoo00Uoo`002Woo00<0
07ooOol08goo0P00hgoo00<007ooOol027oo0009Ool00`00Oomoo`0TOol00`00Oomoo`3ROol00`00
Oomoo`08Ool000Uoo`03001oogoo02Aoo`03001oogoo0>9oo`03001oogoo00Qoo`0027oo00<007oo
Ool09Goo00<007ooOol0hgoo00<007ooOol01goo0008Ool00`00Oomoo`0UOol00`00Oomoo`0iOol3
000lOol3000iOol2000]Ool00`00Oomoo`07Ool000Qoo`03001oogoo02Eoo`8003Yoo`03001oogoo
03eoo`03001oogoo03Qoo`03001oo`0002aoo`03001oogoo00Moo`001goo00<007ooOol09Woo00<0
07ooOol0>Woo00<007ooOol0>Woo1000>Goo00<007oo0000;7oo00<007ooOol01goo0007Ool00`00
Oomoo`0VOol00`00Oomoo`0jOol00`00Oomoo`0jOol00`00Ool0000jOol2000^Ool00`00Oomoo`06
Ool000Moo`03001oogoo02Ioo`03001oogoo03Uoo`03001oo`0003aoo`8003Yoo`03001oogoo02eo
o`03001oogoo00Ioo`001goo00<007ooOol09Woo00<007ooOol0>Woo00<007ooOol0?7oo00<007oo
Ool0>Goo0P00;Goo00<007ooOol01Woo0007Ool00`00Oomoo`0VOol00`00Oomoo`3TOol00`00Oomo
o`06Ool000Moo`03001oogoo02Ioo`800>Eoo`03001oogoo00Ioo`001goo00<007ooOol09Woo00<0
07ooOol0i7oo00<007ooOol01Woo0007Ool00`00Oomoo`0VOol00`00Oomoo`3TOol00`00Oomoo`06
Ool000Moo`03001oogoo02Ioo`03001oogoo0>Aoo`03001oogoo00Ioo`001goo00<007ooOol09Woo
00<007ooOol0i7oo00<007ooOol01Woo003o000P0001Ool00003Ool007oo00Aoo`03001oogoo00Mo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00Ioo`001goo00<007ooOol09Woo00<007oo
Ool0>Woo00<007ooOol0>goo00<007ooOol0>goo00<007ooOol0:goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0VOol00`00Oomoo`3TOol00`00Oomoo`06Ool000Moo`03001oogoo02Ioo`03001oogoo
0>Aoo`03001oogoo00Ioo`001goo00<007ooOol09Woo0P00iGoo00<007ooOol01Woo0007Ool00`00
Oomoo`0VOol00`00Oomoo`3TOol00`00Oomoo`06Ool000Moo`03001oogoo02Ioo`03001oogoo0>Ao
o`03001oogoo00Ioo`001goo00<007ooOol09Woo00<007ooOol0i7oo00<007ooOol01Woo0007Ool0
0`00Oomoo`0VOol00`00Oomoo`3TOol00`00Oomoo`06Ool000Moo`03001oogoo02Ioo`03001oogoo
0>Aoo`03001oogoo00Ioo`0027oo00<007ooOol09Goo0P00i7oo00<007ooOol01goo0008Ool00`00
Oomoo`0UOol00`00Oomoo`3SOol00`00Oomoo`07Ool000Qoo`03001oogoo02Eoo`03001oogoo0>=o
o`03001oogoo00Moo`0027oo00<007ooOol09Goo00<007ooOol0hgoo00<007ooOol01goo0009Ool0
0`00Oomoo`0TOol00`00Oomoo`3ROol00`00Oomoo`08Ool000Uoo`03001oogoo02Aoo`800>=oo`03
001oogoo00Qoo`002Goo00<007ooOol097oo00<007ooOol0hWoo00<007ooOol027oo000:Ool00`00
Oomoo`0SOol00`00Oomoo`3QOol00`00Oomoo`09Ool000Yoo`03001oogoo02=oo`03001oogoo0>5o
o`03001oogoo00Uoo`002goo00<007ooOol08Woo00<007ooOol0hGoo00<007ooOol02Goo000;Ool0
0`00Oomoo`0ROol2003QOol00`00Oomoo`0:Ool000]oo`03001oogoo029oo`03001oogoo0>1oo`03
001oogoo00Yoo`0037oo00<007ooOol08Goo00<007ooOol0ggoo00<007ooOol02goo000<Ool00`00
Oomoo`0QOol00`00Oomoo`3OOol00`00Oomoo`0;Ool000eoo`03001oogoo01Moo`D000Aoo`03001o
ogoo0=ioo`03001oogoo00aoo`003Goo00<007ooOol06Goo00<007ooOol017oo00<007ooOol0gWoo
00<007ooOol037oo000>Ool00`00Oomoo`0HOol00`00Oomoo`04Ool2003NOol00`00Oomoo`0=Ool0
00ioo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00eoo`003goo00<0
07ooOol05goo00<007ooOol017oo00<007ooOol0g7oo00<007ooOol03Woo000?Ool00`00Oomoo`0F
Ool20006Ool00`00Oomoo`3KOol00`00Oomoo`0?Ool0011oo`03001oogoo01eoo`03001oogoo0=]o
o`03001oogoo00moo`004Goo00<007ooOol077oo0P00fgoo00<007ooOol047oo000BOol00`00Oomo
o`0KOol00`00Oomoo`3IOol00`00Oomoo`0AOol0019oo`03001oogoo01]oo`03001oogoo0=Uoo`03
001oogoo015oo`004goo00<007ooOol06Woo00<007ooOol0f7oo00<007ooOol04Woo000DOol00`00
Oomoo`0IOol00`00Oomoo`3GOol00`00Oomoo`0COol001Eoo`03001oogoo01Qoo`800=Moo`03001o
ogoo01Aoo`005Woo00<007ooOol05goo00<007ooOol0eWoo00<007ooOol057oo000FOol00`00Oomo
o`0GOol00`00Oomoo`3EOol00`00Oomoo`0EOol001Moo`03001oogoo01Ioo`03001oogoo0=Aoo`03
001oogoo01Ioo`0067oo00<007ooOol05Goo00<007ooOol0dgoo00<007ooOol05goo000IOol00`00
Oomoo`0DOol00`00Oomoo`3BOol00`00Oomoo`0HOol001Yoo`03001oogoo01=oo`800=9oo`03001o
ogoo01Uoo`006goo00<007ooOol04Woo00<007ooOol0d7oo00<007ooOol06Woo000LOol00`00Oomo
o`0AOol00`00Oomoo`3?Ool00`00Oomoo`0KOol001eoo`03001oogoo011oo`03001oogoo0<ioo`03
001oogoo01aoo`007Woo0P0047oo00<007ooOol0cGoo00<007ooOol07Goo000POol00`00Oomoo`0=
Ool2003=Ool00`00Oomoo`0NOol0025oo`03001oogoo00aoo`03001oogoo0<]oo`03001oogoo01mo
o`008Woo00<007ooOol02goo00<007ooOol0bWoo00<007ooOol087oo000SOol00`00Oomoo`0:Ool0
0`00Oomoo`39Ool00`00Oomoo`0QOol002Aoo`04001oogooOol30005Ool00`00Oomoo`37Ool2000T
Ool002Eoo`800003Ool007oo00Ioo`03001oogoo0<Ioo`03001oogoo02Aoo`009goo00<007oo0000
1Woo0P00aGoo0P009goo000XOol20006Ool00`00Oomoo`33Ool00`00Oomoo`0WOol002Qoo`04001o
o`000004Ool00`00Oomoo`31Ool2000ZOol002Uoo`04001oogoo0003Ool00`00Oomoo`30Ool00`00
Oomoo`0ZOol002eoo`800003Ool007oo0;moo`8002eoo`00;goo0`00_Woo00<007ooOol0;Goo000`
Ool2002lOol2000`Ool0031oo`03001oo`000;Yoo`03001oogoo031oo`00<7oo00<007ooOol00P00
]Woo0P00<goo000`Ool00`00Oomoo`02Ool2002bOol2000eOol0031oo`8000Eoo`800:ioo`8003Mo
o`00<7oo00<007ooOol01Woo00<007ooOol0ZGoo0P00>Goo000`Ool00`00Oomoo`07Ool2002WOol2
000kOol0031oo`03001oogoo00Uoo`800:=oo`8003eoo`00<7oo00<007ooOol02goo0P00Wgoo0P00
?goo000`Ool00`00Oomoo`0=Ool2002KOol20011Ool0031oo`80011oo`<009Ioo`8004=oo`00<7oo
00<007ooOol04Woo0P00TGoo0`00AGoo000`Ool00`00Oomoo`0DOol2002<Ool30018Ool0031oo`03
001oogoo01Ioo`<008Moo`8004]oo`00<7oo00<007ooOol06Goo1000P7oo0`00CGoo000`Ool2000N
Ool4001iOol3001@Ool0031oo`03001oogoo025oo`@0075oo`@005=oo`00<7oo00<007ooOol09Goo
1000JWoo0`00Egoo000XOol20006Ool00`00Oomoo`0YOol4001ROol4001JOol002Yoo`03001oogoo
00=oo`03001oogoo02eoo`<005Yoo`D005ioo`00:Goo00<007ooOol017oo0P00<Goo1000DGoo1@00
Hgoo000ZOol00`00Oomoo`03Ool00`00Oomoo`0dOol40019Ool4001XOol002Qoo`03001oo`0000Eo
o`03001oogoo03Qoo`L003eoo`D006aoo`00:Goo00<007ooOol017oo00<007ooOol0?goo300097oo
3@00LGoo000`Ool00`00Oomoo`1;OolT001nOol0031oo`03001oogoo0>eoo`00<7oo0P00kWoo000`
Ool00`00Oomoo`3]Ool0031oo`03001oogoo0>eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.55549, -3.30791, 
  0.0323608, 0.0373917}}],

Cell[OutputFormData["\<\
Graphics[{{Line[{{7.499999999999634, 4.851755903574053*^-7}, 
      {7.499953837016894, 0.01437385509651273}, {7.49983228572254, \
0.0274508929980874}, 
      {7.499597472503522, 0.04254552418152349}, {7.499282376475584, \
0.05681399354436718}, 
      {7.498498285900103, 0.08219034366466576}, {7.497323056541762, \
0.1097319075182296}, 
      {7.495638377890331, 0.1400570810745835}, {7.49340533135513, \
0.1721972832552636}, 
      {7.488245373099996, 0.2298325628766628}, {7.481364786923887, \
0.2892732996574523}, 
      {7.473484403444842, 0.3449029129520086}, {7.45035314558944, \
0.471326644166371}, 
      {7.41931130098721, 0.5998100508654406}, {7.384292748310524, \
0.716830858875329}, 
      {7.282120970397343, 0.977870772666138}, {7.166711037961146, \
1.201301860358714}, 
      {7.011990653029168, 1.4403326560594}, {6.820802191583472, \
1.679610928487543}, 
      {6.618580011026407, 1.889479249727068}, {6.121306295273011, \
2.287935560759533}, 
      {5.83126876797732, 2.467596404008049}, {5.481648119838996, \
2.646673074794757}, 
      {5.11757759899063, 2.797508610093881}, {4.675417706525257, \
2.939651093900344}, 
      {4.45651074803813, 2.995244373485142}, {4.210220982923166, \
3.047008565243496}, 
      {3.966281673724115, 3.08756647753876}, {3.733756614820659, \
3.116685172866112}, 
      {3.606810756705823, 3.128751142426373}, {3.468811166821998, \
3.138845545275991}, 
      {3.411162728004399, 3.142137970891119}, {3.348387209272206, \
3.145106452536196}, 
      {3.312150399166657, 3.146527965975166}, {3.278734425205602, \
3.147649674665325}, 
      {3.244179419504797, 3.148618927022819}, {3.212612128467084, \
3.149335081132059}, 
      {3.178003028722562, 3.14993468017631}, {3.140815156484458, \
3.150362785921385}, 
      {3.106160339540671, 3.150560209814307}, {3.073267658230897, \
3.150567767047669}, 
      {3.03467056687865, 3.150353300830905}, {2.998874765146998, \
3.149938814541429}, 
      {2.980084393922566, 3.149638155976072}, {2.959351192826701, \
3.149239990663103}, 
      {2.917240787795786, 3.148216652604496}, {2.837478176568954, \
3.145489420322253}, 
      {2.750696172175182, 3.141346968125188}, {2.667726768558523, \
3.136236512611692}, 
      {2.591013330553048, 3.130505934401299}, {2.439247126526639, \
3.116301355386443}, 
      {2.273974195357454, 3.096447559660075}, {1.966995169107228, \
3.04712088575351}, 
      {1.585168016534086, 2.962072954575932}, {1.223508377551273, \
2.855288963647616}, 
      {0.8395032071404999, 2.710545815689612}, {0.4745345127177492, \
2.538104477284848}, 
      {0.06427001274164778, 2.293983461157724}, {-0.3696092679712778, \
1.956544372250618}, 
      {-0.7377848337660162, 1.568559545227503}, {-0.9253011906558825, \
1.30792212138969}, 
      {-1.075406134856366, 1.04147601656724}, {-1.190052758641639, \
0.7688145776008852}, 
      {-1.24116810726267, 0.6055411552779713}, {-1.278246858872396, \
0.4497049129898332}, 
      {-1.301936460366368, 0.3105357477609931}, {-1.311606145516299, \
0.230390051960728}, 
      {-1.318088777725509, 0.1547905383212595}, {-1.322164963170612, \
0.07500408084820846}, 
      {-1.323413317140208, 0.001800958043033311}, {-1.322040374268506, \
-0.0785689619608223}, 
      {-1.317510445542904, -0.1628870046285334}, {-1.309698502236655, \
-0.2481893872024674}, 
      {-1.303891391143673, -0.2960156084573295}, {-1.297663469097243, \
-0.3398548469800084}, 
      {-1.266691083881809, -0.5035367343361086}, {-1.228916600870275, \
-0.6485330987382395}, 
      {-1.179883495944872, -0.7970330640646539}, {-1.052354925438976, \
-1.087246401021494}, 
      {-0.8814962720773602, -1.374319399618886}, {-0.5292714609493165, \
-1.80320672634473}, 
      {-0.1738528946586313, -2.120954806481823}, {0.2507744124252032, \
-2.412308177920581}, 
      {0.6474908830823448, -2.624314965101141}, {0.9911208752833196, \
-2.771678445705797}, 
      {1.357680670447381, -2.897874477329192}, {1.706154121298184, \
-2.991785844825327}, 
      {2.060801710849796, -3.063743409938691}, {2.213644240135803, \
-3.087840627106752}, 
      {2.375018157129324, -3.10892465836645}, {2.513260882969868, \
-3.123494087971229}, 
      {2.658073571080876, -3.135351712902976}, {2.738161871704119, \
-3.140428283248247}, 
      {2.810166818248407, -3.144097421765434}, {2.881766581422741, \
-3.146908738459554}, 
      {2.913712865317948, -3.147894349582908}, {2.948701423275986, \
-3.148783814076157}, 
      {2.98628471996469, -3.14951815510876}, {3.006757717599043, \
-3.149821901456099}, 
      {3.025868151703243, -3.150044179319392}, {3.059884335508619, \
-3.150293527719962}, 
      {3.096254740769635, -3.150352919897223}, {3.11649179851648, \
-3.150293235428256}, 
      {3.138496141526158, -3.150153079579025}, {3.159209018761502, \
-3.149949501919673}, 
      {3.178367647782805, -3.149699347756881}, {3.214378472975043, \
-3.149068292117893}, 
      {3.252518353477864, -3.148170811790083}, {3.329645932599298, \
-3.145634604265365}, 
      {3.411943467134618, -3.141861443485153}, {3.558259582434605, \
-3.132420542588144}, 
      {3.697244441560142, -3.120187555683842}, {3.822112232364179, \
-3.106453099027079}, 
      {4.067032855982986, -3.071827501029622}, {4.285728545888918, \
-3.03206208896898}, 
      {4.749229887352177, -2.918515117971231}, {5.163097779724565, \
-2.780153101397275}, 
      {5.505594256199015, -2.635270035401072}, {5.851029079438955, \
-2.456041044639317}, 
      {6.137726347593511, -2.276484393986817}, {6.622753009198827, \
-1.885188469364049}, 
      {6.833527549649639, -1.6647827424568}, {7.003856104247896, \
-1.451247386914887}, 
      {7.144036033187314, -1.239486247458402}, {7.265931252245051, \
-1.012214659760586}, 
      {7.365574841287628, -0.7713682519243122}, {7.432597162837131, \
-0.5480821848378853}, 
      {7.458183649847765, -0.4321142210525238}, {7.469641803975742, \
-0.3682463149871797}, 
      {7.478767401808912, -0.3078978838551931}, {7.485807083221134, \
-0.2515328667507508}, 
      {7.491829828317371, -0.1904081275671284}, {7.493958456747428, \
-0.1634030134050086}, 
      {7.495856974227397, -0.134818879852544}, {7.497204758416231, \
-0.110107232957955}, 
      {7.498349362371158, -0.08356858691117864}, {7.498750606128385, \
-0.07198799242975553}, 
      {7.499076187845761, -0.06099903188436451}, {7.499341572829065, \
-0.0503003594048774}, 
      {7.49954207447535, -0.04038553376078718}, {7.499691294995001, \
-0.0310223261711167}, 
      {7.499807281396927, -0.02105871555081055}, {7.499884323395219, \
-0.0100048133090618}, 
      {7.499907228444051, -4.848322561496615*^-7}}]}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ellipseM = ParametricPlot[{orbitM[t][[1]], orbitM[t][[2]]}, {t,0,t0}]\
\>", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"ellipseM\"
     is similar to existing symbol \"ellipsem\".\
\>", "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.833344 0.323814 0.309027 0.280247 [
[.02381 .29653 -12 -9 ]
[.02381 .29653 12 0 ]
[.18572 .29653 -6 -9 ]
[.18572 .29653 6 0 ]
[.34762 .29653 -12 -9 ]
[.34762 .29653 12 0 ]
[.50953 .29653 -6 -9 ]
[.50953 .29653 6 0 ]
[.67144 .29653 -12 -9 ]
[.67144 .29653 12 0 ]
[.99525 .29653 -9 -9 ]
[.99525 .29653 9 0 ]
[.82084 .02878 -12 -4.5 ]
[.82084 .02878 0 4.5 ]
[.82084 .1689 -24 -4.5 ]
[.82084 .1689 0 4.5 ]
[.82084 .44915 -18 -4.5 ]
[.82084 .44915 0 4.5 ]
[.82084 .58927 -6 -4.5 ]
[.82084 .58927 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30903 m
.02381 .31528 L
s
[(-2.5)] .02381 .29653 0 1 Mshowa
.18572 .30903 m
.18572 .31528 L
s
[(-2)] .18572 .29653 0 1 Mshowa
.34762 .30903 m
.34762 .31528 L
s
[(-1.5)] .34762 .29653 0 1 Mshowa
.50953 .30903 m
.50953 .31528 L
s
[(-1)] .50953 .29653 0 1 Mshowa
.67144 .30903 m
.67144 .31528 L
s
[(-0.5)] .67144 .29653 0 1 Mshowa
.99525 .30903 m
.99525 .31528 L
s
[(0.5)] .99525 .29653 0 1 Mshowa
.125 Mabswid
.05619 .30903 m
.05619 .31278 L
s
.08857 .30903 m
.08857 .31278 L
s
.12095 .30903 m
.12095 .31278 L
s
.15334 .30903 m
.15334 .31278 L
s
.2181 .30903 m
.2181 .31278 L
s
.25048 .30903 m
.25048 .31278 L
s
.28286 .30903 m
.28286 .31278 L
s
.31524 .30903 m
.31524 .31278 L
s
.38 .30903 m
.38 .31278 L
s
.41239 .30903 m
.41239 .31278 L
s
.44477 .30903 m
.44477 .31278 L
s
.47715 .30903 m
.47715 .31278 L
s
.54191 .30903 m
.54191 .31278 L
s
.57429 .30903 m
.57429 .31278 L
s
.60667 .30903 m
.60667 .31278 L
s
.63906 .30903 m
.63906 .31278 L
s
.70382 .30903 m
.70382 .31278 L
s
.7362 .30903 m
.7362 .31278 L
s
.76858 .30903 m
.76858 .31278 L
s
.80096 .30903 m
.80096 .31278 L
s
.86573 .30903 m
.86573 .31278 L
s
.89811 .30903 m
.89811 .31278 L
s
.93049 .30903 m
.93049 .31278 L
s
.96287 .30903 m
.96287 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.83334 .02878 m
.83959 .02878 L
s
[(-1)] .82084 .02878 1 0 Mshowa
.83334 .1689 m
.83959 .1689 L
s
[(-0.5)] .82084 .1689 1 0 Mshowa
.83334 .44915 m
.83959 .44915 L
s
[(0.5)] .82084 .44915 1 0 Mshowa
.83334 .58927 m
.83959 .58927 L
s
[(1)] .82084 .58927 1 0 Mshowa
.125 Mabswid
.83334 .05681 m
.83709 .05681 L
s
.83334 .08483 m
.83709 .08483 L
s
.83334 .11285 m
.83709 .11285 L
s
.83334 .14088 m
.83709 .14088 L
s
.83334 .19693 m
.83709 .19693 L
s
.83334 .22495 m
.83709 .22495 L
s
.83334 .25298 m
.83709 .25298 L
s
.83334 .281 m
.83709 .281 L
s
.83334 .33705 m
.83709 .33705 L
s
.83334 .36508 m
.83709 .36508 L
s
.83334 .3931 m
.83709 .3931 L
s
.83334 .42113 m
.83709 .42113 L
s
.83334 .47717 m
.83709 .47717 L
s
.83334 .5052 m
.83709 .5052 L
s
.83334 .53322 m
.83709 .53322 L
s
.83334 .56125 m
.83709 .56125 L
s
.83334 .00076 m
.83709 .00076 L
s
.83334 .6173 m
.83709 .6173 L
s
.25 Mabswid
.83334 0 m
.83334 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30903 m
.02381 .30768 L
.02383 .30646 L
.02385 .30505 L
.02389 .30372 L
.02397 .30135 L
.0241 .29878 L
.02428 .29594 L
.02452 .29294 L
.02508 .28756 L
.02582 .282 L
.02667 .27681 L
.02917 .265 L
.03252 .253 L
.0363 .24206 L
.04733 .21768 L
.05978 .19681 L
.07648 .17448 L
.09712 .15213 L
.11895 .13252 L
.17262 .0953 L
.20393 .07852 L
.24167 .06179 L
.28096 .0477 L
.32869 .03442 L
.35232 .02922 L
.3789 .02439 L
.40523 .0206 L
.43033 .01788 L
.44403 .01675 L
.45893 .01581 L
.46515 .0155 L
.47193 .01523 L
.47584 .01509 L
.47944 .01499 L
.48317 .0149 L
.48658 .01483 L
.49032 .01477 L
.49433 .01473 L
.49807 .01472 L
.50162 .01472 L
.50579 .01474 L
.50965 .01477 L
.51168 .0148 L
.51392 .01484 L
.51846 .01493 L
.52707 .01519 L
.53644 .01558 L
.5454 .01605 L
.55368 .01659 L
Mistroke
.57006 .01792 L
.5879 .01977 L
.62103 .02438 L
.66224 .03232 L
.70128 .0423 L
.74273 .05582 L
.78212 .07193 L
.82641 .09473 L
.87324 .12626 L
.91298 .1625 L
.93322 .18685 L
.94942 .21174 L
.9618 .23721 L
.96731 .25246 L
.97132 .26702 L
.97387 .28002 L
.97492 .28751 L
.97562 .29457 L
.97606 .30202 L
.97619 .30886 L
.97604 .31637 L
.97555 .32424 L
.97471 .33221 L
.97408 .33668 L
.97341 .34077 L
.97007 .35607 L
.96599 .36961 L
.9607 .38348 L
.94693 .41059 L
.92849 .43741 L
.89047 .47747 L
.85211 .50716 L
.80628 .53437 L
.76346 .55418 L
.72636 .56794 L
.6868 .57973 L
.64919 .58851 L
.61091 .59523 L
.59441 .59748 L
.57699 .59945 L
.56207 .60081 L
.54644 .60192 L
.53779 .60239 L
.53002 .60273 L
.52229 .603 L
.51884 .60309 L
.51507 .60317 L
.51101 .60324 L
.5088 .60327 L
.50674 .60329 L
Mistroke
.50307 .60331 L
.49914 .60332 L
.49696 .60331 L
.49458 .6033 L
.49235 .60328 L
.49028 .60326 L
.48639 .6032 L
.48227 .60312 L
.47395 .60288 L
.46507 .60253 L
.44927 .60164 L
.43427 .6005 L
.42079 .59922 L
.39436 .59598 L
.37075 .59227 L
.32072 .58166 L
.27605 .56874 L
.23908 .5552 L
.2018 .53846 L
.17085 .52169 L
.1185 .48513 L
.09575 .46454 L
.07736 .4446 L
.06223 .42481 L
.04907 .40358 L
.03832 .38108 L
.03108 .36023 L
.02832 .34939 L
.02709 .34343 L
.0261 .33779 L
.02534 .33252 L
.02469 .32681 L
.02446 .32429 L
.02426 .32162 L
.02411 .31931 L
.02399 .31683 L
.02394 .31575 L
.02391 .31473 L
.02388 .31373 L
.02386 .3128 L
.02384 .31192 L
.02383 .31099 L
.02382 .30996 L
.02382 .30903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00jGoo00<007ooOol0=7oo003YOol2000eOol00>Uoo`03001oogoo03Aoo`00jGoo
00<007ooOol0=7oo0029Ool:001FOol00`00Oomoo`0dOol007Qooa4000Yooa4004Eoo`03001oogoo
03Aoo`00LGoo1`00;7oo1`00=Woo1@000goo00<007ooOol0=7oo001ZOol7000jOol7000aOol00`00
Oomoo`03Ool00`00Oomoo`0dOol006Aoo`H004Qoo`H002Eoo`<000=oo`03001oogoo00=oo`<003Ao
o`00HGoo0`00E7oo10009goo00<007ooOol00goo00<007ooOol0=7oo001MOol4001KOol4000SOol0
0`00Oomoo`03Ool00`00Oomoo`0dOol005Uoo`@006=oo`@001ioo`8000Eoo`03001oogoo03Aoo`00
EGoo1000Jgoo0`008Woo00<007ooOol0=7oo001AOol4001bOol3000OOol00`00Oomoo`0dOol004io
o`<007Uoo`8001eoo`03001oogoo03Aoo`00C7oo0P00OWoo0`006Woo00<007ooOol0=7oo0019Ool3
0023Ool3000GOol2000eOol004Moo`8008Uoo`<001Aoo`03001oogoo03Aoo`00AGoo0P00SWoo0P00
4Woo00<007ooOol0=7oo0013Ool2002BOol3000?Ool00`00Oomoo`0dOol0045oo`8009Moo`8000eo
o`03001oogoo03Aoo`00?goo0P00Vgoo0P002goo00<007ooOol0=7oo000mOol2002OOol20009Ool0
0`00Oomoo`0dOol003]oo`800:=oo`8000Moo`03001oogoo03Aoo`00>Goo0P00Ygoo0P001Goo0P00
=Goo000gOol2002[Ool20003Ool00`00Oomoo`0dOol003Eoo`800:moo`800003Ool007oo03Eoo`00
=7oo00<007ooOol0/Goo0P00=Woo000bOol2002eOol2000eOol0035oo`03001oogoo0;Eoo`04001o
o`00000cOol0031oo`03001oogoo0;Ioo`05001oogooOol0000bOol002ioo`800;Uoo`8000=oo`03
001oogoo02moo`00;Goo00<007ooOol0^Goo00<007ooOol00goo0P00;goo000[Ool2002lOol00`00
Oomoo`05Ool00`00Oomoo`0/Ool002Yoo`03001oogoo0;aoo`03001oogoo00Ioo`8002aoo`00:Goo
00<007ooOol0_Goo00<007ooOol027oo00<007ooOol0:Goo000WOol20030Ool00`00Oomoo`09Ool0
0`00Oomoo`0XOol002Ioo`03001oogoo0<1oo`03001oogoo00Yoo`03001oogoo02Moo`009Goo00<0
07ooOol0`Goo00<007ooOol02goo00<007ooOol09Woo000TOol00`00Oomoo`32Ool2000=Ool00`00
Oomoo`0UOol0029oo`800<Eoo`03001oogoo00eoo`8002Eoo`008Goo00<007ooOol0aGoo00<007oo
Ool03goo00<007ooOol08Woo000POol00`00Oomoo`36Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol0
01moo`03001oogoo0<Moo`03001oogoo015oo`03001oogoo021oo`007Woo00<007ooOol0b7oo00<0
07ooOol04Woo00<007ooOol07goo000MOol00`00Oomoo`2iOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`0NOol001aoo`03001oogoo0;Uoo`03001o
o`0000Moo`03001oo`0000Aoo`03001oogoo01Aoo`03001oogoo01eoo`006goo00<007ooOol0]Goo
0`000Woo00<007oo00002Goo00<007ooOol00Woo0`005Goo00<007ooOol077oo000JOol00`00Oomo
o`2kOol00`00Ool00007Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`0KOol001Uoo`03001oogoo
0;aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo01]oo`0067oo00<0
07ooOol0_Woo00<007ooOol01Woo0`0017oo00<007ooOol05goo00<007ooOol06Woo000GOol00`00
Oomoo`3?Ool00`00Oomoo`0HOol00`00Oomoo`0IOol001Moo`03001oogoo0<moo`03001oogoo01Uo
o`03001oogoo01Qoo`005Woo00<007ooOol0d7oo00<007ooOol06Woo00<007ooOol05goo000EOol0
0`00Oomoo`3AOol2000KOol00`00Oomoo`0GOol001Aoo`03001oogoo0=9oo`03001oogoo01]oo`03
001oogoo01Ioo`0057oo00<007ooOol0dWoo00<007ooOol077oo00<007ooOol05Goo000COol00`00
Oomoo`3COol00`00Oomoo`0LOol00`00Oomoo`0EOol001=oo`03001oogoo0==oo`03001oogoo01eo
o`03001oogoo01Aoo`004Woo00<007ooOol0e7oo00<007ooOol07Goo00<007ooOol057oo000BOol0
0`00Oomoo`3DOol00`00Oomoo`0NOol00`00Oomoo`0COol0019oo`03001oogoo0=Aoo`03001oogoo
01ioo`03001oogoo01=oo`004Goo00<007ooOol0eGoo0P0087oo00<007ooOol04Woo000AOol00`00
Oomoo`3EOol00`00Oomoo`0OOol00`00Oomoo`0BOol0011oo`03001oogoo0=Ioo`03001oogoo021o
o`03001oogoo015oo`0047oo00<007ooOol0eWoo00<007ooOol087oo00<007ooOol04Goo000?Ool0
0`00Oomoo`3GOol00`00Oomoo`0POol00`00Oomoo`0AOol000moo`03001oogoo0=Moo`03001oogoo
025oo`03001oogoo011oo`003goo00<007ooOol0egoo00<007ooOol08Goo00<007ooOol047oo000>
Ool00`00Oomoo`3HOol00`00Oomoo`0ROol00`00Oomoo`0?Ool000ioo`03001oogoo0=Qoo`8002=o
o`03001oogoo00moo`003Woo00<007ooOol0f7oo00<007ooOol08Woo00<007ooOol03goo000=Ool0
0`00Oomoo`3IOol00`00Oomoo`0SOol00`00Oomoo`0>Ool000eoo`03001oogoo0=Uoo`03001oogoo
02=oo`03001oogoo00ioo`0027oo0`000Woo0P0017oo00<007ooOol08goo0`008goo1@000Woo00<0
07ooOol00Woo00<007ooOol08goo1@0097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
8Woo00<007ooOol08goo0P0017oo00<007ooOol00Woo00<007ooOol00goo0008Ool01@00Oomoogoo
00001Goo00<007oo000097oo00<007ooOol09Goo00<007ooOol01Woo00<007oo00009Woo00<007oo
Ool08goo00<007oo00001goo00<007oo00008goo00<007ooOol08goo00<007oo00001goo00<007oo
000017oo0003Ool30003Ool01000Oomoo`001goo00<007ooOol07Goo0`000goo00<007ooOol07Woo
0`000goo00<007ooOol027oo00<007ooOol07Woo0`000goo00<007ooOol07Woo0`000Woo00<007oo
00002Goo00<007ooOol08Goo00<007ooOol08goo0`002Goo00<007ooOol00Woo0009Ool01000Oomo
o`001Goo0P009Woo00<007ooOol097oo00<007ooOol01Woo0P009goo00<007ooOol08goo00<007oo
00001goo0P0097oo0P0097oo0`001goo0P001Goo0008Ool01@00Ool007oo00001Goo00<007ooOol0
97oo00<007oo00009Goo00<007ooOol01Woo00<007ooOol09Woo00<007ooOol08goo00<007oo0000
1goo00<007ooOol08goo00<007ooOol08goo0`001goo00<007ooOol017oo0009Ool01000Oomoo`00
1Goo0`009Goo00<007ooOol08goo0P0027oo0`009Goo0P009Woo00<007ooOol01Woo0`008goo00<0
07ooOol097oo00<007ooOol01Woo0`0017oo000<Ool00`00Oomoo`3JOol00`00Oomoo`0TOol00`00
Oomoo`0=Ool000aoo`03001oogoo0=Yoo`03001oogoo02Aoo`03001oogoo00eoo`0037oo00<007oo
Ool0fWoo00<007ooOol097oo00<007ooOol03Goo000<Ool00`00Oomoo`3JOol00`00Oomoo`0TOol0
0`00Oomoo`0=Ool000aoo`03001oogoo0=Yoo`03001oogoo02Aoo`03001oogoo00eoo`001Gooo`00
500027oo000<Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
1000Oomoo`001Goo00<007ooOol01goo000<Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomo
o`0ZOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0TOol00`00Oomoo`03Ool00`00Oomo
o`07Ool000aoo`03001oogoo0=Yoo`03001oogoo02Aoo`03001oogoo00eoo`0037oo00<007ooOol0
fWoo00<007ooOol097oo00<007ooOol03Goo000<Ool00`00Oomoo`3JOol00`00Oomoo`0TOol00`00
Oomoo`0=Ool000aoo`03001oogoo0=Yoo`03001oogoo02Aoo`03001oogoo00eoo`0037oo00<007oo
Ool0fWoo00<007ooOol097oo00<007ooOol03Goo000<Ool00`00Oomoo`3JOol2000UOol00`00Oomo
o`0=Ool000aoo`03001oogoo0=Yoo`03001oogoo02Aoo`03001oogoo00eoo`003Goo00<007ooOol0
fGoo00<007ooOol097oo00<007ooOol03Goo000=Ool00`00Oomoo`3IOol00`00Oomoo`0SOol00`00
Oomoo`0>Ool000eoo`03001oogoo0=Uoo`03001oogoo02=oo`03001oogoo00ioo`003Goo00<007oo
Ool0fGoo00<007ooOol08goo00<007ooOol03Woo000=Ool00`00Oomoo`3IOol00`00Oomoo`0ROol0
0`00Oomoo`0?Ool000eoo`03001oogoo0=Uoo`8002=oo`03001oogoo00moo`003Woo00<007ooOol0
f7oo00<007ooOol08Goo00<007ooOol047oo000>Ool00`00Oomoo`3HOol00`00Oomoo`0QOol00`00
Oomoo`0@Ool000ioo`03001oogoo0=Qoo`03001oogoo025oo`03001oogoo011oo`003goo00<007oo
Ool0egoo00<007ooOol087oo00<007ooOol04Goo000?Ool00`00Oomoo`3GOol00`00Oomoo`0POol0
0`00Oomoo`0AOol0011oo`03001oogoo0=Ioo`03001oogoo01moo`03001oogoo019oo`0047oo00<0
07ooOol0eWoo00<007ooOol07goo00<007ooOol04Woo000AOol00`00Oomoo`3EOol2000OOol00`00
Oomoo`0COol0015oo`03001oogoo0=Eoo`03001oogoo01ioo`03001oogoo01=oo`004Woo00<007oo
Ool0e7oo00<007ooOol07Goo00<007ooOol057oo000BOol00`00Oomoo`3DOol00`00Oomoo`0MOol0
0`00Oomoo`0DOol001=oo`03001oogoo0==oo`03001oogoo01aoo`03001oogoo01Eoo`004goo00<0
07ooOol0dgoo00<007ooOol077oo00<007ooOol05Goo000DOol00`00Oomoo`3BOol00`00Oomoo`0K
Ool00`00Oomoo`0FOol001Eoo`03001oogoo0=5oo`03001oogoo01]oo`03001oogoo01Ioo`005Goo
00<007ooOol0dGoo0P006goo00<007ooOol05goo000FOol00`00Oomoo`3@Ool00`00Oomoo`0IOol0
0`00Oomoo`0HOol001Moo`03001oogoo0<moo`03001oogoo01Qoo`03001oogoo01Uoo`0067oo00<0
07ooOol0cWoo00<007ooOol067oo00<007ooOol06Goo000HOol00`00Oomoo`3>Ool00`00Oomoo`0G
Ool00`00Oomoo`0JOol001Uoo`03001oogoo0;eoo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo01Ioo`03001oogoo01]oo`006Woo00<007ooOol0^goo00<007oo00001goo
00<007oo000017oo00<007ooOol05Goo00<007ooOol077oo000KOol00`00Oomoo`2jOol00`00Ool0
0009Ool00`00Oomoo`02Ool3000DOol00`00Oomoo`0MOol001aoo`03001oogoo0;Uoo`03001oo`00
00Moo`8000Eoo`03001oogoo01=oo`03001oogoo01ioo`007Goo00<007ooOol0^7oo00<007oo0000
1goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol07goo000MOol00`00Oomoo`2iOol00`00
Oomoo`06Ool30004Ool00`00Oomoo`0BOol00`00Oomoo`0OOol001ioo`03001oogoo0<Qoo`03001o
ogoo015oo`03001oogoo021oo`007goo00<007ooOol0agoo00<007ooOol047oo00<007ooOol08Goo
000POol00`00Oomoo`36Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol0025oo`03001oogoo0<Eoo`03
001oogoo00ioo`03001oogoo02=oo`008Woo0P00aGoo0P003Woo00<007ooOol097oo000TOol00`00
Oomoo`32Ool00`00Oomoo`0;Ool2000WOol002Eoo`03001oogoo0<5oo`03001oogoo00Yoo`03001o
ogoo02Moo`009Woo0P00`Goo00<007ooOol02Goo00<007ooOol0:7oo000XOol00`00Oomoo`2nOol0
0`00Oomoo`07Ool2000[Ool002Uoo`800;ioo`03001oogoo00Ioo`03001oogoo02]oo`00:goo00<0
07ooOol0^goo00<007ooOol01Goo00<007ooOol0;7oo000/Ool2002kOol00`00Oomoo`03Ool2000_
Ool002ioo`03001oogoo0;Qoo`8000=oo`03001oogoo02moo`00;goo0P00^7oo00<007ooOol00P00
<Woo000aOol00`00Oomoo`2eOol00`00Ool0000dOol0039oo`800;Eoo`8003Eoo`00=7oo00<007oo
Ool0/Goo0P00=Woo000eOol2002_Ool200000goo001oo`0eOol003Moo`03001oogoo0:]oo`05001o
ogooOol0000fOol003Qoo`800:Uoo`8000Aoo`8003Eoo`00>Woo0P00YGoo0P001Woo00<007ooOol0
=7oo000lOol2002QOol20008Ool00`00Oomoo`0dOol003ioo`8009eoo`8000Yoo`03001oogoo03Ao
o`00@7oo0`00Ugoo0`0037oo00<007ooOol0=7oo0013Ool2002COol2000?Ool00`00Oomoo`0dOol0
04Eoo`<008eoo`<0015oo`03001oogoo03Aoo`00B7oo0`00R7oo0P0057oo00<007ooOol0=7oo001;
Ool20023Ool3000FOol2000eOol004eoo`<007ioo`8001Uoo`03001oogoo03Aoo`00D7oo0`00N7oo
0`006goo00<007ooOol0=7oo001COol3001aOol4000NOol00`00Oomoo`0dOol005Ioo`<006Yoo`@0
029oo`03001oogoo03Aoo`00FGoo0`00I7oo0`009Woo00<007ooOol0=7oo001LOol4001MOol3000Q
Ool50003Ool00`00Oomoo`0dOol0061oo`@005Eoo`@002Ioo`03001oogoo00=oo`03001oogoo03Ao
o`00I7oo1@00BGoo1`00:Woo00<007ooOol00goo0`00=7oo001YOol5000mOol7000aOol00`00Oomo
o`03Ool00`00Oomoo`0dOol006ioo``002aoo`D003Qoo`03001oogoo00=oo`03001oogoo03Aoo`00
NWoo3P003Woo4000?7oo0P001Goo00<007ooOol0=7oo0028Ool>001COol00`00Oomoo`0dOol00>Uo
o`03001oogoo03Aoo`00jGoo00<007ooOol0=7oo003YOol2000eOol00>Uoo`03001oogoo03Aoo`00
ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.63535, -1.15293, 
  0.0112783, 0.0130316}}],

Cell[OutputFormData["\<\
Graphics[{{Line[{{-2.499999999999877, -1.617251967858017*^-7}, 
      {-2.499984612338964, -0.004791285032170911}, 
      {-2.499944095240846, -0.009150297666029134}, {-2.49986582416784, \
-0.01418184139384116}, 
      {-2.499760792158528, -0.01893799784812239}, {-2.499499428633367, \
-0.02739678122155525}, 
      {-2.49910768551392, -0.03657730250607654}, {-2.498546125963443, \
-0.04668569369152785}, 
      {-2.497801777118377, -0.05739909441842121}, {-2.496081791033331, \
-0.07661085429222094}, 
      {-2.493788262307962, -0.09642443321915081}, {-2.491161467814947, \
-0.1149676376506695}, 
      {-2.483451048529813, -0.1571088813887903}, {-2.473103766995736, \
-0.1999366836218135}, 
      {-2.461430916103508, -0.2389436196251097}, {-2.427373656799114, \
-0.325956924222046}, 
      {-2.388903679320382, -0.4004339534529048}, {-2.337330217676389, \
-0.4801108853531336}, 
      {-2.273600730527824, -0.5598703094958477}, {-2.206193337008802, \
-0.6298264165756894}, 
      {-2.04043543175767, -0.7626451869198447}, {-1.94375625599244, \
-0.8225321346693498}, 
      {-1.827216039946332, -0.8822243582649191}, {-1.705859199663543, \
-0.9325028700312937}, 
      {-1.558472568841752, -0.9798836979667814}, {-1.485503582679377, \
-0.9984147911617142}, 
      {-1.403406994307722, -1.015669521747832}, {-1.322093891241371, \
-1.029188825846253}, 
      {-1.244585538273553, -1.038895057622037}, {-1.202270252235274, \
-1.042917047475457}, 
      {-1.156270388940666, -1.04628184842533}, {-1.137054242668133, \
-1.047379323630373}, 
      {-1.116129069757402, -1.048368817512065}, {-1.104050133055552, \
-1.048842655325055}, 
      {-1.092911475068534, -1.049216558221775}, {-1.081393139834932, \
-1.049539642340939}, 
      {-1.070870709489028, -1.049778360377352}, {-1.05933434290752, \
-1.049978226725436}, 
      {-1.046938385494819, -1.050120928640461}, {-1.03538677984689, \
-1.050186736604769}, 
      {-1.024422552743632, -1.050189255682556}, {-1.011556855626216, \
-1.050117766943635}, 
      {-0.9996249217156661, -1.049979604847143}, {-0.9933614646408553, \
-1.049879385325357}, 
      {-0.9864503976089002, -1.049746663554367}, {-0.9724135959319289, \
-1.049405550868165}, 
      {-0.9458260588563183, -1.048496473440751}, {-0.9168987240583941, \
-1.047115656041729}, 
      {-0.8892422561861742, -1.045412170870564}, {-0.8636711101843495, \
-1.043501978133766}, 
      {-0.8130823755088798, -1.038767118462147}, {-0.7579913984524847, \
-1.032149186553358}, 
      {-0.655665056369076, -1.015706961917836}, {-0.5283893388446955, \
-0.9873576515253107}, 
      {-0.4078361258504245, -0.9517629878825388}, {-0.2798344023801666, \
-0.9035152718965376}, 
      {-0.1581781709059163, -0.8460348257616161}, {-0.02142333758054926, \
-0.7646611537192415}, 
      {0.1232030893237592, -0.6521814574168728}, {0.2459282779220054, \
-0.5228531817425011}, 
      {0.3084337302186275, -0.4359740404632303}, {0.3584687116187887, \
-0.34715867218908}, 
      {0.3966842528805463, -0.2562715258669617}, {0.41372270242089, \
-0.2018470517593237}, 
      {0.426082286290799, -0.1499016376632777}, {0.4339788201221227, \
-0.103511915920331}, 
      {0.4372020485054333, -0.07679668398690936}, {0.4393629259085029, \
-0.05159684610708651}, 
      {0.4407216543902042, -0.02500136028273614}, 
      {0.4411377723800696, -0.0006003193476777703}, {0.4406801247561689, \
0.02618965398694077}, 
      {0.4391701485143014, 0.05429566820951116}, {0.4365661674122184, \
0.08272979573415582}, 
      {0.4346304637145578, 0.09867186948577653}, {0.4325544896990811, \
0.1132849489933361}, 
      {0.4222303612939363, 0.1678455781120362}, {0.4096388669567585, \
0.2161776995794132}, 
      {0.3932944986482909, 0.2656776880215513}, {0.3507849751463255, \
0.3624154670071649}, 
      {0.2938320906924534, 0.4581064665396286}, {0.1764238203164388, \
0.6010689087815769}, 
      {0.05795096488621044, 0.7069849354939411}, {-0.08359147080840108, \
0.8041027259735271}, 
      {-0.2158302943607815, 0.8747716550337136}, {-0.3303736250944399, \
0.9238928152352656}, 
      {-0.4525602234824605, 0.965958159109731}, {-0.5687180404327282, \
0.9972619482751092}, 
      {-0.6869339036165986, 1.021247803312897}, {-0.7378814133786012, \
1.029280209035584}, 
      {-0.791672719043108, 1.036308219455483}, {-0.8377536276566228, \
1.041164695990409}, 
      {-0.8860245236936254, 1.045117237634325}, {-0.9127206239013732, \
1.046809427749415}, 
      {-0.936722272749469, 1.048032473921811}, {-0.9605888604742471, \
1.048969579486518}, 
      {-0.9712376217726493, 1.049298116527636}, {-0.9829004744253289, \
1.049594604692052}, 
      {-0.9954282399882304, 1.049839385036253}, {-1.002252572533014, \
1.049940633818699}, 
      {-1.008622717234414, 1.050014726439797}, {-1.019961445169539, \
1.05009784257332}, 
      {-1.032084913589878, 1.050117639965741}, {-1.038830599505493, \
1.050097745142752}, 
      {-1.046165380508719, 1.050051026526341}, {-1.0530696729205, \
1.049983167306557}, 
      {-1.059455882594268, 1.049899782585627}, {-1.071459490991681, \
1.049689430705964}, 
      {-1.084172784492621, 1.049390270596694}, {-1.109881977533099, \
1.048544868088455}, 
      {-1.137314489044872, 1.047287147828384}, {-1.186086527478201, \
1.044140180862714}, 
      {-1.23241481385338, 1.04006251856128}, {-1.274037410788059, \
1.035484366342359}, 
      {-1.355677618660995, 1.023942500343207}, {-1.428576181962972, \
1.01068736298966}, 
      {-1.583076629117392, 0.972838372657077}, {-1.721032593241521, \
0.9267177004657584}, 
      {-1.835198085399671, 0.8784233451336907}, {-1.950343026479652, \
0.8186803482131058}, 
      {-2.04590878253117, 0.7588281313289391}, {-2.207584336399609, \
0.628396156454683}, 
      {-2.277842516549879, 0.5549275808189334}, {-2.334618701415965, \
0.4837491289716291}, 
      {-2.381345344395771, 0.413162082486134}, {-2.421977084081683, \
0.3374048865868622}, 
      {-2.455191613762542, 0.2571227506414373}, {-2.477532387612377, \
0.1826940616126284}, 
      {-2.486061216615921, 0.1440380736841746}, {-2.489880601325247, \
0.1227487716623932}, 
      {-2.492922467269637, 0.102632627951731}, {-2.495269027740377, \
0.08384428891691696}, 
      {-2.497276609439123, 0.06346937585570948}, {-2.497986152249142, \
0.05446767113500287}, 
      {-2.498618991409132, 0.04493962661751468}, {-2.49906825280541, \
0.03670241098598501}, 
      {-2.499449787457052, 0.02785619563705954}, {-2.499583535376128, \
0.02399599747658518}, 
      {-2.499692062615253, 0.0203330106281215}, {-2.499780524276355, \
0.01676678646829246}, 
      {-2.499847358158449, 0.01346184458692906}, {-2.499897098331667, \
0.01034077539037223}, 
      {-2.499935760465642, 0.007019571850270184}, {-2.499961441131739, \
0.003334937769687267}, 
      {-2.499969076148017, 1.616107520498871*^-7}}]}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ellipses = Show[ellipsem,ellipseM]", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"ellipses\"
     is similar to existing symbol \"ellipsem\".\
\>", "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0952381 0.309007 0.0934155 [
[.07143 .29651 -6 -9 ]
[.07143 .29651 6 0 ]
[.45238 .29651 -3 -9 ]
[.45238 .29651 3 0 ]
[.64286 .29651 -3 -9 ]
[.64286 .29651 3 0 ]
[.83333 .29651 -3 -9 ]
[.83333 .29651 3 0 ]
[.2494 .02876 -12 -4.5 ]
[.2494 .02876 0 4.5 ]
[.2494 .12218 -12 -4.5 ]
[.2494 .12218 0 4.5 ]
[.2494 .21559 -12 -4.5 ]
[.2494 .21559 0 4.5 ]
[.2494 .40242 -6 -4.5 ]
[.2494 .40242 0 4.5 ]
[.2494 .49584 -6 -4.5 ]
[.2494 .49584 0 4.5 ]
[.2494 .58925 -6 -4.5 ]
[.2494 .58925 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.07143 .30901 m
.07143 .31526 L
s
[(-2)] .07143 .29651 0 1 Mshowa
.45238 .30901 m
.45238 .31526 L
s
[(2)] .45238 .29651 0 1 Mshowa
.64286 .30901 m
.64286 .31526 L
s
[(4)] .64286 .29651 0 1 Mshowa
.83333 .30901 m
.83333 .31526 L
s
[(6)] .83333 .29651 0 1 Mshowa
.125 Mabswid
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.21429 .30901 m
.21429 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.40476 .30901 m
.40476 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.59524 .30901 m
.59524 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.78571 .30901 m
.78571 .31276 L
s
.02381 .30901 m
.02381 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.97619 .30901 m
.97619 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.2619 .02876 m
.26815 .02876 L
s
[(-3)] .2494 .02876 1 0 Mshowa
.2619 .12218 m
.26815 .12218 L
s
[(-2)] .2494 .12218 1 0 Mshowa
.2619 .21559 m
.26815 .21559 L
s
[(-1)] .2494 .21559 1 0 Mshowa
.2619 .40242 m
.26815 .40242 L
s
[(1)] .2494 .40242 1 0 Mshowa
.2619 .49584 m
.26815 .49584 L
s
[(2)] .2494 .49584 1 0 Mshowa
.2619 .58925 m
.26815 .58925 L
s
[(3)] .2494 .58925 1 0 Mshowa
.125 Mabswid
.2619 .04744 m
.26565 .04744 L
s
.2619 .06613 m
.26565 .06613 L
s
.2619 .08481 m
.26565 .08481 L
s
.2619 .10349 m
.26565 .10349 L
s
.2619 .14086 m
.26565 .14086 L
s
.2619 .15954 m
.26565 .15954 L
s
.2619 .17823 m
.26565 .17823 L
s
.2619 .19691 m
.26565 .19691 L
s
.2619 .23427 m
.26565 .23427 L
s
.2619 .25296 m
.26565 .25296 L
s
.2619 .27164 m
.26565 .27164 L
s
.2619 .29032 m
.26565 .29032 L
s
.2619 .32769 m
.26565 .32769 L
s
.2619 .34637 m
.26565 .34637 L
s
.2619 .36506 m
.26565 .36506 L
s
.2619 .38374 m
.26565 .38374 L
s
.2619 .42111 m
.26565 .42111 L
s
.2619 .43979 m
.26565 .43979 L
s
.2619 .45847 m
.26565 .45847 L
s
.2619 .47715 m
.26565 .47715 L
s
.2619 .51452 m
.26565 .51452 L
s
.2619 .5332 m
.26565 .5332 L
s
.2619 .55189 m
.26565 .55189 L
s
.2619 .57057 m
.26565 .57057 L
s
.2619 .01008 m
.26565 .01008 L
s
.2619 .60794 m
.26565 .60794 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .30901 m
.97619 .31035 L
.97617 .31157 L
.97615 .31298 L
.97612 .31431 L
.97605 .31668 L
.97594 .31926 L
.97578 .32209 L
.97556 .32509 L
.97507 .33048 L
.97442 .33603 L
.97367 .34123 L
.97146 .35304 L
.96851 .36504 L
.96517 .37597 L
.95544 .40036 L
.94445 .42123 L
.92971 .44356 L
.9115 .46591 L
.89225 .48551 L
.84489 .52274 L
.81726 .53952 L
.78397 .55625 L
.74929 .57034 L
.70718 .58362 L
.68633 .58881 L
.66288 .59364 L
.63965 .59743 L
.6175 .60015 L
.60541 .60128 L
.59227 .60222 L
.58678 .60253 L
.5808 .60281 L
.57735 .60294 L
.57417 .60305 L
.57087 .60314 L
.56787 .6032 L
.56457 .60326 L
.56103 .6033 L
.55773 .60332 L
.5546 .60332 L
.55092 .6033 L
.54751 .60326 L
.54572 .60323 L
.54375 .60319 L
.53974 .6031 L
.53214 .60284 L
.52388 .60246 L
.51597 .60198 L
.50867 .60144 L
Mistroke
.49421 .60012 L
.47847 .59826 L
.44924 .59366 L
.41287 .58571 L
.37843 .57574 L
.34186 .56221 L
.3071 .54611 L
.26803 .5233 L
.2267 .49178 L
.19164 .45553 L
.17378 .43119 L
.15949 .4063 L
.14857 .38083 L
.1437 .36557 L
.14017 .35102 L
.13791 .33802 L
.13699 .33053 L
.13637 .32347 L
.13598 .31601 L
.13587 .30918 L
.136 .30167 L
.13643 .29379 L
.13717 .28582 L
.13772 .28135 L
.13832 .27726 L
.14127 .26197 L
.14487 .24842 L
.14953 .23455 L
.16168 .20744 L
.17795 .18062 L
.2115 .14056 L
.24535 .11088 L
.28579 .08366 L
.32357 .06386 L
.3563 .05009 L
.39121 .0383 L
.4244 .02953 L
.45817 .02281 L
.47273 .02055 L
.4881 .01859 L
.50126 .01722 L
.51505 .01612 L
.52268 .01564 L
.52954 .0153 L
.53636 .01504 L
.5394 .01494 L
.54273 .01486 L
.54631 .01479 L
.54826 .01476 L
.55008 .01474 L
Mistroke
.55332 .01472 L
.55679 .01472 L
.55871 .01472 L
.56081 .01473 L
.56278 .01475 L
.56461 .01478 L
.56804 .01484 L
.57167 .01492 L
.57901 .01516 L
.58685 .01551 L
.60079 .01639 L
.61402 .01753 L
.62592 .01882 L
.64924 .02205 L
.67007 .02577 L
.71421 .03637 L
.75363 .0493 L
.78625 .06283 L
.81915 .07957 L
.84645 .09635 L
.89264 .1329 L
.91272 .15349 L
.92894 .17344 L
.94229 .19322 L
.9539 .21445 L
.96339 .23695 L
.96977 .25781 L
.97221 .26864 L
.9733 .27461 L
.97417 .28024 L
.97484 .28551 L
.97541 .29122 L
.97562 .29374 L
.9758 .29641 L
.97592 .29872 L
.97603 .3012 L
.97607 .30228 L
.9761 .30331 L
.97613 .30431 L
.97615 .30523 L
.97616 .30611 L
.97617 .30704 L
.97618 .30807 L
.97618 .30901 L
Mfstroke
.02381 .30901 m
.02381 .30856 L
.02381 .30815 L
.02382 .30768 L
.02383 .30724 L
.02386 .30645 L
.02389 .30559 L
.02395 .30465 L
.02402 .30364 L
.02418 .30185 L
.0244 .3 L
.02465 .29827 L
.02539 .29433 L
.02637 .29033 L
.02748 .28669 L
.03073 .27856 L
.03439 .2716 L
.0393 .26416 L
.04537 .25671 L
.05179 .25017 L
.06758 .23776 L
.07679 .23217 L
.08788 .22659 L
.09944 .2219 L
.11348 .21747 L
.12043 .21574 L
.12825 .21413 L
.13599 .21286 L
.14337 .21196 L
.1474 .21158 L
.15178 .21127 L
.15361 .21117 L
.15561 .21107 L
.15676 .21103 L
.15782 .21099 L
.15891 .21096 L
.15992 .21094 L
.16102 .21092 L
.1622 .21091 L
.1633 .2109 L
.16434 .2109 L
.16557 .21091 L
.1667 .21092 L
.1673 .21093 L
.16796 .21094 L
.16929 .21098 L
.17183 .21106 L
.17458 .21119 L
.17722 .21135 L
.17965 .21153 L
Mistroke
.18447 .21197 L
.18972 .21259 L
.19946 .21412 L
.21158 .21677 L
.22306 .2201 L
.23525 .2246 L
.24684 .22997 L
.25986 .23758 L
.27364 .24808 L
.28533 .26016 L
.29128 .26828 L
.29604 .27658 L
.29968 .28507 L
.30131 .29015 L
.30248 .295 L
.30324 .29934 L
.30354 .30183 L
.30375 .30419 L
.30388 .30667 L
.30392 .30895 L
.30387 .31145 L
.30373 .31408 L
.30348 .31674 L
.3033 .31822 L
.3031 .31959 L
.30212 .32469 L
.30092 .3292 L
.29936 .33383 L
.29531 .34286 L
.28989 .3518 L
.27871 .36516 L
.26742 .37505 L
.25394 .38412 L
.24135 .39072 L
.23044 .39531 L
.2188 .39924 L
.20774 .40217 L
.19648 .40441 L
.19163 .40516 L
.18651 .40581 L
.18212 .40627 L
.17752 .40664 L
.17498 .4068 L
.17269 .40691 L
.17042 .407 L
.16941 .40703 L
.1683 .40706 L
.1671 .40708 L
.16645 .40709 L
.16585 .40709 L
Mistroke
.16477 .4071 L
.16361 .4071 L
.16297 .4071 L
.16227 .4071 L
.16161 .40709 L
.161 .40708 L
.15986 .40706 L
.15865 .40704 L
.1562 .40696 L
.15359 .40684 L
.14894 .40655 L
.14453 .40616 L
.14057 .40574 L
.13279 .40466 L
.12585 .40342 L
.11114 .39989 L
.098 .39558 L
.08712 .39107 L
.07616 .38548 L
.06706 .37989 L
.05166 .36771 L
.04497 .36085 L
.03956 .3542 L
.03511 .3476 L
.03124 .34053 L
.02808 .33303 L
.02595 .32607 L
.02514 .32246 L
.02477 .32047 L
.02448 .31859 L
.02426 .31684 L
.02407 .31494 L
.024 .3141 L
.02394 .31321 L
.0239 .31244 L
.02386 .31161 L
.02385 .31125 L
.02384 .31091 L
.02383 .31057 L
.02382 .31026 L
.02382 .30997 L
.02382 .30966 L
.02381 .30932 L
.02381 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OBgoo00<007ooOol0
dWoo001;Ool00`00Oomoo`3BOol004]oo`800==oo`00Bgoo00<007ooOol0dWoo001;Ool00`00Oomo
o`10OolP001bOol004]oo`03001oogoo03Qoo`P0021oo`T006Uoo`00@goo0P001Woo00<007ooOol0
<goo1@00<Goo1P00Hgoo0015Ool00`00Oomoo`03Ool00`00Oomoo`0^Ool5000lOol5001NOol003io
o`<000=oo`03001oogoo00Aoo`<002Yoo`@004Ioo`@005Yoo`00AGoo00<007ooOol00goo00<007oo
Ool09goo0`00CWoo1000EWoo0013Ool00`00Ool00005Ool00`00Oomoo`0TOol3001EOol4001BOol0
04Aoo`03001oogoo00Aoo`03001oogoo025oo`<005aoo`<004moo`00Bgoo00<007ooOol07Woo0`00
HWoo0`00C7oo001;Ool2000KOol4001XOol30019Ool004]oo`03001oogoo01Moo`<006moo`<004Io
o`00Bgoo00<007ooOol05Goo0P00MGoo0P00A7oo001;Ool00`00Oomoo`0BOol3001iOol20012Ool0
04]oo`03001oogoo011oo`8007ioo`80041oo`00Bgoo0P003goo0P00PWoo0`00?Goo001;Ool00`00
Oomoo`0<Ool20027Ool2000kOol004]oo`03001oogoo00Yoo`8008]oo`8003Uoo`00Bgoo00<007oo
Ool02Goo00<007ooOol0SGoo0P00=goo001;Ool00`00Oomoo`07Ool2002BOol2000eOol004]oo`03
001oogoo00Eoo`8009Ioo`8003=oo`00Bgoo0P001Goo00<007ooOol0V7oo00<007ooOol0<7oo001;
Ool00`00Oomoo`02Ool2002LOol2000`Ool004]oo`03001oogoo00800:1oo`8002ioo`00Bgoo00<0
07oo0000Y7oo00<007ooOol0:goo001;Ool2002VOol00`00Oomoo`0ZOol004Uoo`@00:Moo`03001o
ogoo02Uoo`00Agoo0P000Woo00<007ooOol0Ygoo0P00:Goo0016Ool00`00Oomoo`02Ool00`00Oomo
o`2YOol00`00Oomoo`0VOol004Eoo`03001oogoo00=oo`03001oogoo0:Yoo`03001oogoo02Eoo`00
@goo0`001Goo00<007ooOol0Zgoo00<007ooOol097oo0013Ool00`00Oomoo`05Ool00`00Oomoo`2/
Ool00`00Oomoo`0SOol003ioo`<00004Ool007oo0006Ool3002]Ool2000SOol0041oo`80009oo`03
001oogoo00Aoo`03001oogoo0:moo`03001oogoo021oo`00?goo00L007ooOomoo`00Ool00005Ool0
0`00Oomoo`2`Ool00`00Oomoo`0OOol003ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
0;5oo`03001oogoo01ioo`00?Goo00<007ooOol02goo00<007ooOol0/Woo00<007ooOol07Goo000l
Ool00`00Oomoo`0<Ool2002dOol00`00Oomoo`0LOol003]oo`03001oogoo00eoo`03001oogoo0;Ao
o`03001oogoo01]oo`00>Woo00<007ooOol03Woo00<007ooOol0]Goo00<007ooOol06Woo000jOol0
0`00Oomoo`0>Ool00`00Oomoo`2fOol00`00Oomoo`0IOol003Uoo`03001oogoo00moo`03001oogoo
0;Moo`03001oogoo01Qoo`00>7oo00<007ooOol047oo0P00^Goo00<007ooOol05goo000gOol00`00
Oomoo`0AOol00`00Oomoo`2iOol00`00Oomoo`0FOol003Ioo`03001oogoo019oo`03001oogoo0;Yo
o`03001oogoo01Eoo`00=Goo00<007ooOol04goo00<007ooOol0^goo00<007ooOol057oo000eOol0
0`00Oomoo`0COol00`00Oomoo`2lOol00`00Oomoo`0COol003Aoo`03001oogoo01Aoo`03001oogoo
0;eoo`03001oogoo019oo`00<goo00<007ooOol05Goo0P00_Woo00<007ooOol04Woo000bOol00`00
Oomoo`0FOol00`00Oomoo`2nOol00`00Oomoo`0AOol0039oo`03001oogoo01Ioo`03001oogoo0;mo
o`03001oogoo011oo`00<Goo00<007ooOol05goo00<007ooOol0_goo00<007ooOol047oo000`Ool0
0`00Oomoo`0HOol00`00Oomoo`30Ool00`00Oomoo`0?Ool0031oo`03001oogoo01Qoo`800<9oo`03
001oogoo00ioo`00;goo00<007ooOol06Goo00<007ooOol0`Goo00<007ooOol03Woo000_Ool00`00
Oomoo`0IOol00`00Oomoo`32Ool00`00Oomoo`0=Ool002ioo`03001oogoo015oo`D000Aoo`03001o
ogoo0<9oo`03001oogoo00eoo`00:Goo3`0037oo00<007ooOol017oo00<007ooOol0`goo00<007oo
Ool037oo000ROol70004Ool00`00Oomoo`08Ool30003Ool30003Ool00`00Oomoo`04Ool30033Ool0
0`00Oomoo`0<Ool001moo`<000]oo`03001oogoo00]oo`<000Ioo`03001oogoo00Aoo`03001oogoo
0<Aoo`03001oogoo00]oo`006goo10003Goo00<007ooOol03goo10000Woo00<007ooOol017oo00<0
07ooOol0a7oo00<007ooOol02goo000IOol2000AOol00`00Oomoo`0COol30006Ool00`00Oomoo`35
Ool00`00Oomoo`0:Ool001Moo`8001=oo`03001oogoo01Ioo`<000=oo`03001oogoo0<Eoo`03001o
ogoo00Yoo`005Woo00<007ooOol04Woo00<007ooOol06Woo00@007ooOol00<Qoo`03001oogoo00Uo
o`0057oo0P005Goo00<007ooOol06goo00@007oo00000<Moo`03001oogoo00Uoo`004goo00<007oo
Ool057oo00<007ooOol07Goo0P00b7oo00<007ooOol02Goo000BOol00`00Oomoo`0EOol00`00Oomo
o`0NOol00`00Oomoo`36Ool00`00Oomoo`09Ool0011oo`8001Moo`03001oogoo01moo`<00<Moo`03
001oogoo00Qoo`003goo00<007ooOol05goo00<007ooOol07goo00@007ooOol00<Ioo`03001oogoo
00Qoo`003Woo00<007ooOol067oo00<007ooOol07goo0P000Woo00<007ooOol0`goo00<007ooOol0
27oo000=Ool00`00Oomoo`0HOol00`00Oomoo`0POol00`00Oomoo`02Ool20033Ool00`00Oomoo`08
Ool000aoo`03001oogoo01Uoo`03001oogoo021oo`03001oogoo00Aoo`03001oogoo0<1oo`03001o
ogoo00Qoo`002goo00<007ooOol06Woo00<007ooOol087oo00<007ooOol01Goo00<007ooOol0`7oo
00<007ooOol01goo000:Ool00`00Oomoo`08Ool3000@Ool00`00Oomoo`0POol00`00Oomoo`05Ool0
0`00Oomoo`0ZOol3000dOol3000cOol2000WOol00`00Oomoo`07Ool000Yoo`03001oogoo00Qoo`03
001oogoo00moo`03001oogoo025oo`8000Moo`03001oogoo02Uoo`03001oogoo03Eoo`03001oogoo
039oo`03001oo`0002Moo`03001oogoo00Ioo`002Goo00<007ooOol017oo0`000goo00<007ooOol0
3Woo00<007ooOol08Goo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol0<Woo1000<goo00<0
07oo00009goo00<007ooOol01Woo0009Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0Q
Ool00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`0bOol00`00Ool0000dOol2000XOol00`00
Oomoo`06Ool000Uoo`03001oogoo00Uoo`03001oo`0000moo`03001oogoo025oo`03001oogoo00Qo
o`03001oogoo02Moo`03001oo`0003Aoo`8003Aoo`03001oogoo02Moo`03001oogoo00Ioo`0027oo
00<007ooOol02goo00<007ooOol03Woo00<007ooOol08Goo00<007ooOol027oo00<007ooOol0:7oo
00<007ooOol0=7oo00<007ooOol0<goo0P009goo00<007ooOol01Woo0008Ool00`00Oomoo`0LOol0
0`00Oomoo`0QOol00`00Oomoo`08Ool00`00Oomoo`2nOol00`00Oomoo`06Ool000Moo`03001oogoo
01eoo`03001oogoo025oo`8000Uoo`03001oogoo0;ioo`03001oogoo00Ioo`001goo00<007ooOol0
7Goo00<007ooOol08Goo00<007ooOol027oo00<007ooOol0_Woo00<007ooOol01Woo0007Ool00`00
Oomoo`0MOol00`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`2mOol00`00Oomoo`06Ool000Mo
o`03001oogoo01eoo`03001oogoo025oo`03001oogoo00Uoo`03001oogoo0;eoo`03001oogoo00Io
o`001goo00<007ooOol07Goo00<007ooOol08Goo00<007ooOol02Goo00<007ooOol0_Goo00<007oo
Ool01Woo003o000P0001Ool000Moo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uoo`8000eoo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`001goo00<007ooOol02Woo00<0
07ooOol047oo00<007ooOol08Goo00<007ooOol02Goo00<007ooOol09goo00<007ooOol0=7oo00<0
07ooOol0<goo00<007ooOol09Woo00<007ooOol01Woo0007Ool00`00Oomoo`0MOol00`00Oomoo`0Q
Ool00`00Oomoo`09Ool00`00Oomoo`2mOol00`00Oomoo`06Ool000Moo`03001oogoo01eoo`03001o
ogoo025oo`03001oogoo00Qoo`03001oogoo0;ioo`03001oogoo00Ioo`001goo00<007ooOol07Goo
00<007ooOol08Goo0P002Goo00<007ooOol0_Woo00<007ooOol01Woo0008Ool00`00Oomoo`0LOol0
0`00Oomoo`0QOol00`00Oomoo`08Ool00`00Oomoo`2nOol00`00Oomoo`06Ool000Qoo`03001oogoo
01aoo`03001oogoo025oo`03001oogoo00Qoo`03001oogoo0;ioo`03001oogoo00Ioo`002Goo00<0
07ooOol06goo00<007ooOol08Goo00<007ooOol01goo00<007ooOol0_goo00<007ooOol01Woo0009
Ool00`00Oomoo`0KOol00`00Oomoo`0QOol00`00Oomoo`07Ool00`00Oomoo`2oOol00`00Oomoo`06
Ool000Yoo`03001oogoo01]oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo0<1oo`03001o
ogoo00Ioo`002Woo00<007ooOol06goo00<007ooOol087oo0P001Woo00<007ooOol0`7oo00<007oo
Ool01goo000;Ool00`00Oomoo`0JOol00`00Oomoo`0POol00`00Oomoo`05Ool00`00Oomoo`30Ool0
0`00Oomoo`07Ool000]oo`03001oogoo01Yoo`03001oogoo021oo`03001oogoo00Aoo`03001oogoo
0<5oo`03001oogoo00Moo`0037oo00<007ooOol06Woo00<007ooOol07goo00<007ooOol00goo00<0
07ooOol0`Woo00<007ooOol01goo000=Ool00`00Oomoo`0IOol00`00Oomoo`0OOol00`00Oomoo`03
Ool00`00Oomoo`31Ool00`00Oomoo`08Ool000ioo`03001oogoo01Qoo`03001oogoo01moo`8000=o
o`03001oogoo0<9oo`03001oogoo00Qoo`003goo00<007ooOol05goo00<007ooOol07goo00D007oo
Oomoo`000<Eoo`03001oogoo00Qoo`0047oo00<007ooOol05Woo00<007ooOol07goo00@007oo0000
0<Eoo`03001oogoo00Uoo`004Goo0P005goo00<007ooOol07Woo0P00agoo00<007ooOol02Goo000C
Ool00`00Oomoo`0DOol00`00Oomoo`0NOol00`00Oomoo`36Ool00`00Oomoo`09Ool001Aoo`8001Ao
o`03001oogoo01eoo`<00<Ioo`03001oogoo00Yoo`005Woo00<007ooOol04Woo00<007ooOol06Woo
0P0000=oo`00Ool0aWoo00<007ooOol02Woo000GOol2000BOol00`00Oomoo`0GOol30003Ool00`00
Oomoo`34Ool00`00Oomoo`0;Ool001Uoo`80015oo`03001oogoo01Aoo`8000Ioo`03001oogoo0<Ao
o`03001oogoo00]oo`006goo0`003Woo00<007ooOol04Woo1P0017oo00<007ooOol0`goo00<007oo
Ool037oo000NOol4000;Ool00`00Oomoo`0=Ool40003Ool00`00Oomoo`04Ool00`00Oomoo`33Ool0
0`00Oomoo`0<Ool0029oo`D000Ioo`03001oogoo00Qoo`D000Moo`03001oogoo00Aoo`<00<9oo`03
001oogoo00eoo`009goo4@0037oo00<007ooOol017oo00<007ooOol0`Woo00<007ooOol03Goo000_
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`31Ool00`00Oomoo`0>Ool002moo`03001o
ogoo015oo`8000Ioo`03001oogoo0<5oo`03001oogoo00ioo`00<7oo00<007ooOol067oo00<007oo
Ool0`7oo00<007ooOol03goo000`Ool00`00Oomoo`0HOol20031Ool00`00Oomoo`0?Ool0035oo`03
001oogoo01Moo`03001oogoo0;moo`03001oogoo011oo`00<Goo00<007ooOol05goo00<007ooOol0
_goo00<007ooOol047oo000bOol00`00Oomoo`0FOol00`00Oomoo`2nOol00`00Oomoo`0AOol003=o
o`03001oogoo01Eoo`03001oogoo0;ioo`03001oogoo015oo`00<goo00<007ooOol05Goo0P00_Woo
00<007ooOol04Woo000dOol00`00Oomoo`0DOol00`00Oomoo`2mOol00`00Oomoo`0BOol003Eoo`03
001oogoo01=oo`03001oogoo0;aoo`03001oogoo01=oo`00=Woo00<007ooOol04Woo00<007ooOol0
^goo00<007ooOol057oo000fOol00`00Oomoo`0BOol00`00Oomoo`2jOol00`00Oomoo`0EOol003Mo
o`03001oogoo015oo`03001oogoo0;Uoo`03001oogoo01Ioo`00>7oo00<007ooOol047oo0P00^Woo
00<007ooOol05Woo000iOol00`00Oomoo`0?Ool00`00Oomoo`2hOol00`00Oomoo`0GOol003Yoo`03
001oogoo00ioo`03001oogoo0;Moo`03001oogoo01Qoo`00>goo00<007ooOol03Goo00<007ooOol0
]Woo00<007ooOol06Goo000lOol00`00Oomoo`0<Ool00`00Oomoo`2eOol00`00Oomoo`0JOol003eo
o`03001oogoo00]oo`800;Eoo`03001oogoo01]oo`00?Woo00<007ooOol02Woo00<007ooOol0/goo
00<007ooOol077oo000oOol00`00Oomoo`09Ool00`00Oomoo`2bOol00`00Oomoo`0MOol0041oo`03
001oogoo00Qoo`03001oogoo0;5oo`03001oogoo01ioo`00@Goo00<007oo00000P001Goo00<007oo
Ool0/7oo00<007ooOol07goo0012Ool20007Ool00`00Oomoo`2^Ool2000ROol004=oo`8000Ioo`<0
0:eoo`03001oogoo029oo`00A7oo0P001Goo00<007ooOol0[7oo00<007ooOol08goo0013Ool01000
Ool0000017oo00<007ooOol0ZWoo0P009Woo0014Ool00`00Oomoo`020002Ool00`00Oomoo`2YOol0
0`00Oomoo`0VOol004Uoo`03001oo`000:Yoo`03001oogoo02Moo`00BWoo0`00Ygoo0P00:Woo001;
Ool2002VOol00`00Oomoo`0ZOol004]oo`03001oo`000:Aoo`03001oogoo02]oo`00Bgoo00<007oo
Ool00P00X7oo0P00;Woo001;Ool00`00Oomoo`02Ool00`00Oomoo`2LOol00`00Oomoo`0^Ool004]o
o`8000Aoo`8009Yoo`80035oo`00Bgoo00<007ooOol01Goo0P00UWoo0P00<goo001;Ool00`00Oomo
o`07Ool00`00Oomoo`2BOol00`00Oomoo`0cOol004]oo`03001oogoo00Qoo`80091oo`8003Ioo`00
Bgoo00<007ooOol02Woo00<007ooOol0Rgoo0P00>7oo001;Ool00`00Oomoo`0;Ool20029Ool2000j
Ool004]oo`8000ioo`8008Eoo`8003aoo`00Bgoo00<007ooOol03goo0P00P7oo0`00?Woo001;Ool0
0`00Oomoo`0AOol2001lOol20011Ool004]oo`03001oogoo01=oo`<007Ioo`<004=oo`00Bgoo00<0
07ooOol05Woo0`00LGoo0P00AWoo001;Ool2000JOol4001ZOol30018Ool004]oo`03001oogoo01eo
o`<006Aoo`<004]oo`00Bgoo00<007ooOol087oo0`00GWoo0`00CWoo0013Ool20006Ool00`00Oomo
o`0SOol4001GOol3001AOol004Eoo`03001oogoo00=oo`03001oogoo02Moo`<0051oo`@005Aoo`00
A7oo00<007ooOol017oo0`00:Woo0`00B7oo1@00F7oo0015Ool00`00Oomoo`03Ool00`00Oomoo`0]
Ool40011Ool3001MOol004=oo`03001oo`0000Eoo`03001oogoo035oo`H003Ioo`D0061oo`00A7oo
00<007ooOol017oo00<007ooOol0=goo2P008Goo2`00IGoo001;Ool00`00Oomoo`11OolQ001`Ool0
04]oo`03001oogoo0=9oo`00Bgoo0P00dgoo001;Ool00`00Oomoo`3BOol004]oo`03001oogoo0=9o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.76302, -3.30791, 
  0.0366761, 0.0373917}}],

Cell[OutputFormData["\<\
Graphics[{{{Line[{{7.499999999999634, 4.851755903574053*^-7}, 
       {7.499953837016894, 0.01437385509651273}, {7.49983228572254, \
0.0274508929980874}, 
       {7.499597472503522, 0.04254552418152349}, {7.499282376475584, \
0.05681399354436718}, 
       {7.498498285900103, 0.08219034366466576}, {7.497323056541762, \
0.1097319075182296}, 
       {7.495638377890331, 0.1400570810745835}, {7.49340533135513, \
0.1721972832552636}, 
       {7.488245373099996, 0.2298325628766628}, {7.481364786923887, \
0.2892732996574523}, 
       {7.473484403444842, 0.3449029129520086}, {7.45035314558944, \
0.471326644166371}, 
       {7.41931130098721, 0.5998100508654406}, {7.384292748310524, \
0.716830858875329}, 
       {7.282120970397343, 0.977870772666138}, {7.166711037961146, \
1.201301860358714}, 
       {7.011990653029168, 1.4403326560594}, {6.820802191583472, \
1.679610928487543}, 
       {6.618580011026407, 1.889479249727068}, {6.121306295273011, \
2.287935560759533}, 
       {5.83126876797732, 2.467596404008049}, {5.481648119838996, \
2.646673074794757}, 
       {5.11757759899063, 2.797508610093881}, {4.675417706525257, \
2.939651093900344}, 
       {4.45651074803813, 2.995244373485142}, {4.210220982923166, \
3.047008565243496}, 
       {3.966281673724115, 3.08756647753876}, {3.733756614820659, \
3.116685172866112}, 
       {3.606810756705823, 3.128751142426373}, {3.468811166821998, \
3.138845545275991}, 
       {3.411162728004399, 3.142137970891119}, {3.348387209272206, \
3.145106452536196}, 
       {3.312150399166657, 3.146527965975166}, {3.278734425205602, \
3.147649674665325}, 
       {3.244179419504797, 3.148618927022819}, {3.212612128467084, \
3.149335081132059}, 
       {3.178003028722562, 3.14993468017631}, {3.140815156484458, \
3.150362785921385}, 
       {3.106160339540671, 3.150560209814307}, {3.073267658230897, \
3.150567767047669}, 
       {3.03467056687865, 3.150353300830905}, {2.998874765146998, \
3.149938814541429}, 
       {2.980084393922566, 3.149638155976072}, {2.959351192826701, \
3.149239990663103}, 
       {2.917240787795786, 3.148216652604496}, {2.837478176568954, \
3.145489420322253}, 
       {2.750696172175182, 3.141346968125188}, {2.667726768558523, \
3.136236512611692}, 
       {2.591013330553048, 3.130505934401299}, {2.439247126526639, \
3.116301355386443}, 
       {2.273974195357454, 3.096447559660075}, {1.966995169107228, \
3.04712088575351}, 
       {1.585168016534086, 2.962072954575932}, {1.223508377551273, \
2.855288963647616}, 
       {0.8395032071404999, 2.710545815689612}, {0.4745345127177492, \
2.538104477284848}, 
       {0.06427001274164778, 2.293983461157724}, {-0.3696092679712778, \
1.956544372250618}, 
       {-0.7377848337660162, 1.568559545227503}, {-0.9253011906558825, \
1.30792212138969}, 
       {-1.075406134856366, 1.04147601656724}, {-1.190052758641639, \
0.7688145776008852}, 
       {-1.24116810726267, 0.6055411552779713}, {-1.278246858872396, \
0.4497049129898332}, 
       {-1.301936460366368, 0.3105357477609931}, {-1.311606145516299, \
0.230390051960728}, 
       {-1.318088777725509, 0.1547905383212595}, {-1.322164963170612, \
0.07500408084820846}, 
       {-1.323413317140208, 0.001800958043033311}, {-1.322040374268506, \
-0.0785689619608223}, 
       {-1.317510445542904, -0.1628870046285334}, {-1.309698502236655, \
-0.2481893872024674}, 
       {-1.303891391143673, -0.2960156084573295}, {-1.297663469097243, \
-0.3398548469800084}, 
       {-1.266691083881809, -0.5035367343361086}, {-1.228916600870275, \
-0.6485330987382395}, 
       {-1.179883495944872, -0.7970330640646539}, {-1.052354925438976, \
-1.087246401021494}, 
       {-0.8814962720773602, -1.374319399618886}, {-0.5292714609493165, \
-1.80320672634473}, 
       {-0.1738528946586313, -2.120954806481823}, {0.2507744124252032, \
-2.412308177920581}, 
       {0.6474908830823448, -2.624314965101141}, {0.9911208752833196, \
-2.771678445705797}, 
       {1.357680670447381, -2.897874477329192}, {1.706154121298184, \
-2.991785844825327}, 
       {2.060801710849796, -3.063743409938691}, {2.213644240135803, \
-3.087840627106752}, 
       {2.375018157129324, -3.10892465836645}, {2.513260882969868, \
-3.123494087971229}, 
       {2.658073571080876, -3.135351712902976}, {2.738161871704119, \
-3.140428283248247}, 
       {2.810166818248407, -3.144097421765434}, {2.881766581422741, \
-3.146908738459554}, 
       {2.913712865317948, -3.147894349582908}, {2.948701423275986, \
-3.148783814076157}, 
       {2.98628471996469, -3.14951815510876}, {3.006757717599043, \
-3.149821901456099}, 
       {3.025868151703243, -3.150044179319392}, {3.059884335508619, \
-3.150293527719962}, 
       {3.096254740769635, -3.150352919897223}, {3.11649179851648, \
-3.150293235428256}, 
       {3.138496141526158, -3.150153079579025}, {3.159209018761502, \
-3.149949501919673}, 
       {3.178367647782805, -3.149699347756881}, {3.214378472975043, \
-3.149068292117893}, 
       {3.252518353477864, -3.148170811790083}, {3.329645932599298, \
-3.145634604265365}, 
       {3.411943467134618, -3.141861443485153}, {3.558259582434605, \
-3.132420542588144}, 
       {3.697244441560142, -3.120187555683842}, {3.822112232364179, \
-3.106453099027079}, 
       {4.067032855982986, -3.071827501029622}, {4.285728545888918, \
-3.03206208896898}, 
       {4.749229887352177, -2.918515117971231}, {5.163097779724565, \
-2.780153101397275}, 
       {5.505594256199015, -2.635270035401072}, {5.851029079438955, \
-2.456041044639317}, 
       {6.137726347593511, -2.276484393986817}, {6.622753009198827, \
-1.885188469364049}, 
       {6.833527549649639, -1.6647827424568}, {7.003856104247896, \
-1.451247386914887}, 
       {7.144036033187314, -1.239486247458402}, {7.265931252245051, \
-1.012214659760586}, 
       {7.365574841287628, -0.7713682519243122}, {7.432597162837131, \
-0.5480821848378853}, 
       {7.458183649847765, -0.4321142210525238}, {7.469641803975742, \
-0.3682463149871797}, 
       {7.478767401808912, -0.3078978838551931}, {7.485807083221134, \
-0.2515328667507508}, 
       {7.491829828317371, -0.1904081275671284}, {7.493958456747428, \
-0.1634030134050086}, 
       {7.495856974227397, -0.134818879852544}, {7.497204758416231, \
-0.110107232957955}, 
       {7.498349362371158, -0.08356858691117864}, {7.498750606128385, \
-0.07198799242975553}, 
       {7.499076187845761, -0.06099903188436451}, {7.499341572829065, \
-0.0503003594048774}, 
       {7.49954207447535, -0.04038553376078718}, {7.499691294995001, \
-0.0310223261711167}, 
       {7.499807281396927, -0.02105871555081055}, {7.499884323395219, \
-0.0100048133090618}, 
       {7.499907228444051, -4.848322561496615*^-7}}]}}, 
   {{Line[{{-2.499999999999877, -1.617251967858017*^-7}, 
       {-2.499984612338964, -0.004791285032170911}, 
       {-2.499944095240846, -0.009150297666029134}, {-2.49986582416784, \
-0.01418184139384116}, 
       {-2.499760792158528, -0.01893799784812239}, {-2.499499428633367, \
-0.02739678122155525}, 
       {-2.49910768551392, -0.03657730250607654}, {-2.498546125963443, \
-0.04668569369152785}, 
       {-2.497801777118377, -0.05739909441842121}, {-2.496081791033331, \
-0.07661085429222094}, 
       {-2.493788262307962, -0.09642443321915081}, {-2.491161467814947, \
-0.1149676376506695}, 
       {-2.483451048529813, -0.1571088813887903}, {-2.473103766995736, \
-0.1999366836218135}, 
       {-2.461430916103508, -0.2389436196251097}, {-2.427373656799114, \
-0.325956924222046}, 
       {-2.388903679320382, -0.4004339534529048}, {-2.337330217676389, \
-0.4801108853531336}, 
       {-2.273600730527824, -0.5598703094958477}, {-2.206193337008802, \
-0.6298264165756894}, 
       {-2.04043543175767, -0.7626451869198447}, {-1.94375625599244, \
-0.8225321346693498}, 
       {-1.827216039946332, -0.8822243582649191}, {-1.705859199663543, \
-0.9325028700312937}, 
       {-1.558472568841752, -0.9798836979667814}, {-1.485503582679377, \
-0.9984147911617142}, 
       {-1.403406994307722, -1.015669521747832}, {-1.322093891241371, \
-1.029188825846253}, 
       {-1.244585538273553, -1.038895057622037}, {-1.202270252235274, \
-1.042917047475457}, 
       {-1.156270388940666, -1.04628184842533}, {-1.137054242668133, \
-1.047379323630373}, 
       {-1.116129069757402, -1.048368817512065}, {-1.104050133055552, \
-1.048842655325055}, 
       {-1.092911475068534, -1.049216558221775}, {-1.081393139834932, \
-1.049539642340939}, 
       {-1.070870709489028, -1.049778360377352}, {-1.05933434290752, \
-1.049978226725436}, 
       {-1.046938385494819, -1.050120928640461}, {-1.03538677984689, \
-1.050186736604769}, 
       {-1.024422552743632, -1.050189255682556}, {-1.011556855626216, \
-1.050117766943635}, 
       {-0.9996249217156661, -1.049979604847143}, {-0.9933614646408553, \
-1.049879385325357}, 
       {-0.9864503976089002, -1.049746663554367}, {-0.9724135959319289, \
-1.049405550868165}, 
       {-0.9458260588563183, -1.048496473440751}, {-0.9168987240583941, \
-1.047115656041729}, 
       {-0.8892422561861742, -1.045412170870564}, {-0.8636711101843495, \
-1.043501978133766}, 
       {-0.8130823755088798, -1.038767118462147}, {-0.7579913984524847, \
-1.032149186553358}, 
       {-0.655665056369076, -1.015706961917836}, {-0.5283893388446955, \
-0.9873576515253107}, 
       {-0.4078361258504245, -0.9517629878825388}, {-0.2798344023801666, \
-0.9035152718965376}, 
       {-0.1581781709059163, -0.8460348257616161}, 
       {-0.02142333758054926, -0.7646611537192415}, {0.1232030893237592, \
-0.6521814574168728}, 
       {0.2459282779220054, -0.5228531817425011}, {0.3084337302186275, \
-0.4359740404632303}, 
       {0.3584687116187887, -0.34715867218908}, {0.3966842528805463, \
-0.2562715258669617}, 
       {0.41372270242089, -0.2018470517593237}, {0.426082286290799, \
-0.1499016376632777}, 
       {0.4339788201221227, -0.103511915920331}, {0.4372020485054333, \
-0.07679668398690936}, 
       {0.4393629259085029, -0.05159684610708651}, {0.4407216543902042, \
-0.02500136028273614}, 
       {0.4411377723800696, -0.0006003193476777703}, 
       {0.4406801247561689, 0.02618965398694077}, {0.4391701485143014, \
0.05429566820951116}, 
       {0.4365661674122184, 0.08272979573415582}, {0.4346304637145578, \
0.09867186948577653}, 
       {0.4325544896990811, 0.1132849489933361}, {0.4222303612939363, \
0.1678455781120362}, 
       {0.4096388669567585, 0.2161776995794132}, {0.3932944986482909, \
0.2656776880215513}, 
       {0.3507849751463255, 0.3624154670071649}, {0.2938320906924534, \
0.4581064665396286}, 
       {0.1764238203164388, 0.6010689087815769}, {0.05795096488621044, \
0.7069849354939411}, 
       {-0.08359147080840108, 0.8041027259735271}, {-0.2158302943607815, \
0.8747716550337136}, 
       {-0.3303736250944399, 0.9238928152352656}, {-0.4525602234824605, \
0.965958159109731}, 
       {-0.5687180404327282, 0.9972619482751092}, {-0.6869339036165986, \
1.021247803312897}, 
       {-0.7378814133786012, 1.029280209035584}, {-0.791672719043108, \
1.036308219455483}, 
       {-0.8377536276566228, 1.041164695990409}, {-0.8860245236936254, \
1.045117237634325}, 
       {-0.9127206239013732, 1.046809427749415}, {-0.936722272749469, \
1.048032473921811}, 
       {-0.9605888604742471, 1.048969579486518}, {-0.9712376217726493, \
1.049298116527636}, 
       {-0.9829004744253289, 1.049594604692052}, {-0.9954282399882304, \
1.049839385036253}, 
       {-1.002252572533014, 1.049940633818699}, {-1.008622717234414, \
1.050014726439797}, 
       {-1.019961445169539, 1.05009784257332}, {-1.032084913589878, \
1.050117639965741}, 
       {-1.038830599505493, 1.050097745142752}, {-1.046165380508719, \
1.050051026526341}, 
       {-1.0530696729205, 1.049983167306557}, {-1.059455882594268, \
1.049899782585627}, 
       {-1.071459490991681, 1.049689430705964}, {-1.084172784492621, \
1.049390270596694}, 
       {-1.109881977533099, 1.048544868088455}, {-1.137314489044872, \
1.047287147828384}, 
       {-1.186086527478201, 1.044140180862714}, {-1.23241481385338, \
1.04006251856128}, 
       {-1.274037410788059, 1.035484366342359}, {-1.355677618660995, \
1.023942500343207}, 
       {-1.428576181962972, 1.01068736298966}, {-1.583076629117392, \
0.972838372657077}, 
       {-1.721032593241521, 0.9267177004657584}, {-1.835198085399671, \
0.8784233451336907}, 
       {-1.950343026479652, 0.8186803482131058}, {-2.04590878253117, \
0.7588281313289391}, 
       {-2.207584336399609, 0.628396156454683}, {-2.277842516549879, \
0.5549275808189334}, 
       {-2.334618701415965, 0.4837491289716291}, {-2.381345344395771, \
0.413162082486134}, 
       {-2.421977084081683, 0.3374048865868622}, {-2.455191613762542, \
0.2571227506414373}, 
       {-2.477532387612377, 0.1826940616126284}, {-2.486061216615921, \
0.1440380736841746}, 
       {-2.489880601325247, 0.1227487716623932}, {-2.492922467269637, \
0.102632627951731}, 
       {-2.495269027740377, 0.08384428891691696}, {-2.497276609439123, \
0.06346937585570948}, 
       {-2.497986152249142, 0.05446767113500287}, {-2.498618991409132, \
0.04493962661751468}, 
       {-2.49906825280541, 0.03670241098598501}, {-2.499449787457052, \
0.02785619563705954}, 
       {-2.499583535376128, 0.02399599747658518}, {-2.499692062615253, \
0.0203330106281215}, 
       {-2.499780524276355, 0.01676678646829246}, {-2.499847358158449, \
0.01346184458692906}, 
       {-2.499897098331667, 0.01034077539037223}, {-2.499935760465642, \
0.007019571850270184}, 
       {-2.499961441131739, 0.003334937769687267}, {-2.499969076148017, \
1.616107520498871*^-7}}
]}}}, {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
   DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, Axes -> \
Automatic, 
   AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel -> None, Ticks -> \
Automatic, 
   GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
   Background -> Automatic, DefaultColor -> Automatic, DefaultFont :> \
$DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, 
   FrameLabel -> None, PlotRegion -> Automatic, ImageSize -> Automatic, 
   TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell["ellipses = ellipses[[1]];", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Union of the graphics of the bodies and the orbits", "Subsection"],

Cell["objects[t_] = {ellipses, objm[t], objM[t]};", "Input"],

Cell[CellGroupData[{

Cell["\<\
picture[t_] = Graphics[objects[t],
                              Axes-> True,
                              AspectRatio->Automatic,
                              PlotRange-> {{-3,8},{-3.5,3.5}}
                              ]\
\>", "Input"],

Cell[OutputFormData["\<\
Graphics[{{{{Line[{{7.499999999999634, 4.851755903574053*^-7}, 
        {7.499953837016894, 0.01437385509651273}, {7.49983228572254, \
0.0274508929980874}, 
        {7.499597472503522, 0.04254552418152349}, {7.499282376475584, \
0.05681399354436718}, 
        {7.498498285900103, 0.08219034366466576}, {7.497323056541762, \
0.1097319075182296}, 
        {7.495638377890331, 0.1400570810745835}, {7.49340533135513, \
0.1721972832552636}, 
        {7.488245373099996, 0.2298325628766628}, {7.481364786923887, \
0.2892732996574523}, 
        {7.473484403444842, 0.3449029129520086}, {7.45035314558944, \
0.471326644166371}, 
        {7.41931130098721, 0.5998100508654406}, {7.384292748310524, \
0.716830858875329}, 
        {7.282120970397343, 0.977870772666138}, {7.166711037961146, \
1.201301860358714}, 
        {7.011990653029168, 1.4403326560594}, {6.820802191583472, \
1.679610928487543}, 
        {6.618580011026407, 1.889479249727068}, {6.121306295273011, \
2.287935560759533}, 
        {5.83126876797732, 2.467596404008049}, {5.481648119838996, \
2.646673074794757}, 
        {5.11757759899063, 2.797508610093881}, {4.675417706525257, \
2.939651093900344}, 
        {4.45651074803813, 2.995244373485142}, {4.210220982923166, \
3.047008565243496}, 
        {3.966281673724115, 3.08756647753876}, {3.733756614820659, \
3.116685172866112}, 
        {3.606810756705823, 3.128751142426373}, {3.468811166821998, \
3.138845545275991}, 
        {3.411162728004399, 3.142137970891119}, {3.348387209272206, \
3.145106452536196}, 
        {3.312150399166657, 3.146527965975166}, {3.278734425205602, \
3.147649674665325}, 
        {3.244179419504797, 3.148618927022819}, {3.212612128467084, \
3.149335081132059}, 
        {3.178003028722562, 3.14993468017631}, {3.140815156484458, \
3.150362785921385}, 
        {3.106160339540671, 3.150560209814307}, {3.073267658230897, \
3.150567767047669}, 
        {3.03467056687865, 3.150353300830905}, {2.998874765146998, \
3.149938814541429}, 
        {2.980084393922566, 3.149638155976072}, {2.959351192826701, \
3.149239990663103}, 
        {2.917240787795786, 3.148216652604496}, {2.837478176568954, \
3.145489420322253}, 
        {2.750696172175182, 3.141346968125188}, {2.667726768558523, \
3.136236512611692}, 
        {2.591013330553048, 3.130505934401299}, {2.439247126526639, \
3.116301355386443}, 
        {2.273974195357454, 3.096447559660075}, {1.966995169107228, \
3.04712088575351}, 
        {1.585168016534086, 2.962072954575932}, {1.223508377551273, \
2.855288963647616}, 
        {0.8395032071404999, 2.710545815689612}, {0.4745345127177492, \
2.538104477284848}, 
        {0.06427001274164778, 2.293983461157724}, {-0.3696092679712778, \
1.956544372250618}, 
        {-0.7377848337660162, 1.568559545227503}, {-0.9253011906558825, \
1.30792212138969}, 
        {-1.075406134856366, 1.04147601656724}, {-1.190052758641639, \
0.7688145776008852}, 
        {-1.24116810726267, 0.6055411552779713}, {-1.278246858872396, \
0.4497049129898332}, 
        {-1.301936460366368, 0.3105357477609931}, {-1.311606145516299, \
0.230390051960728}, 
        {-1.318088777725509, 0.1547905383212595}, {-1.322164963170612, \
0.07500408084820846}, 
        {-1.323413317140208, 0.001800958043033311}, 
        {-1.322040374268506, -0.0785689619608223}, 
        {-1.317510445542904, -0.1628870046285334}, 
        {-1.309698502236655, -0.2481893872024674}, 
        {-1.303891391143673, -0.2960156084573295}, 
        {-1.297663469097243, -0.3398548469800084}, 
        {-1.266691083881809, -0.5035367343361086}, 
        {-1.228916600870275, -0.6485330987382395}, 
        {-1.179883495944872, -0.7970330640646539}, {-1.052354925438976, \
-1.087246401021494}, 
        {-0.8814962720773602, -1.374319399618886}, {-0.5292714609493165, \
-1.80320672634473}, 
        {-0.1738528946586313, -2.120954806481823}, {0.2507744124252032, \
-2.412308177920581}, 
        {0.6474908830823448, -2.624314965101141}, {0.9911208752833196, \
-2.771678445705797}, 
        {1.357680670447381, -2.897874477329192}, {1.706154121298184, \
-2.991785844825327}, 
        {2.060801710849796, -3.063743409938691}, {2.213644240135803, \
-3.087840627106752}, 
        {2.375018157129324, -3.10892465836645}, {2.513260882969868, \
-3.123494087971229}, 
        {2.658073571080876, -3.135351712902976}, {2.738161871704119, \
-3.140428283248247}, 
        {2.810166818248407, -3.144097421765434}, {2.881766581422741, \
-3.146908738459554}, 
        {2.913712865317948, -3.147894349582908}, {2.948701423275986, \
-3.148783814076157}, 
        {2.98628471996469, -3.14951815510876}, {3.006757717599043, \
-3.149821901456099}, 
        {3.025868151703243, -3.150044179319392}, {3.059884335508619, \
-3.150293527719962}, 
        {3.096254740769635, -3.150352919897223}, {3.11649179851648, \
-3.150293235428256}, 
        {3.138496141526158, -3.150153079579025}, {3.159209018761502, \
-3.149949501919673}, 
        {3.178367647782805, -3.149699347756881}, {3.214378472975043, \
-3.149068292117893}, 
        {3.252518353477864, -3.148170811790083}, {3.329645932599298, \
-3.145634604265365}, 
        {3.411943467134618, -3.141861443485153}, {3.558259582434605, \
-3.132420542588144}, 
        {3.697244441560142, -3.120187555683842}, {3.822112232364179, \
-3.106453099027079}, 
        {4.067032855982986, -3.071827501029622}, {4.285728545888918, \
-3.03206208896898}, 
        {4.749229887352177, -2.918515117971231}, {5.163097779724565, \
-2.780153101397275}, 
        {5.505594256199015, -2.635270035401072}, {5.851029079438955, \
-2.456041044639317}, 
        {6.137726347593511, -2.276484393986817}, {6.622753009198827, \
-1.885188469364049}, 
        {6.833527549649639, -1.6647827424568}, {7.003856104247896, \
-1.451247386914887}, 
        {7.144036033187314, -1.239486247458402}, {7.265931252245051, \
-1.012214659760586}, 
        {7.365574841287628, -0.7713682519243122}, {7.432597162837131, \
-0.5480821848378853}, 
        {7.458183649847765, -0.4321142210525238}, {7.469641803975742, \
-0.3682463149871797}, 
        {7.478767401808912, -0.3078978838551931}, {7.485807083221134, \
-0.2515328667507508}, 
        {7.491829828317371, -0.1904081275671284}, {7.493958456747428, \
-0.1634030134050086}, 
        {7.495856974227397, -0.134818879852544}, {7.497204758416231, \
-0.110107232957955}, 
        {7.498349362371158, -0.08356858691117864}, 
        {7.498750606128385, -0.07198799242975553}, 
        {7.499076187845761, -0.06099903188436451}, {7.499341572829065, \
-0.0503003594048774}, 
        {7.49954207447535, -0.04038553376078718}, {7.499691294995001, \
-0.0310223261711167}, 
        {7.499807281396927, -0.02105871555081055}, {7.499884323395219, \
-0.0100048133090618}, 
        {7.499907228444051, -4.848322561496615*^-7}}]}}, 
    {{Line[{{-2.499999999999877, -1.617251967858017*^-7}, 
        {-2.499984612338964, -0.004791285032170911}, 
        {-2.499944095240846, -0.009150297666029134}, 
        {-2.49986582416784, -0.01418184139384116}, 
        {-2.499760792158528, -0.01893799784812239}, 
        {-2.499499428633367, -0.02739678122155525}, 
        {-2.49910768551392, -0.03657730250607654}, 
        {-2.498546125963443, -0.04668569369152785}, 
        {-2.497801777118377, -0.05739909441842121}, 
        {-2.496081791033331, -0.07661085429222094}, 
        {-2.493788262307962, -0.09642443321915081}, 
        {-2.491161467814947, -0.1149676376506695}, {-2.483451048529813, \
-0.1571088813887903}, 
        {-2.473103766995736, -0.1999366836218135}, {-2.461430916103508, \
-0.2389436196251097}, 
        {-2.427373656799114, -0.325956924222046}, {-2.388903679320382, \
-0.4004339534529048}, 
        {-2.337330217676389, -0.4801108853531336}, {-2.273600730527824, \
-0.5598703094958477}, 
        {-2.206193337008802, -0.6298264165756894}, {-2.04043543175767, \
-0.7626451869198447}, 
        {-1.94375625599244, -0.8225321346693498}, {-1.827216039946332, \
-0.8822243582649191}, 
        {-1.705859199663543, -0.9325028700312937}, {-1.558472568841752, \
-0.9798836979667814}, 
        {-1.485503582679377, -0.9984147911617142}, {-1.403406994307722, \
-1.015669521747832}, 
        {-1.322093891241371, -1.029188825846253}, {-1.244585538273553, \
-1.038895057622037}, 
        {-1.202270252235274, -1.042917047475457}, {-1.156270388940666, \
-1.04628184842533}, 
        {-1.137054242668133, -1.047379323630373}, {-1.116129069757402, \
-1.048368817512065}, 
        {-1.104050133055552, -1.048842655325055}, {-1.092911475068534, \
-1.049216558221775}, 
        {-1.081393139834932, -1.049539642340939}, {-1.070870709489028, \
-1.049778360377352}, 
        {-1.05933434290752, -1.049978226725436}, {-1.046938385494819, \
-1.050120928640461}, 
        {-1.03538677984689, -1.050186736604769}, {-1.024422552743632, \
-1.050189255682556}, 
        {-1.011556855626216, -1.050117766943635}, {-0.9996249217156661, \
-1.049979604847143}, 
        {-0.9933614646408553, -1.049879385325357}, {-0.9864503976089002, \
-1.049746663554367}, 
        {-0.9724135959319289, -1.049405550868165}, {-0.9458260588563183, \
-1.048496473440751}, 
        {-0.9168987240583941, -1.047115656041729}, {-0.8892422561861742, \
-1.045412170870564}, 
        {-0.8636711101843495, -1.043501978133766}, {-0.8130823755088798, \
-1.038767118462147}, 
        {-0.7579913984524847, -1.032149186553358}, {-0.655665056369076, \
-1.015706961917836}, 
        {-0.5283893388446955, -0.9873576515253107}, 
        {-0.4078361258504245, -0.9517629878825388}, 
        {-0.2798344023801666, -0.9035152718965376}, 
        {-0.1581781709059163, -0.8460348257616161}, 
        {-0.02142333758054926, -0.7646611537192415}, 
        {0.1232030893237592, -0.6521814574168728}, {0.2459282779220054, \
-0.5228531817425011}, 
        {0.3084337302186275, -0.4359740404632303}, {0.3584687116187887, \
-0.34715867218908}, 
        {0.3966842528805463, -0.2562715258669617}, {0.41372270242089, \
-0.2018470517593237}, 
        {0.426082286290799, -0.1499016376632777}, {0.4339788201221227, \
-0.103511915920331}, 
        {0.4372020485054333, -0.07679668398690936}, 
        {0.4393629259085029, -0.05159684610708651}, 
        {0.4407216543902042, -0.02500136028273614}, 
        {0.4411377723800696, -0.0006003193476777703}, 
        {0.4406801247561689, 0.02618965398694077}, {0.4391701485143014, \
0.05429566820951116}, 
        {0.4365661674122184, 0.08272979573415582}, {0.4346304637145578, \
0.09867186948577653}, 
        {0.4325544896990811, 0.1132849489933361}, {0.4222303612939363, \
0.1678455781120362}, 
        {0.4096388669567585, 0.2161776995794132}, {0.3932944986482909, \
0.2656776880215513}, 
        {0.3507849751463255, 0.3624154670071649}, {0.2938320906924534, \
0.4581064665396286}, 
        {0.1764238203164388, 0.6010689087815769}, {0.05795096488621044, \
0.7069849354939411}, 
        {-0.08359147080840108, 0.8041027259735271}, 
        {-0.2158302943607815, 0.8747716550337136}, {-0.3303736250944399, \
0.9238928152352656}, 
        {-0.4525602234824605, 0.965958159109731}, {-0.5687180404327282, \
0.9972619482751092}, 
        {-0.6869339036165986, 1.021247803312897}, {-0.7378814133786012, \
1.029280209035584}, 
        {-0.791672719043108, 1.036308219455483}, {-0.8377536276566228, \
1.041164695990409}, 
        {-0.8860245236936254, 1.045117237634325}, {-0.9127206239013732, \
1.046809427749415}, 
        {-0.936722272749469, 1.048032473921811}, {-0.9605888604742471, \
1.048969579486518}, 
        {-0.9712376217726493, 1.049298116527636}, {-0.9829004744253289, \
1.049594604692052}, 
        {-0.9954282399882304, 1.049839385036253}, {-1.002252572533014, \
1.049940633818699}, 
        {-1.008622717234414, 1.050014726439797}, {-1.019961445169539, \
1.05009784257332}, 
        {-1.032084913589878, 1.050117639965741}, {-1.038830599505493, \
1.050097745142752}, 
        {-1.046165380508719, 1.050051026526341}, {-1.0530696729205, \
1.049983167306557}, 
        {-1.059455882594268, 1.049899782585627}, {-1.071459490991681, \
1.049689430705964}, 
        {-1.084172784492621, 1.049390270596694}, {-1.109881977533099, \
1.048544868088455}, 
        {-1.137314489044872, 1.047287147828384}, {-1.186086527478201, \
1.044140180862714}, 
        {-1.23241481385338, 1.04006251856128}, {-1.274037410788059, \
1.035484366342359}, 
        {-1.355677618660995, 1.023942500343207}, {-1.428576181962972, \
1.01068736298966}, 
        {-1.583076629117392, 0.972838372657077}, {-1.721032593241521, \
0.9267177004657584}, 
        {-1.835198085399671, 0.8784233451336907}, {-1.950343026479652, \
0.8186803482131058}, 
        {-2.04590878253117, 0.7588281313289391}, {-2.207584336399609, \
0.628396156454683}, 
        {-2.277842516549879, 0.5549275808189334}, {-2.334618701415965, \
0.4837491289716291}, 
        {-2.381345344395771, 0.413162082486134}, {-2.421977084081683, \
0.3374048865868622}, 
        {-2.455191613762542, 0.2571227506414373}, {-2.477532387612377, \
0.1826940616126284}, 
        {-2.486061216615921, 0.1440380736841746}, {-2.489880601325247, \
0.1227487716623932}, 
        {-2.492922467269637, 0.102632627951731}, {-2.495269027740377, \
0.08384428891691696}, 
        {-2.497276609439123, 0.06346937585570948}, {-2.497986152249142, \
0.05446767113500287}, 
        {-2.498618991409132, 0.04493962661751468}, {-2.49906825280541, \
0.03670241098598501}, 
        {-2.499449787457052, 0.02785619563705954}, {-2.499583535376128, \
0.02399599747658518}, 
        {-2.499692062615253, 0.0203330106281215}, {-2.499780524276355, \
0.01676678646829246}, 
        {-2.499847358158449, 0.01346184458692906}, {-2.499897098331667, \
0.01034077539037223}, 
        {-2.499935760465642, 0.007019571850270184}, 
        {-2.499961441131739, 0.003334937769687267}, 
        {-2.499969076148017, 1.616107520498871*^-7}}]}}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], 
    Point[{(3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, \
{0}}, 
           {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
             0.3454932045144168, 0.5149133009685714, 1.113321247101875, 
             1.711729193235179, 2.310137139368483, 2.908545085501787, \
3.549213715257329, 
             4.189882345012872, 4.830550974768414, 5.471219604523957, \
6.430775161993191, 
             7.390330719462426, 8.349886276931659, 9.309441834400892, \
10.26899739187012, 
             11.41745542047073, 12.56591344907135, 13.71437147767196, \
14.86282950627257, 
             15.76989538380499, 16.6769612613374, 17.40744088188177, \
18.13792050242614, 
             18.7397772796289, 19.34163405683166, 19.94349083403443, \
20.42462129550812, 
             20.90575175698181, 21.3868822184555, 21.77942040848143, \
22.17195859850736, 
             22.49017329751688, 22.80838799652641, 23.12660269553594, \
23.35744832997994, 
             23.58829396442394, 23.81913959886794, 24.04998523331195, \
24.22894594708866, 
             24.40790666086538, 24.5868673746421, 24.73263739132645, \
24.87840740801079, 
             25.02417742469514, 25.16994744137948, 25.31571745806383, \
25.43261413721928, 
             25.54951081637472, 25.66640749553017, 25.75972519687526, \
25.85304289822035, 
             25.94636059956543, 26.03967830091052, 26.1329960022556, \
26.22631370360069, 
             26.32916651294125, 26.43201932228183, 26.5348721316224, \
26.63772494096296, 
             26.74057775030353, 26.8434305596441, 26.95721757772128, \
27.07100459579846, 
             27.18479161387564, 27.29857863195281, 27.41236565002999, \
27.52615266810717, 
             27.6607436925243, 27.79533471694143, 27.92992574135857, \
28.0645167657757, 
             28.19910779019284, 28.33369881460997, 28.4682898390271, \
28.63486540147832, 
             28.80144096392953, 28.96801652638075, 29.13459208883196, \
29.30116765128317, 
             29.46774321373439, 29.7177331909978, 29.9677231682612, \
30.2177131455246, 
             30.46770312278801, 30.71769310005141, 30.96768307731482, \
31.30105415814421, 
             31.6344252389736, 31.967796319803, 32.30116740063239, \
32.63453848146179, 
             32.96790956229118, 33.41142573145399, 33.85494190061679, \
34.2984580697796, 
             34.7419742389424, 35.18549040810521, 35.62900657726801, \
36.23354433912698, 
             36.83808210098595, 37.44261986284493, 38.0471576247039, \
38.65169538656287, 
             39.25623314842184, 40.10946709220665, 40.96270103599147, \
41.81593497977629, 
             42.6691689235611, 43.52240286734591, 44.37563681113073, \
45.41195548490509, 
             46.44827415867943, 47.48459283245379, 48.52091150622815, \
49.5572301800025, 
             50.59354885377685, 51.68339752171315, 52.}}, 
           {{10., 0.}, {9.999999668030779, -0.00009979517922659892, \
-0.01500000077182846}, 
            {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, \

             -1.322286343058508*^-7}, 
            {9.999534630881093, -0.005282323784489644, -0.01500076832270247, 
             -1.507556879980259*^-6}, 
            {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
             -4.303953042407377*^-6}, 
            {9.996022280142259, -0.01544977367720093, -0.01500656577947253, 
             -7.102518978703048*^-6, -4.12962510774654*^-6}, 
            {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
             -0.00001911254788268681, -4.721536529157213*^-6}, 
            {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
             -0.00002843965797539134, -4.17160237245598*^-6}, 
            {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
             -0.00003863663157999305, -4.230562589262589*^-6}, 
            {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
             -0.00004907835452562485, -4.318382798300356*^-6}, 
            {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
             -0.00006058324022271351, -4.43239809319311*^-6}, 
            {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
             -0.00007254388067269821, -4.588965459026183*^-6}, 
            {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
             -0.00008504165353778693, -4.780886831038984*^-6}, 
            {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
             -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
            {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
             -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
            {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
             -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
            {8.9333000040121, -0.260711383344569, -0.0169126745304145, 
             -0.0001688916601208405, -7.056168354057571*^-6, \
-1.313845897946621*^-7}, 
            {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
             -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
            {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
             -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
             -6.674609404533344*^-9}, 
            {7.968828654203694, -0.3701677267394483, -0.01893656311738351, 
             -0.0002787120557484119, -0.00001107459120877045, \
-3.431225329765139*^-7, 
             -1.221235206138657*^-8}, 
            {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
             -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
             -1.346430675352864*^-8}, 
            {7.014966306469673, -0.4621643951747192, -0.02125743383726544, 
             -0.0004024832669310073, -0.00001612207743260069, \
-5.188299501191256*^-7, 
             -1.214130185849565*^-8}, 
            {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
             -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
             -1.354357959188541*^-8}, 
            {5.971354327636086, -0.5552694173247879, -0.02419934375167602, 
             -0.0005601240439740879, -0.00002240270713257671, \
-6.795896221578519*^-7, 
             -1.201709349193833*^-8}, 
            {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
             -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
             -1.583376666742293*^-9}, 
            {4.994559169969892, -0.6394373103400424, -0.02732862996656363, 
             -0.0007171994723376593, -0.00002519742550426964, \
-1.641290240708912*^-7, 
             3.910597107780506*^-8}, 
            {4.512594792329623, -0.6805479316610102, -0.02897566532185714, 
             -0.0007858734411303971, -0.00002283819031739034, \
6.281580292262645*^-7, 
             9.577105762745674*^-8}, 
            {4.092333097008952, -0.7162958456331559, -0.03043328001834313, 
             -0.0008273002171360841, -0.00001411116814184291, \
2.773103753343612*^-6, 
             2.950546781062066*^-7}, 
            {3.650020866463042, -0.7538337447048592, -0.03194053384702654, 
             -0.000837781640951464, 2.907707968555054*^-6, \
5.852540359820091*^-6, 
             5.181368394863152*^-7}, 
            {3.184571840689228, -0.7931742380695744, -0.03340796215459502, 
             -0.0007783073126224044, 0.00004020831399575819, \
0.00001252969451950441, 
             1.050499280912101*^-6}, 
            {2.795135498386905, -0.825830794134082, -0.03443182974317923, 
             -0.0006278837202671806, 0.0001043308691637567, \
0.00002636995433250329, 
             2.548041348411085*^-6}, 
            {2.38977107808601, -0.8593358948133683, -0.03513375184134562, 
             -0.000319913380216462, 0.0002060515099388112, \
0.00004421380258099794, 
             4.001314036998032*^-6}, 
            {1.968166385363971, -0.8932395940637682, -0.03519115346953409, 
             0.0002827427630627121, 0.0003953025819406979, \
0.00008034764600886729, 
             7.407586137339988*^-6}, 
            {1.612143333988495, -0.9206107463009619, -0.03436732147393313, 
             0.001167408375879762, 0.0006871165481036591, \
0.0001488881693373802, 
             0.00001608512153778298}, 
            {1.245564862078643, -0.9468476617076561, -0.03218992389889563, 
             0.002621839915004895, 0.001129466927246893, \
0.0002361002834123236, 
             0.00002446272968897194}, 
            {0.9411036630779808, -0.9663582346870491, -0.02882442468204031, 
             0.004524953127547926, 0.001773934206673067, \
0.0004076052929450417, 
             0.00005060830769685972}, 
            {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, 
             0.007385850858260214, 0.002672644657907155, \
0.0005975972454227846, 
             0.00007016870897342483}, 
            {0.3159401433660997, -0.9951819807516075, -0.0141810564371504, 
             0.01177969329600485, 0.004105758348508652, \
0.0009339734047126293, 
             0.0001125727572013773}, 
            {0.08560933537464546, -0.9996129071047306, -0.004482625115979116, \

             0.01642148422154501, 0.005766813443267503, 0.001456041061702653, \

             0.0002183132824744149}, 
            {-0.1451655451007285, -0.9987483123162489, 0.008944489593331621, 
             0.02264330478484971, 0.007723831164850311, 0.001834097872355712, \

             0.0002401682337663385}, 
            {-0.3749422448675035, -0.9905775772121858, 0.02741903505059772, 
             0.03107584026681068, 0.01043305827566561, 0.002464002718034116, 
             0.0003260132232436369}, 
            {-0.6017366959356142, -0.9723927003509583, 0.05264297022337499, 
             0.04225298673259487, 0.01376536310562221, 0.003084637463279821, 
             0.0003748430742714523}, 
            {-0.7738140143777483, -0.9491604221345081, 0.07814523672066643, 
             0.0530975554303808, 0.01662705757449755, 0.003411909325867013, 
             0.0003468215640078723}, 
            {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, 
             0.06584191092106879, 0.01927853582407632, 0.003240100434734713, 
             0.0001440904775641987}, 
            {-1.100807501258846, -0.8695729934305591, 0.1490503491214294, 
             0.08005627726477126, 0.02099483499621253, 0.002195345619101353, 
             -0.0003027390708880932}, 
            {-1.22414138467131, -0.82077085304674, 0.1866028279478249, 
             0.09179484841508957, 0.02021543417588093, -0.000754274587538044, \

             -0.001530626941211491}, 
            {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, 
             0.1026147787935418, 0.01746781961115515, -0.004103986580530314, 
             -0.002450338209772962}, 
            {-1.44516147054655, -0.686759968869766, 0.2758334004910389, 
             0.1105177241750504, 0.0106742864278701, -0.009800257288146374, 
             -0.004075343469478164}, 
            {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, 
             0.1131708883596251, -0.0007350026571956852, \
-0.01685438505251352, 
             -0.005671350902054768}, 
            {-1.619160447134986, -0.4973382762736237, 0.3735908896734561, 
             0.1079524283682205, -0.01688511860132406, -0.02423508582492491, 
             -0.006778310725377359}, 
            {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, 
             0.09666214457796037, -0.03204065521875401, -0.02840436636139767, \

             -0.006444744621113192}, 
            {-1.713702367726152, -0.3061747204096225, 0.4406455090291952, 
             0.0785742469749175, -0.0470257534782241, -0.02861634111365265, 
             -0.00398773686340812}, {-1.743354980747793, -0.2002393810076641, \

             0.4641460871409876, 0.05414735876830688, -0.05977983902013911, 
             -0.02439011013378813, 0.00001759514469461788}, 
            {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, 
             0.03131763081762755, -0.0651267030424638, -0.01330108771073375, 
             0.007932614219398512}, {-1.764279633198327, \
-0.02290728516546019, 
             0.4815191300064316, 0.006382340077340566, -0.06878153330095417, 
             -0.00607622203589427, 0.009921051344796055}, 
            {-1.762223869805497, 0.0669098889538212, 0.4797874360581084, 
             -0.01881564820658439, -0.06715504466041756, 0.0052941015385649, 
             0.014075650991735}, {-1.751822051888362, 0.1557504845998194, 
             0.4711087322811719, -0.04290594361192289, -0.06177008484910881, 
             0.01515215349206186, 0.01548803581768913}, 
            {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, 
             -0.06450374890421965, -0.05309737444319933, 0.02305207122611793, \

             0.01493656511780418}, {-1.706693534600896, 0.325611997587172, 
             0.4353010176743601, -0.08256681154941546, -0.04224156850021461, 
             0.02801462883846634, 0.01250721686243972}, 
            {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, 
             -0.09760253037063431, -0.02888818242959219, 0.0306691934708478, 
             0.009224953760383584}, {-1.622080963140679, 0.4929301210117905, 
             0.3755325162049182, -0.1074178334999123, -0.01633310637884133, 
             0.02856039286749514, 0.004168099462073743}, 
            {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, 
             -0.1122527924612216, -0.005160721979258902, 0.02417131244294108, \

             -0.0003440345314113444}, 
            {-1.505751224868501, 0.6333664485834628, 0.306641269066246, 
             -0.1127997113966985, 0.003903182359577255, 0.01843886863229986, 
             -0.003922050103786528}, 
            {-1.437486215807195, 0.6928851431186745, 0.2721892254033128, 
             -0.1099263646846194, 0.01072931196339118, 0.01262842140521531, 
             -0.006119419347288539}, 
            {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, 
             -0.1045481470172331, 0.01544034474959015, 0.007498171284307598, 
             -0.006996953823451097}, 
            {-1.27569539364364, 0.7958744566460811, 0.2046554692122192, 
             -0.0967041517292661, 0.0185064284735578, 0.002960749536155133, 
             -0.006856601949068641}, 
            {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, 
             -0.08779459299724857, 0.01979767319192345, \
-0.0003066249582991479, 
             -0.006028282943382096}, 
            {-1.085063458885453, 0.8749251188130202, 0.144782245099154, 
             -0.07854258397670186, 0.01986264568980367, \
-0.002297713136917443, 
             -0.004783528255310104}, 
            {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, 
             -0.06946500901627999, 0.01908920268180254, \
-0.003359677058435248, 
             -0.003492310907858758}, 
            {-0.8793265410504286, 0.9295658946373885, 0.09732709937304962, 
             -0.0608924971492783, 0.01779753275101055, -0.003788394790891112, \

             -0.002346567941738405}, 
            {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, 
             -0.05301145859825892, 0.01623278484580223, \
-0.003814067204285791, 
             -0.00142298197321629, 0.001159542229646304}, 
            {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, 
             -0.04468096904705857, 0.01441045900308664, \
-0.002783953394204672, 
             0.001188784376355514, 0.001697085509141072}, 
            {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, 
             -0.03741547808128195, 0.0128042870890071, -0.001516085052811469, \

             0.002492470180502037, 0.001592641575583569}, 
            {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, 
             -0.03126812679688145, 0.01073262941726728, \
-0.002037579725773561, 
             0.001248140166443795, 0.000621510220514931}, 
            {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, 
             -0.02604465129166512, 0.008980331918121603, \
-0.002095510898895228, 
             0.0006953458839076041, 0.0002187584774474667}, 
            {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, 
             -0.02163335504587148, 0.007533052625606419, \
-0.001862875274342468, 
             0.0005412212424280951, 0.00009130883576918053}, 
            {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
             -0.01793006544947133, 0.006305477814234636, \
-0.001607987009029117, 
             0.0004376460542311089, 0.00002422708367731202}, 
            {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
             -0.01483069730268437, 0.00526623201595544, \
-0.001376927490964432, 
             0.0003454596158002636}, 
            {0.3238530675731096, 0.995016345930049, -0.0144640796213406, 
             -0.0116871546883609, 0.004231198363091821, \
-0.001064594641186693, 
             0.0003322772383557684}, 
            {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, 
             -0.00917301401911442, 0.003397859160363781, \
-0.000819933720088739, 
             0.0002972842358494771}, 
            {0.6533538559313423, 0.9820447155621451, -0.02372070399070088, 
             -0.007162526259702596, 0.002726309336887593, \
-0.0006384642833766479, 
             0.0002509980162091398}, 
            {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, 
             -0.005553834168748899, 0.002185764859300605, \
-0.0005041528357430196, 
             0.000204352772054328}, {0.9776558814470167, 0.9642105857215122, 
             -0.02932920777076483, -0.004264733145196217, \
0.001753679572068895, 
             -0.0003999863031745657, 0.0001643010647412814}, 
            {1.137437570202047, 0.9541144596710516, -0.03119425522545939, 
             -0.003230475051281675, 0.001408187583593927, \
-0.000318863443275577, 
             0.0001310475300282612}, 
            {1.373962009270192, 0.9379913626951294, -0.03315104071340928, 
             -0.002035992528092278, 0.001055017058722285, \
-0.0001754137530066389, 
             0.0001168833024258509}, 
            {1.606350517388015, 0.9210897263708773, -0.03435027793903866, 
             -0.001185643298369978, 0.0007611892730192848, \
-0.0001263674244384825, 
             0.00008320952677836924}, 
            {1.834451124462977, 0.9037326412745143, -0.03500295728260755, 
             -0.0005720113774542266, 0.0005488589661374675, \
-0.0000923366591773421, 
             0.00005900095063806828}, 
            {2.05818068749326, 0.8861532298832889, -0.03526139771076708, 
             -0.0001299066826636304, 0.0003943010523705895, \
-0.00006860755394809425, 
             0.00004172858547342076}, 
            {2.277505796363031, 0.8685194772734156, -0.03523617500405487, 
             0.0001875161539186697, 0.0002818251856303586, \
-0.0000511645549180407, 
             0.00002968880418123365}, 
            {2.492428788195139, 0.8509519705097273, -0.03500799092175404, 
             0.0004136601693357046, 0.0001995415136804703, \
-0.00003828804738911866, 
             0.00002124715551700476}, 
            {2.772238550718317, 0.8277725006882704, -0.03448789441543038, 
             0.0006187349731000154, 0.0001352320034684956, \
-0.00001425422529863956, 
             0.00001755451345997014}, 
            {3.044385230797065, 0.8049972229139195, -0.03380947075089432, 
             0.0007368050289671234, 0.00007834634628596583, \
-0.00001122391314621417, 
             0.00001113870188222071}, 
            {3.309018587737515, 0.7827080320625583, -0.03303896113559139, 
             0.0008026315339952361, 0.00004206218440122728, \
-7.530342783184703*^-6, 
             7.421851557590777*^-6}, 
            {3.566309067033361, 0.7609505320860362, -0.0322207398277254, 
             0.0008326581797725729, 0.00001753263227045104, \
-5.206456476998877*^-6, 
             4.91783556921768*^-6}, {3.81643803262864, 0.7397459514613501, 
             -0.03138449367913013, 0.000838939799644164, \
1.35077760291538*^-6, 
             -3.443913900758643*^-6, 3.303169942357289*^-6}, 
            {4.059591012015883, 0.7190992617954302, -0.03054996995098544, 
             0.0008294710638224421, -9.266693762532051*^-6, \
-2.176304405457542*^-6, 
             2.235395158274695*^-6}, 
            {4.372585721165242, 0.6924846048814831, -0.02946402757201999, 
             0.0008029885517503858, -0.00001512205360717179, \
8.250783523782558*^-7, 
             1.79238678863533*^-6}, {4.673987267678016, 0.6668147871373053, 
             -0.02842204472668379, 0.0007647138190854807, \
-0.00002078611834098472, 
             6.541365780799917*^-7, 1.049737140101165*^-6}, 
            {4.964205394312013, 0.6420460382904659, -0.02743350214751175, 
             0.0007221979607514677, -0.00002314976507814556, \
7.761061031756697*^-7, 
             6.481760049899586*^-7}, 
            {5.243628875125201, 0.6181288506037192, -0.02650242749678078, 
             0.0006781875255987336, -0.00002393452362995146, \
7.931800302684875*^-7, 
             3.914720523938617*^-7}, 
            {5.5126240130368, 0.5950117248664654, -0.0256295578461628, 
             0.0006345834841070335, -0.00002369251940469708, \
8.021342089770415*^-7, 
             2.362291693947091*^-7}, 
            {5.771534255654154, 0.5726434521487585, -0.02481369104364359, 
             0.0005924255277376992, -0.00002288648698303586, \
7.853559496375988*^-7, 
             1.392154952244304*^-7}, 
            {6.108778136511332, 0.5432709949881284, -0.02378916494031363, 
             0.0005385767396017946, -0.00002090222196923115, \
9.634231569526953*^-7, 
             1.031660310217783*^-7}, 
            {6.428627940347904, 0.5150795809575441, -0.02285881763700148, 
             0.000488650474985677, -0.00001936889068213984, \
7.862704461763962*^-7, 
             4.236373274532015*^-8}, 
            {6.731764237016638, 0.4879601358421129, -0.02201464865538692, 
             0.0004432614671721073, -0.00001769376947598321, \
6.751452578811216*^-7, 
             1.316367698170899*^-8}, 
            {7.018804533876454, 0.4618132537833407, -0.02124878476612005, 
             0.000402127590503264, -0.00001608643168964409, \
5.795259274427188*^-7, 
             -2.64641555573496*^-9}, 
            {7.29030909335201, 0.4365487805184312, -0.02055383300618015, 
             0.0003649289266705499, -0.00001458398933991611, \
5.033512661358331*^-7, 
             -9.988169502319166*^-9}, 
            {7.546786291865488, 0.4120851279505025, -0.01992303747611581, 
             0.0003312779634424161, -0.00001322154918966636, \
4.37551534672063*^-7, 
             -1.324910477258141*^-8}, 
            {7.884086056271611, 0.3787788434178949, -0.01913029312120552, 
             0.0002891023262879505, -0.0000115291594594324, \
3.63777393971772*^-7, 
             -1.371373898326033*^-8}, 
            {8.193519584742434, 0.3467373043198655, -0.01843847943647414, 
             0.0002522379007700076, -0.00001012456090970589, \
2.940570752419515*^-7, 
             -1.367577777664127*^-8}, 
            {8.476095686537853, 0.3157992553430406, -0.01783509007823322, 
             0.0002198514717341092, -8.938518663488416*^-6, \
2.402965656917715*^-7, 
             -1.240599571914663*^-8}, 
            {8.732694164207696, 0.2858229861605473, -0.01730967605233079, 
             0.0001911921984056844, -7.945451424014868*^-6, \
1.975592634101514*^-7, 
             -1.078283810070344*^-8}, 
            {8.964081092156048, 0.2566830884024056, -0.01685353056247505, 
             0.0001656356738916059, -7.115162259841*^-6, \
1.634975150107237*^-7, 
             -9.131086931191294*^-9}, 
            {9.170921496420231, 0.2282677220189242, -0.01645941987193715, 
             0.0001426479705924626, -6.427511170842572*^-6, \
1.348052317356517*^-7, 
             -7.720497902122285*^-9}, 
            {9.389954355144068, 0.1945852773909356, -0.01605562025513275, 
             0.000117523846926549, -5.77104513440084*^-6, \
1.004193245520244*^-7, 
             -6.84435365281206*^-9}, 
            {9.574487972549572, 0.1616616916001712, -0.01572586742018316, 
             0.00009490549903810554, -5.233270606636592*^-6, \
7.898604003413424*^-8, 
             -5.485421307730566*^-9}, 
            {9.725231796860384, 0.1293508421880767, -0.01546336168132292, 
             0.00007419723225491459, -4.824923276518464*^-6, \
5.934261569317994*^-8, 
             -4.554919700878265*^-9}, 
            {9.842750599262039, 0.09751900870274404, -0.01526288472030978, 
             0.000054940201293084, -4.52067132704201*^-6, \
4.262303874918333*^-8, 
             -3.808526825726381*^-9}, 
            {9.927475673864893, 0.06604185470753681, -0.0151205676271804, 
             0.00003672919236845725, -4.308672419068996*^-6, \
2.762596707450741*^-8, 
             -3.249881860652005*^-9}, 
            {9.979713178406525, 0.03480181166196349, -0.01503372618961092, 
             0.00001920328638020516, -4.180602396326156*^-6, \
1.358486971789759*^-8, 
             -2.853196789546286*^-9}, 
            {9.999804221413857, 0.002079784470556782, -0.01500049198937566, 
             1.146333605182019*^-6, -4.131571602154404*^-6, \
-1.008292044867596*^-9, 
             -2.604590129466682*^-9}, 
            {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
             -4.065399346041674*^-6, -4.111443091414769*^-6, \
7.927537361729354*^-9, 
             3.188545681628212*^-10}}][t])/4, 
      (3*InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
           {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
             0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
             2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
             4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
             8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
             12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
             16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
             19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
             21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
             22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
             23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
             24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
             25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
             25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
             26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
             26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
             26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
             27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
             27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
             28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
             28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
             29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
             30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
             31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
             33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
             35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
             37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
             40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
             43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
             47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
             51.68339752171315, 52.}}, 
           {{0., 0.3}, {0.0009979517077872255, 0.2999999900409223, \
-1.496927738092378*^-6}, 
            {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, \

             -0.0001500000440689237}, 
            {0.05282074703033888, 0.2999860382470232, \
-0.00007923886649939536, 
             -0.0001500117406492253}, 
            {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
             -0.0001500829092720493}, 
            {0.1544524067542601, 0.2998806333275119, -0.0002318722535893141, 
             -0.0001502226433836075, -2.061947113752874*^-7}, 
            {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
             -0.0001512573923248744, -3.56926535101178*^-7}, 
            {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
             -0.0001532344335889719, -6.696147194160083*^-7}, 
            {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
             -0.0001561772311865011, -1.0428234784246*^-6}, 
            {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
             -0.0001600680606887075, -1.43126921114028*^-6}, 
            {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
             -0.0001652995935706142, -1.838046254173493*^-6}, 
            {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
             -0.000171839413657207, -2.313982825558378*^-6}, 
            {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
             -0.0001797480698000253, -2.828724047048563*^-6}, 
            {1.616193851195026, 0.28597129085274, -0.002670225693750562, 
             -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
            {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
             -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
            {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
             -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
            {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
             -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
            {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
             -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
            {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
             -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
             -1.747260442740121*^-8}, 
            {3.175344187221096, 0.2289633086353855, -0.007545671364715371, 
             -0.0004088562867722723, -0.00001760680137464635, \
-8.727270794121078*^-7, 
             -3.447284626861373*^-8}, 
            {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
             -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
             -4.451638240754114*^-8}, 
            {3.65591142716557, 0.186792033285195, -0.01107850554171452, 
             -0.0006407044351002397, -0.00003391896655161902, \
-1.770630454265917*^-6, 
             -5.499941220723898*^-8}, 
            {3.85478077194519, 0.1585724953229884, -0.01360311058181845, 
             -0.0008339122439545453, -0.0000489443172128367, \
-2.712322351006786*^-6, 
             -8.766377802768383*^-8}, 
            {3.986763005165946, 0.131667061984029, -0.01615666214412804, 
             -0.001051626041925007, -0.00006869661225566872, \
-4.393137681215513*^-6, 
             -1.761332361311671*^-7}, 
            {4.092061561834391, 0.0995298917764175, -0.01940869599958157, 
             -0.001352395704445139, -0.00009571282431003663, \
-6.281214100632805*^-6, 
             -2.444479897469488*^-7}, 
            {4.153850886158325, 0.06883885260811142, -0.02272856290784795, 
             -0.001690501313216549, -0.0001316398123092309, \
-9.940863233820019*^-6, 
             -4.806638869588175*^-7}, 
            {4.191306423956496, 0.03269842564989161, -0.02691267068137347, 
             -0.002148302610858181, -0.0001796379888607316, \
-0.00001388813348710936, 
             -6.486429479295039*^-7}, 
            {4.200742249681569, -0.002208228754422552, -0.0312395051651517, 
             -0.002663840093236035, -0.0002423648979153841, \
-0.00002118918286358118, 
             -1.197910773667203*^-6}, 
            {4.187480484699273, -0.04294029965292303, -0.03664374955205367, 
             -0.003351432661554625, -0.0003255129417403924, \
-0.00002918221867922413, 
             -1.604121647400555*^-6}, 
            {4.147582708325752, -0.09101196819194772, -0.04351056025037764, 
             -0.004295458408425854, -0.0004497713933866242, \
-0.00004287189467316768, 
             -2.47885545821094*^-6}, 
            {4.093216338662262, -0.1360882405850764, -0.05042227215046736, 
             -0.005319578435935783, -0.0006006220945709141, \
-0.00006396231737026914, 
             -4.409656157769888*^-6}, 
            {4.015439499996313, -0.1885954484836499, -0.05903393771043326, 
             -0.006668642152566507, -0.0007954597141818747, \
-0.00008583296722324174, 
             -5.6762468467354*^-6}, {3.910243506625146, -0.2504281729333795, 
             -0.06991601053462865, -0.008485369119217001, \
-0.001075857440459364, 
             -0.0001215320852716722, -8.352309163308866*^-6}, 
            {3.800626326934144, -0.3095265512549151, -0.0810211001084475, 
             -0.01044535109360783, -0.001399096395540943, \
-0.0001697669761996192, 
             -0.00001320335121470718}, 
            {3.665972999146803, -0.378327542653802, -0.09474229302615215, 
             -0.01295459443587661, -0.001793921254600053, \
-0.0002144492937412613, 
             -0.00001551062565886725}, 
            {3.535553015059292, -0.4428061177064114, -0.1082883390327763, 
             -0.01550358393254631, -0.00220095651893553, \
-0.0002668360165914096, 
             -0.00002028150696806179}, 
            {3.383157176300779, -0.5167289059824787, -0.1245035267716008, 
             -0.01856317910150786, -0.00262862077236768, \
-0.0002906382154606718, 
             -0.00001715551624775262}, 
            {3.20549373901541, -0.6019516096016301, -0.1438811536990364, 
             -0.02213377125985196, -0.003028422675279043, \
-0.0002756180044960396, 
             -7.146543113549753*^-6}, 
            {3.058588130827458, -0.6720624861181122, -0.1601545679841135, 
             -0.02490566730718879, -0.003089766360970424, \
-0.00009058479323536484, 
             0.00004914842109632001}, 
            {2.894596323375797, -0.7501316342604838, -0.1783524392815316, 
             -0.02765292754581667, -0.002939806242666361, \
0.0001373209277761948, 
             0.00009530669209766431}, 
            {2.71158077479672, -0.8370178977712138, -0.1982936201330007, 
             -0.02988428120237179, -0.002118996299412064, \
0.0007045924544449787, 
             0.0002210082169551333}, 
            {2.507421795656775, -0.9334055715055376, -0.2193614638360956, 
             -0.03078067221328464, -0.0001732800370884182, \
0.001720488442029996, 
             0.000425988858941995}, {2.33317849523205, -1.014847597695069, 
             -0.2356208100425164, -0.02955058544284709, 0.003046032316439744, \

             0.003590979279397424, 0.0009523908779487415}, 
            {2.143850052796314, -1.101919841659889, -0.2505885269406052, 
             -0.0257551642988426, 0.007412414361894901, 0.005279973333030467, \

             0.001200620682765593}, {1.938487117181982, -1.193862438764723, 
             -0.2624730364011236, -0.0178540166471961, 0.01421257642856188, 
             0.008004913431379991, 0.001735470468834257}, 
            {1.75883264928784, -1.271316953078838, -0.2681090023709465, 
             -0.007281781650419494, 0.02174468381572495, 0.01086883249466218, \

             0.002351071097237822}, {1.567803973134603, -1.34965284368106, 
             -0.2681888997706034, 0.007755152293289466, 0.03018262959327178, 
             0.01265091525278751, 0.002225662920469842}, 
            {1.365404745815049, -1.426949826614714, -0.2606107999898968, 
             0.02785461651196843, 0.03933114451231477, 0.01367846572910126, 
             0.001805339147952605}, {1.151964525852244, -1.500657049331877, 
             -0.2432083773649155, 0.05271498302494613, 0.04725609485920589, 
             0.0121762506290482, 0.0003961782992654656}, 
            {0.9282290908341909, -1.567631287112038, -0.2141720714913058, 
             0.08087452593462236, 0.05143956554555599, 0.006857316057938279, 
             -0.002194862118939511}, 
            {0.7421893162287318, -1.614082667611147, -0.1818521353382827, 
             0.1036384967185181, 0.04854416792859499, -0.004146149653291475, 
             -0.007592239941335828}, 
            {0.5511972731511882, -1.652053966237579, -0.1417298011263864, 
             0.1248433419007408, 0.04251471658064646, -0.01247735974733354, 
             -0.00930666804245882}, {0.3563470626035425, -1.679827849714072, 
             -0.0948729889153013, 0.1416220962583256, 0.03002609653483467, 
             -0.02382700420146366, -0.01205675068522526}, 
            {0.1988803856063542, -1.693747230698574, -0.05387307904427518, 
             0.1504911307725392, 0.01707885010501343, -0.03104601206841266, 
             -0.01239134837489694}, {0.04047800614247131, -1.699822619873736, \

             -0.01104749066017452, 0.1544758791615086, 0.002904805753834867, 
             -0.03443803199776515, -0.009858086267061791}, 
            {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, 
             0.1531408660534355, -0.01167634603044878, -0.03485997177461622, 
             -0.006216287801323393}, 
            {-0.27615166724078, -1.687886476853531, 0.07426415750684713, 
             0.1466406120061692, -0.02502213731263542, -0.03148565897311392, 
             -0.001319145505838771}, 
            {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, 
             0.1355750756867236, -0.03599301035345136, -0.02507396577743876, 
             0.003789060726332308}, {-0.5876646366009311, -1.645599954367274, \

             0.149886984217886, 0.1209186002645799, -0.04381958582674411, 
             -0.0167474495269128, 0.008221944332663039}, 
            {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, 
             0.1019891041979152, -0.04877571161287061, -0.007753678783690814, \

             0.01076270805849416}, {-0.9188591999930354, -1.57017430368858, 
             0.2127277830279036, 0.0818110606661343, -0.04943939416432463, 
             0.001581489445512773, 0.01250845176538342}, 
            {-1.078022007311201, -1.524033745659761, 0.2348479541369871, 
             0.06175197825101608, -0.04718114182999041, 0.008400797491673479, \

             0.01192517916639287}, {-1.23222676597908, -1.473969978010766, 
             0.2509389357975537, 0.04295023556381035, -0.0428030994569332, 
             0.01270243240769841, 0.009943321676064535}, 
            {-1.381132132554967, -1.421173821015353, 0.2615185199513495, 
             0.02615011505720406, -0.0372470249172224, 0.01458154268469676, 
             0.007183986167612035}, {-1.52451303706018, -1.366709763304248, 
             0.2672792569516805, 0.01175094508843675, -0.03124282318580188, 
             0.01462385001478342, 0.004337814273567681}, 
            {-1.676554155554152, -1.305608867189375, 0.2689638069601199, 
             -0.001217053979193587, -0.02444610851301589, \
0.01402117366548132, 
             0.00224958656739477}, {-1.821639069964926, -1.244590074076928, 
             0.2667220610870114, -0.0113128728396274, -0.01864935539868304, 
             0.01161388704344243, -0.00006065302064348859}, 
            {-1.959823689587621, -1.184436938921008, 0.2615032087283585, 
             -0.01878286271819812, -0.01354138262907623, \
0.009331003691403976, 
             -0.001373910151833233}, 
            {-2.091241362794932, -1.125730764971378, 0.2541299320700626, 
             -0.02404459475853125, -0.009317813474587454, \
0.007160120981883526, 
             -0.002096244383309918}, 
            {-2.216081519973962, -1.068881633376215, 0.2452839969799536, 
             -0.02750822913116375, -0.005921779540154439, \
0.005321449744103576, 
             -0.002335005570329405}, 
            {-2.334572036779301, -1.014160218395938, 0.2355105012068567, 
             -0.02955739610497582, -0.003267957858955671, \
0.003847437519762102, 
             -0.0022646122431367, 0.00008837730146102579}, 
            {-2.466875653158295, -0.9523955635414637, 0.2233247841202344, 
             -0.03060923986977494, -0.0009206404428521231, \
0.002668607114008318, 
             -0.001642610820709008, 0.0002789857387758132}, 
            {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, 
             -0.0305867528862542, 0.0007931576405303536, \
0.002021643534149319, 
             -0.0008785619396256485, 0.0004563152055443385}, 
            {-2.707659006010745, -0.8388172181424984, 0.1987180081228845, 
             -0.02986498356771943, 0.001850571136714643, \
0.001311821166285018, 
             -0.0006006837699262708, 0.0004025249678476842}, 
            {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, 
             -0.02868642525878178, 0.002510879609608891, \
0.0008222015537418208, 
             -0.0003592654655979457, 0.000353765107692091}, 
            {-2.919626045506723, -0.7381571877771078, 0.175586089260012, 
             -0.02723906829815367, 0.002875048835861939, \
0.0004616915237353225, 
             -0.0002051292907194143, 0.0002903776349041168}, 
            {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, 
             -0.02565419087941412, 0.003033030217916483, \
0.0002014497612882507, 
             -0.0001107920060412756, 0.0002269621421637012}, 
            {-3.106117892072866, -0.6493204211172826, 0.1548734590809113, 
             -0.02402116089273098, 0.003055539450422462, \
0.00002599975151483897, 
             -0.00004758785347185354}, 
            {-3.210090129745036, -0.5996681315994481, 0.1433705576419095, 
             -0.02201677832120685, 0.002985222599816919, \
-0.0000958294047673527, 
             -0.00007731102712422072}, 
            {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, 
             -0.02011385735927098, 0.002763124856175378, \
-0.0002864118307802861, 
             -0.0001226612803402779}, 
            {-3.394736399961399, -0.5110487433641276, 0.1232494875931549, 
             -0.01832912002286514, 0.002545956219616085, \
-0.0003344654449797207, 
             -0.00009282872655880584}, 
            {-3.476527520813544, -0.471466600434013, 0.1145100431816513, 
             -0.01668087231558483, 0.002340654063149804, \
-0.0003120801939574286, 
             -0.00004673823831166822}, 
            {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, 
             -0.01517795810854488, 0.00213323204377452, \
-0.0002847408987506403, 
             -0.0000171012438948165}, 
            {-3.62147634589714, -0.4003879298933642, 0.09931907937959756, 
             -0.01381624455578609, 0.0019329271910969, -0.000256584599016029, \

             1.007933302260962*^-6}, 
            {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, 
             -0.01202278498544689, 0.001642061747291683, \
-0.000235249621043713, 
             6.294315540307676*^-6}, 
            {-3.798446943438669, -0.3105342664181361, 0.08122614330861257, 
             -0.01048688148137613, 0.001408458250699894, \
-0.0001884038544520576, 
             0.00001626929459300319}, 
            {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, 
             -0.00917947523972208, 0.001204544204314665, \
-0.0001528026664484259, 
             0.00001925560751478185}, 
            {-3.934630385946802, -0.2365213821444215, 0.06740931090421369, 
             -0.008065641383147081, 0.001029940565630871, \
-0.0001250578171946844, 
             0.0000189522876063627}, 
            {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, 
             -0.007114652075869174, 0.000882042765250185, \
-0.0001030409363367319, 
             0.00001724277618273266}, 
            {-4.036983057207475, -0.1746882790891004, 0.05670238403676125, 
             -0.006300486571572722, 0.0007570421935068591, \
-0.00008565931813226637, 
             0.00001498094973042025}, 
            {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, 
             -0.005388164125577655, 0.0006254981305204854, \
-0.00006275759347351894, 
             0.00001356839613907586}, 
            {-4.129977973626481, -0.1066698407990083, 0.04586552357996159, 
             -0.004640446873950072, 0.0005154961431997248, \
-0.00005002292097234296, 
             0.00001068768379513849}, 
            {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, 
             -0.004021722679494938, 0.0004278764083609402, \
-0.00003998672821139463, 
             8.419621550322354*^-6}, 
            {-4.181992277724197, -0.05114937617478823, 0.03778328353121347, 
             -0.003506550900720839, 0.0003572087299784264, \
-0.00003242813775361963, 
             6.563319850414154*^-6}, 
            {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, 
             -0.003074675807083444, 0.0003001534886949304, \
-0.00002647017776461171, 
             5.129448984486421*^-6}, 
            {-4.200273762534801, -0.005059630122047486, 0.03160865927633907, 
             -0.002710379401726163, 0.0002537304737997015, \
-0.00002179055275345088, 
             4.013488418448823*^-6}, 
            {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, 
             -0.002307804699369244, 0.0002080180677235468, \
-0.00001467874931531174, 
             3.477096307713213*^-6}, 
            {-4.181640046440592, 0.04524848451510998, 0.02542812434125149, 
             -0.001982916488272914, 0.0001688840778693765, \
-0.00001193572980333215, 
             2.498571878633773*^-6}, 
            {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, 
             -0.001716367034850311, 0.0001387847490468397, \
-9.539748932217889*^-6, 
             1.859292472751585*^-6}, 
            {-4.122785355809635, 0.0860961029326029, 0.02083744114211, 
             -0.001496038192667138, 0.0001149375476116196, \
-7.752989220148379*^-6, 
             1.384150391219296*^-6}, 
            {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, 
             -0.001312377553500777, 0.00009598075726336363, \
-6.330002216054171*^-6, 
             1.044385030161512*^-6}, 
            {-4.0309990753539, 0.1198195246330904, 0.01733056688268946, 
             -0.001158156672391711, 0.00008074314435794473, \
-5.205832344760582*^-6, 
             7.956094303782612*^-7}, 
            {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
             -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
             6.853161548526208*^-7}, 
            {-3.862684295208088, 0.1571524415300303, 0.01373487047827056, 
             -0.0008458709268748281, 0.00005292158849075478, \
-2.717703778739206*^-6, 
             4.776227802405111*^-7}, 
            {-3.762840313497239, 0.172874054360284, 0.01230548051000591, 
             -0.000732964029147417, 0.00004313135460575885, \
-2.174487587840614*^-6, 
             3.464779702597154*^-7}, 
            {-3.653990683732458, 0.186983619109208, 0.01106211919053541, 
             -0.0006402696967549964, 0.0000354544481395366, \
-1.769433689206584*^-6, 
             2.525549483911888*^-7}, 
            {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, 
             -0.0005634894736334127, 0.00002940436207093559, \
-1.444926260924889*^-6, 
             1.873187047108245*^-7}, 
            {-3.412804993833292, 0.2111489245800355, 0.009009588330419845, 
             -0.0004994138122043501, 0.00002457256285304119, \
-1.188314081952184*^-6, 
             1.406896678162243*^-7}, 
            {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, 
             -0.0004254398735934686, 0.00001981390334171221, \
-7.142813890569568*^-7, 
             1.214519187305689*^-7}, 
            {-3.028544710651558, 0.2379623057313892, 0.006815353873336178, 
             -0.0003674996746395192, 0.00001563491183483192, \
-5.86375308215994*^-7, 
             8.286497780628049*^-8}, 
            {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, 
             -0.0003211413486115556, 0.00001249454537016901, \
-4.723075689651174*^-7, 
             5.863156687991705*^-8}, 
            {-2.604332817704375, 0.2582797769625237, 0.005162226805369295, 
             -0.0002838187140553005, 0.00001004906765736633, \
-3.87289508354963*^-7, 
             4.18217498152932*^-8}, {-2.380372883980649, 0.2664918453580231, 
             0.004475381304397052, -0.0002535927280720157, \
8.127093887680922*^-6, 
             -3.191386114183283*^-7, 3.041795891583185*^-8}, 
            {-2.149888330991454, 0.273593607663118, 0.00385849017216741, 
             -0.0002290448730929102, 6.587497754854157*^-6, \
-2.659372328911577*^-7, 
             2.240761720314729*^-8}, 
            {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, 
             -0.0002052376119308477, 5.184646117813377*^-6, \
-1.904354091683055*^-7, 
             1.830162350662408*^-8}, 
            {-1.568184016554942, 0.2868392209174812, 0.002575703742891957, 
             -0.0001869906042160404, 3.949989067622175*^-6, \
-1.664155420757597*^-7, 
             1.252617879183773*^-8}, 
            {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, 
             -0.0001730929726651855, 2.962637641249672*^-6, \
-1.425953503160539*^-7, 
             9.048066793624791*^-9}, 
            {-0.9642073675986177, 0.2952248515659734, 0.001495169624718867, 
             -0.0001628678796415216, 2.124382504834869*^-6, \
-1.268869055338464*^-7, 
             6.439368669983838*^-9}, 
            {-0.6568336412300838, 0.2978072625251313, 0.001000424961613838, 
             -0.0001558063063980045, 1.393261933326278*^-6, \
-1.16189512124211*^-7, 
             4.551787476216529*^-9}, 
            {-0.3473080080181212, 0.2993839255588992, 0.0005231945129639924, 
             -0.0001515786954507069, 7.289963028536484*^-7, \
-1.10308871975636*^-7, 
             3.109375691580504*^-9}, 
            {-0.02059882830471778, 0.2999868284345344, \
0.00003089963017686534, 
             -0.0001499710129035118, 7.391732362642512*^-8, \
-1.071809864811129*^-7, 
             2.056959960532262*^-9}, 
            {0.07437607712204962, 0.2999612878079299, -0.0001115897022763641, \

             -0.0001501074630631385, -2.296620186836703*^-7, \
-1.774557747218172*^-7, 
             -1.356351577917269*^-8}}][t])/4}]}, 
   {RGBColor[1, 0, 0], PointSize[0.06], 
    Point[{-InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, \

          {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
            0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
            2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
            4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
            8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
            12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
            16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
            19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
            21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
            22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
            23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
            24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
            25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
            25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
            26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
            26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
            26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
            27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
            27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
            28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
            28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
            29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
            30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
            31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
            33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
            35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
            37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
            40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
            43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
            47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
            51.68339752171315, 52.}}, 
          {{10., 0.}, {9.999999668030779, -0.00009979517922659892, \
-0.01500000077182846}, 
           {9.999999004092288, -0.0001995903672323653, -0.01500000209140642, 
            -1.322286343058508*^-7}, 
           {9.999534630881093, -0.005282323784489644, -0.01500076832270247, 
            -1.507556879980259*^-6}, 
           {9.998209098094816, -0.0103655576280027, -0.01500295585112121, 
            -4.303953042407377*^-6}, 
           {9.996022280142259, -0.01544977367720093, -0.01500656577947253, 
            -7.102518978703048*^-6, -4.12962510774654*^-6}, 
           {9.981400593490121, -0.03342230820498616, -0.01503073261230838, 
            -0.00001911254788268681, -4.721536529157213*^-6}, 
           {9.956013022933289, -0.05143472861659827, -0.01507282525788923, 
            -0.00002843965797539134, -4.17160237245598*^-6}, 
           {9.919829422265767, -0.0695083794671598, -0.0151330970744481, 
            -0.00003863663157999305, -4.230562589262589*^-6}, 
           {9.872806607521704, -0.08766523133166012, -0.01521192543463029, 
            -0.00004907835452562485, -4.318382798300356*^-6}, 
           {9.810383964650146, -0.1072221139199094, -0.01531745094498254, 
            -0.00006058324022271351, -4.43239809319311*^-6}, 
           {9.735385449078862, -0.1269286088610892, -0.01544557929235542, 
            -0.00007254388067269821, -4.588965459026183*^-6}, 
           {9.647705787368241, -0.1468142650452391, -0.01559725578076811, 
            -0.00008504165353778693, -4.780886831038984*^-6}, 
           {9.547220374825469, -0.1669099648103735, -0.01577361976315558, 
            -0.0000981827009109115, -5.012205194280729*^-6, \
-7.221154665556483*^-8}, 
           {9.372446221713216, -0.1974722204799199, -0.01608694927728915, 
            -0.0001195926414170735, -5.787011173022882*^-6, \
-1.168521118499263*^-7}, 
           {9.16803848329466, -0.2286962212754445, -0.01646431261357922, 
            -0.0001429398422662282, -6.364539735664658*^-6, \
-1.186131454734799*^-7}, 
           {8.9333000040121, -0.260711383344569, -0.0169126745304145, 
            -0.0001688916601208405, -7.056168354057571*^-6, \
-1.313845897946621*^-7}, 
           {8.667404587672008, -0.2936619157657202, -0.01744069182536042, 
            -0.0001982621290127823, -7.992802614714835*^-6, \
-1.633035539189112*^-7}, 
           {8.369378216107282, -0.3277105940602582, -0.01805905837960469, 
            -0.0002317412492909662, -9.145034320510493*^-6, \
-2.017315052072494*^-7, 
            -6.674609404533344*^-9}, 
           {7.968828654203694, -0.3701677267394483, -0.01893656311738351, 
            -0.0002787120557484119, -0.00001107459120877045, \
-3.431225329765139*^-7, 
            -1.221235206138657*^-8}, 
           {7.518288034053902, -0.414837109722486, -0.01999077203536757, 
            -0.0003349565845911475, -0.0000134310000281622, \
-4.488420368790152*^-7, 
            -1.346430675352864*^-8}, 
           {7.014966306469673, -0.4621643951747192, -0.02125743383726544, 
            -0.0004024832669310073, -0.00001612207743260069, \
-5.188299501191256*^-7, 
            -1.214130185849565*^-8}, 
           {6.455512902890977, -0.5126865555719547, -0.02278077919181758, 
            -0.0004842873768802196, -0.00001950339211749401, \
-6.266494605200327*^-7, 
            -1.354357959188541*^-8}, 
           {5.971354327636086, -0.5552694173247879, -0.02419934375167602, 
            -0.0005601240439740879, -0.00002240270713257671, \
-6.795896221578519*^-7, 
            -1.201709349193833*^-8}, 
           {5.447344756733164, -0.6006203860064261, -0.02583679655234428, 
            -0.0006452311021927112, -0.00002488203251787149, \
-6.030303672602093*^-7, 
            -1.583376666742293*^-9}, 
           {4.994559169969892, -0.6394373103400424, -0.02732862996656363, 
            -0.0007171994723376593, -0.00002519742550426964, \
-1.641290240708912*^-7, 
            3.910597107780506*^-8}, {4.512594792329623, -0.6805479316610102, 
            -0.02897566532185714, -0.0007858734411303971, \
-0.00002283819031739034, 
            6.281580292262645*^-7, 9.577105762745674*^-8}, 
           {4.092333097008952, -0.7162958456331559, -0.03043328001834313, 
            -0.0008273002171360841, -0.00001411116814184291, \
2.773103753343612*^-6, 
            2.950546781062066*^-7}, {3.650020866463042, -0.7538337447048592, 
            -0.03194053384702654, -0.000837781640951464, \
2.907707968555054*^-6, 
            5.852540359820091*^-6, 5.181368394863152*^-7}, 
           {3.184571840689228, -0.7931742380695744, -0.03340796215459502, 
            -0.0007783073126224044, 0.00004020831399575819, \
0.00001252969451950441, 
            1.050499280912101*^-6}, {2.795135498386905, -0.825830794134082, 
            -0.03443182974317923, -0.0006278837202671806, \
0.0001043308691637567, 
            0.00002636995433250329, 2.548041348411085*^-6}, 
           {2.38977107808601, -0.8593358948133683, -0.03513375184134562, 
            -0.000319913380216462, 0.0002060515099388112, \
0.00004421380258099794, 
            4.001314036998032*^-6}, {1.968166385363971, -0.8932395940637682, 
            -0.03519115346953409, 0.0002827427630627121, \
0.0003953025819406979, 
            0.00008034764600886729, 7.407586137339988*^-6}, 
           {1.612143333988495, -0.9206107463009619, -0.03436732147393313, 
            0.001167408375879762, 0.0006871165481036591, \
0.0001488881693373802, 
            0.00001608512153778298}, 
           {1.245564862078643, -0.9468476617076561, -0.03218992389889563, 
            0.002621839915004895, 0.001129466927246893, \
0.0002361002834123236, 
            0.00002446272968897194}, 
           {0.9411036630779808, -0.9663582346870491, -0.02882442468204031, 
            0.004524953127547926, 0.001773934206673067, \
0.0004076052929450417, 
            0.00005060830769685972}, 
           {0.6308434436758507, -0.9830617967058087, -0.02321559819713965, 
            0.007385850858260214, 0.002672644657907155, \
0.0005975972454227846, 
            0.00007016870897342483}, 
           {0.3159401433660997, -0.9951819807516075, -0.0141810564371504, 
            0.01177969329600485, 0.004105758348508652, 0.0009339734047126293, \

            0.0001125727572013773}, {0.08560933537464546, \
-0.9996129071047306, 
            -0.004482625115979116, 0.01642148422154501, 0.005766813443267503, \

            0.001456041061702653, 0.0002183132824744149}, 
           {-0.1451655451007285, -0.9987483123162489, 0.008944489593331621, 
            0.02264330478484971, 0.007723831164850311, 0.001834097872355712, 
            0.0002401682337663385}, {-0.3749422448675035, \
-0.9905775772121858, 
            0.02741903505059772, 0.03107584026681068, 0.01043305827566561, 
            0.002464002718034116, 0.0003260132232436369}, 
           {-0.6017366959356142, -0.9723927003509583, 0.05264297022337499, 
            0.04225298673259487, 0.01376536310562221, 0.003084637463279821, 
            0.0003748430742714523}, {-0.7738140143777483, \
-0.9491604221345081, 
            0.07814523672066643, 0.0530975554303808, 0.01662705757449755, 
            0.003411909325867013, 0.0003468215640078723}, 
           {-0.9408520004092066, -0.9156991754896342, 0.1099734795798445, 
            0.06584191092106879, 0.01927853582407632, 0.003240100434734713, 
            0.0001440904775641987}, {-1.100807501258846, -0.8695729934305591, \

            0.1490503491214294, 0.08005627726477126, 0.02099483499621253, 
            0.002195345619101353, -0.0003027390708880932}, 
           {-1.22414138467131, -0.82077085304674, 0.1866028279478249, \
0.09179484841508957, 
            0.02021543417588093, -0.000754274587538044, \
-0.001530626941211491}, 
           {-1.339527614124526, -0.7602840760297278, 0.2291397469888283, 
            0.1026147787935418, 0.01746781961115515, -0.004103986580530314, 
            -0.002450338209772962}, {-1.44516147054655, -0.686759968869766, 
            0.2758334004910389, 0.1105177241750504, 0.0106742864278701, 
            -0.009800257288146374, -0.004075343469478164}, 
           {-1.539064653707057, -0.5992161988009501, 0.3249342293604037, 
            0.1131708883596251, -0.0007350026571956852, -0.01685438505251352, \

            -0.005671350902054768}, {-1.619160447134986, -0.4973382762736237, \

            0.3735908896734561, 0.1079524283682205, -0.01688511860132406, 
            -0.02423508582492491, -0.006778310725377359}, 
           {-1.672023718269121, -0.4056993260111488, 0.4096806494224735, 
            0.09666214457796037, -0.03204065521875401, -0.02840436636139767, 
            -0.006444744621113192}, {-1.713702367726152, -0.3061747204096225, \

            0.4406455090291952, 0.0785742469749175, -0.0470257534782241, 
            -0.02861634111365265, -0.00398773686340812}, 
           {-1.743354980747793, -0.2002393810076641, 0.4641460871409876, 
            0.05414735876830688, -0.05977983902013911, -0.02439011013378813, 
            0.00001759514469461788}, 
           {-1.757959254457417, -0.1123882156998269, 0.4761992589402015, 
            0.03131763081762755, -0.0651267030424638, -0.01330108771073375, 
            0.007932614219398512}, {-1.764279633198327, -0.02290728516546019, \

            0.4815191300064316, 0.006382340077340566, -0.06878153330095417, 
            -0.00607622203589427, 0.009921051344796055}, 
           {-1.762223869805497, 0.0669098889538212, 0.4797874360581084, 
            -0.01881564820658439, -0.06715504466041756, 0.0052941015385649, 
            0.014075650991735}, {-1.751822051888362, 0.1557504845998194, 
            0.4711087322811719, -0.04290594361192289, -0.06177008484910881, 
            0.01515215349206186, 0.01548803581768913}, 
           {-1.733224604791979, 0.2423597914699506, 0.4559953383181955, 
            -0.06450374890421965, -0.05309737444319933, 0.02305207122611793, 
            0.01493656511780418}, {-1.706693534600896, 0.325611997587172, 
            0.4353010176743601, -0.08256681154941546, -0.04224156850021461, 
            0.02801462883846634, 0.01250721686243972}, 
           {-1.668692859482766, 0.4123587270420406, 0.4073367414453398, 
            -0.09760253037063431, -0.02888818242959219, 0.0306691934708478, 
            0.009224953760383584}, {-1.622080963140679, 0.4929301210117905, 
            0.3755325162049182, -0.1074178334999123, -0.01633310637884133, 
            0.02856039286749514, 0.004168099462073743}, 
           {-1.567527838465231, 0.5667023943768438, 0.3414871066560261, 
            -0.1122527924612216, -0.005160721979258902, 0.02417131244294108, 
            -0.0003440345314113444}, 
           {-1.505751224868501, 0.6333664485834628, 0.306641269066246, 
            -0.1127997113966985, 0.003903182359577255, 0.01843886863229986, 
            -0.003922050103786528}, {-1.437486215807195, 0.6928851431186745, 
            0.2721892254033128, -0.1099263646846194, 0.01072931196339118, 
            0.01262842140521531, -0.006119419347288539}, 
           {-1.36346007849281, 0.7454381662825406, 0.2390433099240477, 
            -0.1045481470172331, 0.01544034474959015, 0.007498171284307598, 
            -0.006996953823451097}, {-1.27569539364364, 0.7958744566460811, 
            0.2046554692122192, -0.0967041517292661, 0.0185064284735578, 
            0.002960749536155133, -0.006856601949068641}, 
           {-1.182624806837935, 0.8388072225663128, 0.1731584749868979, 
            -0.08779459299724857, 0.01979767319192345, \
-0.0003066249582991479, 
            -0.006028282943382096}, {-1.085063458885453, 0.8749251188130202, 
            0.144782245099154, -0.07854258397670186, 0.01986264568980367, 
            -0.002297713136917443, -0.004783528255310104}, 
           {-0.9837461114773752, 0.9049437715476159, 0.119545938333377, 
            -0.06946500901627999, 0.01908920268180254, -0.003359677058435248, \

            -0.003492310907858758}, {-0.8793265410504286, 0.9295658946373885, \

            0.09732709937304962, -0.0608924971492783, 0.01779753275101055, 
            -0.003788394790891112, -0.002346567941738405}, 
           {-0.7723805707186532, 0.9494556605823984, 0.07791739671236562, 
            -0.05301145859825892, 0.01623278484580223, -0.003814067204285791, \

            -0.00142298197321629, 0.001159542229646304}, 
           {-0.6433048170868872, 0.9677057910471042, 0.05823802142742399, 
            -0.04468096904705857, 0.01441045900308664, -0.002783953394204672, \

            0.001188784376355514, 0.001697085509141072}, 
           {-0.5121095748854393, 0.9810895893644596, 0.04169122596658565, 
            -0.03741547808128195, 0.0128042870890071, -0.001516085052811469, 
            0.002492470180502037, 0.001592641575583569}, 
           {-0.3793958721349377, 0.9903923174534956, 0.02784424034262888, 
            -0.03126812679688145, 0.01073262941726728, -0.002037579725773561, \

            0.001248140166443795, 0.000621510220514931}, 
           {-0.2456664780092288, 0.9962859463080013, 0.01629774299047672, 
            -0.02604465129166512, 0.008980331918121603, \
-0.002095510898895228, 
            0.0006953458839076041, 0.0002187584774474667}, 
           {-0.1113407854287719, 0.9993407044576816, 0.006696023109974216, 
            -0.02163335504587148, 0.007533052625606419, \
-0.001862875274342468, 
            0.0005412212424280951, 0.00009130883576918053}, 
           {0.02323242649556178, 1.000037398259186, -0.001270322947428585, 
            -0.01793006544947133, 0.006305477814234636, \
-0.001607987009029117, 
            0.0004376460542311089, 0.00002422708367731202}, 
           {0.1577637429652595, 0.9987796241790409, -0.007866224138143035, 
            -0.01483069730268437, 0.00526623201595544, -0.001376927490964432, \

            0.0003454596158002636}, {0.3238530675731096, 0.995016345930049, 
            -0.0144640796213406, -0.0116871546883609, 0.004231198363091821, 
            -0.001064594641186693, 0.0003322772383557684}, 
           {0.4891462415685021, 0.9892980145152426, -0.01965510139244523, 
            -0.00917301401911442, 0.003397859160363781, \
-0.000819933720088739, 
            0.0002972842358494771}, {0.6533538559313423, 0.9820447155621451, 
            -0.02372070399070088, -0.007162526259702596, \
0.002726309336887593, 
            -0.0006384642833766479, 0.0002509980162091398}, 
           {0.8162492234476889, 0.9735925497470967, -0.02688566131071034, 
            -0.005553834168748899, 0.002185764859300605, \
-0.0005041528357430196, 
            0.000204352772054328}, {0.9776558814470167, 0.9642105857215122, 
            -0.02932920777076483, -0.004264733145196217, \
0.001753679572068895, 
            -0.0003999863031745657, 0.0001643010647412814}, 
           {1.137437570202047, 0.9541144596710516, -0.03119425522545939, 
            -0.003230475051281675, 0.001408187583593927, \
-0.000318863443275577, 
            0.0001310475300282612}, {1.373962009270192, 0.9379913626951294, 
            -0.03315104071340928, -0.002035992528092278, \
0.001055017058722285, 
            -0.0001754137530066389, 0.0001168833024258509}, 
           {1.606350517388015, 0.9210897263708773, -0.03435027793903866, 
            -0.001185643298369978, 0.0007611892730192848, \
-0.0001263674244384825, 
            0.00008320952677836924}, 
           {1.834451124462977, 0.9037326412745143, -0.03500295728260755, 
            -0.0005720113774542266, 0.0005488589661374675, \
-0.0000923366591773421, 
            0.00005900095063806828}, 
           {2.05818068749326, 0.8861532298832889, -0.03526139771076708, 
            -0.0001299066826636304, 0.0003943010523705895, \
-0.00006860755394809425, 
            0.00004172858547342076}, 
           {2.277505796363031, 0.8685194772734156, -0.03523617500405487, 
            0.0001875161539186697, 0.0002818251856303586, \
-0.0000511645549180407, 
            0.00002968880418123365}, 
           {2.492428788195139, 0.8509519705097273, -0.03500799092175404, 
            0.0004136601693357046, 0.0001995415136804703, \
-0.00003828804738911866, 
            0.00002124715551700476}, 
           {2.772238550718317, 0.8277725006882704, -0.03448789441543038, 
            0.0006187349731000154, 0.0001352320034684956, \
-0.00001425422529863956, 
            0.00001755451345997014}, 
           {3.044385230797065, 0.8049972229139195, -0.03380947075089432, 
            0.0007368050289671234, 0.00007834634628596583, \
-0.00001122391314621417, 
            0.00001113870188222071}, 
           {3.309018587737515, 0.7827080320625583, -0.03303896113559139, 
            0.0008026315339952361, 0.00004206218440122728, \
-7.530342783184703*^-6, 
            7.421851557590777*^-6}, {3.566309067033361, 0.7609505320860362, 
            -0.0322207398277254, 0.0008326581797725729, \
0.00001753263227045104, 
            -5.206456476998877*^-6, 4.91783556921768*^-6}, 
           {3.81643803262864, 0.7397459514613501, -0.03138449367913013, 
            0.000838939799644164, 1.35077760291538*^-6, \
-3.443913900758643*^-6, 
            3.303169942357289*^-6}, {4.059591012015883, 0.7190992617954302, 
            -0.03054996995098544, 0.0008294710638224421, \
-9.266693762532051*^-6, 
            -2.176304405457542*^-6, 2.235395158274695*^-6}, 
           {4.372585721165242, 0.6924846048814831, -0.02946402757201999, 
            0.0008029885517503858, -0.00001512205360717179, \
8.250783523782558*^-7, 
            1.79238678863533*^-6}, {4.673987267678016, 0.6668147871373053, 
            -0.02842204472668379, 0.0007647138190854807, \
-0.00002078611834098472, 
            6.541365780799917*^-7, 1.049737140101165*^-6}, 
           {4.964205394312013, 0.6420460382904659, -0.02743350214751175, 
            0.0007221979607514677, -0.00002314976507814556, \
7.761061031756697*^-7, 
            6.481760049899586*^-7}, {5.243628875125201, 0.6181288506037192, 
            -0.02650242749678078, 0.0006781875255987336, \
-0.00002393452362995146, 
            7.931800302684875*^-7, 3.914720523938617*^-7}, 
           {5.5126240130368, 0.5950117248664654, -0.0256295578461628, 
            0.0006345834841070335, -0.00002369251940469708, \
8.021342089770415*^-7, 
            2.362291693947091*^-7}, {5.771534255654154, 0.5726434521487585, 
            -0.02481369104364359, 0.0005924255277376992, \
-0.00002288648698303586, 
            7.853559496375988*^-7, 1.392154952244304*^-7}, 
           {6.108778136511332, 0.5432709949881284, -0.02378916494031363, 
            0.0005385767396017946, -0.00002090222196923115, \
9.634231569526953*^-7, 
            1.031660310217783*^-7}, {6.428627940347904, 0.5150795809575441, 
            -0.02285881763700148, 0.000488650474985677, \
-0.00001936889068213984, 
            7.862704461763962*^-7, 4.236373274532015*^-8}, 
           {6.731764237016638, 0.4879601358421129, -0.02201464865538692, 
            0.0004432614671721073, -0.00001769376947598321, \
6.751452578811216*^-7, 
            1.316367698170899*^-8}, {7.018804533876454, 0.4618132537833407, 
            -0.02124878476612005, 0.000402127590503264, \
-0.00001608643168964409, 
            5.795259274427188*^-7, -2.64641555573496*^-9}, 
           {7.29030909335201, 0.4365487805184312, -0.02055383300618015, 
            0.0003649289266705499, -0.00001458398933991611, \
5.033512661358331*^-7, 
            -9.988169502319166*^-9}, 
           {7.546786291865488, 0.4120851279505025, -0.01992303747611581, 
            0.0003312779634424161, -0.00001322154918966636, \
4.37551534672063*^-7, 
            -1.324910477258141*^-8}, 
           {7.884086056271611, 0.3787788434178949, -0.01913029312120552, 
            0.0002891023262879505, -0.0000115291594594324, \
3.63777393971772*^-7, 
            -1.371373898326033*^-8}, 
           {8.193519584742434, 0.3467373043198655, -0.01843847943647414, 
            0.0002522379007700076, -0.00001012456090970589, \
2.940570752419515*^-7, 
            -1.367577777664127*^-8}, 
           {8.476095686537853, 0.3157992553430406, -0.01783509007823322, 
            0.0002198514717341092, -8.938518663488416*^-6, \
2.402965656917715*^-7, 
            -1.240599571914663*^-8}, 
           {8.732694164207696, 0.2858229861605473, -0.01730967605233079, 
            0.0001911921984056844, -7.945451424014868*^-6, \
1.975592634101514*^-7, 
            -1.078283810070344*^-8}, 
           {8.964081092156048, 0.2566830884024056, -0.01685353056247505, 
            0.0001656356738916059, -7.115162259841*^-6, \
1.634975150107237*^-7, 
            -9.131086931191294*^-9}, 
           {9.170921496420231, 0.2282677220189242, -0.01645941987193715, 
            0.0001426479705924626, -6.427511170842572*^-6, \
1.348052317356517*^-7, 
            -7.720497902122285*^-9}, 
           {9.389954355144068, 0.1945852773909356, -0.01605562025513275, 
            0.000117523846926549, -5.77104513440084*^-6, \
1.004193245520244*^-7, 
            -6.84435365281206*^-9}, {9.574487972549572, 0.1616616916001712, 
            -0.01572586742018316, 0.00009490549903810554, \
-5.233270606636592*^-6, 
            7.898604003413424*^-8, -5.485421307730566*^-9}, 
           {9.725231796860384, 0.1293508421880767, -0.01546336168132292, 
            0.00007419723225491459, -4.824923276518464*^-6, \
5.934261569317994*^-8, 
            -4.554919700878265*^-9}, 
           {9.842750599262039, 0.09751900870274404, -0.01526288472030978, 
            0.000054940201293084, -4.52067132704201*^-6, \
4.262303874918333*^-8, 
            -3.808526825726381*^-9}, 
           {9.927475673864893, 0.06604185470753681, -0.0151205676271804, 
            0.00003672919236845725, -4.308672419068996*^-6, \
2.762596707450741*^-8, 
            -3.249881860652005*^-9}, 
           {9.979713178406525, 0.03480181166196349, -0.01503372618961092, 
            0.00001920328638020516, -4.180602396326156*^-6, \
1.358486971789759*^-8, 
            -2.853196789546286*^-9}, 
           {9.999804221413857, 0.002079784470556782, -0.01500049198937566, 
            1.146333605182019*^-6, -4.131571602154404*^-6, \
-1.008292044867596*^-9, 
            -2.604590129466682*^-9}, 
           {9.998959082774867, -0.007418778925791529, -0.01500187815261033, 
            -4.065399346041674*^-6, -4.111443091414769*^-6, \
7.927537361729354*^-9, 
            3.188545681628212*^-10}}][t]/4, 
      -InterpolatingFunction[{{0., 52.}}, {1, 7, False, Real, {1}, {0}}, 
          {{0., 0.003326505803053839, 0.006653011606107678, \
0.1760731080602622, 
            0.3454932045144168, 0.5149133009685714, 1.113321247101875, \
1.711729193235179, 
            2.310137139368483, 2.908545085501787, 3.549213715257329, \
4.189882345012872, 
            4.830550974768414, 5.471219604523957, 6.430775161993191, \
7.390330719462426, 
            8.349886276931659, 9.309441834400892, 10.26899739187012, \
11.41745542047073, 
            12.56591344907135, 13.71437147767196, 14.86282950627257, \
15.76989538380499, 
            16.6769612613374, 17.40744088188177, 18.13792050242614, \
18.7397772796289, 
            19.34163405683166, 19.94349083403443, 20.42462129550812, \
20.90575175698181, 
            21.3868822184555, 21.77942040848143, 22.17195859850736, \
22.49017329751688, 
            22.80838799652641, 23.12660269553594, 23.35744832997994, \
23.58829396442394, 
            23.81913959886794, 24.04998523331195, 24.22894594708866, \
24.40790666086538, 
            24.5868673746421, 24.73263739132645, 24.87840740801079, \
25.02417742469514, 
            25.16994744137948, 25.31571745806383, 25.43261413721928, \
25.54951081637472, 
            25.66640749553017, 25.75972519687526, 25.85304289822035, \
25.94636059956543, 
            26.03967830091052, 26.1329960022556, 26.22631370360069, \
26.32916651294125, 
            26.43201932228183, 26.5348721316224, 26.63772494096296, \
26.74057775030353, 
            26.8434305596441, 26.95721757772128, 27.07100459579846, \
27.18479161387564, 
            27.29857863195281, 27.41236565002999, 27.52615266810717, \
27.6607436925243, 
            27.79533471694143, 27.92992574135857, 28.0645167657757, \
28.19910779019284, 
            28.33369881460997, 28.4682898390271, 28.63486540147832, \
28.80144096392953, 
            28.96801652638075, 29.13459208883196, 29.30116765128317, \
29.46774321373439, 
            29.7177331909978, 29.9677231682612, 30.2177131455246, \
30.46770312278801, 
            30.71769310005141, 30.96768307731482, 31.30105415814421, \
31.6344252389736, 
            31.967796319803, 32.30116740063239, 32.63453848146179, \
32.96790956229118, 
            33.41142573145399, 33.85494190061679, 34.2984580697796, \
34.7419742389424, 
            35.18549040810521, 35.62900657726801, 36.23354433912698, \
36.83808210098595, 
            37.44261986284493, 38.0471576247039, 38.65169538656287, \
39.25623314842184, 
            40.10946709220665, 40.96270103599147, 41.81593497977629, \
42.6691689235611, 
            43.52240286734591, 44.37563681113073, 45.41195548490509, \
46.44827415867943, 
            47.48459283245379, 48.52091150622815, 49.5572301800025, \
50.59354885377685, 
            51.68339752171315, 52.}}, 
          {{0., 0.3}, {0.0009979517077872255, 0.2999999900409223, \
-1.496927738092378*^-6}, 
           {0.001995903349316586, 0.299999970122765, -2.993855789253197*^-6, 
            -0.0001500000440689237}, {0.05282074703033888, \
0.2999860382470232, 
            -0.00007923886649939536, -0.0001500117406492253}, 
           {0.1036410413319679, 0.299946265368849, -0.0001555200493943675, 
            -0.0001500829092720493}, {0.1544524067542601, 0.2998806333275119, \

            -0.0002318722535893141, -0.0001502226433836075, \
-2.061947113752874*^-7}, 
           {0.3337902862308161, 0.2994412445837021, -0.0005026462546543925, 
            -0.0001512573923248744, -3.56926535101178*^-7}, 
           {0.5127656407898185, 0.2986762013592599, -0.0007762976603711723, 
            -0.0001532344335889719, -6.696147194160083*^-7}, 
           {0.6911846639419304, 0.2975811261907948, -0.001054430187904299, 
            -0.0001561772311865011, -1.0428234784246*^-6}, 
           {0.868848049581404, 0.2961496636728365, -0.001338713029291882, 
            -0.0001600680606887075, -1.43126921114028*^-6}, 
           {1.05798950032964, 0.2942346427695965, -0.001651893195715194, 
            -0.0001652995935706142, -1.838046254173493*^-6}, 
           {1.245773954048422, 0.2919112807621309, -0.001976470827894482, 
            -0.000171839413657207, -2.313982825558378*^-6}, 
           {1.431934770245561, 0.2891633697453571, -0.002314981271114216, 
            -0.0001797480698000253, -2.828724047048563*^-6}, 
           {1.616193851195026, 0.28597129085274, -0.002670225693750562, 
            -0.0001891832977074768, -3.397434289546612*^-6, \
-1.775364723929283*^-7}, 
           {1.887969116886099, 0.2803076374177811, -0.003240529009765943, 
            -0.0002072780859326736, -5.221261131605496*^-6, \
-2.788381938828235*^-7}, 
           {2.153768380769201, 0.2734970220318928, -0.003867818935861487, 
            -0.0002294381802057415, -6.431829724465898*^-6, \
-2.655783988637725*^-7}, 
           {2.412433330554526, 0.2654158466017701, -0.004567259996799199, 
            -0.0002572619737618737, -7.902611695922691*^-6, \
-2.860666162534704*^-7}, 
           {2.662673326125159, 0.2559082295468512, -0.005357876121799781, 
            -0.0002926858378040523, -9.973696094715828*^-6, \
-3.588711908498042*^-7}, 
           {2.903028607000796, 0.244776794952918, -0.006264023860191164, 
            -0.0003376675751241998, -0.00001266075107069725, \
-4.594667989404502*^-7, 
            -1.747260442740121*^-8}, {3.175344187221096, 0.2289633086353855, 
            -0.007545671364715371, -0.0004088562867722723, \
-0.00001760680137464635, 
            -8.727270794121078*^-7, -3.447284626861373*^-8}, 
           {3.427693211989913, 0.2098940230544755, -0.009114079092598725, 
            -0.0005060976270138674, -0.00002445938672013374, \
-1.283289477521906*^-6, 
            -4.451638240754114*^-8}, {3.65591142716557, 0.186792033285195, 
            -0.01107850554171452, -0.0006407044351002397, \
-0.00003391896655161902, 
            -1.770630454265917*^-6, -5.499941220723898*^-8}, 
           {3.85478077194519, 0.1585724953229884, -0.01360311058181845, 
            -0.0008339122439545453, -0.0000489443172128367, \
-2.712322351006786*^-6, 
            -8.766377802768383*^-8}, {3.986763005165946, 0.131667061984029, 
            -0.01615666214412804, -0.001051626041925007, \
-0.00006869661225566872, 
            -4.393137681215513*^-6, -1.761332361311671*^-7}, 
           {4.092061561834391, 0.0995298917764175, -0.01940869599958157, 
            -0.001352395704445139, -0.00009571282431003663, \
-6.281214100632805*^-6, 
            -2.444479897469488*^-7}, {4.153850886158325, 0.06883885260811142, \

            -0.02272856290784795, -0.001690501313216549, \
-0.0001316398123092309, 
            -9.940863233820019*^-6, -4.806638869588175*^-7}, 
           {4.191306423956496, 0.03269842564989161, -0.02691267068137347, 
            -0.002148302610858181, -0.0001796379888607316, \
-0.00001388813348710936, 
            -6.486429479295039*^-7}, {4.200742249681569, \
-0.002208228754422552, 
            -0.0312395051651517, -0.002663840093236035, \
-0.0002423648979153841, 
            -0.00002118918286358118, -1.197910773667203*^-6}, 
           {4.187480484699273, -0.04294029965292303, -0.03664374955205367, 
            -0.003351432661554625, -0.0003255129417403924, \
-0.00002918221867922413, 
            -1.604121647400555*^-6}, {4.147582708325752, \
-0.09101196819194772, 
            -0.04351056025037764, -0.004295458408425854, \
-0.0004497713933866242, 
            -0.00004287189467316768, -2.47885545821094*^-6}, 
           {4.093216338662262, -0.1360882405850764, -0.05042227215046736, 
            -0.005319578435935783, -0.0006006220945709141, \
-0.00006396231737026914, 
            -4.409656157769888*^-6}, {4.015439499996313, -0.1885954484836499, \

            -0.05903393771043326, -0.006668642152566507, \
-0.0007954597141818747, 
            -0.00008583296722324174, -5.6762468467354*^-6}, 
           {3.910243506625146, -0.2504281729333795, -0.06991601053462865, 
            -0.008485369119217001, -0.001075857440459364, \
-0.0001215320852716722, 
            -8.352309163308866*^-6}, {3.800626326934144, -0.3095265512549151, \

            -0.0810211001084475, -0.01044535109360783, -0.001399096395540943, \

            -0.0001697669761996192, -0.00001320335121470718}, 
           {3.665972999146803, -0.378327542653802, -0.09474229302615215, 
            -0.01295459443587661, -0.001793921254600053, \
-0.0002144492937412613, 
            -0.00001551062565886725}, 
           {3.535553015059292, -0.4428061177064114, -0.1082883390327763, 
            -0.01550358393254631, -0.00220095651893553, \
-0.0002668360165914096, 
            -0.00002028150696806179}, 
           {3.383157176300779, -0.5167289059824787, -0.1245035267716008, 
            -0.01856317910150786, -0.00262862077236768, \
-0.0002906382154606718, 
            -0.00001715551624775262}, 
           {3.20549373901541, -0.6019516096016301, -0.1438811536990364, 
            -0.02213377125985196, -0.003028422675279043, \
-0.0002756180044960396, 
            -7.146543113549753*^-6}, {3.058588130827458, -0.6720624861181122, \

            -0.1601545679841135, -0.02490566730718879, -0.003089766360970424, \

            -0.00009058479323536484, 0.00004914842109632001}, 
           {2.894596323375797, -0.7501316342604838, -0.1783524392815316, 
            -0.02765292754581667, -0.002939806242666361, \
0.0001373209277761948, 
            0.00009530669209766431}, {2.71158077479672, -0.8370178977712138, 
            -0.1982936201330007, -0.02988428120237179, -0.002118996299412064, \

            0.0007045924544449787, 0.0002210082169551333}, 
           {2.507421795656775, -0.9334055715055376, -0.2193614638360956, 
            -0.03078067221328464, -0.0001732800370884182, \
0.001720488442029996, 
            0.000425988858941995}, {2.33317849523205, -1.014847597695069, 
            -0.2356208100425164, -0.02955058544284709, 0.003046032316439744, 
            0.003590979279397424, 0.0009523908779487415}, 
           {2.143850052796314, -1.101919841659889, -0.2505885269406052, 
            -0.0257551642988426, 0.007412414361894901, 0.005279973333030467, 
            0.001200620682765593}, {1.938487117181982, -1.193862438764723, 
            -0.2624730364011236, -0.0178540166471961, 0.01421257642856188, 
            0.008004913431379991, 0.001735470468834257}, 
           {1.75883264928784, -1.271316953078838, -0.2681090023709465, 
            -0.007281781650419494, 0.02174468381572495, 0.01086883249466218, 
            0.002351071097237822}, {1.567803973134603, -1.34965284368106, 
            -0.2681888997706034, 0.007755152293289466, 0.03018262959327178, 
            0.01265091525278751, 0.002225662920469842}, 
           {1.365404745815049, -1.426949826614714, -0.2606107999898968, 
            0.02785461651196843, 0.03933114451231477, 0.01367846572910126, 
            0.001805339147952605}, {1.151964525852244, -1.500657049331877, 
            -0.2432083773649155, 0.05271498302494613, 0.04725609485920589, 
            0.0121762506290482, 0.0003961782992654656}, 
           {0.9282290908341909, -1.567631287112038, -0.2141720714913058, 
            0.08087452593462236, 0.05143956554555599, 0.006857316057938279, 
            -0.002194862118939511}, {0.7421893162287318, -1.614082667611147, 
            -0.1818521353382827, 0.1036384967185181, 0.04854416792859499, 
            -0.004146149653291475, -0.007592239941335828}, 
           {0.5511972731511882, -1.652053966237579, -0.1417298011263864, 
            0.1248433419007408, 0.04251471658064646, -0.01247735974733354, 
            -0.00930666804245882}, {0.3563470626035425, -1.679827849714072, 
            -0.0948729889153013, 0.1416220962583256, 0.03002609653483467, 
            -0.02382700420146366, -0.01205675068522526}, 
           {0.1988803856063542, -1.693747230698574, -0.05387307904427518, 
            0.1504911307725392, 0.01707885010501343, -0.03104601206841266, 
            -0.01239134837489694}, {0.04047800614247131, -1.699822619873736, 
            -0.01104749066017452, 0.1544758791615086, 0.002904805753834867, 
            -0.03443803199776515, -0.009858086267061791}, 
           {-0.1181161136909721, -1.697846420748768, 0.03215863828671498, 
            0.1531408660534355, -0.01167634603044878, -0.03485997177461622, 
            -0.006216287801323393}, {-0.27615166724078, -1.687886476853531, 
            0.07426415750684713, 0.1466406120061692, -0.02502213731263542, 
            -0.03148565897311392, -0.001319145505838771}, 
           {-0.4328973298464462, -1.670279487280053, 0.1138913571118683, 
            0.1355750756867236, -0.03599301035345136, -0.02507396577743876, 
            0.003789060726332308}, {-0.5876646366009311, -1.645599954367274, 
            0.149886984217886, 0.1209186002645799, -0.04381958582674411, 
            -0.0167474495269128, 0.008221944332663039}, 
           {-0.7552067273082034, -1.611122048795638, 0.1843500532498049, 
            0.1019891041979152, -0.04877571161287061, -0.007753678783690814, 
            0.01076270805849416}, {-0.9188591999930354, -1.57017430368858, 
            0.2127277830279036, 0.0818110606661343, -0.04943939416432463, 
            0.001581489445512773, 0.01250845176538342}, 
           {-1.078022007311201, -1.524033745659761, 0.2348479541369871, 
            0.06175197825101608, -0.04718114182999041, 0.008400797491673479, 
            0.01192517916639287}, {-1.23222676597908, -1.473969978010766, 
            0.2509389357975537, 0.04295023556381035, -0.0428030994569332, 
            0.01270243240769841, 0.009943321676064535}, 
           {-1.381132132554967, -1.421173821015353, 0.2615185199513495, 
            0.02615011505720406, -0.0372470249172224, 0.01458154268469676, 
            0.007183986167612035}, {-1.52451303706018, -1.366709763304248, 
            0.2672792569516805, 0.01175094508843675, -0.03124282318580188, 
            0.01462385001478342, 0.004337814273567681}, 
           {-1.676554155554152, -1.305608867189375, 0.2689638069601199, 
            -0.001217053979193587, -0.02444610851301589, 0.01402117366548132, \

            0.00224958656739477}, {-1.821639069964926, -1.244590074076928, 
            0.2667220610870114, -0.0113128728396274, -0.01864935539868304, 
            0.01161388704344243, -0.00006065302064348859}, 
           {-1.959823689587621, -1.184436938921008, 0.2615032087283585, 
            -0.01878286271819812, -0.01354138262907623, 0.009331003691403976, \

            -0.001373910151833233}, {-2.091241362794932, -1.125730764971378, 
            0.2541299320700626, -0.02404459475853125, -0.009317813474587454, 
            0.007160120981883526, -0.002096244383309918}, 
           {-2.216081519973962, -1.068881633376215, 0.2452839969799536, 
            -0.02750822913116375, -0.005921779540154439, \
0.005321449744103576, 
            -0.002335005570329405}, {-2.334572036779301, -1.014160218395938, 
            0.2355105012068567, -0.02955739610497582, -0.003267957858955671, 
            0.003847437519762102, -0.0022646122431367, \
0.00008837730146102579}, 
           {-2.466875653158295, -0.9523955635414637, 0.2233247841202344, 
            -0.03060923986977494, -0.0009206404428521231, \
0.002668607114008318, 
            -0.001642610820709008, 0.0002789857387758132}, 
           {-2.591088702967029, -0.8939472474122327, 0.2109425067876435, 
            -0.0305867528862542, 0.0007931576405303536, 0.002021643534149319, \

            -0.0008785619396256485, 0.0004563152055443385}, 
           {-2.707659006010745, -0.8388172181424984, 0.1987180081228845, 
            -0.02986498356771943, 0.001850571136714643, 0.001311821166285018, \

            -0.0006006837699262708, 0.0004025249678476842}, 
           {-2.817028698996167, -0.7869293117380876, 0.1868844408054953, 
            -0.02868642525878178, 0.002510879609608891, \
0.0008222015537418208, 
            -0.0003592654655979457, 0.000353765107692091}, 
           {-2.919626045506723, -0.7381571877771078, 0.175586089260012, 
            -0.02723906829815367, 0.002875048835861939, \
0.0004616915237353225, 
            -0.0002051292907194143, 0.0002903776349041168}, 
           {-3.015860140566406, -0.6923447237997232, 0.1649036297205248, 
            -0.02565419087941412, 0.003033030217916483, \
0.0002014497612882507, 
            -0.0001107920060412756, 0.0002269621421637012}, 
           {-3.106117892072866, -0.6493204211172826, 0.1548734590809113, 
            -0.02402116089273098, 0.003055539450422462, \
0.00002599975151483897, 
            -0.00004758785347185354}, 
           {-3.210090129745036, -0.5996681315994481, 0.1433705576419095, 
            -0.02201677832120685, 0.002985222599816919, \
-0.0000958294047673527, 
            -0.00007731102712422072}, 
           {-3.306101574544106, -0.5536834922534725, 0.1328472873662427, 
            -0.02011385735927098, 0.002763124856175378, \
-0.0002864118307802861, 
            -0.0001226612803402779}, {-3.394736399961399, \
-0.5110487433641276, 
            0.1232494875931549, -0.01832912002286514, 0.002545956219616085, 
            -0.0003344654449797207, -0.00009282872655880584}, 
           {-3.476527520813544, -0.471466600434013, 0.1145100431816513, 
            -0.01668087231558483, 0.002340654063149804, \
-0.0003120801939574286, 
            -0.00004673823831166822}, 
           {-3.551960275086282, -0.4346630130552844, 0.1065570990233334, 
            -0.01517795810854488, 0.00213323204377452, \
-0.0002847408987506403, 
            -0.0000171012438948165}, {-3.62147634589714, -0.4003879298933642, \

            0.09931907937959756, -0.01381624455578609, 0.0019329271910969, 
            -0.000256584599016029, 1.007933302260962*^-6}, 
           {-3.715570806053682, -0.3532036350111527, 0.08964950628084922, 
            -0.01202278498544689, 0.001642061747291683, \
-0.000235249621043713, 
            6.294315540307676*^-6}, {-3.798446943438669, -0.3105342664181361, \

            0.08122614330861257, -0.01048688148137613, 0.001408458250699894, 
            -0.0001884038544520576, 0.00001626929459300319}, 
           {-3.871159570071973, -0.2718037895607341, 0.07386514440783659, 
            -0.00917947523972208, 0.001204544204314665, \
-0.0001528026664484259, 
            0.00001925560751478185}, {-3.934630385946802, \
-0.2365213821444215, 
            0.06740931090421369, -0.008065641383147081, 0.001029940565630871, \

            -0.0001250578171946844, 0.0000189522876063627}, 
           {-3.989667693788011, -0.2042686509665383, 0.06172568788923138, 
            -0.007114652075869174, 0.000882042765250185, \
-0.0001030409363367319, 
            0.00001724277618273266}, {-4.036983057207475, \
-0.1746882790891004, 
            0.05670238403676125, -0.006300486571572722, \
0.0007570421935068591, 
            -0.00008565931813226637, 0.00001498094973042025}, 
           {-4.089141669394019, -0.1388772341346019, 0.05087075128427734, 
            -0.005388164125577655, 0.0006254981305204854, \
-0.00006275759347351894, 
            0.00001356839613907586}, {-4.129977973626481, \
-0.1066698407990083, 
            0.04586552357996159, -0.004640446873950072, \
0.0005154961431997248, 
            -0.00005002292097234296, 0.00001068768379513849}, 
           {-4.160607102404618, -0.07756530193825572, 0.04154165509616745, 
            -0.004021722679494938, 0.0004278764083609402, \
-0.00003998672821139463, 
            8.419621550322354*^-6}, {-4.181992277724197, \
-0.05114937617478823, 
            0.03778328353121347, -0.003506550900720839, \
0.0003572087299784264, 
            -0.00003242813775361963, 6.563319850414154*^-6}, 
           {-4.194970580420816, -0.02707716769868808, 0.03449735446282021, 
            -0.003074675807083444, 0.0003001534886949304, \
-0.00002647017776461171, 
            5.129448984486421*^-6}, {-4.200273762534801, \
-0.005059630122047486, 
            0.03160865927633907, -0.002710379401726163, \
0.0002537304737997015, 
            -0.00002179055275345088, 4.013488418448823*^-6}, 
           {-4.196527059133943, 0.02146125572686395, 0.02827767779621063, 
            -0.002307804699369244, 0.0002080180677235468, \
-0.00001467874931531174, 
            3.477096307713213*^-6}, {-4.181640046440592, 0.04524848451510998, \

            0.02542812434125149, -0.001982916488272914, \
0.0001688840778693765, 
            -0.00001193572980333215, 2.498571878633773*^-6}, 
           {-4.15673652658868, 0.06668802481335287, 0.02297121363625496, 
            -0.001716367034850311, 0.0001387847490468397, \
-9.539748932217889*^-6, 
            1.859292472751585*^-6}, {-4.122785355809635, 0.0860961029326029, 
            0.02083744114211, -0.001496038192667138, 0.0001149375476116196, 
            -7.752989220148379*^-6, 1.384150391219296*^-6}, 
           {-4.080627749673199, 0.1037340341763129, 0.0189718502418653, 
            -0.001312377553500777, 0.00009598075726336363, \
-6.330002216054171*^-6, 
            1.044385030161512*^-6}, {-4.0309990753539, 0.1198195246330904, 
            0.01733056688268946, -0.001158156672391711, \
0.00008074314435794473, 
            -5.205832344760582*^-6, 7.956094303782612*^-7}, 
           {-3.952475311563787, 0.1395697189638076, 0.01539196079309724, 
            -0.0009845094817148179, 0.00006584206721644325, \
-3.320123427647478*^-6, 
            6.853161548526208*^-7}, {-3.862684295208088, 0.1571524415300303, 
            0.01373487047827056, -0.0008458709268748281, \
0.00005292158849075478, 
            -2.717703778739206*^-6, 4.776227802405111*^-7}, 
           {-3.762840313497239, 0.172874054360284, 0.01230548051000591, 
            -0.000732964029147417, 0.00004313135460575885, \
-2.174487587840614*^-6, 
            3.464779702597154*^-7}, {-3.653990683732458, 0.186983619109208, 
            0.01106211919053541, -0.0006402696967549964, \
0.0000354544481395366, 
            -1.769433689206584*^-6, 2.525549483911888*^-7}, 
           {-3.537046154954697, 0.1996855178939522, 0.009972121764422109, 
            -0.0005634894736334127, 0.00002940436207093559, \
-1.444926260924889*^-6, 
            1.873187047108245*^-7}, {-3.412804993833292, 0.2111489245800355, 
            0.009009588330419845, -0.0004994138122043501, \
0.00002457256285304119, 
            -1.188314081952184*^-6, 1.406896678162243*^-7}, 
           {-3.226384080591982, 0.2254888689910921, 0.00782863863198294, 
            -0.0004254398735934686, 0.00001981390334171221, \
-7.142813890569568*^-7, 
            1.214519187305689*^-7}, {-3.028544710651558, 0.2379623057313892, 
            0.006815353873336178, -0.0003674996746395192, \
0.00001563491183483192, 
            -5.86375308215994*^-7, 8.286497780628049*^-8}, 
           {-2.820766127855042, 0.2488246275196445, 0.005935351079990573, 
            -0.0003211413486115556, 0.00001249454537016901, \
-4.723075689651174*^-7, 
            5.863156687991705*^-8}, {-2.604332817704375, 0.2582797769625237, 
            0.005162226805369295, -0.0002838187140553005, \
0.00001004906765736633, 
            -3.87289508354963*^-7, 4.18217498152932*^-8}, 
           {-2.380372883980649, 0.2664918453580231, 0.004475381304397052, 
            -0.0002535927280720157, 8.127093887680922*^-6, \
-3.191386114183283*^-7, 
            3.041795891583185*^-8}, {-2.149888330991454, 0.273593607663118, 
            0.00385849017216741, -0.0002290448730929102, \
6.587497754854157*^-6, 
            -2.659372328911577*^-7, 2.240761720314729*^-8}, 
           {-1.862461949229833, 0.2808796276058946, 0.003184570856174013, 
            -0.0002052376119308477, 5.184646117813377*^-6, \
-1.904354091683055*^-7, 
            1.830162350662408*^-8}, {-1.568184016554942, 0.2868392209174812, 
            0.002575703742891957, -0.0001869906042160404, \
3.949989067622175*^-6, 
            -1.664155420757597*^-7, 1.252617879183773*^-8}, 
           {-1.268364868295478, 0.2915909328124841, 0.002016731272518744, 
            -0.0001730929726651855, 2.962637641249672*^-6, \
-1.425953503160539*^-7, 
            9.048066793624791*^-9}, {-0.9642073675986177, 0.2952248515659734, \

            0.001495169624718867, -0.0001628678796415216, \
2.124382504834869*^-6, 
            -1.268869055338464*^-7, 6.439368669983838*^-9}, 
           {-0.6568336412300838, 0.2978072625251313, 0.001000424961613838, 
            -0.0001558063063980045, 1.393261933326278*^-6, \
-1.16189512124211*^-7, 
            4.551787476216529*^-9}, {-0.3473080080181212, 0.2993839255588992, \

            0.0005231945129639924, -0.0001515786954507069, \
7.289963028536484*^-7, 
            -1.10308871975636*^-7, 3.109375691580504*^-9}, 
           {-0.02059882830471778, 0.2999868284345344, 0.00003089963017686534, \

            -0.0001499710129035118, 7.391732362642512*^-8, \
-1.071809864811129*^-7, 
            2.056959960532262*^-9}, {0.07437607712204962, 0.2999612878079299, \

            -0.0001115897022763641, -0.0001501074630631385, \
-2.296620186836703*^-7, 
            -1.774557747218172*^-7, -1.356351577917269*^-8}}][t]/4}]}}, Axes \
-> True, 
  AspectRatio -> Automatic, PlotRange -> {{-3, 8}, {-3.5, 3.5}}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[picture[0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63636 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.272727 0.0909091 0.318182 0.0909091 [
[.09091 .30568 -6 -9 ]
[.09091 .30568 6 0 ]
[.45455 .30568 -3 -9 ]
[.45455 .30568 3 0 ]
[.63636 .30568 -3 -9 ]
[.63636 .30568 3 0 ]
[.81818 .30568 -3 -9 ]
[.81818 .30568 3 0 ]
[1 .30568 -3 -9 ]
[1 .30568 3 0 ]
[.26023 .04545 -12 -4.5 ]
[.26023 .04545 0 4.5 ]
[.26023 .13636 -12 -4.5 ]
[.26023 .13636 0 4.5 ]
[.26023 .22727 -12 -4.5 ]
[.26023 .22727 0 4.5 ]
[.26023 .40909 -6 -4.5 ]
[.26023 .40909 0 4.5 ]
[.26023 .5 -6 -4.5 ]
[.26023 .5 0 4.5 ]
[.26023 .59091 -6 -4.5 ]
[.26023 .59091 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .63636 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.09091 .31818 m
.09091 .32443 L
s
[(-2)] .09091 .30568 0 1 Mshowa
.45455 .31818 m
.45455 .32443 L
s
[(2)] .45455 .30568 0 1 Mshowa
.63636 .31818 m
.63636 .32443 L
s
[(4)] .63636 .30568 0 1 Mshowa
.81818 .31818 m
.81818 .32443 L
s
[(6)] .81818 .30568 0 1 Mshowa
1 .31818 m
1 .32443 L
s
[(8)] 1 .30568 0 1 Mshowa
.125 Mabswid
.13636 .31818 m
.13636 .32193 L
s
.18182 .31818 m
.18182 .32193 L
s
.22727 .31818 m
.22727 .32193 L
s
.31818 .31818 m
.31818 .32193 L
s
.36364 .31818 m
.36364 .32193 L
s
.40909 .31818 m
.40909 .32193 L
s
.5 .31818 m
.5 .32193 L
s
.54545 .31818 m
.54545 .32193 L
s
.59091 .31818 m
.59091 .32193 L
s
.68182 .31818 m
.68182 .32193 L
s
.72727 .31818 m
.72727 .32193 L
s
.77273 .31818 m
.77273 .32193 L
s
.86364 .31818 m
.86364 .32193 L
s
.90909 .31818 m
.90909 .32193 L
s
.95455 .31818 m
.95455 .32193 L
s
.04545 .31818 m
.04545 .32193 L
s
.25 Mabswid
0 .31818 m
1 .31818 L
s
.27273 .04545 m
.27898 .04545 L
s
[(-3)] .26023 .04545 1 0 Mshowa
.27273 .13636 m
.27898 .13636 L
s
[(-2)] .26023 .13636 1 0 Mshowa
.27273 .22727 m
.27898 .22727 L
s
[(-1)] .26023 .22727 1 0 Mshowa
.27273 .40909 m
.27898 .40909 L
s
[(1)] .26023 .40909 1 0 Mshowa
.27273 .5 m
.27898 .5 L
s
[(2)] .26023 .5 1 0 Mshowa
.27273 .59091 m
.27898 .59091 L
s
[(3)] .26023 .59091 1 0 Mshowa
.125 Mabswid
.27273 .06364 m
.27648 .06364 L
s
.27273 .08182 m
.27648 .08182 L
s
.27273 .1 m
.27648 .1 L
s
.27273 .11818 m
.27648 .11818 L
s
.27273 .15455 m
.27648 .15455 L
s
.27273 .17273 m
.27648 .17273 L
s
.27273 .19091 m
.27648 .19091 L
s
.27273 .20909 m
.27648 .20909 L
s
.27273 .24545 m
.27648 .24545 L
s
.27273 .26364 m
.27648 .26364 L
s
.27273 .28182 m
.27648 .28182 L
s
.27273 .3 m
.27648 .3 L
s
.27273 .33636 m
.27648 .33636 L
s
.27273 .35455 m
.27648 .35455 L
s
.27273 .37273 m
.27648 .37273 L
s
.27273 .39091 m
.27648 .39091 L
s
.27273 .42727 m
.27648 .42727 L
s
.27273 .44545 m
.27648 .44545 L
s
.27273 .46364 m
.27648 .46364 L
s
.27273 .48182 m
.27648 .48182 L
s
.27273 .51818 m
.27648 .51818 L
s
.27273 .53636 m
.27648 .53636 L
s
.27273 .55455 m
.27648 .55455 L
s
.27273 .57273 m
.27648 .57273 L
s
.27273 .02727 m
.27648 .02727 L
s
.27273 .00909 m
.27648 .00909 L
s
.27273 .60909 m
.27648 .60909 L
s
.27273 .62727 m
.27648 .62727 L
s
.25 Mabswid
.27273 0 m
.27273 .63636 L
s
0 0 m
1 0 L
1 .63636 L
0 .63636 L
closepath
clip
newpath
.5 Mabswid
.95455 .31818 m
.95454 .31949 L
.95453 .32068 L
.95451 .32205 L
.95448 .32335 L
.95441 .32565 L
.9543 .32816 L
.95415 .33091 L
.95395 .33384 L
.95348 .33908 L
.95285 .34448 L
.95213 .34954 L
.95003 .36103 L
.94721 .37271 L
.94403 .38335 L
.93474 .40708 L
.92425 .42739 L
.91018 .44912 L
.8928 .47087 L
.87442 .48995 L
.82921 .52618 L
.80284 .54251 L
.77106 .55879 L
.73796 .5725 L
.69777 .58542 L
.67786 .59048 L
.65547 .59518 L
.6333 .59887 L
.61216 .60152 L
.60062 .60261 L
.58807 .60353 L
.58283 .60383 L
.57713 .6041 L
.57383 .60423 L
.57079 .60433 L
.56765 .60442 L
.56478 .60449 L
.56164 .60454 L
.55826 .60458 L
.55511 .6046 L
.55212 .6046 L
.54861 .60458 L
.54535 .60454 L
.54364 .60451 L
.54176 .60448 L
.53793 .60438 L
.53068 .60414 L
.52279 .60376 L
.51525 .60329 L
.50827 .60277 L
Mistroke
.49448 .60148 L
.47945 .59968 L
.45155 .59519 L
.41683 .58746 L
.38396 .57775 L
.34905 .5646 L
.31587 .54892 L
.27857 .52673 L
.23913 .49605 L
.20566 .46078 L
.18861 .43708 L
.17496 .41286 L
.16454 .38807 L
.15989 .37323 L
.15652 .35906 L
.15437 .34641 L
.15349 .33913 L
.1529 .33225 L
.15253 .325 L
.15242 .31835 L
.15254 .31104 L
.15295 .30337 L
.15366 .29562 L
.15419 .29127 L
.15476 .28729 L
.15757 .27241 L
.16101 .25922 L
.16547 .24572 L
.17706 .21934 L
.19259 .19324 L
.22461 .15425 L
.25692 .12537 L
.29552 .09888 L
.33159 .07961 L
.36283 .06621 L
.39615 .05474 L
.42783 .0462 L
.46007 .03966 L
.47397 .03747 L
.48864 .03555 L
.50121 .03423 L
.51437 .03315 L
.52165 .03269 L
.5282 .03235 L
.53471 .0321 L
.53761 .03201 L
.54079 .03193 L
.54421 .03186 L
.54607 .03183 L
.54781 .03181 L
Mistroke
.5509 .03179 L
.5542 .03179 L
.55604 .03179 L
.55805 .0318 L
.55993 .03182 L
.56167 .03185 L
.56494 .0319 L
.56841 .03198 L
.57542 .03222 L
.5829 .03256 L
.59621 .03342 L
.60884 .03453 L
.62019 .03578 L
.64246 .03892 L
.66234 .04254 L
.70448 .05286 L
.7421 .06544 L
.77324 .07861 L
.80464 .09491 L
.8307 .11123 L
.8748 .1468 L
.89396 .16684 L
.90944 .18625 L
.92219 .2055 L
.93327 .22616 L
.94232 .24806 L
.94842 .26836 L
.95074 .2789 L
.95179 .2847 L
.95262 .29019 L
.95326 .29532 L
.9538 .30087 L
.954 .30333 L
.95417 .30593 L
.95429 .30817 L
.9544 .31058 L
.95443 .31164 L
.95446 .31264 L
.95449 .31361 L
.9545 .31451 L
.95452 .31536 L
.95453 .31627 L
.95453 .31727 L
.95454 .31818 L
Mfstroke
.04545 .31818 m
.04546 .31775 L
.04546 .31735 L
.04547 .31689 L
.04548 .31646 L
.0455 .31569 L
.04554 .31486 L
.04559 .31394 L
.04565 .31296 L
.04581 .31122 L
.04602 .30942 L
.04626 .30773 L
.04696 .3039 L
.0479 .30001 L
.04896 .29646 L
.05206 .28855 L
.05555 .28178 L
.06024 .27454 L
.06604 .26728 L
.07216 .26092 L
.08723 .24885 L
.09602 .24341 L
.10662 .23798 L
.11765 .23341 L
.13105 .2291 L
.13768 .22742 L
.14514 .22585 L
.15254 .22462 L
.15958 .22374 L
.16343 .22337 L
.16761 .22307 L
.16936 .22297 L
.17126 .22288 L
.17236 .22283 L
.17337 .2228 L
.17442 .22277 L
.17538 .22275 L
.17642 .22273 L
.17755 .22272 L
.1786 .22271 L
.1796 .22271 L
.18077 .22272 L
.18185 .22273 L
.18242 .22274 L
.18305 .22275 L
.18433 .22278 L
.18674 .22286 L
.18937 .22299 L
.19189 .22314 L
.19421 .22332 L
Mistroke
.19881 .22375 L
.20382 .22435 L
.21312 .22584 L
.22469 .22842 L
.23565 .23166 L
.24729 .23604 L
.25835 .24127 L
.27078 .24867 L
.28393 .25889 L
.29508 .27065 L
.30077 .27855 L
.30532 .28662 L
.30879 .29488 L
.31034 .29983 L
.31146 .30455 L
.31218 .30877 L
.31247 .3112 L
.31267 .31349 L
.31279 .31591 L
.31283 .31813 L
.31279 .32056 L
.31265 .32312 L
.31242 .3257 L
.31224 .32715 L
.31205 .32848 L
.31111 .33344 L
.30997 .33783 L
.30848 .34233 L
.30462 .35113 L
.29944 .35983 L
.28877 .37282 L
.278 .38245 L
.26513 .39128 L
.25311 .39771 L
.24269 .40217 L
.23159 .406 L
.22103 .40884 L
.21028 .41102 L
.20565 .41175 L
.20076 .41239 L
.19657 .41283 L
.19218 .41319 L
.18975 .41335 L
.18757 .41346 L
.1854 .41354 L
.18443 .41357 L
.18337 .4136 L
.18223 .41362 L
.18161 .41363 L
.18103 .41364 L
Mistroke
.18 .41365 L
.1789 .41365 L
.17829 .41365 L
.17762 .41364 L
.17699 .41363 L
.17641 .41363 L
.17532 .41361 L
.17417 .41358 L
.17183 .4135 L
.16934 .41339 L
.1649 .4131 L
.16069 .41273 L
.15691 .41232 L
.14948 .41127 L
.14286 .41006 L
.12881 .40662 L
.11627 .40243 L
.10589 .39804 L
.09542 .39261 L
.08674 .38717 L
.07204 .37531 L
.06565 .36863 L
.06049 .36216 L
.05624 .35574 L
.05255 .34885 L
.04953 .34156 L
.0475 .33479 L
.04672 .33128 L
.04637 .32934 L
.0461 .32751 L
.04588 .3258 L
.0457 .32395 L
.04564 .32313 L
.04558 .32227 L
.04554 .32152 L
.0455 .32071 L
.04549 .32036 L
.04548 .32003 L
.04547 .31971 L
.04547 .31941 L
.04546 .31912 L
.04546 .31882 L
.04546 .31848 L
.04546 .31818 L
Mfstroke
1 0 0 r
.02 w
.95455 .31818 Mdot
.06 w
.04545 .31818 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 183.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000]a000`40O003h00Oogoo8Goo001=Ool0
0`00Oomoo`3@Ool004eoo`03001oogoo0=1oo`00CGoo00<007ooOol0d7oo001=Ool2003AOol004eo
o`03001oogoo0=1oo`00CGoo00<007ooOol0d7oo001=Ool00`00Oomoo`3@Ool004eoo`03001oogoo
0=1oo`00CGoo0P00dGoo001=Ool00`00Oomoo`10OolG001iOol004eoo`03001oogoo03Qoo`P001Mo
o``006eoo`00AGoo0P001Woo00<007ooOol0<7oo2000:goo1P00Igoo0017Ool00`00Oomoo`03Ool0
0`00Oomoo`0/Ool4000iOol5001ROol0041oo`<000=oo`03001oogoo00Aoo`<002Qoo`@0049oo`@0
05ioo`00Agoo00<007ooOol00goo00<007ooOol09Goo0`00BWoo1000FWoo0015Ool00`00Ool00005
Ool00`00Oomoo`0ROol3001AOol4001FOol004Ioo`03001oogoo00Aoo`03001oogoo01moo`<005Qo
o`8005Aoo`00CGoo00<007ooOol077oo0`00GGoo0`00DGoo001=Ool2000JOol3001SOol2001?Ool0
04eoo`03001oogoo01Ioo`<006Qoo`<004aoo`00CGoo00<007ooOol057oo0P00KWoo0`00BGoo001=
Ool00`00Oomoo`0BOol2001cOol30016Ool004eoo`03001oogoo011oo`8007Qoo`8004Aoo`00CGoo
0P003Woo0`00O7oo0P00@Woo001=Ool00`00Oomoo`0;Ool20021Ool20010Ool004eoo`03001oogoo
00Uoo`8008Eoo`8003ioo`00CGoo00<007ooOol01goo0P00RGoo0P00?7oo001=Ool00`00Oomoo`05
Ool2002=Ool00`00Oomoo`0iOol004eoo`8000Aoo`80091oo`8003Uoo`00CGoo00@007ooOomoo`80
09Aoo`03001oogoo03Ioo`00CGoo00@007ooOol009Moo`03001oogoo03Eoo`00CGoo00<007oo0000
VGoo0P00=Goo001=Ool2002LOol00`00Oomoo`0bOol004aoo`8009ioo`03001oogoo035oo`00Bgoo
00@007oo000009ioo`80035oo`00BGoo0P000Woo00<007ooOol0Wgoo00<007ooOol0;Woo0018Ool0
0`00Oomoo`02Ool00`00Oomoo`2POol00`00Oomoo`0]Ool004Eoo`<000Eoo`03001oogoo0:5oo`80
02eoo`00AGoo0P001Woo00<007ooOol0Xgoo00<007ooOol0:Woo0010Ool30002Ool20006Ool3002T
Ool00`00Oomoo`0YOol004=oo`800003Ool007oo00Eoo`03001oogoo0:Eoo`8002Uoo`00@Woo00H0
07ooOol007oo0005Ool00`00Oomoo`2WOol00`00Oomoo`0VOol0045oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo0:Qoo`03001oogoo02Eoo`00@7oo00<007ooOol02Woo00<007ooOol0ZGoo
00<007ooOol097oo000oOol00`00Oomoo`0;Ool2002[Ool00`00Oomoo`0SOol003ioo`03001oogoo
00aoo`03001oogoo0:]oo`03001oogoo029oo`00?Goo00<007ooOol03Goo00<007ooOol0[7oo00<0
07ooOol08Goo000mOol00`00Oomoo`0=Ool00`00Oomoo`2]Ool00`00Oomoo`0POol003aoo`03001o
ogoo00ioo`03001oogoo0:ioo`03001oogoo01moo`00>goo00<007ooOol03goo0P00/7oo00<007oo
Ool07Woo000jOol00`00Oomoo`0@Ool00`00Oomoo`2`Ool00`00Oomoo`0MOol003Uoo`03001oogoo
015oo`03001oogoo0;1oo`03001oogoo01eoo`00>7oo00<007ooOol04Woo00<007ooOol0/Goo00<0
07ooOol077oo000hOol00`00Oomoo`0BOol00`00Oomoo`2bOol00`00Oomoo`0KOol003Moo`03001o
ogoo01=oo`800;Aoo`03001oogoo01Yoo`00=Woo00<007ooOol057oo00<007ooOol0/goo00<007oo
Ool06Woo000eOol00`00Oomoo`0EOol00`00Oomoo`2dOol00`00Oomoo`0IOol003Eoo`03001oogoo
01Eoo`03001oogoo0;Aoo`03001oogoo01Uoo`00=7oo00<007ooOol05Woo00<007ooOol0]Goo00<0
07ooOol067oo000dOol00`00Oomoo`0FOol2002gOol00`00Oomoo`0GOol003=oo`03001oogoo01Mo
o`03001oogoo0;Ioo`03001oogoo01Moo`00<goo00<007ooOol05goo00<007ooOol0]goo00<007oo
Ool05Woo000bOol00`00Oomoo`0HOol00`00Oomoo`2hOol00`00Oomoo`0EOol002ioo`X000aoo`D0
00Aoo`03001oogoo0;Qoo`03001oogoo01Eoo`00:7oo1P000goo00<007ooOol017oo1P0027oo00<0
07ooOol017oo00<007ooOol0^Goo00<007ooOol057oo000SOol50009Ool00`00Oomoo`0:Ool50003
Ool00`00Oomoo`04Ool3002iOol00`00Oomoo`0DOol0025oo`8000eoo`03001oogoo00ioo`<0009o
o`03001oogoo00Aoo`03001oogoo0;Yoo`03001oogoo01=oo`007goo0P003goo00<007ooOol04Goo
0`001Woo00<007ooOol0^Woo00<007ooOol04goo000MOol2000@Ool00`00Oomoo`0COol40004Ool0
0`00Oomoo`2jOol00`00Oomoo`0COol001]oo`80019oo`03001oogoo01Moo`05001oogooOol0002m
Ool00`00Oomoo`0BOol001Uoo`8001=oo`03001oogoo01Uoo`800003Ool000000;aoo`03001oogoo
019oo`0067oo00<007ooOol04goo00<007ooOol06goo0P00_Goo00<007ooOol04Woo000FOol2000F
Ool00`00Oomoo`0LOol00`00Oomoo`2lOol00`00Oomoo`0AOol001Eoo`03001oogoo01Eoo`03001o
ogoo01eoo`<00;aoo`03001oogoo015oo`0057oo00<007ooOol05Woo00<007ooOol07Goo00@007oo
Ool00;]oo`03001oogoo015oo`004goo00<007ooOol05goo00<007ooOol07Goo0P000Woo00<007oo
Ool0^Goo00<007ooOol047oo000BOol00`00Oomoo`0GOol00`00Oomoo`0NOol00`00Oomoo`02Ool0
0`00Oomoo`2hOol00`00Oomoo`0@Ool0019oo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo
00=oo`03001oogoo0;Moo`03001oogoo011oo`004Goo00<007ooOol067oo00<007ooOol07Woo00<0
07ooOol017oo00<007ooOol0]goo00<007ooOol03goo000@Ool00`00Oomoo`07Ool3000?Ool00`00
Oomoo`0NOol00`00Oomoo`05Ool00`00Oomoo`0WOol3000bOol3000_Ool2000VOol00`00Oomoo`0:
Ool00`00Oomoo`02Ool000moo`03001oogoo00Qoo`03001oogoo00ioo`03001oogoo01moo`8000Mo
o`03001oogoo02Ioo`03001oogoo03=oo`03001oogoo02ioo`03001oo`0002Eoo`03001oogoo00Uo
o`03001oo`0000=oo`003goo00<007ooOol00goo0`000goo00<007ooOol03Goo00<007ooOol07goo
00<007ooOol01Woo00<007ooOol09goo00<007ooOol0<7oo1000;goo00<007oo00009Goo00<007oo
Ool02Goo00<007oo00000goo000:Ool5O00<Ool00`00Oomoo`0=Ool00`00Oomoo`0OOol00`00Oomo
o`06Ool00`00Oomoo`0WOol00`00Oomoo`0`Ool00`00Ool0000`Ool2000VOol00`00Oomoo`0:Ool0
0`00Oomoo`02Ool000Qoo`Ul00Uoo`03001oo`0000ioo`03001oogoo01moo`03001oogoo00Moo`03
001oogoo02Eoo`03001oo`00039oo`80031oo`03001oogoo02Eoo`03001oogoo00Uoo`03001oo`00
00=oo`001goo2g`02Goo00<007ooOol03Goo00<007ooOol07goo00<007ooOol01goo00<007ooOol0
9Woo00<007ooOol0<Woo00<007ooOol0;goo0P009Goo00<007ooOol02Woo00<007ooOol00Woo0006
Ool=O00HOol00`00Oomoo`0OOol20009Ool00`00Oomoo`2cOol00`00Oomoo`0?Ool000Eoo`ml01Mo
o`03001oogoo01moo`03001oogoo00Qoo`03001oogoo0;=oo`03001oogoo00moo`001Goo3g`05goo
00<007ooOol07goo00<007ooOol027oo00<007ooOol0/goo00<007ooOol03goo0004OolAO00FOol0
0`00Oomoo`0OOol00`00Oomoo`08Ool00`00Oomoo`2dOol00`00Oomoo`0>Ool000Aooa5l01Ioo`03
001oogoo01moo`03001oogoo00Qoo`03001oogoo0;9oo`=l011oo`0010004G`0m`001G`030000goo
0004OolAO004Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Ool0000<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool5O00;Ool00`00Oomoo`01Ool000Aooa5l00Aoo`03001oogoo00moo`03001oogoo
01moo`03001oogoo00Qoo`03001oogoo02Ioo`03001oogoo031oo`03001oogoo035oo`03001oogoo
025oo`El00]oo`03001oogoo005oo`001Goo3g`05goo00<007ooOol07goo00<007ooOol027oo00<0
07ooOol0/Woo0g`047oo0005Ool?O00GOol00`00Oomoo`0OOol00`00Oomoo`08Ool00`00Oomoo`2c
Ool00`00Oomoo`0?Ool000Ioo`el01Qoo`03001oogoo01moo`03001oogoo00Qoo`03001oogoo0;=o
o`03001oogoo00moo`001goo2g`06Goo00<007ooOol07goo0P002Goo00<007ooOol0/goo00<007oo
Ool03goo0008Ool9O00JOol00`00Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`2dOol00`00Oomo
o`0?Ool000Yoo`El01aoo`03001oogoo01moo`03001oogoo00Moo`03001oogoo0;Aoo`03001oogoo
00moo`003Woo00<007ooOol06Woo00<007ooOol07goo00<007ooOol01Woo00<007ooOol0]Goo00<0
07ooOol03goo000>Ool00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`06Ool00`00Oomoo`2e
Ool00`00Oomoo`0?Ool000moo`03001oogoo01Yoo`03001oogoo01ioo`8000Ioo`03001oogoo0;Eo
o`03001oogoo011oo`0047oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol01Goo00<007oo
Ool0]Goo00<007ooOol047oo000AOol00`00Oomoo`0HOol00`00Oomoo`0NOol00`00Oomoo`04Ool0
0`00Oomoo`2fOol00`00Oomoo`0@Ool0015oo`03001oogoo01Qoo`03001oogoo01ioo`03001oogoo
00=oo`03001oogoo0;Moo`03001oogoo011oo`004Woo00<007ooOol067oo00<007ooOol07Goo00<0
07ooOol00goo00<007ooOol0]goo00<007ooOol047oo000COol00`00Oomoo`0GOol00`00Oomoo`0M
Ool20003Ool00`00Oomoo`2hOol00`00Oomoo`0@Ool001Aoo`03001oogoo01Ioo`03001oogoo01eo
o`05001oogooOol0002kOol00`00Oomoo`0@Ool001Eoo`8001Ioo`03001oogoo01eoo`04001oo`00
002kOol00`00Oomoo`0AOol001Moo`03001oogoo01Aoo`03001oogoo01aoo`800;eoo`03001oogoo
015oo`0067oo00<007ooOol04goo00<007ooOol06goo0P00_Woo00<007ooOol04Goo000IOol2000C
Ool00`00Oomoo`0JOol01000Ool00000_7oo00<007ooOol04Woo000KOol2000BOol00`00Oomoo`0G
Ool20002Ool00`00Oomoo`2kOol00`00Oomoo`0BOol001eoo`<000moo`03001oogoo01Aoo`<000Ao
o`03001oogoo0;Yoo`03001oogoo01=oo`0087oo0`003Goo00<007ooOol047oo1P0017oo00<007oo
Ool0^Woo00<007ooOol04goo000SOol40009Ool00`00Oomoo`0=Ool30003Ool00`00Oomoo`04Ool0
0`00Oomoo`2iOol00`00Oomoo`0DOol002Moo`<000Moo`03001oogoo00Uoo`<000Ioo`03001oogoo
00Aoo`<00;Uoo`03001oogoo01Aoo`00:Woo4`002Goo00<007ooOol017oo00<007ooOol0^7oo00<0
07ooOol05Goo000bOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`2hOol00`00Oomoo`0E
Ool0039oo`03001oogoo011oo`8000Ioo`03001oogoo0;Moo`03001oogoo01Ioo`00<goo00<007oo
Ool05goo00<007ooOol0]goo00<007ooOol05Woo000cOol00`00Oomoo`0GOol2002gOol00`00Oomo
o`0GOol003Aoo`03001oogoo01Ioo`03001oogoo0;Eoo`03001oogoo01Qoo`00=7oo00<007ooOol0
5Woo00<007ooOol0]Goo00<007ooOol067oo000eOol00`00Oomoo`0EOol00`00Oomoo`2dOol00`00
Oomoo`0IOol003Ioo`03001oogoo01Aoo`03001oogoo0;Aoo`03001oogoo01Uoo`00=Woo00<007oo
Ool057oo00<007ooOol0/goo00<007ooOol06Woo000gOol00`00Oomoo`0COol2002dOol00`00Oomo
o`0JOol003Qoo`03001oogoo019oo`03001oogoo0;9oo`03001oogoo01]oo`00>Goo00<007ooOol0
4Goo00<007ooOol0/Goo00<007ooOol077oo000iOol00`00Oomoo`0AOol00`00Oomoo`2`Ool00`00
Oomoo`0MOol003Yoo`03001oogoo011oo`03001oogoo0:moo`03001oogoo01ioo`00>goo00<007oo
Ool03goo0P00/7oo00<007ooOol07Woo000lOol00`00Oomoo`0>Ool00`00Oomoo`2^Ool00`00Oomo
o`0OOol003eoo`03001oogoo00eoo`03001oogoo0:eoo`03001oogoo021oo`00?Woo00<007ooOol0
37oo00<007ooOol0[7oo00<007ooOol08Goo000nOol00`00Oomoo`0<Ool00`00Oomoo`2[Ool00`00
Oomoo`0ROol003moo`03001oogoo00]oo`800:]oo`03001oogoo02=oo`00@7oo00<007ooOol02Woo
00<007ooOol0ZGoo00<007ooOol097oo0011Ool00`00Oomoo`09Ool00`00Oomoo`2XOol00`00Oomo
o`0UOol0049oo`03001oogoo00<000Eoo`03001oogoo0:Moo`03001oogoo02Ioo`00@goo00<007oo
00001goo00<007ooOol0YGoo0P00:Goo0014Ool30006Ool3002TOol00`00Oomoo`0YOol004Ioo`03
001oogoo00Aoo`03001oogoo0:=oo`03001oogoo02Yoo`00AGoo00<007oo00001Goo00<007ooOol0
XGoo0P00;Goo0016Ool01000Ool000000goo00<007ooOol0X7oo00<007ooOol0;Goo001:Ool01000
Oomoo`00XGoo00<007ooOol0;Woo001;Ool01000Ool00000WWoo0P00<Goo001<Ool2002NOol00`00
Oomoo`0aOol004eoo`8009aoo`03001oogoo039oo`00CGoo00<007oo0000VGoo0P00=Goo001=Ool0
0`00Oomoo`02002FOol00`00Oomoo`0eOol004eoo`8000=oo`8009=oo`03001oogoo03Ioo`00CGoo
00<007ooOol017oo00<007ooOol0SWoo0P00>Goo001=Ool00`00Oomoo`05Ool2002=Ool00`00Oomo
o`0iOol004eoo`03001oogoo00Moo`8008Uoo`8003aoo`00CGoo00<007ooOol02Goo0P00QGoo0P00
?Woo001=Ool00`00Oomoo`0;Ool20021Ool20010Ool004eoo`8000ioo`<007aoo`80049oo`00CGoo
00<007ooOol047oo0P00Mgoo0`00A7oo001=Ool00`00Oomoo`0BOol3001bOol20017Ool004eoo`03
001oogoo01Eoo`8006ioo`8004Uoo`00CGoo00<007ooOol05goo0`00JGoo0P00Bgoo001=Ool2000K
Ool2001TOol3001=Ool004eoo`03001oogoo01aoo`<005eoo`@0051oo`00CGoo00<007ooOol07goo
0`00EWoo1000E7oo0015Ool20006Ool00`00Oomoo`0ROol3001@Ool3001HOol004Moo`03001oogoo
00=oo`03001oogoo02Eoo`@004Uoo`<005]oo`00AWoo00<007ooOol017oo0`00:Goo1@00@7oo1000
GWoo0017Ool00`00Oomoo`03Ool00`00Oomoo`0^Ool7000bOol7001ROol004Eoo`03001oo`0000Eo
o`03001oogoo03Eoo`H002Ioo`H006Uoo`00AWoo00<007ooOol017oo00<007ooOol0>goo2`003goo
3000Kgoo001=Ool00`00Oomoo`16Ool?001kOol004eoo`800=5oo`00CGoo00<007ooOol0d7oo001=
Ool00`00Oomoo`3@Ool004eoo`03001oogoo0=1oo`00CGoo00<007ooOol0d7oo001=Ool2003AOol0
04eoo`03001oogoo0=1oo`00CGoo00<007ooOol0d7oo001=Ool00`00Oomoo`3@Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {182.25, 0}} -> {-3.00005, -3.52955, 
  0.0387328, 0.0387328}}],

Cell[OutputFormData["\<\
Graphics[{{{{Line[{{7.499999999999634, 4.851755903574053*^-7}, 
        {7.499953837016894, 0.01437385509651273}, {7.49983228572254, \
0.0274508929980874}, 
        {7.499597472503522, 0.04254552418152349}, {7.499282376475584, \
0.05681399354436718}, 
        {7.498498285900103, 0.08219034366466576}, {7.497323056541762, \
0.1097319075182296}, 
        {7.495638377890331, 0.1400570810745835}, {7.49340533135513, \
0.1721972832552636}, 
        {7.488245373099996, 0.2298325628766628}, {7.481364786923887, \
0.2892732996574523}, 
        {7.473484403444842, 0.3449029129520086}, {7.45035314558944, \
0.471326644166371}, 
        {7.41931130098721, 0.5998100508654406}, {7.384292748310524, \
0.716830858875329}, 
        {7.282120970397343, 0.977870772666138}, {7.166711037961146, \
1.201301860358714}, 
        {7.011990653029168, 1.4403326560594}, {6.820802191583472, \
1.679610928487543}, 
        {6.618580011026407, 1.889479249727068}, {6.121306295273011, \
2.287935560759533}, 
        {5.83126876797732, 2.467596404008049}, {5.481648119838996, \
2.646673074794757}, 
        {5.11757759899063, 2.797508610093881}, {4.675417706525257, \
2.939651093900344}, 
        {4.45651074803813, 2.995244373485142}, {4.210220982923166, \
3.047008565243496}, 
        {3.966281673724115, 3.08756647753876}, {3.733756614820659, \
3.116685172866112}, 
        {3.606810756705823, 3.128751142426373}, {3.468811166821998, \
3.138845545275991}, 
        {3.411162728004399, 3.142137970891119}, {3.348387209272206, \
3.145106452536196}, 
        {3.312150399166657, 3.146527965975166}, {3.278734425205602, \
3.147649674665325}, 
        {3.244179419504797, 3.148618927022819}, {3.212612128467084, \
3.149335081132059}, 
        {3.178003028722562, 3.14993468017631}, {3.140815156484458, \
3.150362785921385}, 
        {3.106160339540671, 3.150560209814307}, {3.073267658230897, \
3.150567767047669}, 
        {3.03467056687865, 3.150353300830905}, {2.998874765146998, \
3.149938814541429}, 
        {2.980084393922566, 3.149638155976072}, {2.959351192826701, \
3.149239990663103}, 
        {2.917240787795786, 3.148216652604496}, {2.837478176568954, \
3.145489420322253}, 
        {2.750696172175182, 3.141346968125188}, {2.667726768558523, \
3.136236512611692}, 
        {2.591013330553048, 3.130505934401299}, {2.439247126526639, \
3.116301355386443}, 
        {2.273974195357454, 3.096447559660075}, {1.966995169107228, \
3.04712088575351}, 
        {1.585168016534086, 2.962072954575932}, {1.223508377551273, \
2.855288963647616}, 
        {0.8395032071404999, 2.710545815689612}, {0.4745345127177492, \
2.538104477284848}, 
        {0.06427001274164778, 2.293983461157724}, {-0.3696092679712778, \
1.956544372250618}, 
        {-0.7377848337660162, 1.568559545227503}, {-0.9253011906558825, \
1.30792212138969}, 
        {-1.075406134856366, 1.04147601656724}, {-1.190052758641639, \
0.7688145776008852}, 
        {-1.24116810726267, 0.6055411552779713}, {-1.278246858872396, \
0.4497049129898332}, 
        {-1.301936460366368, 0.3105357477609931}, {-1.311606145516299, \
0.230390051960728}, 
        {-1.318088777725509, 0.1547905383212595}, {-1.322164963170612, \
0.07500408084820846}, 
        {-1.323413317140208, 0.001800958043033311}, 
        {-1.322040374268506, -0.0785689619608223}, 
        {-1.317510445542904, -0.1628870046285334}, 
        {-1.309698502236655, -0.2481893872024674}, 
        {-1.303891391143673, -0.2960156084573295}, 
        {-1.297663469097243, -0.3398548469800084}, 
        {-1.266691083881809, -0.5035367343361086}, 
        {-1.228916600870275, -0.6485330987382395}, 
        {-1.179883495944872, -0.7970330640646539}, {-1.052354925438976, \
-1.087246401021494}, 
        {-0.8814962720773602, -1.374319399618886}, {-0.5292714609493165, \
-1.80320672634473}, 
        {-0.1738528946586313, -2.120954806481823}, {0.2507744124252032, \
-2.412308177920581}, 
        {0.6474908830823448, -2.624314965101141}, {0.9911208752833196, \
-2.771678445705797}, 
        {1.357680670447381, -2.897874477329192}, {1.706154121298184, \
-2.991785844825327}, 
        {2.060801710849796, -3.063743409938691}, {2.213644240135803, \
-3.087840627106752}, 
        {2.375018157129324, -3.10892465836645}, {2.513260882969868, \
-3.123494087971229}, 
        {2.658073571080876, -3.135351712902976}, {2.738161871704119, \
-3.140428283248247}, 
        {2.810166818248407, -3.144097421765434}, {2.881766581422741, \
-3.146908738459554}, 
        {2.913712865317948, -3.147894349582908}, {2.948701423275986, \
-3.148783814076157}, 
        {2.98628471996469, -3.14951815510876}, {3.006757717599043, \
-3.149821901456099}, 
        {3.025868151703243, -3.150044179319392}, {3.059884335508619, \
-3.150293527719962}, 
        {3.096254740769635, -3.150352919897223}, {3.11649179851648, \
-3.150293235428256}, 
        {3.138496141526158, -3.150153079579025}, {3.159209018761502, \
-3.149949501919673}, 
        {3.178367647782805, -3.149699347756881}, {3.214378472975043, \
-3.149068292117893}, 
        {3.252518353477864, -3.148170811790083}, {3.329645932599298, \
-3.145634604265365}, 
        {3.411943467134618, -3.141861443485153}, {3.558259582434605, \
-3.132420542588144}, 
        {3.697244441560142, -3.120187555683842}, {3.822112232364179, \
-3.106453099027079}, 
        {4.067032855982986, -3.071827501029622}, {4.285728545888918, \
-3.03206208896898}, 
        {4.749229887352177, -2.918515117971231}, {5.163097779724565, \
-2.780153101397275}, 
        {5.505594256199015, -2.635270035401072}, {5.851029079438955, \
-2.456041044639317}, 
        {6.137726347593511, -2.276484393986817}, {6.622753009198827, \
-1.885188469364049}, 
        {6.833527549649639, -1.6647827424568}, {7.003856104247896, \
-1.451247386914887}, 
        {7.144036033187314, -1.239486247458402}, {7.265931252245051, \
-1.012214659760586}, 
        {7.365574841287628, -0.7713682519243122}, {7.432597162837131, \
-0.5480821848378853}, 
        {7.458183649847765, -0.4321142210525238}, {7.469641803975742, \
-0.3682463149871797}, 
        {7.478767401808912, -0.3078978838551931}, {7.485807083221134, \
-0.2515328667507508}, 
        {7.491829828317371, -0.1904081275671284}, {7.493958456747428, \
-0.1634030134050086}, 
        {7.495856974227397, -0.134818879852544}, {7.497204758416231, \
-0.110107232957955}, 
        {7.498349362371158, -0.08356858691117864}, 
        {7.498750606128385, -0.07198799242975553}, 
        {7.499076187845761, -0.06099903188436451}, {7.499341572829065, \
-0.0503003594048774}, 
        {7.49954207447535, -0.04038553376078718}, {7.499691294995001, \
-0.0310223261711167}, 
        {7.499807281396927, -0.02105871555081055}, {7.499884323395219, \
-0.0100048133090618}, 
        {7.499907228444051, -4.848322561496615*^-7}}]}}, 
    {{Line[{{-2.499999999999877, -1.617251967858017*^-7}, 
        {-2.499984612338964, -0.004791285032170911}, 
        {-2.499944095240846, -0.009150297666029134}, 
        {-2.49986582416784, -0.01418184139384116}, 
        {-2.499760792158528, -0.01893799784812239}, 
        {-2.499499428633367, -0.02739678122155525}, 
        {-2.49910768551392, -0.03657730250607654}, 
        {-2.498546125963443, -0.04668569369152785}, 
        {-2.497801777118377, -0.05739909441842121}, 
        {-2.496081791033331, -0.07661085429222094}, 
        {-2.493788262307962, -0.09642443321915081}, 
        {-2.491161467814947, -0.1149676376506695}, {-2.483451048529813, \
-0.1571088813887903}, 
        {-2.473103766995736, -0.1999366836218135}, {-2.461430916103508, \
-0.2389436196251097}, 
        {-2.427373656799114, -0.325956924222046}, {-2.388903679320382, \
-0.4004339534529048}, 
        {-2.337330217676389, -0.4801108853531336}, {-2.273600730527824, \
-0.5598703094958477}, 
        {-2.206193337008802, -0.6298264165756894}, {-2.04043543175767, \
-0.7626451869198447}, 
        {-1.94375625599244, -0.8225321346693498}, {-1.827216039946332, \
-0.8822243582649191}, 
        {-1.705859199663543, -0.9325028700312937}, {-1.558472568841752, \
-0.9798836979667814}, 
        {-1.485503582679377, -0.9984147911617142}, {-1.403406994307722, \
-1.015669521747832}, 
        {-1.322093891241371, -1.029188825846253}, {-1.244585538273553, \
-1.038895057622037}, 
        {-1.202270252235274, -1.042917047475457}, {-1.156270388940666, \
-1.04628184842533}, 
        {-1.137054242668133, -1.047379323630373}, {-1.116129069757402, \
-1.048368817512065}, 
        {-1.104050133055552, -1.048842655325055}, {-1.092911475068534, \
-1.049216558221775}, 
        {-1.081393139834932, -1.049539642340939}, {-1.070870709489028, \
-1.049778360377352}, 
        {-1.05933434290752, -1.049978226725436}, {-1.046938385494819, \
-1.050120928640461}, 
        {-1.03538677984689, -1.050186736604769}, {-1.024422552743632, \
-1.050189255682556}, 
        {-1.011556855626216, -1.050117766943635}, {-0.9996249217156661, \
-1.049979604847143}, 
        {-0.9933614646408553, -1.049879385325357}, {-0.9864503976089002, \
-1.049746663554367}, 
        {-0.9724135959319289, -1.049405550868165}, {-0.9458260588563183, \
-1.048496473440751}, 
        {-0.9168987240583941, -1.047115656041729}, {-0.8892422561861742, \
-1.045412170870564}, 
        {-0.8636711101843495, -1.043501978133766}, {-0.8130823755088798, \
-1.038767118462147}, 
        {-0.7579913984524847, -1.032149186553358}, {-0.655665056369076, \
-1.015706961917836}, 
        {-0.5283893388446955, -0.9873576515253107}, 
        {-0.4078361258504245, -0.9517629878825388}, 
        {-0.2798344023801666, -0.9035152718965376}, 
        {-0.1581781709059163, -0.8460348257616161}, 
        {-0.02142333758054926, -0.7646611537192415}, 
        {0.1232030893237592, -0.6521814574168728}, {0.2459282779220054, \
-0.5228531817425011}, 
        {0.3084337302186275, -0.4359740404632303}, {0.3584687116187887, \
-0.34715867218908}, 
        {0.3966842528805463, -0.2562715258669617}, {0.41372270242089, \
-0.2018470517593237}, 
        {0.426082286290799, -0.1499016376632777}, {0.4339788201221227, \
-0.103511915920331}, 
        {0.4372020485054333, -0.07679668398690936}, 
        {0.4393629259085029, -0.05159684610708651}, 
        {0.4407216543902042, -0.02500136028273614}, 
        {0.4411377723800696, -0.0006003193476777703}, 
        {0.4406801247561689, 0.02618965398694077}, {0.4391701485143014, \
0.05429566820951116}, 
        {0.4365661674122184, 0.08272979573415582}, {0.4346304637145578, \
0.09867186948577653}, 
        {0.4325544896990811, 0.1132849489933361}, {0.4222303612939363, \
0.1678455781120362}, 
        {0.4096388669567585, 0.2161776995794132}, {0.3932944986482909, \
0.2656776880215513}, 
        {0.3507849751463255, 0.3624154670071649}, {0.2938320906924534, \
0.4581064665396286}, 
        {0.1764238203164388, 0.6010689087815769}, {0.05795096488621044, \
0.7069849354939411}, 
        {-0.08359147080840108, 0.8041027259735271}, 
        {-0.2158302943607815, 0.8747716550337136}, {-0.3303736250944399, \
0.9238928152352656}, 
        {-0.4525602234824605, 0.965958159109731}, {-0.5687180404327282, \
0.9972619482751092}, 
        {-0.6869339036165986, 1.021247803312897}, {-0.7378814133786012, \
1.029280209035584}, 
        {-0.791672719043108, 1.036308219455483}, {-0.8377536276566228, \
1.041164695990409}, 
        {-0.8860245236936254, 1.045117237634325}, {-0.9127206239013732, \
1.046809427749415}, 
        {-0.936722272749469, 1.048032473921811}, {-0.9605888604742471, \
1.048969579486518}, 
        {-0.9712376217726493, 1.049298116527636}, {-0.9829004744253289, \
1.049594604692052}, 
        {-0.9954282399882304, 1.049839385036253}, {-1.002252572533014, \
1.049940633818699}, 
        {-1.008622717234414, 1.050014726439797}, {-1.019961445169539, \
1.05009784257332}, 
        {-1.032084913589878, 1.050117639965741}, {-1.038830599505493, \
1.050097745142752}, 
        {-1.046165380508719, 1.050051026526341}, {-1.0530696729205, \
1.049983167306557}, 
        {-1.059455882594268, 1.049899782585627}, {-1.071459490991681, \
1.049689430705964}, 
        {-1.084172784492621, 1.049390270596694}, {-1.109881977533099, \
1.048544868088455}, 
        {-1.137314489044872, 1.047287147828384}, {-1.186086527478201, \
1.044140180862714}, 
        {-1.23241481385338, 1.04006251856128}, {-1.274037410788059, \
1.035484366342359}, 
        {-1.355677618660995, 1.023942500343207}, {-1.428576181962972, \
1.01068736298966}, 
        {-1.583076629117392, 0.972838372657077}, {-1.721032593241521, \
0.9267177004657584}, 
        {-1.835198085399671, 0.8784233451336907}, {-1.950343026479652, \
0.8186803482131058}, 
        {-2.04590878253117, 0.7588281313289391}, {-2.207584336399609, \
0.628396156454683}, 
        {-2.277842516549879, 0.5549275808189334}, {-2.334618701415965, \
0.4837491289716291}, 
        {-2.381345344395771, 0.413162082486134}, {-2.421977084081683, \
0.3374048865868622}, 
        {-2.455191613762542, 0.2571227506414373}, {-2.477532387612377, \
0.1826940616126284}, 
        {-2.486061216615921, 0.1440380736841746}, {-2.489880601325247, \
0.1227487716623932}, 
        {-2.492922467269637, 0.102632627951731}, {-2.495269027740377, \
0.08384428891691696}, 
        {-2.497276609439123, 0.06346937585570948}, {-2.497986152249142, \
0.05446767113500287}, 
        {-2.498618991409132, 0.04493962661751468}, {-2.49906825280541, \
0.03670241098598501}, 
        {-2.499449787457052, 0.02785619563705954}, {-2.499583535376128, \
0.02399599747658518}, 
        {-2.499692062615253, 0.0203330106281215}, {-2.499780524276355, \
0.01676678646829246}, 
        {-2.499847358158449, 0.01346184458692906}, {-2.499897098331667, \
0.01034077539037223}, 
        {-2.499935760465642, 0.007019571850270184}, 
        {-2.499961441131739, 0.003334937769687267}, 
        {-2.499969076148017, 1.616107520498871*^-7}}]}}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], Point[{7.5, 0.}]}, 
   {RGBColor[1, 0, 0], PointSize[0.06], Point[{-2.5, 0.}]}}, 
  {Axes -> True, AspectRatio -> Automatic, PlotRange -> {{-3, 8}, {-3.5, \
3.5}}}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The animation", "Subsection"],

Cell["film[n_] := Table[picture[t], {t,0,t0 - t0/n, t0/n}]", "Input"],

Cell["\<\
We generate an animation of 40 pictures. However, other numbers of picture \
(for instance 60) yield good results, too.\
\>", "Text"],

Cell["movie = Show[#]& /@ film[40]", "Input"],

Cell[CellGroupData[{

Cell["SetOptions[Display,ImageSize -> {288,190}]", "Input"],

Cell[OutputFormData["\<\
{CharacterEncoding -> {}, ImageOffset -> Automatic, ImageResolution -> \
Automatic, 
  ImageRotated -> False, ImageSize -> {288, 190}}\
\>", "\<\
{CharacterEncoding -> {}, ImageOffset -> Automatic, ImageResolution -> \
Automatic, 
 
  ImageRotated -> False, ImageSize -> {288, 190}}\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "The next line ",
  StyleBox["saves",
    FontWeight->"Bold"],
  " the pictures of the animation in files x1.gif, x2.gif, ... xn.gif. To use \
this line you have to delete the brackets ",
  StyleBox["(*",
    FontWeight->"Bold"],
  " and ",
  StyleBox["*)",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["Attention",
    FontWeight->"Bold"],
  ": Display will ",
  StyleBox["overwrite",
    FontWeight->"Bold"],
  " files with names ",
  StyleBox["x1.gif, x2.gif,...",
    FontWeight->"Bold"],
  " in the current directory."
}], "Text"],

Cell["\<\
(*
Do[
  With[{filename = \"x\"<>ToString[i]<>\".gif\"},
        Display[filename,movie[[i]],\"GIF\"]
      ],
  {i,1,Length[movie]}
  ]
*)\
\>", "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->"EditBar",
WindowSize->{772, 608},
WindowMargins->{{1, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 62, 0, 150, "Title"],
Cell[1796, 53, 56, 0, 64, "Subtitle"],
Cell[1855, 55, 132, 3, 71, "Subsubtitle"],
Cell[1990, 60, 73, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2088, 64, 78, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[2191, 68, 48, 0, 47, "Subsection"],
Cell[2242, 70, 68, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[2335, 78, 45, 0, 30, "Input"],
Cell[2383, 80, 90, 4, 27, "Output"]
}, Open  ]],
Cell[2488, 87, 40, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2553, 91, 47, 0, 30, "Input"],
Cell[2603, 93, 141, 4, 27, "Output"]
}, Open  ]],
Cell[2759, 100, 100, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[2884, 109, 42, 0, 30, "Input"],
Cell[2929, 111, 138, 5, 37, "Output"]
}, Open  ]],
Cell[3082, 119, 91, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[3198, 125, 54, 0, 30, "Input"],
Cell[3255, 127, 142, 4, 42, "Message"],
Cell[3400, 133, 681, 16, 107, "Output"]
}, Open  ]],
Cell[4096, 152, 113, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[4234, 159, 38, 0, 30, "Input"],
Cell[4275, 161, 730, 18, 107, "Output"]
}, Open  ]],
Cell[5020, 182, 442, 20, 33, "Text"],

Cell[CellGroupData[{
Cell[5487, 206, 48, 0, 30, "Input"],
Cell[5538, 208, 110, 4, 27, "Output"]
}, Open  ]],
Cell[5663, 215, 124, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[5812, 222, 107, 3, 48, "Input"],
Cell[5922, 227, 245, 6, 27, "Output"]
}, Open  ]],
Cell[6182, 236, 75, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[6282, 240, 45, 0, 30, "Input"],
Cell[6330, 242, 874, 21, 127, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7253, 269, 96, 2, 31, "Subsection"],
Cell[7352, 273, 152, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[7529, 279, 72, 0, 30, "Input"],
Cell[7604, 281, 104249, 2125, 67, "Output"]
}, Open  ]],
Cell[111868, 2409, 129, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[112022, 2416, 63, 0, 30, "Input"],
Cell[112088, 2418, 20786, 528, 186, 4749, 325, "GraphicsData", 
"PostScript", "Graphics"],
Cell[132877, 2948, 5539, 123, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138453, 3076, 63, 0, 30, "Input"],
Cell[138519, 3078, 142, 4, 42, "Message"],
Cell[138664, 3084, 20613, 530, 186, 4961, 332, "GraphicsData", 
"PostScript", "Graphics"],
Cell[159280, 3616, 7212, 160, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166529, 3781, 55, 0, 30, "Input"],
Cell[166587, 3783, 9744, 308, 186, 3180, 222, "GraphicsData", 
"PostScript", "Graphics"],
Cell[176334, 4093, 1402, 31, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177773, 4129, 34, 0, 30, "Input"],
Cell[177810, 4131, 26704, 734, 186, 7371, 491, "GraphicsData", 
"PostScript", "Graphics"],
Cell[204517, 4867, 12188, 268, 27, "Output"]
}, Open  ]],
Cell[216720, 5138, 183, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[216928, 5145, 71, 0, 30, "Input"],
Cell[217002, 5147, 52822, 1061, 67, "Output"]
}, Open  ]],
Cell[269839, 6211, 86, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[269950, 6217, 47, 0, 30, "Input"],
Cell[270000, 6219, 52022, 1057, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322059, 7281, 58, 0, 30, "Input"],
Cell[322120, 7283, 54745, 1010, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[376902, 8298, 59, 0, 30, "Input"],
Cell[376964, 8300, 142, 3, 42, "Message"],
Cell[377109, 8305, 53850, 1018, 87, "Output"]
}, Open  ]],
Cell[430974, 9326, 276, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[431275, 9339, 67, 0, 30, "Input"],
Cell[431345, 9341, 92, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[431474, 9350, 32, 0, 30, "Input"],
Cell[431509, 9352, 78, 4, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[431648, 9363, 57, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[431730, 9367, 52, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[431807, 9371, 171, 5, 84, "Input"],
Cell[431981, 9378, 49527, 922, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[481545, 10305, 171, 5, 84, "Input"],
Cell[481719, 10312, 140, 4, 42, "Message"],
Cell[481862, 10318, 48697, 912, 87, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[530608, 11236, 72, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[530705, 11240, 94, 2, 30, "Input"],
Cell[530802, 11244, 14957, 495, 186, 5436, 373, "GraphicsData", 
"PostScript", "Graphics"],
Cell[545762, 11741, 7262, 159, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553061, 11905, 94, 2, 30, "Input"],
Cell[553158, 11909, 146, 3, 42, "Message"],
Cell[553307, 11914, 15717, 512, 186, 5560, 382, "GraphicsData", 
"PostScript", "Graphics"],
Cell[569027, 12428, 7468, 159, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[576532, 12592, 51, 0, 30, "Input"],
Cell[576586, 12594, 146, 3, 42, "Message"],
Cell[576735, 12599, 18822, 670, 186, 7802, 529, "GraphicsData", 
"PostScript", "Graphics"],
Cell[595560, 13271, 14184, 303, 27, "Output"]
}, Open  ]],
Cell[609759, 13577, 42, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[609838, 13582, 72, 0, 31, "Subsection"],
Cell[609913, 13584, 60, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[609998, 13588, 250, 6, 102, "Input"],
Cell[610251, 13596, 115746, 2206, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[726034, 15807, 33, 0, 30, "Input"],
Cell[726070, 15809, 18890, 684, 192, 8047, 546, "GraphicsData", 
"PostScript", "Graphics"],
Cell[744963, 16495, 14021, 295, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[759033, 16796, 35, 0, 31, "Subsection"],
Cell[759071, 16798, 69, 0, 30, "Input"],
Cell[759143, 16800, 143, 3, 33, "Text"],
Cell[759289, 16805, 45, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[759359, 16809, 59, 0, 30, "Input"],
Cell[759421, 16811, 324, 9, 47, "Output"]
}, Open  ]],
Cell[759760, 16823, 553, 21, 52, "Text"],
Cell[760316, 16846, 164, 9, 156, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

